<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use DB;
use Carbon\Carbon;
use Mail;
use Log;
use Crypt;

class MailScheduler extends Command
{
    protected $signature = 'mailscheduler';

    protected $description = 'Checks for scheduled mail.';

    public function __construct()
    {
        parent::__construct();
    }

	public function handle()
	{
		$running_tasks = DB::table('mailing_activities')
			->where('mailing_process', 5)
			->get();

		if (count($running_tasks) < 1) {
			$future_send = DB::table('mailing_activities')
				->where('mailing_process', 4)
				->whereNull('deleted_at')
				->get();
			
			$app_timezone = DB::table('timezones')
				->where('id', env('APP_TIME_ZONE',58))
				->value('timezone');

			foreach ($future_send as $send) {
				$event_timezone = DB::table('events')
					->join('timezones','events.timezone_id','=','timezones.id')
					->where('events.id', $send->event_id)
					->value('timezones.timezone');

				$dateTime_now = Carbon::now()
					->setTimezone($event_timezone)
					->format('Y-m-d H:i:00');

				if ($dateTime_now == $send->scheduled_ts) {

					if($send->sidebar_included) 
						$email_template = 'template_720';
					else 
						$email_template = 'template_600';

					$event_colors = DB::table('events')
						->leftJoin('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
						->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
						->select('background_color', 'titles_color')
						->where('events.id', $send->event_id)
						->first();

					if($send->background_color == NULL) {
						if ($send->header_text == NULL) {
							$bg_color = '#8e8e8e';
						} else if ($event_colors) {
							$bg_color = $event_colors->background_color;
						} else {
							$bg_color = '#8e8e8e';
						}
					} else {
						$bg_color = $send->background_color;
					}

					if($send->titles_color == NULL) {
						if ($send->header_text == NULL) {
							$title_color = '#fff';
						} else if ($event_colors) {
							$title_color = $event_colors->titles_color;
						} else {
							$title_color = '#fff';
						}
					} else {
						$title_color = $send->titles_color;
					}

					$server_limit = env('APP_MAIL_LIMIT', 200);

					$event_info = DB::table('events')
						->where('id', $send->event_id)
						->get();

					$data['subject'] = $send->email_subject;
					$data['from_name'] = $send->email_from_name;
					$data['from_email'] = $send->email_from_email;
					$data['reply_to'] = $send->email_replyto_email;
					$data['title'] = $send->header_text;
					$data['register'] = $send->register_button;
					$data['confirm'] = $send->confirm_button;
					$data['banner'] = $send->header_img_url;
					$data['logo'] = $send->logo_url;
					$data['bgColor'] = $bg_color;
					$data['titleColor'] = $title_color;
					$data['unsub'] = $send->unsubscribe_text;
					$data['copyright'] = $send->copyright_statement;
					$data['calendar_icon'] = env('APP_URL') . '/assets/images/mail-icons/mail-calendar-icon.png';
					$data['location_icon'] = env('APP_URL') . '/assets/images/mail-icons/mail-location-icon.png';
					$data['mailing_activity_code'] = $send->mailing_activity_code;
					$data['url'] = env('APP_URL');
					$data['ics_included'] = $send->ics_included;
					
					$data['lang'] = DB::table('events')->where('event_code', $event_info[0]->event_code)->value('lang');

					if ($send->sidebar_included) {
						$mail_info = DB::table('events')
							->select(array('type_by_venue as venue',
								'venue_name as v_name',
								'venue_address as address',
								'venue_city as city',
								'venue_postal_code as postal',
								'countries.country_name as country',
								'start_ts as start',
								'end_ts as end'))
							->leftJoin('countries','countries.id','=','events.venue_country_id')
							->where('event_code', $event_info[0]->event_code)
							->get();
						$mail_info = json_decode(json_encode($mail_info[0]), true);
						if ($data['lang'] == 'hr') {
							$mail_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $mail_info['start'])->format('d.m.Y. H:m');
							$mail_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $mail_info['end'])->format('d.m.Y. H:m');
						} else {
							$mail_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $mail_info['start'])->format('d/m/Y h:i a');
							$mail_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $mail_info['end'])->format('d/m/Y h:i a');
						}
						$data['v_name'] = $mail_info['v_name'];
						$data['address'] = $mail_info['address'];
						$data['city'] = $mail_info['city'];
						$data['postal'] = $mail_info['postal'];
						$data['country'] = $mail_info['country'];
						$data['start'] = $mail_info['start'];
						$data['end'] = $mail_info['end'];
						$data['show_location'] = $mail_info['venue'] == 'online' ? false : true;
					}

					$contacts = DB::table('mailings')
						->where('mailing_activity_id', $send->id)
						->whereNull('sent_ts')
						->whereNull('deleted_at')
						->get();

					$bar = $this->output->createProgressBar(count($contacts));

					foreach ($contacts as $key=>$contact) {
						$bar->advance();

						$isStop = DB::table('mailing_activities')
							->where('id', $send->id)
							->pluck('mailing_process');

						if($isStop[0] == 6) {
							$timestamp = Carbon::now()
								->setTimezone($app_timezone)
								->format('Y-m-d H:i:s');

							DB::table('mailings')
							->where('mailing_activity_id', $send->id)
							->whereNull('sent_ts')
							->update([
								'deleted_at' => $timestamp
							]);
							
							break;
						}

						if($key == 0){
							DB::table('mailing_activities')
								->where('id', $send->id)
								->update(array('mailing_process' => 5));
						}

						$is_opt = DB::table('leads')
							->where('id', $contact->lead_id)
							->select('opt_in','opt_in_method')
							->get();

						if ($is_opt[0]->opt_in == 'Yes' && (strpos($is_opt[0]->opt_in_method, 'email') !== false)) {

							$dateTime_now = Carbon::now()
								->setTimezone($app_timezone)
								->format('Y-m-d H:i:s');

							$lead = DB::table('leads')
								->where('id', $contact->lead_id)
								->get();

							$registration_link = env('APP_URL') . '/registration/' . $event_info[0]->event_code  . '/' . $lead[0]->email;
							$confirmation_link = env('APP_URL') . '/confirmation/' . $event_info[0]->event_code . '/' . $lead[0]->lead_code;
                            $tracking_link = env('APP_URL') . '/mail-image/' . $send->mailing_activity_code . '/' . $lead[0]->lead_code;
                            $unsubscribe_link = env('APP_URL') . '/unsubscribe/' . $send->mailing_activity_code . '/' . Crypt::encrypt($lead[0]->lead_code);

							$data['lead_code_encrypted'] = Crypt::encrypt($lead[0]->lead_code);
							$data['registration_link'] = $registration_link;
							$data['confirmation_link'] = $confirmation_link;
							$data['tracking_img_url'] = $tracking_link;

                            if ($send->custom_html) {
                                $email_template = 'template_custom';
                                $body_wysiwyg = $send->body_html;
                            } else {
                                $body_wysiwyg = $send->body_wysiwyg;
                            }
                            
							$body_content = str_replace('{lead_title}', $lead[0]->title, $body_wysiwyg);
							$body_content = str_replace('{lead_first_name}', $lead[0]->first_name, $body_content);
							$body_content = str_replace('{lead_last_name}', $lead[0]->last_name, $body_content);
							$body_content = str_replace('{lead_email}', $lead[0]->email, $body_content);
							$body_content = str_replace('{registration_link}', $registration_link, $body_content);
							$body_content = str_replace('{confirmation_link}', $confirmation_link, $body_content);
                            $body_content = str_replace('{tracking_link}', $tracking_link, $body_content);
                            $body_content = str_replace('{unsubscribe_link}', $unsubscribe_link, $body_content);
							
							// Variacije pozdrava u pravom licu
							$body_content = $this->leadAlias($body_content, $lead[0]);
                            
                            // Lead barcode
							$leadRregistration = DB::table('leads')
								->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
								->where('leads.email', $lead[0]->email)
								->where('registrations.event_id', $send->event_id)
								->whereNull('registrations.deleted_at')
								->groupBy('leads.email')
								->first();
							if ($leadRregistration) $body_content = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_content);
                            
                            // Ics privitak
                            $data['ics'] = $this->IcsAttachment($send->mailing_activity_code);
                            
                            $data['body_content'] = $this->leadAlias($body_content, $lead[0]);
                            $data['html'] = $data['body_content'];

							Mail::queue('mail-templates.'.$email_template, $data, function ($message) use ($send,$lead,$data) {
                                if ($data['ics_included'] == 1) {
                                    $message->from($send->email_from_email, $send->email_from_name)
    									->to($lead[0]->email)
    									->replyTo($send->email_replyto_email)
    									->subject($send->email_subject)
                                        ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
                                } else {
                                    $message->from($send->email_from_email, $send->email_from_name)
    									->to($lead[0]->email)
    									->replyTo($send->email_replyto_email)
    									->subject($send->email_subject);
                                }
							});

							DB::table('mailings')
								->where('id', $contact->id)
								->whereNull('deleted_at')
								->update(array('sent_ts' => $dateTime_now));

							$already_registered_or_attended = DB::table('leads_on_events_insights')
								->where('lead_id', $contact->lead_id)
								->value("event_id_" . $event_info[0]->id);

							if($already_registered_or_attended != 'did not come' && $already_registered_or_attended != 'attended') {
								DB::table('leads_on_events_insights')
									->where('lead_id', $contact->lead_id)
									->update([
										"event_id_" . $event_info[0]->id => 'not responded'
									]);
							}
							sleep(3600 / $server_limit);
						} else {
							DB::table('mailings')
								->where('id', $contact->id)
								->whereNull('deleted_at')
								->update(array('sent_ts' => '1970-01-01 00:00:00'));
						}

						if($key == (count($contacts)-1)){
							DB::table('mailing_activities')
								->where('id', $send->id)
								->update(array('mailing_process' => 0));
						}
					}
					$bar->finish();
				}
			}
	
			if (!count($future_send)) $this->info('No scheduled mail.');

        } else {
			$this->info('Sending already in progress.');
		}
	}
        
    /**
     * Variacije pozdrava u pravom licu
     */
    private function leadAlias($body_wysiwyg, $lead) {
        if($lead->gender == 'Mr.') {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovani', $body_wysiwyg);
        } else if($lead->gender == 'Ms.') {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovana', $body_wysiwyg);
        } else {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovani', $body_wysiwyg);
        }
        
        $offset = 0;
        $occurrences = array();
        
        while(($position = strpos($body_wysiwyg, '{lead_alias', $offset)) !== FALSE) {
            $offset = $position + 1;
            $occurrences[] = $position;
        }
        
        $occurrences = array_reverse($occurrences);
        
        foreach($occurrences as $key => $occurrence) {
            $equal = substr($body_wysiwyg, ($occurrence + 11), 1);

            if($equal == '=') {
                $comma = strpos($body_wysiwyg, ',', $occurrence);
                $end = strpos($body_wysiwyg, '}', $occurrence);
                
                if($comma && $end) {
                    $male = substr($body_wysiwyg, $occurrence + 12, ($comma - ($occurrence + 12)));
                    $female = substr($body_wysiwyg, $comma + 1, ($end - $comma - 1));
                    
                    if($lead->gender == 'Mr.') {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $male, $occurrence, ($end - $occurrence + 1));
                    } else if($lead->gender == 'Ms.') {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $female, $occurrence, ($end - $occurrence + 1));
                    } else {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $male, $occurrence, ($end - $occurrence + 1));
                    }
                }
            }
        }
        
        return $body_wysiwyg;
    }
    
    /**
     * Generiranje ICS privitka
     */
    private function IcsAttachment($mailing_activity_code)
    {
        $event = DB::table('mailing_activities')
            ->leftjoin('events', 'mailing_activities.event_id', '=', 'events.id')
            ->where('mailing_activity_code', $mailing_activity_code)
            ->first();
        
        if ($event->ics_included == 1) {
            $attach = $event->name . ".ics";
            $ics[0] = "BEGIN:VCALENDAR";
            $ics[1] = "PRODID:-//Krikstudio//KrikEM//EN";
            $ics[2] = "VERSION:2.0";
            $ics[3] = "METHOD:REQUEST";
            $ics[4] = "BEGIN:VEVENT";
            if (date("I")) {
                $ics[5] = "DTSTART:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->start_ts)->format('Ymd\THis\Z'); 
                $ics[6] = "DTEND:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->end_ts)->format('Ymd\THis\Z');
            } else {
                $ics[5] = "DTSTART:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->start_ts)->subHour(1)->format('Ymd\THis\Z'); 
                $ics[6] = "DTEND:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->end_ts)->subHour(1)->format('Ymd\THis\Z');
            }
            $ics[7] = "DTSTAMP:" . gmdate('Ymd\THis\Z', time() + 3600 * (1 + date("I")));
            $ics[8] = "UID:" . date('YmdHis') . '-' . rand();
            $ics[9] = "ORGANIZER;CN=" . $event->email_name . ":" . $event->email_sender;
            $ics[10] = "DESCRIPTION:" . $event->description;
            if ($event->type_by_venue == 'physical') $ics[11] = "LOCATION:" . $event->venue_name . ", " . $event->venue_address . ', ' . $event->venue_city;
            $ics[12] = "SUMMARY:" . $event->name;
            $ics[13] = "END:VEVENT";
            $ics[14] = "END:VCALENDAR";
            $ics = implode("\r\n", $ics);
            file_put_contents(public_path() . '/ics/' . $attach, $ics);
            
            return $attach;
        } else {
            return false;
        }
    }
}
