<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use View;
use DB;
use Redirect;
use Illuminate\Support\Facades\Cache;

class AdminCategoriesController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
            'global/plugins/bower_components/x-editable/dist/bootstrap3-editable/css/bootstrap-editable.css'
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/x-editable/dist/bootstrap3-editable/js/bootstrap-editable.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Admin Categories');
    }
    
    /**
     * Admin kategorije
     */
    public function GetAdminCategories()
    {
        $lead_types = $this->GetLeadTypes();
        View::share('lead_types', $lead_types);
        
        $lead_type_descriptions = $this->GetLeadTypeDescriptions();
        View::share('lead_type_descriptions', $lead_type_descriptions);

        $settings = $this->GetSettings();
        View::share('settings', $settings);
        
        return view('admin/categories');
    }

    /**
     * Spremi admin plaćanje
     */
    public function SaveAdminCategories(Request $request)
    {
        DB::table('settings')
            ->where('id', 1)
            ->update([
                'lead_types' => $request->input('lead_types'),
                'lead_type_descriptions' => $request->input('lead_type_descriptions')
            ]);

        Cache::forget('mailings-table');
        
        return Redirect::back();
    }
    
    /**
     * Ažuriranje lead typeova
     */
    public function UpdateLeadTypes(Request $request)
    {
        $id = $request->input('pk');
        $value = $request->input('value');

        if($value !== '') {
            DB::table('lead_types')
                ->where('id', $id)
                ->update([
                    'name' => $value
                ]);
        }

        return http_response_code(200);
    }
    
    /**
     * Ažuriranje lead type descriptions
     */
    public function UpdateLeadTypeDescriptions(Request $request)
    {
        $id = $request->input('pk');
        $value = $request->input('value');

        if($value !== '') {
            DB::table('lead_type_descriptions')
                ->where('id', $id)
                ->update([
                    'name' => $value
                ]);
        }

        return http_response_code(200);
    }
    
    /**
     * Brisanje kategorija
     */
    public function DeleteCategories(Request $request)
    {
        $id = $request->input('id');
        $type = $request->input('type');
        
        if ($type == 'admin-lead-types') {
            DB::table('leads')
                ->where('lead_type_id', $id)
                ->update([
                    'lead_type_id' => null
                ]);
            
            DB::table('lead_types')
                ->where('id', $id)
                ->delete();
        } else if($type == 'admin-lead-type-descriptions') {
            DB::table('lead_has_type_descriptions')
                ->where('lead_type_description_id', $id)
                ->delete();
            
            DB::table('lead_type_descriptions')
                ->where('id', $id)
                ->delete();
        }
        
        return http_response_code(200);
    }
    
    /**
     *  Vrati popis tipova
     */
    private function GetLeadTypes()
    {
        $lead_types = DB::table('lead_types')
            ->get();

        return $lead_types;
    }
    
    /**
     *  Vrati popis opisa tipova
     */
    private function GetLeadTypeDescriptions()
    {
        $lead_type_descriptions = DB::table('lead_type_descriptions')
            ->orderBy('name')
            ->get();

        return $lead_type_descriptions;
    }

    /**
     * Dohvati postavke
     */
    private function GetSettings()
    {
        return DB::table('settings')
            ->first();
    }
}
