<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use DB;
use Datatables;
use View;
use App\User;
use App\Http\Requests\User\NewUser;
use App\Http\Requests\User\EditUser;
use App\Http\Requests\User\DeleteUser;
use Illuminate\Support\Facades\Cache;

class AdminUsersController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css',
            'global/plugins/bower_components/select2/dist/css/select2.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
            'global/plugins/bower_components/x-editable/dist/bootstrap3-editable/css/bootstrap-editable.css'
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/x-editable/dist/bootstrap3-editable/js/bootstrap-editable.min.js',
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js',
            'global/plugins/bower_components/select2/dist/js/select2.js',
        ];
        $this->js['additionalScripts'] = [
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js',
            getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Users');
    }

    /**
     * Svi korisnici
     */
    public function GetAdminUsers()
    {
        return view('admin/users/users');
    }

    /**
     * Novi korisnik
     */
    public function NewAdminUser()
    {
        $permissions = $this->GetPermissions();
        View::share('permissions', $permissions);

        return view('admin/users/new-user');
    }

    /**
     * Spremanje novog korisnika
     */
    public function CreateAdminUser(NewUser $request)
    {
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
        ]);

        DB::table('user_has_roles')
            ->insert([
                'role_id' => $request->role,
                'user_id' => $user->id
            ]);

        if ($request->user_permissions) {
            foreach($request->user_permissions as $key => $user_permission) {
                DB::table('user_has_permissions')
                    ->insert([
                        'permission_id' => $user_permission,
                        'user_id' => $user->id
                    ]);
            }
        }

        Cache::forget('admin-users-table');

        return redirect()->action('Admin\AdminUsersController@GetAdminUsers');
    }

    /**
     * Uređivanje korisnika
     */
    public function EditAdminUser($user_id)
    {
        $user = User::leftJoin('user_has_roles', 'user_has_roles.user_id', '=', 'users.id')
            ->leftJoin('roles', 'roles.id', '=', 'user_has_roles.role_id')
            ->where('users.id', $user_id)
            ->selectRaw('
                users.id,
                users.name,
                users.email,
                roles.id as role
            ')
            ->first();
        View::share('user', $user);

        $permissions = $this->GetPermissions();
        View::share('permissions', $permissions);

        $user_permissions = DB::table('user_has_permissions')
            ->where('user_id', $user->id)
            ->get();
        View::share('user_permissions', $user_permissions);

        return view('admin/users/edit-user');
    }

    /**
     * Ažuriranje postojećeg korisnika
     */
    public function UpdateAdminUser(EditUser $request, $user_id)
    {
        User::find($user_id)
            ->update([
                'name' => $request->name,
                'password' => bcrypt($request->password),
            ]);

        DB::table('user_has_roles')
            ->where('user_id', $user_id)
            ->update([
                'role_id' => $request->role
            ]);

        DB::table('user_has_permissions')
            ->where('user_id', $user_id)
            ->delete();

        if ($request->user_permissions) {
            foreach($request->user_permissions as $key => $user_permission) {
                DB::table('user_has_permissions')
                    ->insert([
                        'permission_id' => $user_permission,
                        'user_id' => $user_id
                    ]);
            }
        }

        Cache::forget('admin-users-table');

        return redirect()->action('Admin\AdminUsersController@GetAdminUsers');
    }

    /**
     * Brisanje postojećeg korisnika
     */
    public function DeleteAdminUser(DeleteUser $request)
    {
        User::find($request->id)->delete();

        Cache::forget('admin-users-table');

        return redirect()->action('Admin\AdminUsersController@GetAdminUsers');
    }

    /**
     *  Vrati popis korisnika
     */
    public function anyData()
    {
        Cache::forget('admin-users-table');

         return Cache::remember('admin-users-table', 1440, function () {
            $all_users = User::leftJoin('user_has_roles', 'user_has_roles.user_id', '=', 'users.id')
                ->leftJoin('roles', 'roles.id', '=', 'user_has_roles.role_id')
                ->leftJoin('user_has_permissions', 'users.id', '=', 'user_has_permissions.user_id')
                ->leftJoin('permissions', 'user_has_permissions.permission_id', '=', 'permissions.id')
                ->leftJoin('events', 'events.id', '=', 'permissions.name')
                ->selectRaw('
                    users.id,
                    users.name,
                    users.email,
                    roles.name as role,
                    GROUP_CONCAT(DISTINCT events.name SEPARATOR ", ") AS permissions,
                    users.created_at,
                    users.updated_at 
                ')
                ->groupBy('users.id');

            return Datatables::of($all_users)
                ->addColumn('action', function ($all_users) {
                    return '<a href="' . env('APP_URL') . '/admin/users/edit/' . $all_users->id . '"  data-toggle="tooltip" data-placement="top" title="Edit" data-original-title="edit"><i class="fa fa-edit" data-info="tooltip" data-placement="top" title="Edit user"></i></a><button type="button" class="krik-user-delete krik-button-transparent" data-user-id="' . $all_users->id . '" data-toggle="modal" data-target=".krik-delete-user"><i class="fa fa-trash-o" data-info="tooltip" data-placement="top" title="Delete user"></i></button> ';
                })->make(true);
        });
    }

    /**
     *  Vrati popis permissionsa
     */
    private function GetPermissions()
    {
        return DB::table('permissions')
            ->leftJoin('events', 'events.id', '=', 'permissions.name')
            ->selectRaw('
                permissions.id,
                permissions.name,
                events.name AS event_name
            ')
            ->get();
    }
}
