<?php

namespace App\Http\Controllers\Events\All;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Carbon\Carbon;
use Auth;
use Redirect;
use Spatie\Permission\Models\Permission;

class AllEventsController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/jquery.easy-pie-chart/dist/jquery.easypiechart.min.js',
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jquery.matchHeight/0.6.0/jquery.matchHeight-min.js',
        ];
        $this->js['scripts'] = [

        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'All Events');
    }


    /**
     * Prikaz svih aktivnih i prošlih evenata
     */
    public function AllEvents() {
      // Dohvati i proslijedi aktivne evente
      $activeEvents = $this->getActiveEvents();
      View::share('activeEvents', $activeEvents);

      // Dohvati i proslijedi broj registriranih leadova za svaki aktivni pojedinačni event
      $countRegisteredLeadsOnActiveEvents = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        $countRegisteredLeadsOnActiveEvent = $this->GetRegisteredLeadsPerEvent($activeEvent->id);
        $countRegisteredLeadsOnActiveEvents->push($countRegisteredLeadsOnActiveEvent);
      }
      View::share('countRegisteredLeadsOnActiveEvents', $countRegisteredLeadsOnActiveEvents);

      // Dohvati broj ticketa za svaki aktivni pojedinačni event
      $countTiketsOnActiveEvents = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        $countTiketsOnActiveEvent = $this->GetTicketsPerEvent($activeEvent->id);
        $countTiketsOnActiveEvents->push($countTiketsOnActiveEvent);
      }
      View::share('countTiketsOnActiveEvents', $countTiketsOnActiveEvents);

      // Izračunaj postotak registracija u odnosu na broj ticketa
      $registeredTicketsProgress = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        if($countRegisteredLeadsOnActiveEvents[$key] == 0 && $countTiketsOnActiveEvents[$key] == 0) {
          $registeredTicketProgress = 0;
        } elseif($countRegisteredLeadsOnActiveEvents[$key] == $countTiketsOnActiveEvents[$key]) {
          $registeredTicketProgress = 100;
        } elseif($countRegisteredLeadsOnActiveEvents[$key] == 0) {
          $registeredTicketProgress = 0;
        } else {
          $registeredTicketProgress = $countRegisteredLeadsOnActiveEvents[$key] / $countTiketsOnActiveEvents[$key];
          $registeredTicketProgress = $registeredTicketProgress * 100;
        }
        $registeredTicketsProgress->push($registeredTicketProgress);
      }
      View::share('registeredTicketsProgress', $registeredTicketsProgress);

      // Dohvati i proslijedi prošle evente
      $pastEvents = $this->getPastEvents();
      View::share('pastEvents', $pastEvents);

      // Dohvati i proslijedi broj registriranih leadova za svaki prošli pojedinačni event
      $countRegisteredLeadsOnPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $countRegisteredLeadsOnPastEvent = $this->GetRegisteredLeadsPerEvent($pastEvent->id);
        $countRegisteredLeadsOnPastEvents->push($countRegisteredLeadsOnPastEvent);
      }
      View::share('countRegisteredLeadsOnPastEvents', $countRegisteredLeadsOnPastEvents);

      // Dohvati ukupan broj ticketa koji su bili dostupni za svaki prošli pojedinačni event
      $sumTicketsForPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $sumTicketsForPastEvent = $this->GetSumTicketsPerEvent($pastEvent->id);
        $sumTicketsForPastEvents->push($sumTicketsForPastEvent);
      }
      View::share('sumTicketsForPastEvents', $sumTicketsForPastEvents);

      // Dohvati ukupan broj leadova koji su došli na pojedinačni event
      $countAttendeesForPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $countAttendeesForPastEvent = $this->CountAttendeesPerEvent($pastEvent->id);
        $countAttendeesForPastEvents->push($countAttendeesForPastEvent);
      }
      View::share('countAttendeesForPastEvents', $countAttendeesForPastEvents);

      // Broj administratora
      $numberOfAdmins = $this->getAdmins();
      View::share('numberOfAdmins', $numberOfAdmins);

      // Broj reportera po eventu
      $numberOfReportes = $this->getReporters($pastEvents);
      View::share('numberOfReportes', $numberOfReportes);

      // Prazni paremetri potrebni za search
      $search = "";
      $selectedSearchOptionsArray = [];
      View::share('search', $search);
      View::share('selectedSearchOptionsArray', $selectedSearchOptionsArray);

      $now = $this->Now();
      View::share('now', $now);

      return view('events/all/all-events');
    }


    /**
     * Dohvati sve aktivne evente
     * Poveži s odabranim bojama
     * Sortiraj kronološki prema početku eventa
     */
    private function getActiveEvents() {
      $activeEvents = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->selectRaw('events.id as id,
                     events.name,
                     events.description,
                     events.created_at,
                     events.updated_at,
                     events.created_by_id,
                     events.updated_by_id,
                     events.event_look_and_feel_id,
                     events.timezone_id,
                     events.start_ts,
                     events.end_ts,
                     events.event_code,
                     events.registration_start_ts,
                     events.registration_end_ts,
                     events.type_by_venue,
                     events.venue_name,
                     events.venue_address,
                     events.venue_city,
                     events.venue_postal_code,
                     events.venue_country_id,
                     events.access,
                     events.currency_id,
                     events.email_sender,
                     events.tickets_invoice_from_id,
                     events.accomodation_invoice_from_id,
                     events.transfer_invoice_from_id,
                     events.is_draft,
                     color_schemes.background_color,
                     color_schemes.titles_color')
        ->where([
          ['end_ts', '>', $this->Now()]
        ])
        ->whereNotNull('is_draft')
        ->whereNull('deleted_at')
        ->orderBy('is_draft')
        ->orderBy('start_ts')
        ->get();

      return $activeEvents;
    }


    /**
     * Dohvati sve prošle evente
     * Poveži s korisnikom koji je event kreirao
     * Sortiraj kronološki prema kraju eventa
     */
    private function getPastEvents() {
      $pastEvents = Event::join('users', 'created_by_id', '=', 'users.id')
        ->selectRaw('events.id as id,
                     events.name as event_name,
                     users.name as users_name,
                     events.start_ts,
                     events.venue_name,
                     events.description,
                     events.created_at,
                     events.type_by_venue,
                     events.event_code,
					 events.is_draft')
        ->where([
          ['end_ts', '<', $this->Now()]
        ])
        ->whereNotNull('is_draft')
        ->whereNull('events.deleted_at')
        ->orderBy('start_ts', 'desc')
        ->get();

      return $pastEvents;
    }


    /**
     * Ukupan broj administratora na instanci EM-a
     */
    private function getAdmins() {
      $numberOfAdmins = DB::table('user_has_roles')->where('role_id', 1)->count();

      return $numberOfAdmins;
    }


    /**
     * Ukupan broj korisnika koji imaju reporting dozvolu za svaki protekli event
     */
    private function getReporters($pastEvents) {
      $numberOfReportes = collect([]);

      foreach ($pastEvents as $pastEvent) {
        $eventPermission = 'event_id_' . $pastEvent->id;

        $numberOfReportesOnEvent = DB::table('permissions')->where('name', $eventPermission)->count();

        $numberOfReportes->push($numberOfReportesOnEvent);
      }

      return $numberOfReportes;
    }


    /**
     * Brisanje pojedinačnih evenata
     */
    public function DeleteEvent(Request $request) {
      $event_id = $request->input('id');

      if($event_id) {
        Event::where('id', '=', $event_id)
          ->update([
            'deleted_at' => $this->Now()
          ]);
        
        $permission = Permission::where(['name' => $event_id])->first();
        DB::table('user_has_permissions')
            ->where('permission_id', $permission->id)
            ->delete();
        Permission::where(['name' => $event_id])->delete();

        // Deleted event
        $this->Log(124, $event_id);
      }

      return redirect()->action('Events\All\AllEventsController@AllEvents');
    }


    /**
     * Ukupan broj leadova koji su se registrirali na zatraženi event
     */
    private function GetRegisteredLeadsPerEvent($eventId) {
        $countRegisteredLeads = DB::table('registrations')
            ->where('event_id', $eventId)
            ->whereNull('deleted_at')
            ->where(function ($query) {
                $query->where('ticket_approved', 1)
                    ->orWhereNull('ticket_approved');
            })
            ->where(function($query) {
                $query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
            })
            ->count();

        return $countRegisteredLeads;
    }


    /**
     * Ukupan broj tickeata za zatraženi event
     */
    private function GetTicketsPerEvent($eventId) {
        $countTickets = DB::table('tickets')
                          ->where('event_id', '=', $eventId)
                          ->whereNull('deleted_at')
                          ->sum('quantity');

        return $countTickets;
    }


    /**
     * Ukupan zbroj ticketa za zatraženi event
     */
    private function GetSumTicketsPerEvent($eventId) {
        $sumTickets = DB::table('tickets')
                        ->where('event_id', '=', $eventId)
                        ->whereNull('deleted_at')
                        ->sum('quantity');

        return $sumTickets;
    }


    /**
     * Ukupan broj leadova koji su došli na zatraženi event
     */
    private function CountAttendeesPerEvent($eventId) {
      $countAttendees = DB::table('registrations')
                      ->where([
                        ['event_id', '=', $eventId],
                        ['event_attended_flag', '=', '1']
                      ])
                      ->count();

      return $countAttendees;
    }


    /**
     * Provjera da li je POST request za pretragu ili završetak kreiranja novog eventa
     */
    public function ManageEventsPostRequest(Request $request){
        if(isset($_POST['search']))
            return $this->SearchedEvents($request);
        else
            return $this->SaveEventAsDraft($request);
    }


    /**
     * Popis prošlih događanja ovisno o parametrima pretrage
     */
    public function SearchedEvents(Request $request) {
      // Dohvati iz forme parametre za pretragu te sam termin za pretragu
      $search       = $request->input('search');
      $name         = $request->input('name');
      $location     = $request->input('location');
      $description  = $request->input('description');

      // Ukoliko korisnik nije zadao nikakav termin za pretragu, vrati sve događaje
      if(!$search) { return $this->AllEvents(); }

      // Ukoliko je označen parametar pretrage name, promijeni vrijednost na naziv entiteta u bazi
      if($name) $name = 'events.name';

      // Ukoliko je označen parametar pretrage location, promijeni vrijednost na naziv entiteta u bazi
      if($location) $location = 'events.venue_name';

      // Kako bi znali po čemu bazirati pretragu moramo u niz staviti samo one parametre pretrage koje je korisnik odabrao putem forme
      $allPossibleSearchOptions = collect([$name, $location, $description]);
      $selectedSearchOptions = $allPossibleSearchOptions->filter(function ($value, $key) {
          return $value != "";
      });

      // Ukoliko je parametar lokacije odabran dodaj u pretragu odgovarajuće entitete iz baze za koje želimo da se vrši pretraga
      if($selectedSearchOptions->contains('events.venue_name')) {
        $selectedSearchOptions->push('events.venue_address');
        $selectedSearchOptions->push('events.venue_city');
        $selectedSearchOptions->push('events.venue_postal_code');
        $selectedSearchOptions->push('countries.country_name');
        $selectedSearchOptions->push('countries.country_code');
      }

      // Pretvori kolekciju u array
      $selectedSearchOptionsArray = $selectedSearchOptions->toArray();

      // Ukoliko je korisnik odabrao neke parametre za pretragu, uzmi njih u obzir i gradi DB query
      // U suprotnom napravi široko pretraživanje po svim relevantnim entitetima u bazi
      if($selectedSearchOptionsArray) {
        $countSelectedSearchOptions = 0;

        foreach ($selectedSearchOptionsArray as $selectedSearchOption) {

          if($countSelectedSearchOptions == 0) {

            $SQLdate = '"' . $this->Now() . '"';
            $SQLsearch = '"' . $search . '"';

            $pastEvents = "DB::table('events')->join('users', 'created_by_id', '=', 'users.id')->leftJoin('countries', 'events.venue_country_id', '=', 'countries.id')->selectRaw('events.name as event_name, users.name as users_name, events.start_ts, events.venue_name, events.description, events.created_at, events.type_by_venue, events.id, events.event_code, countries.country_name, countries.country_code')->whereRaw('(end_ts < " . $SQLdate . ")  AND (" . $selectedSearchOption . " REGEXP " . $SQLsearch;

          } else {

            $pastEvents = $pastEvents . " OR " . $selectedSearchOption . " REGEXP " . $SQLsearch;

          }

          $countSelectedSearchOptions++;
        }

        $pastEvents = $pastEvents . ")')->whereNotNull('is_draft')->whereNull('events.deleted_at')->orderBy('start_ts', 'desc')->get();";

        // Izvrši string kao PHP naredbu
        eval('$pastEvents = ' . $pastEvents);

      } else {

        $pastEvents = Event::join('users', 'events.created_by_id', '=', 'users.id')
          ->leftJoin('countries', 'events.venue_country_id', '=', 'countries.id')
          ->selectRaw('events.name as event_name,
                       users.name as users_name,
                       events.start_ts,
                       events.venue_name,
                       events.description,
                       events.created_at,
                       events.type_by_venue,
                       events.id,
                       events.event_code,
                       countries.country_name,
                       countries.country_code')
          ->whereRaw('(end_ts < ?)
                      AND (events.name REGEXP ?
                          OR events.venue_name REGEXP ?
                          OR events.venue_address REGEXP ?
                          OR events.venue_city REGEXP ?
                          OR events.venue_postal_code REGEXP ?
                          OR events.description REGEXP ?
                          OR countries.country_name REGEXP ?
                          OR countries.country_code REGEXP ?)',
                      array($this->Now(), $search, $search, $search, $search, $search, $search, $search, $search))
          ->whereNotNull('is_draft')
          ->whereNull('events.deleted_at')
          ->orderBy('start_ts', 'desc')
          ->get();
      }

      View::share('search', $search);
      View::share('selectedSearchOptionsArray', $selectedSearchOptionsArray);
      View::share('pastEvents', $pastEvents);

      // Dohvati i proslijedi aktivne evente
      $activeEvents = $this->getActiveEvents();
      View::share('activeEvents', $activeEvents);

      // Dohvati i proslijedi broj registriranih leadova za svaki aktivni pojedinačni event
      $countRegisteredLeadsOnActiveEvents = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        $countRegisteredLeadsOnActiveEvent = $this->GetRegisteredLeadsPerEvent($activeEvent->id);
        $countRegisteredLeadsOnActiveEvents->push($countRegisteredLeadsOnActiveEvent);
      }
      View::share('countRegisteredLeadsOnActiveEvents', $countRegisteredLeadsOnActiveEvents);

      // Dohvati i proslijedi broj registriranih leadova za svaki prošli pojedinačni event
      $countRegisteredLeadsOnPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $countRegisteredLeadsOnPastEvent = $this->GetRegisteredLeadsPerEvent($pastEvent->id);
        $countRegisteredLeadsOnPastEvents->push($countRegisteredLeadsOnPastEvent);
      }
      View::share('countRegisteredLeadsOnPastEvents', $countRegisteredLeadsOnPastEvents);

      // Dohvati ukupan broj ticketa koji su bili dostupni za svaki prošli pojedinačni event
      $sumTicketsForPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $sumTicketsForPastEvent = $this->GetSumTicketsPerEvent($pastEvent->id);
        $sumTicketsForPastEvents->push($sumTicketsForPastEvent);
      }
      View::share('sumTicketsForPastEvents', $sumTicketsForPastEvents);

      // Dohvati ukupan broj leadova koji su došli na pojedinačni event
      $countAttendeesForPastEvents = collect([]);
      foreach ($pastEvents as $key => $pastEvent) {
        $countAttendeesForPastEvent = $this->CountAttendeesPerEvent($pastEvent->id);
        $countAttendeesForPastEvents->push($countAttendeesForPastEvent);
      }
      View::share('countAttendeesForPastEvents', $countAttendeesForPastEvents);

      // Dohvati broj ticketa za svaki aktivni pojedinačni event
      $countTiketsOnActiveEvents = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        $countTiketsOnActiveEvent = $this->GetTicketsPerEvent($activeEvent->id);
        $countTiketsOnActiveEvents->push($countTiketsOnActiveEvent);
      }
      View::share('countTiketsOnActiveEvents', $countTiketsOnActiveEvents);

      // Izračunaj postotak registracija u odnosu na broj ticketa
      $registeredTicketsProgress = collect([]);
      foreach ($activeEvents as $key => $activeEvent) {
        if($countRegisteredLeadsOnActiveEvents[$key] == 0 && $countTiketsOnActiveEvents[$key] == 0) {
          $registeredTicketProgress = 0;
        } elseif($countRegisteredLeadsOnActiveEvents[$key] == $countTiketsOnActiveEvents[$key]) {
          $registeredTicketProgress = 100;
        } elseif($countRegisteredLeadsOnActiveEvents[$key] == 0) {
          $registeredTicketProgress = 0;
        } else {
          $registeredTicketProgress = $countRegisteredLeadsOnActiveEvents[$key] / $countTiketsOnActiveEvents[$key];
          $registeredTicketProgress = $registeredTicketProgress * 100;
        }
        $registeredTicketsProgress->push($registeredTicketProgress);
      }
      View::share('registeredTicketsProgress', $registeredTicketsProgress);

      // Broj administratora
      $numberOfAdmins = $this->getAdmins();
      View::share('numberOfAdmins', $numberOfAdmins);

      // Broj reportera po eventu
      $numberOfReportes = $this->getReporters($pastEvents);
      View::share('numberOfReportes', $numberOfReportes);

      $now = $this->Now();
      View::share('now', $now);

      return view('events/all/all-events');
    }


    /**
     * Spremi event kao draft
     * @param forma $request
     * @return view
     */
    public function SaveEventAsDraft(Request $request){
        $event = DB::table('events')
          ->where('event_code', $request->input('hash'))
          ->first();

        if ($event->is_draft == null) {
          // New event draft
          $this->Log(121, $event->id);
        }

        if(strlen($request->input('event_name')) > 0){
            //get datetime
            $startTime = substr($request->input('event_date'), 0, 16);
            $endtime   = trim(substr($request->input('event_date'), -16));

            //parse time to db time
            $startTime = Carbon::createFromFormat('d/m/Y H:i', $startTime)->toDateTimeString();
            $endtime   = Carbon::createFromFormat('d/m/Y H:i', $endtime)->toDateTimeString();
            $now = $this->Now();

            //get timezone id
            $timezone_id = DB::table('timezones')
                           ->where('timezone', $request->input('event_timezones'))
                           ->pluck('id');

            if($request->input('event_type') == 'physical'){
                //get country id
                $countries = DB::table('countries')
                             ->where('country_code', $request->input('venue_countries'))
                             ->pluck('id');

                $values = array('name'              => $request->input('event_name'),
                                'description'       => $request->input('event_description'),
                                'created_at'        => $now,
                                'updated_at'        => $now,
                                'timezone_id'       => $timezone_id[0],
                                'start_ts'          => $startTime,
                                'end_ts'            => $endtime,
                                'type_by_venue'     => $request->input('event_type'),
                                'venue_name'        => $request->input('venue_name'),
                                'venue_address'     => $request->input('venue_adress'),
                                'venue_city'        => $request->input('venue_city'),
                                'venue_postal_code' => $request->input('venue_postal_code'),
                                'venue_country_id'  => $countries[0],
                                'access'            => $request->input('access'),
                                'is_draft'          => 1
                        );
            }else{
                $values = array('name'          => $request->input('event_name'),
                                'description'   => $request->input('event_description'),
                                'created_at'    => $now,
                                'updated_at'    => $now,
                                'timezone_id'   => $timezone_id[0],
                                'start_ts'      => $startTime,
                                'end_ts'        => $endtime,
                                'type_by_venue' => $request->input('event_type'),
                                'access'        => $request->input('access'),
                                'is_draft'      => 1
                            );
            }

            DB::table('events')
            ->where('event_code', $request->input('hash'))
            ->update($values);
        }else{

            //get datetime
            $startTime = substr($request->input('registration_duration'), 0, 16);
            $endtime   = substr($request->input('registration_duration'), -16);

            //parse time to db time
            $startTime = Carbon::createFromFormat('d/m/Y H:i', $startTime)->toDateTimeString();
            $endtime   = Carbon::createFromFormat('d/m/Y H:i', $endtime)->toDateTimeString();

            $currency_id = DB::table('currencies')
                           ->where('code', $request->input('currency'))
                           ->pluck('id');

            DB::table('events')
            ->where('event_code', $request->input('hash'))
            ->update(['email_name' => $request->input('email_sender_name'),
                      'email_sender' => $request->input('email_sender'),
                      'currency_id'  => $currency_id[0],
                      'registration_start_ts' => $startTime,
                      'registration_end_ts' => $endtime,
                      'is_draft'     => 1
            ]);
        }

        return $this->AllEvents();
    }


    /**
     * Zatvori regitraciju
     */
    public function CloseRegistration(Request $request) {
      $event_id = $request->input('id');

      Event::where('id', '=', $event_id)
        ->update(array(
          'registration_end_ts' => $this->Now()
        ));

      return Redirect::route('events');
    }
}
