<?php

namespace App\Http\Controllers\Events\Badges;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use App\Lead as Lead;
use View;
use DB;
use Response;
use Datatables;
use Illuminate\Support\Facades\Input;
use DNS1D;
use PDF;
use Carbon\Carbon;
use Redirect;

class BadgesController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
          'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
          'global/plugins/bower_components/animate.css/animate.min.css',
          'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
        ];
        $this->css['themes'] = [
          'admin/css/reset.css',
          'admin/css/layout.css',
          'admin/css/components.css',
          'admin/css/plugins.css',
          'admin/css/themes/laravel.theme.css' => ['id' => ''],
          'admin/css/custom.css',
          'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/css/bootstrap-colorpicker.css',
          'global/plugins/bower_components/jasny-bootstrap-fileinput/css/jasny-bootstrap-fileinput.min.css',
          'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
        ];
        $this->js['plugins'] = [
          'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/js/bootstrap-colorpicker.js',
          'global/plugins/bower_components/jasny-bootstrap-fileinput/js/jasny-bootstrap-fileinput.js',
          'global/plugins/bower_components/bootstrap-switch/dist/js/bootstrap-switch.min.js',
          'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
          'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
          'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js'
        ];
        $this->js['scripts'] = [

        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prikaz formulara za geneiranje nametagova
     */
    public function GetBadges($event_code) {
      // Dohvati informacije o eventu putem event codea koji dobijemo iz URL-a
      $event_info = $this->GetEventInfo($event_code);
      View::share('event_info', $event_info);

      // Ukoliko postoji event nastavi dalje
      // U suprotnom vrati korisnika na početnu
      if($event_info) {

        View::share('title', 'Generate Nametags - ' . $event_info->name);
        View::share('event_code', $event_code);

        $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info->id);
        View::share('event_has_transfers', $event_has_transfers);

        // Proslijedi boje od eventa
        View::share('event_bg', $event_info->background_color);
        View::share('event_color', $event_info->titles_color);

        return view('events/badges/badges');

      } else {

        return redirect()->action('Events\All\AllEventsController@AllEvents');

      }
    }


    /**
     * Generiraj nametagove prema odabiru korisnika
     */
    public function GenerateBadges(Request $request, $event_code) {
        // Dohvati informacije o eventu
        $event_info = $this->GetEventInfo($event_code);
        View::share('event_info', $event_info);

        // Koji tip nametaga je odabran
        $nametag_type = $request->input('nametag-type');

        if(!$nametag_type) {
          return Redirect::back();
        }

        // Podaci na nametagu
        $name = $request->input('name');
        $company_name = $request->input('company-name');
        $country = $request->input('country');
        $barcode = $request->input('barcode');

        // Da li je u headeru naziv eventa ili slika
        $nametag_header = $request->input('nametag-header');

        // Boje u headeru
        $nametags_colors_header_bg = $request->input('nametags-colors-header-bg');
        $nametags_colors_header_text = $request->input('nametags-colors-header-text');

        // Slika u headeru
        if(Input::file('upload_header_img')) {
          $upload_header_img = Input::file('upload_header_img')->move(public_path() . '/images/nametags/' . $event_code . '/', Input::file('upload_header_img')->getClientOriginalName());
        } else {
          $upload_header_img = 'nope';
        }

        // Slike lijeve - desno za naveći nametag
        if(Input::file('upload_left_img')) {
          $upload_left_img = Input::file('upload_left_img')->move(public_path() . '/images/nametags/' . $event_code . '/', Input::file('upload_left_img')->getClientOriginalName());
        } else {
          $upload_left_img = 'nope';
        }
        if(Input::file('upload_right_img')) {
          $upload_right_img = Input::file('upload_right_img')->move(public_path() . '/images/nametags/' . $event_code . '/', Input::file('upload_right_img')->getClientOriginalName());
        } else {
          $upload_right_img = 'nope';
        }

        // Da li je u footeru tekst ili slika
        $nametag_footer = $request->input('nametag-footer');

        // Tekst i boje u footeru
        $nametag_footer_text = $request->input('nametags-footer-text');
        $nametags_colors_footer_bg = $request->input('nametags-colors-footer-bg');
        $nametags_colors_footer_text = $request->input('nametags-colors-footer-text');

        // Slika u footeru
        if(Input::file('upload_footer_img')) {
          $upload_footer_img = Input::file('upload_footer_img')->move(public_path() . '/images/nametags/' . $event_code . '/', Input::file('upload_footer_img')->getClientOriginalName());
        } else {
          $upload_footer_img = 'nope';
        }

        // Generiramo što
        $all_registered_contacts = $request->input('all-registered-contacts');
        $newly_registered_contacts = $request->input('newly-registered-contacts');
        $manually_choose_contacts = $request->input('manually-choose-contacts');

        // Označeni podaci za manually
        $manually_choosen_contacts = $request->input('manually-choosen-contacts');

        // Isfiltriraj podatke o nametagu koji su bili označeni
        $allInputData = collect([$name, $company_name, $country, $barcode]);
        $selectedDataForNametags = $allInputData->filter(function ($value, $key) {
          return $value != "";
        });
        $selectedDataForNametags = $selectedDataForNametags->toArray();

        $badges_order = $request->input('badges_order');

        // Provjeri koji odabir leadova je korisnik odabrao
        // Ako je odabrao sve, povuci sve leadove koji su se registrirali na event
        // Ako je odabrao od prošle generacije, povuci sve leadove koji još nemaju generirani nametag
        // Ako je odabrao manually, uhvati samo te leadove
        if($all_registered_contacts) {

          if($badges_order == 'alphabet') {
				$leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
					->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
					->where('registrations.event_id', $event_info->id)
					->whereNull('registrations.deleted_at')
					->where('registrations.ticket_approved', 1)
					->where(function($query) {
						$query->whereNotNull('registrations.registered_ts')
							->orWhereNotNull('registrations.confirmed_ts');
					})
					->orderBy('leads.last_name')
					->get();
			  
				// $leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
				// 	->leftJoin('countries', 'countries.id', '=', 'registrations.event_id')
				// 	->where('registrations.event_id', $event_info->id)
				// 	->whereNull('registrations.deleted_at')
				// 	->where('registrations.ticket_approved', 1)
				// 	->where(function($query) {
				// 		$query->whereNotNull('registrations.registered_ts')
				// 			->orWhereNotNull('registrations.confirmed_ts');
				// 	})
				// 	->orderBy('leads.last_name')
				// 	->skip(500)
				// 	->take(50)
				// 	->get();
          } else {
				$leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
					->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
					->where('registrations.event_id', $event_info->id)
					->whereNull('registrations.deleted_at')
					->where('registrations.ticket_approved', 1)
					->where(function($query) {
						$query->whereNotNull('registrations.registered_ts')
							->orWhereNotNull('registrations.confirmed_ts');
					})
					->orderBy('registrations.registered_ts')
					->get();
          }

			$registration_ids = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
				->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
				->where('registrations.event_id', $event_info->id)
				->where('registrations.ticket_approved', 1)
				->whereNull('registrations.nametag_generated')
				->whereNull('registrations.deleted_at')
				->where(function($query) {
					$query->whereNotNull('registrations.registered_ts')
						->orWhereNotNull('registrations.confirmed_ts');
				})
				->pluck('registrations.id')
				->toArray();

        } elseif($newly_registered_contacts) {

          if($badges_order == 'alphabet') {
				$leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
				->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
				->where('registrations.event_id', $event_info->id)
				->whereNull('nametag_generated')
				->whereNull('registrations.deleted_at')
				->where('registrations.ticket_approved', 1)
				->where(function($query) {
					$query->whereNotNull('registrations.registered_ts')
						->orWhereNotNull('registrations.confirmed_ts');
				})
				->orderBy('leads.last_name')
				->get();
          } else {
				$leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
					->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
					->where('registrations.event_id', $event_info->id)
					->whereNull('registrations.nametag_generated')
					->whereNull('registrations.deleted_at')
					->where('registrations.ticket_approved', 1)
					->where(function($query) {
						$query->whereNotNull('registrations.registered_ts')
							->orWhereNotNull('registrations.confirmed_ts');
					})
					->orderBy('registrations.registered_ts')
					->orderBy('registrations.confirmed_ts')
					->get();
          }

			$registration_ids = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
				->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
				->where('registrations.event_id', $event_info->id)
				->where('registrations.ticket_approved', 1)
				->whereNull('registrations.nametag_generated')
				->whereNull('registrations.deleted_at')
				->where(function($query) {
					$query->whereNotNull('registrations.registered_ts')
						->orWhereNotNull('registrations.confirmed_ts');
				})
				->pluck('registrations.id')
				->toArray();

        } elseif($manually_choose_contacts) {

          if($badges_order == 'alphabet') {
             $leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
              ->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
              ->whereIn('registrations.id', $manually_choosen_contacts)
              ->orderBy('leads.last_name')
              ->get();
          } else {
             $leads = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
              ->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
              ->whereIn('registrations.id', $manually_choosen_contacts)
              ->orderBy('registrations.registered_ts')
			  ->orderBy('registrations.confirmed_ts')
              ->get();
          }

			$registration_ids = Lead::join('registrations', 'leads.id', '=', 'registrations.lead_id')
				->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
				->whereIn('registrations.id', $manually_choosen_contacts)
				->whereNull('registrations.nametag_generated')
				->whereNull('registrations.deleted_at')
				->where(function($query) {
					$query->whereNotNull('registrations.registered_ts')
						->orWhereNotNull('registrations.confirmed_ts');
				})
				->pluck('registrations.id')
				->toArray();

        }

        if($leads->count() > 0) {
          // Number of generated badges
          $this->Log(189, $leads->count());
        }

        // Provjeri koji tip nametagova je korisnik odabrao
        // Adekvatno odabiru dohvati i proslijedi potrebne podatke za generiranje PDF-a
        if($nametag_type == 'nametag-type-small') {

          $pdf = PDF::loadView('events/badges/templates/90x50',
                    ['leads' => $leads,
                     'event' => $event_info,
                     'selectedDataForNametags' => $selectedDataForNametags,
                     'nametag_header' => $nametag_header,
                     'nametags_colors_header_bg' => $nametags_colors_header_bg,
                     'nametags_colors_header_text' => $nametags_colors_header_text,
                     'upload_header_img' => $upload_header_img])
                    ->setPaper(array(0, 0, 289.133858268, 175.748031496));

          /* $pdf = PDF::loadView('events/badges/templates/90x55',
                    ['leads' => $leads,
                     'event' => $event_info,
                     'selectedDataForNametags' => $selectedDataForNametags,
                     'nametag_header' => $nametag_header,
                     'nametags_colors_header_bg' => $nametags_colors_header_bg,
                     'nametags_colors_header_text' => $nametags_colors_header_text,
                     'upload_header_img' => $upload_header_img])
                    ->setPaper(array(0, 0, 289.133858268, 189.921259843)); */

          if($pdf) {

            // Zapišiti registriranim korisnicima kreiranje nametaga
            $this->NametagGenerated($registration_ids );

            $date = Carbon::createFromFormat('Y-m-d H:i:s', $this->Now())->toDateString();

            // Skini korisniku nametagove
            return $pdf->download('badges-90x50-' . str_replace(' ', '-', strtolower($event_info->name)) . '-' . $date . '.pdf');

          } else {

            return Redirect::back();

          }

        } elseif($nametag_type == 'nametag-type-medium') {

          $pdf = PDF::loadView('events/badges/templates/95x58',
                    ['leads' => $leads,
                     'event' => $event_info,
                     'selectedDataForNametags' => $selectedDataForNametags,
                     'nametag_header' => $nametag_header,
                     'nametags_colors_header_bg' => $nametags_colors_header_bg,
                     'nametags_colors_header_text' => $nametags_colors_header_text,
                     'upload_header_img' => $upload_header_img])
                    ->setPaper(array(0, 0, 303.307086614, 198.42519685));

          if($pdf) {

            // Zapišiti registriranim korisnicima kreiranje nametaga
            $this->NametagGenerated($registration_ids );

            $date = Carbon::createFromFormat('Y-m-d H:i:s', $this->Now())->toDateString();

            return $pdf->download('badges-95x58-' . str_replace(' ', '-', strtolower($event_info->name)) . '-' . $date . '.pdf');

          } else {

            return Redirect::back();

          }

        } elseif($nametag_type == 'nametag-type-large') {

          $pdf = PDF::loadView('events/badges/templates/95x95',
                    ['leads' => $leads,
                     'event' => $event_info,
                     'selectedDataForNametags' => $selectedDataForNametags,
                     'nametag_header' => $nametag_header,
                     'nametags_colors_header_bg' => $nametags_colors_header_bg,
                     'nametags_colors_header_text' => $nametags_colors_header_text,
                     'upload_header_img' => $upload_header_img,
                     'upload_left_img' => $upload_left_img,
                     'upload_right_img' => $upload_right_img,
                     'nametag_footer' => $nametag_footer,
                     'nametag_footer_text' => $nametag_footer_text,
                     'nametags_colors_footer_bg' => $nametags_colors_footer_bg,
                     'nametags_colors_footer_text' => $nametags_colors_footer_text,
                     'upload_footer_img' => $upload_footer_img])
                    ->setPaper(array(0, 0, 303.307086614, 303.307086614));

          if($pdf) {

            // Zapišiti registriranim korisnicima kreiranje nametaga
            $this->NametagGenerated($registration_ids);

            $date = Carbon::createFromFormat('Y-m-d H:i:s', $this->Now())->toDateString();

            return $pdf->download('badges-95x95-' . str_replace(' ', '-', strtolower($event_info->name)) . '-' . $date . '.pdf');

          } else {

            return Redirect::back();

          }

        }

    }


    /**
     * Vrati sve registrirane kontakte na eventu za manually choose contacts tablicu
     */
    public function anyData(Request $request){
        $event_code = $request->input('event_code');

        $event_info = $this->GetEventInfo($event_code);

		$leads = DB::table('leads')
			->join('registrations', 'leads.id', '=', 'registrations.lead_id')
			->selectRaw('registrations.id, CONCAT(first_name, " ", last_name) AS name_surname, leads.company_name')
			->where('registrations.event_id', $event_info->id)
			->whereNull('registrations.deleted_at')
			->where(function($query) {
				$query->whereNotNull('registrations.registered_ts')
					->orWhereNotNull('registrations.confirmed_ts');
			})
			->orderBy('registrations.nametag_generated')
			->orderBy('leads.last_name');

        return Datatables::of($leads)->make(true);
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEventInfo($event_code) {
        $event_info = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
          ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
          ->select('events.id', 'events.name', 'events.start_ts', 'events.type_by_venue', 'events.venue_name', 'color_schemes.background_color', 'color_schemes.titles_color')
          ->where('event_code', '=', $event_code)
          ->first();

        return $event_info;
    }


    /**
     * Zapišiti registriranim korisnicima kreiranje nametaga
     */
    private function NametagGenerated($registration_ids) {
        DB::table('registrations')
          ->whereIn('id', $registration_ids)
          ->update(array(
            'nametag_generated' => '1'
          ));
    }
}
