<?php

namespace App\Http\Controllers\Events\Create;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

use View;
use DB;
use Carbon\Carbon;
use Auth;

use Illuminate\Support\Facades\Input;

use App\Http\Controllers\MainController as MainController;

class EventInfoController extends MainController
{
    public function __construct() {

        $this->middleware('auth');

        parent::__construct();

        $this->setApp();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/select2/dist/css/select2.css',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/select2/dist/js/select2.js',
            'global/plugins/bower_components/moment/min/moment.min.js',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.js'
        ];

        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Event Info');
    }


    /**
     * Prikaz EventInfo viewaa
     * @param  string [$event_code = '']
     * @return view
     */
    public function GetEventInfo($event_code = ''){

        $timezones = $this->GetTimezonesDB();
        $countries = $this->GetCountriesDB();

        if($event_code !== ''){
            View::share('hash', $event_code);
            $this->GetEventData($event_code);
            $event_info = DB::table('events')
              ->where('event_code', $event_code)
              ->pluck('name');
            View::share('title', 'Event Info - ' . $event_info[0]);
        }

        View::share('timezones', $timezones);
        View::share('countries', $countries);
        View::share('event_code', $event_code);

        return view('events/create/event-info');
    }

    /**
     * Spremanje look and feela u bazu
     * @param  forma Request $request
     * @return view
     */
    public function SaveLookAndFeel(Request $request) {

        $hash     = $this->GetHash();
        $filepath = $this->UploadLogo($request, $hash);
        $id_looks = $this->SetEventColors($request,$filepath);
        $now = $this->Now();

        DB::table('events')
        ->insert(['created_at'             => $now,
                  'created_by_id'          => Auth::user()->id,
                  'event_look_and_feel_id' => $id_looks,
                  'event_code'             => $hash,
                  'is_draft'               => NULL,
                  'registration_starting_existing_leads_en' => '<p>Dear {lead_first_name},</p><p>This is a personal and non-transmissible invitation for a event registration.</p><p><b>To continue with the registration, click the button below.</b></p><p>We recognize you from our previous events! Your registration form is going to be completely or partially filled up. Please, change all the outdated information.</p>',
                  'registration_starting_existing_leads_hr' => '<p>{lead_alias} {lead_first_name},</p><p>Ovo je osobna pozivnica za registraciju na događaj i nije prenosiva na druge osobe.</p><p><b>Za nastavak registracije, molimo kliknite na gumb ispod.</b></p><p>Prepoznajemo Vas s naših prijašnjih događaja! Vaš registracijski obrazac bit će popunjen u cijelosti ili djelomično. Molimo Vas nadopunite ili promijenite neispravne podatke.</p>',
                  'registration_starting_new_leads_en' => '<p>Dear,</p><p>This is a personal and non-transmissible invitation for a event registration.</p><p><span style="font-weight: 700;">To continue with the registration, click the button below.</span></p>',
                  'registration_starting_new_leads_hr' => '<p>Dragi/a,</p><p>Ovo je osobna pozivnica za registraciju na događaj i nije prenosiva na druge osobe.</p><p><span style="font-weight: 700;">Za nastavak registracije, molimo kliknite na gumb ispod.</span></p>',
                  'registration_email_signature_en' => '<p>Best Regards,<br>{sender_name}</p>',
                  'registration_email_signature_hr' => '<p>Lijep pozdrav,<br>{sender_name}</p>',
                  'registration_completed_with_invoices_en' => "<p>Dear {lead_first_name},</p><p>You have successfully registered for {event_name}.</p><p>Please, find proforma invoice in the attachment, based on which You can make Your payment if necessary.<br></p><p>We'll be in touch with the updates related to the event.</p><p>Looking forward to seeing You,<br>{sender_name}</p>",
                  'registration_completed_with_invoices_hr' => "<p>{lead_alias} {lead_first_name},</p><p>Uspješno ste se prijavili na {event_name}.</p><p>Informirat ćemo Vas o ostalim detaljima vezanim za događaj.</p><p>Radujemo se Vašem dolasku,&nbsp;<br>{sender_name}</p>",
                  'registration_completed_without_invoices_en' => "<p>Dear {lead_first_name},</p><p>You have successfully registered for {event_name}.</p><p>We'll be in touch with the updates related to the event.</p><p>Looking forward to seeing You,<br>{sender_name}</p>",
                  'registration_completed_without_invoices_hr' => "<p>{lead_alias} {lead_first_name},</p><p>Uspješno ste se prijavili na {event_name}.</p><p>Informirat ćemo Vas o ostalim detaljima vezanim za događaj.</p><p>Radujemo se Vašem dolasku,&nbsp;<br>{sender_name}</p>"
        ]);

        View::share('hash', $hash);

        return $this->GetEventInfo();
    }

    /**
     * Update look and feela
     * @param  string $event_code
     * @param  forma Request $request
     * @return view
     */
    public function UpdateLookAndFeel($event_code, Request $request){

        $filepath = $this->UploadLogo($request, $event_code);
        $id_looks = $this->SetEventColors($request,$filepath);
        $now = $this->Now();

        DB::table('events')
        ->where('event_code', $event_code)
        ->update(['updated_at'             => $now,
                  'updated_by_id'          => Auth::user()->id,
                  'event_look_and_feel_id' => $id_looks
        ]);

        $event = DB::table('events')
            ->where('event_code', $event_code)
            ->first();

        if ((int)$event->is_draft === 0 && !is_null($event->is_draft) ) {
            // Updated event
            $this->Log(123, $event->id);
        }

        $this->GetEventData($event_code);

        return $this->GetEventInfo($event_code);
    }

    /**
     * Dohvati vremenske zone iz baze
     * @return array
     */
    public function GetTimezonesDB(){
        $timezones = DB::table('timezones')
                     ->select('id', 'name','timezone')
                     ->get();

        return $timezones;
    }


    /**
     * Dohvati države iz baze
     * @return array
     */
    public function GetCountriesDB(){
        $countries = DB::table('countries')
                     ->select('country_code','country_name')
                     ->get();

        return $countries;
    }

    /**
     * Uploadaj logo ako već ne postoji
     * @param  forma $request
     * @return string
     */
    public function UploadLogo($request, $hash){
        if($request->input('logo') == 'upload_logo_cb'){
            if($request->file('upload_logo')){
                $header = $request->file('upload_logo');
                $header->move(public_path() . '/images/event/' . $hash . '/', $header->getClientOriginalName());
            }
            else{
                if($request->file('upload_logo_update')){
                    $header = $request->file('upload_logo_update');
                    $header->move(public_path() . '/images/event/' . $hash . '/', $header->getClientOriginalName());
                }
            }
        }

        if($request->input('logo') == 'predifined_logo'){
            $filepath = env('APP_URL') . '/assets/images/logo/logo.png';
        }else if($request->input('logo') == 'no_logo')
            $filepath = NULL;
        else{
            if($request->file('upload_logo')){
                $filepath = env('APP_URL') . '/images/event/'. $hash . '/' . $header->getClientOriginalName();
            }else{
                if($request->file('upload_logo_update')){
                    $filepath = env('APP_URL') . '/images/event/'. $hash . '/' . $header->getClientOriginalName();
                }else{
                    $logo = DB::table('events')
                     ->join('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
                     ->where('event_code',$hash)
                     ->select(array('event_look_feels.event_logo_url as logo'))
                     ->get();

                    $filepath = $logo[0]->logo;
                }
            }
        }

        return $filepath;
    }

    /**
     * Postavljanje boja eventa
     * @param  forma $request
     * @return int
     */
    public function SetEventColors($request, $filepath){
        if($request->input('testColors') == 0){
            $id_color = $request->input('colors');
        }else if ($request->input('testColors') == 2){
            if(!$request->input('colorID')){
                $id_color = DB::table('color_schemes')
                            ->insertGetId(['background_color'  => $request->input('bgColor'),
                                           'titles_color'      => $request->input('titleColor'),
                                            'use_as_template'  => 0,
                ]);
            }else
                $id_color = $request->input('colorID');
        }

        $id_looks = DB::table('event_look_feels')
                    ->insertGetId(['color_scheme_id'      => $id_color,
                                       'titles_font'      => $request->input('titleFont'),
                                       'body_font'        => $request->input('bodyFont'),
                                       'event_logo_url'   => $filepath,
                                       'logo_transparent' => 1
        ]);

        return $id_looks;
    }

    /**
     * Generiranje event koda
     * @return string
     */
    public function GetHash(){
        return 'ev' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }

    /**
     * Informacije o eventu
     * @param string $event_code
     */
    public function GetEventData($event_code){
        //type of event
        $type = DB::table('events')
                ->where('event_code', $event_code)
                ->pluck('type_by_venue');

        if(strlen($type[0]) != 0){
            if($type[0] == 'physical'){
                $event_info = DB::table('events')
                              ->join('timezones', 'timezones.id', '=', 'events.timezone_id')
                              ->join('countries', 'countries.id', '=', 'events.venue_country_id')
                              ->where('event_code', $event_code)
                              ->select(array('events.name as name',
                                             'timezones.timezone as timezone',
                                             'events.start_ts as start_ts',
                                             'events.end_ts as end_ts',
                                             'events.description as description',
                                             'events.lang as lang',
                                             'events.wspay as wspay',
                                             'events.type_by_venue as type',
                                             'events.venue_name as v_name',
                                             'events.venue_address as v_address',
                                             'events.venue_city as v_city',
                                             'events.venue_postal_code as v_code',
                                             'countries.country_code as v_country',
                                             'events.access as access',
                                             'events.is_draft',
                                             'events.name',
                                             'events.id as id'))
                             ->get();
            }else{
                $event_info = DB::table('events')
                              ->join('timezones', 'timezones.id', '=', 'events.timezone_id')
                              ->where('event_code', $event_code)
                              ->select(array('events.name as name',
                                             'timezones.timezone as timezone',
                                             'events.start_ts as start_ts',
                                             'events.end_ts as end_ts',
                                             'events.description as description',
                                             'events.lang as lang',
                                             'events.wspay as wspay',
                                             'events.type_by_venue as type',
                                             'events.access as access',
                                             'events.is_draft',
                                             'events.name',
                                             'events.id as id'))
                             ->get();
            }

            $event_has_accommodations = $this->eventHasAccommodations($event_info[0]->id);
            View::share('event_has_accommodations', $event_has_accommodations);

            $event_has_transfers = $this->eventHasTransfers($event_info[0]->id);
            View::share('event_has_transfers', $event_has_transfers);

            //object to array
            $event_info = json_decode(json_encode($event_info[0]),true);

            //format date for js
            $event_info['start_ts'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start_ts'])->format('d/m/Y H:i');
            $event_info['end_ts']   = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end_ts'])->format('d/m/Y H:i');

            View::share('event_info', $event_info);
        }
    }
}
