<?php

namespace App\Http\Controllers\Events\Create;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

use View;
use DB;
use Carbon\Carbon;
use Auth;

use Illuminate\Support\Facades\Input;

use App\Http\Controllers\MainController as MainController;

class LookAndFeelController extends MainController
{
    public function __construct() {

        $this->middleware('auth');

        parent::__construct();

        $this->setApp();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
            'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/css/bootstrap-colorpicker.css',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/css/jasny-bootstrap-fileinput.min.css'
        ];

        // page level plugins
        $this->js['plugins'] = [
            'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/js/bootstrap-colorpicker.js',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/js/jasny-bootstrap-fileinput.js'
        ];

        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Look and Feel');

        View::share('extraClasses', 'lookAndFeel');
    }


    /**
     * Redirekcija prilikom pristupanja nedozvoljenim rutama
     * @return view
     */
    public function RedirectToLookAndFeel() {
        return redirect()->action('Events\Create\LookAndFeelController@GetLookAndFeel');
    }


    /**
     * View za look and feeel
     * @param  string [$event_code = '']
     * @return view
     */
    public function GetLookAndFeel($event_code = '') {
        $colors = DB::table('color_schemes')
                  ->where('use_as_template',1)
                  ->get();

        $logo = env('APP_URL') . '/assets/images/logo/logo.png';

        $titleFonts = array('Abril Fatface',
                            'Arial',
                            'Arvo',
                            'Bad Script',
                            'Comfortaa',
                            'Dancing Script',
                            'Droid Sans',
                            'Georgia',
                            'Open Sans',
                            'Satisfy',
                            'Tahoma',
                            'Times New Roman',
                            'Ubuntu',
                            'Verdana',
                            'Vollkorn');
        $bodyFonts  = array('Arial',
                            'Georgia',
                            'Tahoma',
                            'Times New Roman',
                            'Verdana');
        if($event_code !== ''){
          $event_info = DB::table('events')
            ->where('event_code', $event_code)
            ->first();

          View::share('title', 'Look & Feel - ' . $event_info->name);

          $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($event_info->id);
          View::share('event_has_transfers', $event_has_transfers);
        }

        View::share('colors', $colors);
        View::share('logo', $logo);
        View::share('titleFonts', $titleFonts);
        View::share('bodyFonts', $bodyFonts);
        View::share('event_code', $event_code);

        return view('events/create/look-and-feel');
    }

    /**
     * Dohvaćanje podataka iz baze za look and feel te preusmjeravanje na view
     * @param  string $event_code
     * @return view
     */
    public function GetLookAndFeelData($event_code){

        //colors from database
        $eventColors = $this->GetEventColorsDB($event_code);
        View::share('eventColors', $eventColors);

        $eventLooks = $this->GetEventLooksDB($event_code);
        View::share('eventLooks', $eventLooks);

        return $this->GetLookAndFeel($event_code);
    }

    /**
     * Dohvaćanje boja iz baze za određeni event
     * @param  string $event_code
     * @return array
     */
    public function GetEventColorsDB($event_code){
        $getColors = DB::table('events')
                     ->join('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
                     ->join('color_schemes', 'color_schemes.id', '=', 'event_look_feels.color_scheme_id')
                     ->where('event_code',$event_code)
                     ->select(array('color_schemes.id as id',
                                    'color_schemes.titles_color as title',
                                    'color_schemes.background_color as background',
                                    'color_schemes.use_as_template as template'))
                     ->get();

        //objects to array
        $getColors = json_decode(json_encode($getColors[0]),true);

        return $getColors;
    }


    /**
     * Dohvaćanje izgleda iz baze za određeni event
     * @param  string $event_code
     * @return array
     */
    public function GetEventLooksDB($event_code){
        $logo = env('APP_URL') . '/assets/images/logo/logo.png';

        $eventLooks = DB::table('events')
                     ->leftJoin('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
                     ->where('event_code',$event_code)
                     ->select(array('event_look_feels.titles_font as title',
                                    'event_look_feels.body_font as body',
                                    'event_look_feels.event_logo_url as logo',
                                    'events.name',
                                    'events.is_draft'))
                     ->get();

        //objects to array
        $eventLooks = json_decode(json_encode($eventLooks[0]),true);

        //setting is logo predefined,no logo, uploaded
        if($logo == $eventLooks['logo'])
            $array = array('logo_option' => 0);
        else if(strlen($eventLooks['logo']) == 0)
            $array = array('logo_option' => 1);
        else
            $array = array('logo_option' => 2);

        $eventLooks = array_merge($eventLooks, $array);

        return $eventLooks;
    }

    /**
     * Dodavanje boja u bazu
     * @param  parametri forme $request
     * @return int
     */
    public function SaveColorScheme(Request $request){
        $id = DB::table('color_schemes')
              ->insertGetId(['background_color'  => $request->input('bgColor'),
                             'titles_color'      => $request->input('titleColor'),
                             'use_as_template'   => $request->input('isTemplate')
        ]);

        return $id;
    }

}
