<?php

namespace App\Http\Controllers\Events\Create;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

use View;
use DB;
use Carbon\Carbon;
use Auth;

use App\Http\Controllers\MainController as MainController;

class RegistrationController extends MainController
{
    public function __construct() {

        $this->middleware('auth');

        parent::__construct();

        $this->setApp();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/x-editable/dist/bootstrap3-editable/css/bootstrap-editable.css',
            'global/plugins/bower_components/x-editable/dist/inputs-ext/typeaheadjs/lib/typeahead.js-bootstrap.css',
            'global/plugins/bower_components/x-editable/dist/inputs-ext/address/address.css',
            'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.css',
            'global/plugins/bower_components/select2/dist/css/select2.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/bootstrap-datepicker-vitalets/js/bootstrap-datepicker.js',
            'global/plugins/bower_components/moment/min/moment.min.js',
            'global/plugins/bower_components/jquery-ui/jquery-ui.min.js',
            'global/plugins/bower_components/bootstrap-switch/dist/js/bootstrap-switch.min.js',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.js',
            'global/plugins/bower_components/select2/dist/js/select2.js'
        ];


        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Registration');
        View::share('extraClasses', 'fixRadio Registration');

    }

    /**
     * Prikaz registration viewa
     * @return view
     */
    public function GetRegistration($event_code = ''){
        $currencies     = DB::table('currencies')->get();

        $invoices = DB::table('invoice_froms')
          ->leftJoin('events as tickets_invoice_from', 'invoice_froms.id', '=', 'tickets_invoice_from.tickets_invoice_from_id')
          ->leftJoin('events as accomodation_invoice_from', 'invoice_froms.id', '=', 'accomodation_invoice_from.accomodation_invoice_from_id')
          ->leftJoin('events as transfer_invoice_from', 'invoice_froms.id', '=', 'transfer_invoice_from.transfer_invoice_from_id')
          ->selectRaw('
            invoice_froms.*,
            COUNT(DISTINCT tickets_invoice_from.id) AS tickets_invoice_from_count,
            COUNT(DISTINCT accomodation_invoice_from.id) AS accomodation_invoice_from_count,
            COUNT(DISTINCT transfer_invoice_from.id) AS transfer_invoice_from_count
          ')
          ->whereNull('invoice_froms.deleted_at')
          ->whereNull('tickets_invoice_from.deleted_at')
          ->whereNull('accomodation_invoice_from.deleted_at')
          ->whereNull('transfer_invoice_from.deleted_at')
          ->groupBy('invoice_froms.id')
          ->get();

        if($event_code){
            View::share('hash', $event_code);
            View::share('event_code', $event_code); //for update
            $this->GetRegistrationData($event_code);

            $event_info = DB::table('events')
                ->where('event_code', $event_code)
                ->pluck('name');

            View::share('title', 'Registration - ' . $event_info[0]);
        }

        View::share('currencies', $currencies);
        View::share('invoices', $invoices);

        return view('events/create/registration');
    }

    /**
     * Spremi podatke o registraciji u bazu
     * @param forma $request
     * @return view
     */
    public function SaveEventInfo(Request $request) {
        $this->UpdateEvent('',$request);
        return $this->GetRegistration();
    }

    /**
     * Spremi podatke u bazu i vrati podatke o eventu
     * @param  string $event_code
     * @param  forma $request
     * @return view
     */
    public function SaveLookAndFeelWithEventInfoData($event_code, Request $request){
        $this->UpdateEvent($event_code,$request);
        $this->GetRegistrationData($event_code);
        return $this->GetRegistration($event_code);
    }

    /**
     * Prikaz podataka o eventu
     * @param  string $event_code
     * @return view
     */
    public function GetRegistrationWithData($event_code){
        $this->GetRegistrationData($event_code);
        return $this->GetRegistration($event_code);
    }

    /**
     * Dohvati podatke iz baze o registraciji
     * @param string $event_code
     */
    public function GetRegistrationData($event_code){
        $event_id       = DB::table('events')
                          ->where('event_code', $event_code)
                          ->pluck('id');
        $event_info     = DB::table('events')
                          ->leftJoin('currencies', 'events.currency_id', '=', 'currencies.id')
                          ->where('event_code', $event_code)
                          ->select(array('events.email_sender as email',
                                   'events.email_name',
                                   'events.is_draft',
                                   'currencies.code as currency',
                                   'events.name',
                                   'events.timezone_id',
                                   'events.registration_start_ts as start',
                                   'events.registration_end_ts as end',
                                   'events.tickets_invoice_from_id',
                                   'events.accomodation_invoice_from_id',
                                   'events.transfer_invoice_from_id',
                                   'events.id as id',
                                   'events.registration_notification'))
                          ->get();

        $tickets = DB::table('tickets')
            ->leftJoin('registrations', 'tickets.id', '=', 'registrations.ticket_type_id')
            ->selectRaw('
                tickets.*,
                COUNT(if(registrations.deleted_at IS NULL, if(registrations.registered_ts IS NOT NULL, 1, NULL), NULL)) AS ticket_registration_count
            ')
            ->where('tickets.event_id', $event_id[0])
            ->whereNull('tickets.deleted_at')
            ->groupBy('tickets.id')
            ->get();

        $acc_single = DB::table('accommodations')
            ->join('room_types','room_types.accommodation_id','=','accommodations.id')
            ->leftJoin('registrations', 'room_types.id', '=', 'registrations.accomodation_room_id')
            ->selectRaw('
                accommodations.name as name,
                room_types.price_without_vat as price_single,
                accommodations.id as id,
                COUNT(if(registrations.deleted_at IS NULL, if(registrations.registered_ts IS NOT NULL, 1, NULL), NULL)) AS accommodations_registration_count
            ')
            ->where('accommodations.event_id', $event_id[0])
            ->where('room_types.type', 'Single use')
            ->whereNull('accommodations.deleted_at')
            ->groupBy('accommodations.id')
            ->get();

        $acc_double = DB::table('accommodations')
            ->join('room_types','room_types.accommodation_id','=','accommodations.id')
            ->leftJoin('registrations', 'room_types.id', '=', 'registrations.accomodation_room_id')
            ->selectRaw('
                accommodations.name as name,
                room_types.price_without_vat as price_double,
                accommodations.id as id,
                COUNT(if(registrations.deleted_at IS NULL, if(registrations.registered_ts IS NOT NULL, 1, NULL), NULL)) AS accommodations_registration_count
            ')
            ->where('accommodations.event_id', $event_id[0])
            ->where('room_types.type', 'Double use')
            ->whereNull('accommodations.deleted_at')
            ->groupBy('accommodations.id')
            ->get();

        $transfers = DB::table('transfers')
            ->leftJoin('registration_has_transfers', 'transfers.id', '=', 'registration_has_transfers.transfer_id')
            ->selectRaw('
                transfers.*,
                COUNT(registration_has_transfers.transfer_id) AS transfers_registration_count
            ')
            ->where('event_id', $event_id[0])
            ->whereNull('deleted_at')
            ->groupBy('transfers.id')
            ->get();

        $social_events = DB::table('social_events')
            ->leftJoin('registration_has_social_events', 'social_events.id', '=', 'registration_has_social_events.social_event_id')
            ->selectRaw('
                social_events.*,
                COUNT(registration_has_social_events.social_event_id) AS social_events_registration_count
            ')
            ->where('event_id', $event_id[0])
            ->whereNull('deleted_at')
            ->groupBy('social_events.id')
            ->get();

		foreach($acc_double as $key=>$acc){
			$pos = array_search($acc->name,array_column($acc_single, 'name'));
			$acc_single[$pos]->price_double = $acc->price_double;
		}

        $event_has_accommodations = $this->eventHasAccommodations($event_info[0]->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info[0]->id);
        View::share('event_has_transfers', $event_has_transfers);

        //object to array
        $event_info = json_decode(json_encode($event_info[0]),true);

        if($event_info['start']){
            //format date for js
            $start_past = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start']);
            View::share('start_past', $start_past);

            $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d/m/Y H:i');
            $event_info['end']   = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d/m/Y H:i');
        }

        View::share('now', $this->Now($event_info['timezone_id']));

        View::share('event_info', $event_info);
        View::share('tickets', $tickets);
        View::share('accommodations', $acc_single);
        View::share('transfers', $transfers);
        View::share('socialEvents', $social_events);
    }

    /**
     * Ažuriraj podatke o eventu
     * @param string $event_code
     * @param forma $request
     */
    public function UpdateEvent($event_code, $request){
         //get datetime
        $startTime = substr($request->input('event_date'), 0, 16);
        $endtime   = substr($request->input('event_date'), -16);

        //parse time to db time
        $startTime = Carbon::createFromFormat('d/m/Y H:i', $startTime)->toDateTimeString();
        $endtime   = Carbon::createFromFormat('d/m/Y H:i', $endtime)->toDateTimeString();

        $now = $this->Now();

        if($event_code){
            $user_id     = Auth::user()->id;
            $update_time = $now;
        }else{
            $event_code = $request->input('hash');
            $user_id     = NULL;
            $update_time = NULL;
        }

        //get timezone id
        $timezone_id = DB::table('timezones')
                       ->where('timezone', $request->input('event_timezones'))
                       ->pluck('id');

        if($request->input('event_type') == 'physical'){
            //get country id
            $countries = DB::table('countries')
                         ->where('country_code', $request->input('venue_countries'))
                         ->pluck('id');

            $values = array('name'              => $request->input('event_name'),
                            'description'       => $request->input('event_description'),
                            'lang' => $request->input('lang'),
                            'wspay' => (WSPAY) ? $request->input('wspay') : null,
                            'updated_at'        => $update_time,
                            'updated_by_id'     => $user_id,
                            'timezone_id'       => $timezone_id[0],
                            'start_ts'          => $startTime,
                            'end_ts'            => $endtime,
                            'type_by_venue'     => $request->input('event_type'),
                            'venue_name'        => $request->input('venue_name'),
                            'venue_address'     => $request->input('venue_adress'),
                            'venue_city'        => $request->input('venue_city'),
                            'venue_postal_code' => $request->input('venue_postal_code'),
                            'venue_country_id'  => $countries[0],
                            'access'            => $request->input('access')
                    );
        }else{
            $values = array('name'          => $request->input('event_name'),
                            'description'   => $request->input('event_description'),
                            'lang' => $request->input('lang'),
                            'wspay' => (WSPAY) ? $request->input('wspay') : null,
                            'updated_at'    => $update_time,
                            'updated_by_id' => $user_id,
                            'timezone_id'   => $timezone_id[0],
                            'start_ts'      => $startTime,
                            'end_ts'        => $endtime,
                            'type_by_venue' => $request->input('event_type'),
                            'access'        => $request->input('access')
                        );
        }

        DB::table('events')
        ->where('event_code', $event_code)
        ->update($values);

        $event = DB::table('events')
            ->where('event_code', $event_code)
            ->first();

        if ((int)$event->is_draft === 0 && !is_null($event->is_draft) ) {
            // Updated event
            $this->Log(123, $event->id);
        }

        $event_name = DB::table('events')
              ->where('event_code', $event_code)
              ->pluck('name');
        View::share('event_name', $event_name[0]);

        View::share('hash', $event_code);
    }

          /**
     * Generiranje promo koda karte
     * @return string
     */
    private function GenerateTicketPromoCode(){
        //return substr(str_shuffle('abcdefghijklmnopqrstuvwxyz123456789'), 0, 5) . substr(time(),-5);
        return substr(str_shuffle('abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789'), 0, 10) ;
    }

    /**
     * Spremmi kartu u bazu
     * @param  forma $request
     * @return int or array
     */
    public function SaveTicket(Request $request){
		$startTime  = substr($request->input('event_date'), 0, 16);
		$endtime    = substr($request->input('event_date'), -16);

		$startTime = Carbon::createFromFormat('d/m/Y H:i', $startTime)->toDateTimeString();
        $endtime   = Carbon::createFromFormat('d/m/Y H:i', $endtime)->toDateTimeString();
        
        $quantity = $request->input('quantity');

        if($request->input('edit')){
            $ticket_id = $request->input('id');
            $a = $request->input('quantity');

            DB::table('tickets')
            ->where('id', $ticket_id)
            ->update(['name'              => $request->input('name'),
                      'description'       => $request->input('description'),
                      'quantity'          => $request->input('quantity'),
                      'price_without_VAT' => $request->input('price_wvat'),
                      'VAT'               => $request->input('vat_ticket'),
                      'valid_from_ts'     => $startTime,
                      'valid_until_ts'    => $endtime,
                      'accompany_persons' => $request->input('accompany_persons'),
                      'has_promo_codes'   => $request->input('has_promo_codes')
            ]);

            $get_quantity =  DB::table('tickets')
                            ->where('id', $ticket_id)
                            ->pluck('quantity');

            $count_number_of_ticket_id =  DB::table('promo_codes')
                                        ->where('ticket_id', $ticket_id)
                                        ->count();
            $number_quantity = intval($get_quantity[0]);
          
            if($request->input('has_promo_codes')) {
                if($number_quantity > $count_number_of_ticket_id) {
                    $number_new_promo = $number_quantity - $count_number_of_ticket_id;
                        for ($i=0; $i < $number_new_promo; $i++) { 
                            DB::table('promo_codes')
                            ->insert([
                                'ticket_id' => $ticket_id,
                                'code'       => $this->GenerateTicketPromoCode()
                            ]);
                        }
                } elseif($number_quantity < $count_number_of_ticket_id){
                    $number_delete_promo = $count_number_of_ticket_id - $number_quantity;      
                    for ($i=0; $i < $number_delete_promo; $i++) {    
                        DB::table('promo_codes')
                        ->where('ticket_id', $ticket_id)
                        ->whereNUll('registration_id')
                        ->take(1)
                        ->delete();
                    }
                }
            }
                  
            // Updated ticket
            $this->Log(132, $ticket_id);

            return array('edit', $request->input('id'));

        }else{

            $event_id = DB::table('events')
                        ->where('event_code', $request->input('hash'))
                        ->pluck('id');

            $ticket_id = DB::table('tickets')
                        ->insertGetId(['event_id'          => $event_id[0],
                                       'name'              => $request->input('name'),
                                       'description'       => $request->input('description'),
                                       'quantity'          => $request->input('quantity'),
                                       'price_without_VAT' => $request->input('price_wvat'),
                                       'VAT'               => $request->input('vat_ticket'),
                                       'valid_from_ts'     => $startTime,
                                       'valid_until_ts'    => $endtime,
                                       'accompany_persons' => $request->input('accompany_persons'),
                                       'has_promo_codes'   => $request->input('has_promo_codes')
                        ]);
            // New ticket
            $this->Log(131, $ticket_id);
            if($request->input('has_promo_codes')) {
                for ($i=0; $i < $quantity; $i++) { 
                    DB::table('promo_codes')
                    ->insert([
                        'ticket_id' => $ticket_id,
                        'code'       => $this->GenerateTicketPromoCode()
                    ]);
                }
            }

            return $ticket_id;
        }

    }


    /**
     * Spremi smještaj u bazu
     * @param  forma $request
     * @return int or array
     */
    public function SaveAccommondation(Request $request){
        $startTime  = substr($request->input('room_date'), 0, 10);
        $endtime    = substr($request->input('room_date'), -10);

        $startTime = Carbon::createFromFormat('d/m/Y', $startTime)->toDateTimeString();
        $endtime   = Carbon::createFromFormat('d/m/Y', $endtime)->toDateTimeString();

        if($request->input('edit')){

			$room_single = DB::table('room_types')
						   ->where('accommodation_id', $request->input('id'))
						   ->where('type', 'Single use')
						   ->get();

			$room_double = DB::table('room_types')
						   ->where('accommodation_id', $request->input('id'))
						   ->where('type', 'Double use')
						   ->get();

            DB::table('accommodations')
            ->where('id', $request->input('id'))
            ->update(['name'              => $request->input('hotel_name'),
                      'no_of_rooms'       => $request->input('numbr_rooms'),
                      'details'           => $request->input('room_details'),
					  'available_from'    => $startTime,
                      'available_until'   => $endtime
            ]);

            // Updated accommodation
            $this->Log(142, $request->input('id'));

			if(!empty($room_single)){
				if($request->input('price_wvat_single')){
					DB::table('room_types')
					->where('accommodation_id', $request->input('id'))
					->where('type','Single use')
					->update(['price_without_vat' => $request->input('price_wvat_single'),
							'vat'                 => $request->input('vat')
					]);
				} else {
					DB::table('room_types')
					->where('accommodation_id', $request->input('id'))
					->where('type','Single use')
					->delete();
				}
			} else {
				if($request->input('price_wvat_single')){
					DB::table('room_types')
					->insert(['type'            => 'Single use',
							'price_without_vat' => $request->input('price_wvat_single'),
							'vat'               => $request->input('vat'),
							'accommodation_id'  => $request->input('id')
					]);
				}
			}

			if(!empty($room_double)){
				if($request->input('price_wvat_double')){
					DB::table('room_types')
					->where('accommodation_id', $request->input('id'))
					->where('type','Double use')
					->update(['price_without_vat' => $request->input('price_wvat_double'),
							'vat'                 => $request->input('vat')
					]);
				} else {
					DB::table('room_types')
					->where('accommodation_id', $request->input('id'))
					->where('type','Double use')
					->delete();
				}
			} else {
				if($request->input('price_wvat_double')){
					DB::table('room_types')
					->insert(['type'            => 'Double use',
							'price_without_vat' => $request->input('price_wvat_double'),
							'vat'               => $request->input('vat'),
							'accommodation_id'  => $request->input('id')
					]);
				}
			}

            return array('edit', $request->input('id'));
        }else{

            $event_id = DB::table('events')
                        ->where('event_code', $request->input('hash'))
                        ->pluck('id');

            $acc_id = DB::table('accommodations')
                      ->insertGetId(['name'              => $request->input('hotel_name'),
                                     'event_id'          => $event_id[0],
                                     'no_of_rooms'       => $request->input('numbr_rooms'),
                                     'details'           => $request->input('room_details'),
									 'available_from'    => $startTime,
                      				 'available_until'   => $endtime
            ]);

            // New accommodation
            $this->Log(141, $acc_id);

			if($request->input('price_wvat_single')){
				DB::table('room_types')
				->insert(['type'            => 'Single use',
						'price_without_vat' => $request->input('price_wvat_single'),
						'vat'               => $request->input('vat'),
						'accommodation_id'  => $acc_id
				]);
			}

			if($request->input('price_wvat_double')){
				DB::table('room_types')
				->insert(['type'            => 'Double use',
						'price_without_vat' => $request->input('price_wvat_double'),
						'vat'               => $request->input('vat'),
						'accommodation_id'  => $acc_id
				]);
			}

            return $acc_id;
        }
    }

    /**
     * Spremi transport u bazu
     * @param  forma $request
     * @return array or int
     */
    public function SaveTransfer(Request $request){

        $event_id = DB::table('events')
                    ->where('event_code', $request->input('hash'))
                    ->pluck('id');

        if($request->input('edit')){

            if(!empty($request->input('tf_airport'))){
                $values = array('from' => $request->input('tf_airport'),
                                'to'   => $request->input('tt_venue'),
                                'price_without_vat' => $request->input('price_wvat_ap'),
                                'vat'               => $request->input('vat_ap'));
            }else{
                $values = array('from'              => $request->input('tf_venue'),
                                'to'                => $request->input('tf_airport'),
                                'price_without_vat' => $request->input('price_wvat_ve'),
                                'vat'               => $request->input('vat_ve'));
            }

            DB::table('transfers')
            ->where('id', $request->input('id'))
            ->update($values);

            // Updated transfer
            $this->Log(152, $request->input('id'));

            return $request->input('id');
        }else{
            $transfer_id_first = DB::table('transfers')
                             ->insertGetId(['event_id'          => $event_id[0],
                                            'description'       => 'Transfer From Airport to Venue',
                                            'from'              => $request->input('tf_airport'),
                                            'to'                => $request->input('tt_venue'),
                                            'price_without_vat' => $request->input('price_wvat_ap'),
                                            'vat'               => $request->input('vat_ap')
            ]);

            $transfer_id_second = DB::table('transfers')
                                  ->insertGetId(['event_id'      => $event_id[0],
                                             'description'       => 'Transfer From Venue to Airport',
                                             'from'              => $request->input('tf_venue'),
                                             'to'                => $request->input('tt_airport'),
                                             'price_without_vat' => $request->input('price_wvat_ve'),
                                             'vat'               => $request->input('vat_ve')
            ]);

            // New transfer
            $this->Log(151, $transfer_id_first);
            $this->Log(151, $transfer_id_second);

            return array($transfer_id_first, $transfer_id_second);
        }
    }

    /**
     * Spremmi social event u bazu
     */
    public function saveSocialEvent(Request $request) {
        $name = $request->input('social_event_name');
        $time = $request->input('social_event_time');
		$time = Carbon::createFromFormat('d/m/Y H:i', $time)->toDateTimeString();

        if($request->input('edit')) {
            $social_event_id = $request->input('id');

            DB::table('social_events')
                ->where('id', $social_event_id)
                ->update([
                    'name' => $name,
                    'time' => $time
                ]);

            return array('edit', $social_event_id);
        } else {
            $event_id = DB::table('events')
                ->where('event_code', $request->input('hash'))
                ->value('id');

            $social_event_id = DB::table('social_events')
                ->insertGetId([
                    'name' => $name,
                    'time' => $time,
                    'event_id' => $event_id,
                ]);

            return $social_event_id;
        }
    }

    /**
     * Spremi ili ažuriraj invoice u bazu
     * @param  forma $request
     * @return int
     */
    public function SaveInvoice(Request $request){
        $invoice_id = $request->input('invoice_id');

        if($invoice_id) {
          DB::table('invoice_froms')
            ->where('id', '=', $invoice_id)
            ->update(['name'           => $request->input('name'),
                'invoice_from_details' => $request->input('from'),
                'account_name'         => $request->input('account_name'),
                'account_number'       => $request->input('number'),
                'sort_code'            => $request->input('code'),
                'IBAN'                 => $request->input('iban'),
                'SWIFT'                => $request->input('swift'),
                'bank_name'            => $request->input('b_name'),
                'bank_details'         => $request->input('b_details')
           ]);

          // Updated invoice
          $this->Log(162, $invoice_id);

           return array($invoice_id);
        } else {
          $invoice_id = DB::table('invoice_froms')
                        ->insertGetId(['name'      => $request->input('name'),
                            'invoice_from_details' => $request->input('from'),
                            'account_name'         => $request->input('account_name'),
                            'account_number'       => $request->input('number'),
                            'sort_code'            => $request->input('code'),
                            'IBAN'                 => $request->input('iban'),
                            'SWIFT'                => $request->input('swift'),
                            'bank_name'            => $request->input('b_name'),
                            'bank_details'         => $request->input('b_details')
                       ]);

          $invoice_name = DB::table('invoice_froms')
                          ->where('id', $invoice_id)
                          ->pluck('name');

          // New invoice
          $this->Log(161, $invoice_id);

          return array($invoice_id, $invoice_name[0]);
        }
    }

    /**
     * Vrati mi podatke o ticketu/transferu/accommodationu
     * @param  int $type
     * @param  int $id
     * @return JSON
     */
    public function GetEditData($type, $id){
        if($type == 0)
            $table = 'tickets';
        else if($type == 1)
            $table = 'accommodations';
        else if($type == 2)
            $table = 'transfers';
        else if($type == 3)
            $table = 'social_events';

        $data = DB::table($table)
                ->where('id', $id)
                ->get();

        if($type == 1){
            $room_single = DB::table('room_types')
						   ->where('accommodation_id', $id)
						   ->where('type', 'Single use')
						   ->get();

			$room_double = DB::table('room_types')
						   ->where('accommodation_id', $id)
						   ->where('type', 'Double use')
						   ->get();

			$vat = null;

			if(!empty($room_single)){
				$data[0]->price_without_vat_single = $room_single[0]->price_without_vat;
				$vat = $room_single[0]->vat;
			}
			if(!empty($room_double)){
				$data[0]->price_without_vat_double = $room_double[0]->price_without_vat;
				$data[0]->vat = $room_double[0]->vat;
			}
			$data[0]->vat = $vat;
        }

        //formt date for js
        if(isset($data[0]->valid_from_ts) && !is_null($data[0]->valid_from_ts)){
            $data[0]->valid_from_ts  = Carbon::createFromFormat('Y-m-d H:i:s', $data[0]->valid_from_ts)->format('d/m/Y H:i');
            $data[0]->valid_until_ts = Carbon::createFromFormat('Y-m-d H:i:s', $data[0]->valid_until_ts)->format('d/m/Y H:i');
        }else if(isset($data[0]->available_from)){
            $data[0]->available_from  = Carbon::createFromFormat('Y-m-d', $data[0]->available_from)->format('d/m/Y');
            $data[0]->available_until = Carbon::createFromFormat('Y-m-d', $data[0]->available_until)->format('d/m/Y');
        }

        if($type == 2){
            $data[0]->description = explode(' ', $data[0]->description, 5);
            $data[0]->description = $data[0]->description[2];
        }

        if ($type == 3) {
            $data[0]->time = Carbon::createFromFormat('Y-m-d H:i:s', $data[0]->time)->format('d/m/Y H:i');
        }


        return json_encode($data[0]);
    }

    /**
     * Obriši ticket/transfer/accommodation iz baze
     * Obriši invoice option
     * @param int $type
     * @param int $id
     */
    public function DeleteFromTable($type, $id) {

        if ($type == 'invoice') {
            $table = 'invoice_froms';

            // Deleted invoice
            $this->Log(163, $id);
        } else if ($type == 0) {
            $table = 'tickets';

            // Deleted ticket
            $this->Log(133, $id);
        } else if ($type == 1)  {
            $table = 'accommodations';

            // Deleted accommodation
            $this->Log(143, $id);
        } else if ($type == 2)  {
            $table = 'transfers';

            // Deleted transfer
            $this->Log(153, $id);
        } else if ($type == 3)  {
            $table = 'social_events';
        }

        DB::table($table)
            ->where('id', $id)
            ->update([
                'deleted_at' => $this->Now()
            ]);
    }

}
