<?php

namespace App\Http\Controllers\Events\Gifts;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use View;
use DB;
use App\Event as Event;

class GiftsController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Unos korisnika koji došao po gift
     */
    public function getGift($event_code) {
        $event_info = $this->GetEvent($event_code);
        View::share('event_info', $event_info);
        View::share('event_code', $event_code);

        if($event_info) {

          $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($event_info->id);
          View::share('event_has_transfers', $event_has_transfers);

          View::share('lead', 'no');
          View::share('status', 'no');

          View::share('title', 'Gifts - ' . $event_info->name);

          return view('events/gifts/gifts');

        } else {

          return redirect()->action('Events\All\AllEventsController@AllEvents');

        }
    }


    /**
     * Spremanje dolaska na event
     */
    public function saveGift(Request $request, $event_code) {
        $barcode = $request->input('barcode');

        $event_info = $this->GetEvent($event_code);
        View::share('event_info', $event_info);
        View::share('event_code', $event_code);

        View::share('title', 'Gifts - ' . $event_info->name);
        
        $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info->id);
        View::share('event_has_transfers', $event_has_transfers);

        // Provjeri da li registracija s unesenim barcodom postoji
        $registration = DB::table('registrations')
                          ->where('barcode', '=', $barcode)
                          ->first();

        if($registration) {
          $lead = DB::table('leads')
                    ->where('id', '=', $registration->lead_id)
                    ->first();

           // Pazi da je leadu prvo zabilježen dolazak
           if($registration->event_attended_flag != 1) {
               
                View::share('status', 'notattended');
                View::share('lead', 'nope');

                return view('events/gifts/gifts');

          }

          // Pazi da barcode mora odgovarati eventu na kojem ga unosimo
          if($registration->event_id != $event_info->id) {

                View::share('status', 'wrong');
                View::share('lead', 'nope');

                return view('events/gifts/gifts');

          }

          // Provjeri da li je barcode već registriran
          // Ako nije zapiši davanje gifta
          if($registration->gifts_ts == null) {

            DB::table('registrations')
              ->where('barcode', '=', $barcode)
              ->update(array(
                'gifts_ts' => $this->Now()
              ));

            // Updated gift status
            $this->Log(188, $registration->id);

            View::share('status', 'new');

          } else {

            View::share('status', 'registered');

          }

          View::share('lead', $lead);

        } else {

          View::share('lead', 'nope');
          View::share('status', 'nope');

        }

        return view('events/gifts/gifts');
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('events.event_code', '=', $event_code)
                            ->first();

        return $singleEvent;
    }

}
