<?php

namespace App\Http\Controllers\Events\Mailings;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use View;
use DB;
use DateTime;
use Carbon\Carbon;
use Datatables;
use Response;
use Auth;

class EmailActivitiesController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/morrisjs/morris.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/pages/timeline.css',
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/raphael/raphael-min.js',
            'global/plugins/bower_components/morrisjs/morris.min.js',
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Dohvati sve email activitije za pojedini event
     */
    public function EmailActivities($event_code) {
      // Dohvati informacije o eventu putem event codea koji dobijemo iz URL-a
      $event_info = $this->GetEventInfo($event_code);
      View::share('event_info', $event_info);

      // Ukoliko event postoji prebaci korisnika na email activities
      // U suprotnom vrati korisnika na sve evente
      if($event_info) {

        // Dohvati email activitije za zatraženi event
        $emailActivities = $this->GetEventEmailActivities($event_info->id);

        // Dohvati podatke za graf i proslijedi ih dalje ukoliko postoje
        $chartsData = $this->GetEmailActivitiesChartData($event_info->id);

          if($chartsData) {

            // Magija pretvaranja dobivenih podataka iz viewa u dvostruki array kako bi se mogao on pretvoriti u kolekcije stringova koje plugin želi -.-
            $dataForChart = $this->GenerateEmailActivitiesChartData($chartsData);

            View::share('chartData', 'jap');
            View::share('dataForChart', $dataForChart);

          } else {

            View::share('chartData', 'nope');

          }


        // Proslijedi podatke o email activitijima i mailinzima (jea, la hrvatski) ukoliko postoje
        // U suprotnom proslijedi null vrijednosti
        if($emailActivities) {

          View::share('emailActivities', $emailActivities);

          // Za svaki mailing activity saznaj koliko je ukupno kontakata na koje se šalju pozivi
          $mailings_count = collect([]);
          foreach ($emailActivities as $key => $emailActivitie) {
            $mailing_count = $this->GetMailingsCountForEventEmailActivity($emailActivitie->id);
            $mailings_count->push($mailing_count);
          }
          View::share('mailings_count', $mailings_count);

          // Za svaki mailing activity saznaj na koliko je ukupno kontakata poslan poziv u danom trenutku
          $mailings_count_sent = collect([]);
          foreach ($emailActivities as $key => $emailActivitie) {
            $mailing_count_sent = $this->GetMailingsCountSentForEventEmailActivity($emailActivitie->id);
            $mailings_count_sent->push($mailing_count_sent);
          }
          View::share('mailings_count_sent', $mailings_count_sent);

          // Za svaki mailing activity saznaj kada je prvi mailing poziv poslan
          $mailings_count_sent_first = collect([]);
          foreach ($emailActivities as $key => $emailActivitie) {
            $mailing_count_sent_first = $this->GetMailingsCountSentFirstForEventEmailActivity($emailActivitie->id);
            $mailings_count_sent_first->push($mailing_count_sent_first);
          }
          View::share('mailings_count_sent_first', $mailings_count_sent_first);

          // Za svaki mailing activity saznaj da li je active ili scheduled
          $mailings_processes = collect([]);
          foreach ($emailActivities as $key => $emailActivitie) {
            $mailing_process = $this->GetMailingsProcessForEventEmailActivity($emailActivitie->id);
            $mailing_process = $mailing_process->mailing_process;
            $mailings_processes->push($mailing_process);
          }
          View::share('mailings_processes', $mailings_processes);

          // Za svaki mailing activity saznaj koliko se kontakata odjavilo
          $mailings_count_opt_out = collect([]);
          foreach ($emailActivities as $key => $emailActivitie) {
            $mailing_count_opt_out = $this->GetMailingsCountOptOutsForEventEmailActivity($emailActivitie->id);
            $mailings_count_opt_out->push($mailing_count_opt_out);
          }
          View::share('mailings_count_opt_out', $mailings_count_opt_out);

        } else {

          View::share('emailActivities', 'nope');

        }

        // Browser title bar
        $title = 'E-mail Activities - ' . $event_info->name;
        View::share('title', $title);

        View::share('event_code', $event_code);

        $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info->id);
        View::share('event_has_transfers', $event_has_transfers);

    		$now = Carbon::createFromFormat('Y-m-d H:i:s', $this->Now())->format('H:i');
    		View::share('now', $now);

        return view('events/mailings/email-activities');

      } else {

        return redirect()->action('Events\All\AllEventsController@AllEvents');

      }
    }


    /**
     * Brisanje pojedinačnih activitija
     */
    public function DeleteActivity(Request $request) {
      $activity_id = $request->input('id');

      if($activity_id) {
        DB::table('mailing_activities')
          ->where('id', '=', $activity_id)
          ->update([
            'deleted_at' => $this->Now()
          ]);

        // Deleted e-mail campaign
        $this->Log(174, $activity_id);
      }

      return redirect()->back();
    }
    
    /**
     * Dupliciranje activitija
     */
    public function DuplicateActivity(Request $request) {
        $activity_id = $request->input('id');

        if(!$activity_id) return redirect()->back();

        $activity = \App\MailingActivitie::find($activity_id);
        $activityNew = $activity->replicate();
        $activityNew->mailing_activity_code = 'em' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
        $activityNew->is_draft = 1;
        $activityNew->created_by_id = Auth::user()->id;
        $activityNew->updated_by_id = null;
        $activityNew->updated_at = null;
        $activityNew->save();

        return redirect()->back();
      }

    /**
     * Zaustavi slanje mailinga
     */
    public function UpdateActivity(Request $request) {
      $activity_id = $request->input('activity_id');

      if($activity_id) {
        DB::table('mailing_activities')
          ->where('id', '=', $activity_id)
          ->update(array(
            'mailing_process' => 6
          ));
      }

      return redirect()->back();
    }


    /**
     * Vrati event ID i naziv za dobiveni event code iz URL-a
     */
    private function GetEventInfo($event_code) {
        $event_info = DB::table('events')
          ->select('id', 'name', 'start_ts', 'end_ts', 'type_by_venue', 'venue_name')
          ->where('event_code', '=', $event_code)
          ->first();

        return $event_info;
    }


    /**
     * Vrati event email activitije
     * Spoji s tipovima email activitija
     * Sortiraj kronološki od najnovijih
     */
    private function GetEventEmailActivities($event_id) {
        $emailActivities = DB::table('mailing_activities')
                            ->join('mailing_types', 'mailing_activities.mailing_type_id', '=', 'mailing_types.id')
                            ->join('users', 'mailing_activities.created_by_id', '=', 'users.id')
                            ->selectRaw('mailing_activities.id as id,
                                         mailing_activities.mailing_activity_code,
                                         mailing_activities.name as mailing_activitie_name,
                                         mailing_activities.description,
                                         mailing_activities.email_subject,
                                         mailing_activities.email_from_name,
                                         mailing_activities.email_from_email,
                                         mailing_activities.email_replyto_email,
                                         mailing_activities.created_at,
                                         mailing_activities.is_draft,
                                         mailing_activities.scheduled_ts,
                                         mailing_types.name as mailing_type_name,
                                         users.name as users_name')
                            ->where('mailing_activities.event_id', '=', $event_id)
                            ->whereNull('mailing_activities.deleted_at')
                            ->orderBy('mailing_activities.created_at', 'desc')
                            ->get();

        return $emailActivities;
    }


    /**
     * Vrati ukupan broj kontakata na koje će biti poslan email activity
     */
    private function GetMailingsCountForEventEmailActivity($mailing_activity_id) {
        $mailings_count = DB::table('mailings')
                          ->where('mailing_activity_id', '=', $mailing_activity_id)
                          ->whereNull('deleted_at')
                          ->count();

        return $mailings_count;
    }


    /**
     * Vrati ukupan broj kontakata na koje je poslan email activity
     */
    private function GetMailingsCountSentForEventEmailActivity($mailing_activity_id) {
        $mailings_count_sent = DB::table('mailings')
                              ->where('mailing_activity_id', '=', $mailing_activity_id)
                              ->whereNotNull('sent_ts')
                              ->whereNull('deleted_at')
                              ->count();

        return $mailings_count_sent;
    }


    /**
     * Vrati vrijeme kada je prvi email activity poslan nekom kontaktu
     */
    private function GetMailingsCountSentFirstForEventEmailActivity($mailing_activity_id) {
        $mailings_count_sent_first = DB::table('mailings')
                                    ->select('sent_ts')
                                    ->where('mailing_activity_id', '=', $mailing_activity_id)
                                    ->where('sent_ts', '!=', '1970-01-01 00:00:00')
                                    ->whereNull('deleted_at')
                                    ->whereNotNull('sent_ts')
                                    ->min('sent_ts');

        return $mailings_count_sent_first;
    }


    /**
     * Vrati tip procesa slanja mailinga za određeni mailing activity
     */
    private function GetMailingsProcessForEventEmailActivity($mailing_activity_id) {
      $mailing_process = DB::table('mailing_activities')
        ->select('mailing_process')
        ->where('id', '=', $mailing_activity_id)
        ->first();

      return $mailing_process;
    }


    /**
     * Vrati broj leadova koji su se odjavili s mail poziva za određeni mailing activity
     */
    private function GetMailingsCountOptOutsForEventEmailActivity($mailing_activity_code) {
        $mailings_count_opt_outs = DB::table('leads')
                                   ->where('opt_out_activity_id', '=', $mailing_activity_code)
                                   ->count();

        return $mailings_count_opt_outs;
    }


    /**
     * Dohvati podatke za graf
     * Sva magija odabira podataka za graf se odvija putem DBMS-a u chart_email_activity viewu
     * DBMS vraća zbrojeve sortiranih podataka po datumima
     */
    private function GetEmailActivitiesChartData($eventId) {
        $chartEventMaingsIds = DB::table('mailing_activities')
          ->where('event_id', $eventId)
          ->pluck('id');

        array_push($chartEventMaingsIds, 'nope');

        $chartData = DB::table('chart_email_activity')
          ->where('eventIds', $eventId)
          ->whereIn('activityIds', $chartEventMaingsIds)
          ->orderBy('dates')
          ->get();

        return $chartData;
    }


    /**
     * Obradi dobivene podatke za graf prema želji plugina
     */
    private function GenerateEmailActivitiesChartData($chartsData) {
      $dataForChartPlugin = array();
      $dataForChartPlugin_subarray = array([]);

      foreach($chartsData as $key => $chartData) {
        $pos = array_search($chartData->dates, array_column($dataForChartPlugin, 'date'));

        if($pos !== false) {

          if($chartData->whatDidWeGet == 'sended') {
            $dataForChartPlugin[$pos]['a'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'opened') {
            $dataForChartPlugin[$pos]['b'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'registered') {
            $dataForChartPlugin[$pos]['c'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'optOut') {
            $dataForChartPlugin[$pos]['d'] = $chartData->counts;
          }

        } else {
          $dataForChartPlugin_subarray = array("date" => $chartData->dates);

          if($chartData->whatDidWeGet == 'sended') {
            $dataForChartPlugin_subarray['a'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'opened') {
            $dataForChartPlugin_subarray['b'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'registered') {
            $dataForChartPlugin_subarray['c'] = $chartData->counts;
          } else if($chartData->whatDidWeGet == 'optOut') {
            $dataForChartPlugin_subarray['d'] = $chartData->counts;
          }

          array_push($dataForChartPlugin, $dataForChartPlugin_subarray);
        }
      }

      $dataForChart = collect([]);

      // Saznaj kada će biti zadnji datum
      $keys = array_keys($dataForChartPlugin);
      $lastKey = array_pop($keys);

      foreach ($dataForChartPlugin as $key => $data) {
        if($key == 0) {
          $firstDate = new DateTime($data['date']);
          date_sub($firstDate, date_interval_create_from_date_string('1 days'));
          $dataString = "{ y: '" .  date_format($firstDate, 'Y-m-d') . "', a: 0, b: 0, c: 0, d: 0 },";
          $dataForChart->push($dataString);
        }

        $dataString = "{ y: '" .  $data['date'] . "'";

        if(array_key_exists('a', $data)) {
          $dataString = $dataString . ', a: ' . $data['a'];
        } else {
          $dataString = $dataString . ', a: 0';
        }
        if(array_key_exists('b', $data)) {
          $dataString = $dataString . ', b: ' . $data['b'];
        } else {
          $dataString = $dataString . ', b: 0';
        }
        if(array_key_exists('c', $data)) {
          $dataString = $dataString . ', c: ' . $data['c'];
        } else {
          $dataString = $dataString . ', c: 0';
        }
        if(array_key_exists('d', $data)) {
          $dataString = $dataString . ', d: -' . $data['d'];
        } else {
          $dataString = $dataString . ', d: 0';
        }

        $dataString = $dataString . ' },';

        $dataForChart->push($dataString);

        // Broj dana između dva dana u nizu da dodamo 0 za sve datume između
        // Pazi da to ne radimo na zadnjem datumu
        if($key != $lastKey) {
          $dateStart = new DateTime($data['date']);
          $dateEnd  = new DateTime($dataForChartPlugin[$key+1]['date']);
          $dateDiff = $dateStart->diff($dateEnd);

          if($dateDiff->days > 1) {
			$dateStartPlus = $dateStart;
			date_add($dateStartPlus, date_interval_create_from_date_string('1 days'));
			$dataString = "{ y: '" .  date_format($dateStartPlus, 'Y-m-d') . "', a: 0, b: 0, c: 0, d: 0 },";
			$dataForChart->push($dataString);

			$dateEndMinus = $dateEnd;
			date_add($dateEndMinus, date_interval_create_from_date_string('-1 days'));
			$dataString = "{ y: '" .  date_format($dateEndMinus, 'Y-m-d') . "', a: 0, b: 0, c: 0, d: 0 },";
			$dataForChart->push($dataString);
          }
        } else {
          $lastDate = new DateTime($data['date']);
          date_add($lastDate, date_interval_create_from_date_string('1 days'));

          $dataString = "{ y: '" .  date_format($lastDate, 'Y-m-d') . "', a: 0, b: 0, c: 0, d: 0 },";

          $dataForChart->push($dataString);
        }
      }

      return $dataForChart;
    }


    /**
     * Prikaz mailinga u pregledniku
     */
    public function PreviewMailings($event_code, $mailing_activity_code) {

      $mail_table = DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->get();

      $mail_table = json_decode(json_encode($mail_table[0]),true);
      
      // Custom HTML
      if($mail_table['custom_html']) {
        return view('mail-templates.template_custom', [
            'html' => $mail_table['body_html']
        ]);
      }

      $default_bg_color = '#8e8e8e';
      $default_title_color = '#fff';

      $title = $mail_table['header_text'];
      $register = $mail_table['register_button'];
      $confirm = $mail_table['confirm_button'];
      $banner = $mail_table['header_img_url'];
      $logo = $mail_table['logo_url'];
      $bgColor = $banner ? $default_bg_color : $mail_table['background_color'];
      $titleColor = $banner ? $default_title_color : $mail_table['titles_color'];
      $body_content = $mail_table['body_wysiwyg'];
      $unsub = $mail_table['unsubscribe_text'];
      $copyright = $mail_table['copyright_statement'];
      $preview = 1;
      $calendar_icon = env('APP_URL') . '/assets/images/mail-icons/mail-calendar-icon.png';
      $location_icon = env('APP_URL') . '/assets/images/mail-icons/mail-location-icon.png';
      $mail_template = $mail_table['sidebar_included'] == 1 ? 'mail-templates.template_720' : 'mail-templates.template_600';

      $lang = DB::table('events')->where('event_code', $event_code)->value('lang');

      if ($mail_table['sidebar_included'] == 1) {
        $event_info = DB::table('events')
          ->select(array('type_by_venue as venue',
            'venue_name as v_name',
            'venue_address as address',
            'venue_city as city',
            'venue_postal_code as postal',
            'countries.country_name as country',
            'start_ts as start',
            'end_ts as end'))
          ->leftJoin('countries','countries.id','=','events.venue_country_id')
          ->where('event_code', $event_code)
          ->get();

        $event_info = json_decode(json_encode($event_info[0]),true);
        if ($lang == 'hr') {
          $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d.m.Y. H:m');
          $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d.m.Y. H:m');
        } else {
          $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d/m/Y h:i a');
          $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d/m/Y h:i a');
        }

        $v_name = $event_info['v_name'];
        $address = $event_info['address'];
        $city = $event_info['city'];
        $postal = $event_info['postal'];
        $country= $event_info['country'];
        $start = $event_info['start'];
        $end = $event_info['end'];
        $show_location = $event_info['venue'] == 'online' ? false : true;

        return view($mail_template, [
          'banner' => $banner,
          'title' => $title,
          'register' => $register,
          'confirm' => $confirm,
          'logo' => $logo,
          'bgColor' => $bgColor,
          'titleColor' => $titleColor,
          'body_content' => $body_content,
          'unsub' => $unsub,
          'copyright' => $copyright,
          'preview' => $preview,
          'lang' => $lang,
          'calendar_icon' => $calendar_icon,
          'location_icon' => $location_icon,
          'v_name' => $v_name,
          'address' => $address,
          'city' => $city,
          'postal' => $postal,
          'country' => $country,
          'start' => $start,
          'end' => $end,
          'show_location' => $show_location
        ]);
      }

      return view($mail_template, [
        'banner' => $banner,
        'title' => $title,
        'register' => $register,
        'confirm' => $confirm,
        'logo' => $logo,
        'bgColor' => $bgColor,
        'titleColor' => $titleColor,
        'body_content' => $body_content,
        'unsub' => $unsub,
        'copyright' => $copyright,
        'preview' => $preview,
        'lang' => $lang,
        'calendar_icon' => $calendar_icon,
        'location_icon' => $location_icon
      ]);

    }

    /**
     * Popis leadova za brzo slanje mailova
     */
    public function GetLeadsForQuickSend() {
      $leads = DB::table('leads')
        ->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
        ->selectRaw('
          leads.id AS id,
          leads.company_name AS company_name,
          leads.title AS title,
          leads.first_name AS first_name,
          leads.last_name AS last_name,
          leads.email AS email,
          countries.country_name AS country_name
        ')
        ->whereNull('deleted_at');

      return Datatables::of($leads)->make(true);
    }


    /**
     * Spremi zahtjeve za quick mailing
     * Postavi activity na Continue sending in background
     */
    public function QuickSend(Request $request) {
      $lead_ids = $request->input('choosen_leads');
      $activity_id = $request->input('activity_id');

      if ($lead_ids && $activity_id) {

        foreach ($lead_ids as $key => $lead_id) {

          DB::table('mailings')
            ->insert([
              'mailing_activity_id' => $activity_id,
              'lead_id' => $lead_id
            ]);

        }

        DB::table('mailing_activities')
          ->where('id', $activity_id)
          ->update([
            'mailing_process' => 3
          ]);

        return Response::json('Mailings sended');

      } else {

        return Response::json('No selected leads');

      }

    }
}
