<?php

namespace App\Http\Controllers\Events\Mailings;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;

use App\Event as Event;
use View;
use DB;
use Carbon\Carbon;
use Illuminate\Support\Facades\Input;

class EmailDesignController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
            'global/plugins/bower_components/summernote/dist/summernote.css',
            'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/css/bootstrap-colorpicker.css',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/css/jasny-bootstrap-fileinput.min.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/jquery-ui/jquery-ui.min.js',
            'global/plugins/bower_components/summernote/dist/summernote.min.js',
            'global/plugins/bower_components/bootstrap-switch/dist/js/bootstrap-switch.min.js',
            'global/plugins/bower_components/mjolnic-bootstrap-colorpicker/dist/js/bootstrap-colorpicker.js',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/js/jasny-bootstrap-fileinput.js'
        ];

        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'E-mail Design');
        View::share('extraClasses', 'mailing_activity');
    }




    public function GetEmailDesign($event_code, $mailing_activity_code = '') {
        $event_info = DB::table('events')
            ->select(array('type_by_venue as venue',
                'venue_name as v_name',
                'venue_address as address',
                'venue_city as city',
                'venue_postal_code as postal',
                'countries.country_name as country',
                'start_ts as start',
                'end_ts as end',
                'name',
                'access',
                'events.id'))
            ->leftJoin('countries','countries.id','=','events.venue_country_id')
            ->where('event_code', $event_code)
            ->get();

        $event_has_accommodations = $this->eventHasAccommodations($event_info[0]->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info[0]->id);
        View::share('event_has_transfers', $event_has_transfers);

        $event_info = json_decode(json_encode($event_info[0]),true);

        $types = DB::table('mailing_types')
            ->get();

        $predef_logo = DB::table('events')
            ->join('event_look_feels','event_look_feels.id','=','events.event_look_and_feel_id')
            ->where('events.event_code',$event_code)
            ->pluck('event_look_feels.event_logo_url');

        View::share('event_info', $event_info);
        View::share('predef_logo', $predef_logo);
        View::share('types', $types);
        View::share('event_code', $event_code);

        /* Ako pristupaš novom activityu, nemoj iz URL-a čitati mailing_activity_code već napravi novi */
        if ($mailing_activity_code == "") {
            $mailing_activity_code = $this->GetHash();
        }


        $this->GetEmailMailingsData($event_code, $mailing_activity_code);
        $this->DefaultEventInfo($event_code);
        View::share('mailing_activity_code', $mailing_activity_code);
    View::share('title', 'E-mail Design - ' . $event_info['name']);


        return view('events/mailings/email-design');
    }


    public function GetHash(){
        return 'em' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }


    /**
     * Dohvati podatke o mail activitiju na eventu ako postoji
     * @param $event_code
     * @param $mailing_activity_code
     */
    public function GetEmailMailingsData($event_code, $mailing_activity_code = ''){
        $id = DB::table('mailing_activities')
            ->select(array('events.id as id',
                            'event_look_feels.event_logo_url as url',
                            'mailing_activities.mailing_activity_code',
                            'mailing_activities.header_img_url',
                            'mailing_activities.logo_url',
                            'color_schemes.titles_color',
                            'color_schemes.background_color'))
                        ->leftJoin('events','mailing_activities.event_id','=','events.id')
                        ->leftJoin('event_look_feels','event_look_feels.id','=','events.event_look_and_feel_id')
                        ->leftJoin('color_schemes','color_schemes.id','=','event_look_feels.color_scheme_id')
                        ->where('events.event_code',$event_code)
                        ->where('mailing_activities.mailing_activity_code',$mailing_activity_code)
                        ->get();

    //todo ako nema logo url-a

        if(count($id) > 0){
            //to array
            $id = json_decode(json_encode($id[0]),true);

            $data = DB::table('mailing_activities')
                ->where('event_id', $id['id'])
                ->where('mailing_activities.mailing_activity_code',$mailing_activity_code)
                ->get();

            //to array
            $data = json_decode(json_encode($data[0]),true);
            View::share('data', $data);
            View::share('id', $id);
        }
    }


    /**
     * Podaci eventa
     * @param [[Type]] $event_code [[Description]]
     */
    public function DefaultEventInfo($event_code){
        $originalData = DB::table('events')
            ->select(array('color_schemes.titles_color',
                'color_schemes.background_color',
                'event_look_feels.event_logo_url as url'))
            ->leftJoin('event_look_feels','event_look_feels.id','=','events.event_look_and_feel_id')
            ->leftJoin('color_schemes','color_schemes.id','=','event_look_feels.color_scheme_id')
            ->where('events.event_code',$event_code)
            ->get();

        $originalData = json_decode(json_encode($originalData[0]),true);

        View::share('originalData', $originalData);
    }

    public function SaveWysiwygImage(Request $request){
        if(Input::file('img')) {
            $event_code = $request->input('event_code');
			$img_extension = Input::file('img')->getClientOriginalExtension();
			$img_name_uniq = uniqid() . '.' . $img_extension;
            Input::file('img')->move(public_path() . '/images/mail/' . $event_code, $img_name_uniq);
			$img_url = env('APP_URL') . '/images/mail/' . $event_code . '/' . $img_name_uniq;
			return $img_url;
		} else {
			return '#';
		}
    }

    public function UploadFile(Request $request)
    {
        if(!Input::file('file')) return 'There was an error with upload, please try again!';

        $event_code = $request->input('event_code');
        $file_extension = Input::file('file')->getClientOriginalExtension();
        $file_name_uniq = uniqid() . '.' . $file_extension;
        Input::file('file')->move(public_path() . '/files/' . $event_code, $file_name_uniq);
        return env('APP_URL') . '/files/' . $event_code . '/' . $file_name_uniq;
    }
}
