<?php

namespace App\Http\Controllers\Events\Mailings;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;
use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Carbon\Carbon;
use Auth;
use Datatables;
use Excel;
use App\Lead as Lead;
use App\DataTables\UsersDataTable;
use Redirect;
use Session;
use File;
use Illuminate\Support\Facades\Cache;

class MailingListController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/select2/dist/css/select2.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/css/jasny-bootstrap-fileinput.min.css'
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/bootstrap-switch/dist/js/bootstrap-switch.min.js',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/js/jasny-bootstrap-fileinput.js'
        ];

        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js',
          '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/js/select2.min.js',
          '//cdnjs.cloudflare.com/ajax/libs/yadcf/0.9.4/jquery.dataTables.yadcf.min.js',
        ];

        // pass variable to view
        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('js', $this->js);
        View::share('title', 'Mailing List');

        View::share('extraClasses', 'krik-mailing-list');
    }


    public function getIndex($event_code, $mailing_activity_code) {
        $mailing_activities_count = DB::table('mailing_activities')
            ->where('mailing_activity_code', $mailing_activity_code)
            ->count();

        if ($mailing_activities_count >= 2) {
            DB::table('mailing_activities')
                ->where('mailing_activity_code', $mailing_activity_code)
                ->take($mailing_activities_count - 1)
                ->delete();
        }

        $mailing_activity_id = DB::table('mailing_activities')
                               ->where('mailing_activity_code', $mailing_activity_code)
                               ->pluck('id');
        $nmbrOfMailings = DB::table('mailings')
                          ->where('mailing_activity_id', $mailing_activity_id[0])
                          ->whereNull('deleted_at')
                          ->count();

        $leadIDs = DB::table('leads')
                    ->join('mailings','mailings.lead_id','=','leads.id')
                    ->join('mailing_activities','mailing_activities.id','=','mailings.mailing_activity_id')
                    ->where('mailing_activities.mailing_activity_code', $mailing_activity_code)
                    ->whereNull('mailings.deleted_at')
                    ->whereNull('leads.deleted_at')
                    ->whereNotNull('leads.created_at')
					->distinct()
                    ->pluck('leads.id');

        $allEventContacts = DB::table('events')
                            ->join('mailing_activities','mailing_activities.event_id', '=', 'events.id')
                            ->join('mailings','mailings.mailing_activity_id', '=', 'mailing_activities.id')
                            ->join('leads','mailings.lead_id','=','leads.id')
                            ->where('events.event_code', $event_code)
                            ->whereNull('mailings.deleted_at')
                            ->whereNull('leads.deleted_at')
                            ->whereNotNull('leads.created_at')
							->distinct()
                            ->pluck('leads.id');

        $allRegistratedContatcs = DB::table('events')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->join('mailings','leads.id', '=', 'mailings.lead_id')
                                ->join('mailing_activities','mailing_activities.id', '=', 'mailings.mailing_activity_id')
                                ->where('events.event_code', $event_code)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->where(function($query) {
                                    $query->where('registrations.ticket_approved', null)
                                        ->orWhere('registrations.ticket_approved',1);
                                })
                                ->whereNull('mailings.deleted_at')
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->pluck('leads.id');

        $allNotRegistratedContacts = array_diff($allEventContacts, $allRegistratedContatcs);

        $allAttendedContacts = DB::table('events')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->join('mailings','leads.id', '=', 'mailings.lead_id')
                                ->join('mailing_activities','mailing_activities.id', '=', 'mailings.mailing_activity_id')
                                ->where('events.event_code', $event_code)
                                ->where('registrations.event_attended_flag', 1)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->whereNull('mailings.deleted_at')
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->pluck('leads.id');

        $allNotAttendedContacts = DB::table('events')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->join('mailings','leads.id', '=', 'mailings.lead_id')
                                ->join('mailing_activities','mailing_activities.id', '=', 'mailings.mailing_activity_id')
                                ->where('events.event_code', $event_code)
                                ->where('registrations.event_attended_flag', 0)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->where(function($query) {
                                    $query->where('registrations.ticket_approved', null)
                                        ->orWhere('registrations.ticket_approved',1);
                                })
                                ->whereNull('mailings.deleted_at')
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->pluck('leads.id');

        //za postavljanje stanja switcheva
        if(!empty($leadIDs)){
            if(!empty($allEventContacts)){
                $containsAllEventContacts = 0 == count(array_diff($allEventContacts,  $leadIDs));
                if($containsAllEventContacts)
                    View::share('allInvited', 'true');
            }
			if(!empty($allRegistratedContatcs)){
                $containsAllRegistratedContatcs = 0 == count(array_diff($allRegistratedContatcs,  $leadIDs));
                    if($containsAllRegistratedContatcs)
                        View::share('registrated', 'true');
            }
			if(!empty($allNotRegistratedContacts)){
                $containsAllNotRegistratedContacts = 0 == count(array_diff($allNotRegistratedContacts,  $leadIDs));
                    if($containsAllNotRegistratedContacts)
                        View::share('notRegistrated', 'true');
            }
			if(!empty($allAttendedContacts)){
                $containsAllAttendedContacts = 0 == count(array_diff($allAttendedContacts,  $leadIDs));
                    if($containsAllAttendedContacts)
                        View::share('attended', 'true');
            }
			if(!empty($allNotAttendedContacts)){
                $containsAllNotAttendedContacts = 0 == count(array_diff($allNotAttendedContacts,  $leadIDs));
                    if($containsAllNotAttendedContacts)
                        View::share('notAttended', 'true');
            }
        }


        $event_info = DB::table('events')
            ->select(array('type_by_venue as venue',
                'venue_name as v_name',
                'venue_address as address',
                'venue_city as city',
                'venue_postal_code as postal',
                'countries.country_name as country',
                'start_ts as start',
                'end_ts as end',
                'name',
                'events.id'))
            ->leftJoin('countries','countries.id','=','events.venue_country_id')
            ->where('event_code', $event_code)
            ->get();

        $event_has_accommodations = $this->eventHasAccommodations($event_info[0]->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info[0]->id);
        View::share('event_has_transfers', $event_has_transfers);

        $event_info = json_decode(json_encode($event_info[0]),true);

        View::share('event_info', $event_info);
        View::share('nmbrOfMailings', $nmbrOfMailings);
        View::share('allEventContacts', $allEventContacts);
        View::share('allRegistratedContatcs', $allRegistratedContatcs);
        View::share('allNotRegistratedContacts', $allNotRegistratedContacts);
        View::share('allAttendedContacts', $allAttendedContacts);
        View::share('allNotAttendedContacts', $allNotAttendedContacts);

        View::share('mailing_activity_code', $mailing_activity_code);
        View::share('event_code', $event_code);
        View::share('mailing_activity_id', $mailing_activity_id[0]);
          View::share('title', 'Mailing List - ' . $event_info['name']);
          
        $settings = DB::table('settings')->first();
        View::share('settings', $settings);

        return view('events/mailings/mailing-list');
    }


    /**
     * Vrati sve registrirane kontakte na eventu za manually choose contacts tablicu
     */
    public function anyData(Request $request)
    {
        $settings = DB::table('settings')->first();

        $mailing_activity = DB::table('mailing_activities')
            ->where('mailing_activity_code', $request->input('mailing_code'))
            ->first();

        $leads = Cache::remember('mailings-table', 1440, function () use ($settings) {
            if ($settings->lead_types && $settings->lead_type_descriptions) {
                $leads = DB::table('leads')
                    ->leftJoin('lead_types', 'leads.lead_type_id', '=', 'lead_types.id')
                    ->leftJoin('lead_has_type_descriptions', 'leads.id', '=', 'lead_has_type_descriptions.lead_id')
                    ->leftJoin('lead_type_descriptions', 'lead_has_type_descriptions.lead_type_description_id', '=', 'lead_type_descriptions.id')
                    ->selectRaw('
                        leads.id,
                        leads.company_name,
                        CONCAT(leads.first_name, " ",  leads.last_name) AS full_name,
                        leads.email,
                        lead_types.name AS type,
                        GROUP_CONCAT(DISTINCT lead_type_descriptions.name SEPARATOR ", ") AS type_description
                    ')
                    ->whereNull('leads.deleted_at')
                    ->whereNotNull('leads.created_at')
                    ->groupBy('leads.id')
                    ->get();
            } else if ($settings->lead_types) {
                $leads = DB::table('leads')
                    ->leftJoin('lead_types', 'leads.lead_type_id', '=', 'lead_types.id')
                    ->selectRaw('
                        leads.id,
                        leads.company_name,
                        CONCAT(leads.first_name, " ",  leads.last_name) AS full_name,
                        leads.email,
                        lead_types.name AS type
                    ')
                    ->whereNull('leads.deleted_at')
                    ->whereNotNull('leads.created_at')
                    ->get();
            } else {
                $leads = DB::table('leads')
                    ->leftJoin('lead_has_type_descriptions', 'leads.id', '=', 'lead_has_type_descriptions.lead_id')
                    ->leftJoin('lead_type_descriptions', 'lead_has_type_descriptions.lead_type_description_id', '=', 'lead_type_descriptions.id')
                    ->selectRaw('
                        leads.id,
                        leads.company_name,
                        CONCAT(leads.first_name, " ",  leads.last_name) AS full_name,
                        leads.email,
                        GROUP_CONCAT(DISTINCT lead_type_descriptions.name SEPARATOR ", ") AS type_description
                    ')
                    ->whereNull('leads.deleted_at')
                    ->whereNotNull('leads.created_at')
                    ->groupBy('leads.id')
                    ->get();
            }

            return $leads;
        });
        
        $leads_selected = DB::table('mailings')
            ->where('mailing_activity_id', $mailing_activity->id)
            ->whereNull('mailings.deleted_at')
            ->get();
        
        $leads_selected = collect($leads_selected);
        $leads_combined = collect();

        foreach($leads as $lead) {
            if ($leads_selected->contains('lead_id', $lead->id)) {
                $leads_combined->push([
                    'id' => $lead->id,
                    'company_name' => $lead->company_name,
                    'full_name' =>  $lead->full_name,
                    'email' =>  $lead->email,
                    'type' => ($settings->lead_types) ? $lead->type : '',
                    'type_description' => ($settings->lead_type_descriptions) ? $lead->type_description : '',
                    'status' => 'Invited'
                ]);
            } else {
                $leads_combined->push([
                    'id' => $lead->id,
                    'company_name' => $lead->company_name,
                    'full_name' =>  $lead->full_name,
                    'email' =>  $lead->email,
                    'type' => ($settings->lead_types) ? $lead->type : '',
                    'type_description' => ($settings->lead_type_descriptions) ? $lead->type_description : '',
                    'status' => 'Not Invited'
                ]);
            }
        }

        return Datatables::of($leads_combined)->make(true);
    }


    public function AddContactsToMailing($event_code, $mailing_activity_code, Request $request) {
        $mailing_activity_id = DB::table('mailing_activities')
                                ->where('mailing_activity_code', $mailing_activity_code)
                                ->pluck('id');

        $type = $request->input('inviteType');
        $action = $request->input('action');

        $choosen_leads = $request->input('choosen-leads');
        if((is_array($choosen_leads) ? count($choosen_leads) : 0) > 0) $choosen_leads = array_unique($choosen_leads);

        $leads = DB::table('leads')
                    ->whereIn('id', $choosen_leads)
                    ->get();

		$return_send = $request->input('go-to-send') ? true : false;
		$save_draft = $request->input('draft') ? true : false;

		$already_invited =  DB::table('mailings')
							->where('mailing_activity_id', $mailing_activity_id[0])
                            ->whereNull('deleted_at')
                            ->pluck('lead_id');

        if ($type){
            if($type == 'inviteAll'){
                $typeLeads = DB::table('events')
                                ->select('leads.id')
                                ->join('mailing_activities','mailing_activities.event_id','=','events.id')
                                ->join('mailings','mailings.mailing_activity_id', '=', 'mailing_activities.id')
                                ->join('leads','mailings.lead_id','=','leads.id')
                                ->where('events.event_code', $event_code)
                                ->whereNull('mailings.deleted_at')
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->get();
            }else if($type == 'registrated'){
                $typeLeads = DB::table('events')
                                ->select('leads.id')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->where('events.event_code', $event_code)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->where(function($query) {
                                    $query->where('registrations.ticket_approved', null)
                                        ->orWhere('registrations.ticket_approved',1);
                                })
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->get();
            }else if($type == 'notRegistrated'){
				$allEventContacts = DB::table('events')
                            ->join('mailing_activities','mailing_activities.event_id', '=', 'events.id')
                            ->join('mailings','mailings.mailing_activity_id', '=', 'mailing_activities.id')
                            ->join('leads','mailings.lead_id','=','leads.id')
                            ->where('events.event_code', $event_code)
                            ->whereNull('mailings.deleted_at')
                            ->whereNull('leads.deleted_at')
                            ->whereNotNull('leads.created_at')
							->distinct()
                            ->pluck('leads.id');

				$allRegistratedContatcs = DB::table('events')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->join('mailings','leads.id', '=', 'mailings.lead_id')
                                ->join('mailing_activities','mailing_activities.id', '=', 'mailings.mailing_activity_id')
                                ->where('events.event_code', $event_code)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->whereNull('mailings.deleted_at')
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->pluck('leads.id');

        		$typeLeads  = array_diff($allEventContacts, $allRegistratedContatcs);
            }else if($type == 'attended'){
                $typeLeads = DB::table('events')
                                ->select('leads.id')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->where('events.event_code', $event_code)
                                ->where('registrations.event_attended_flag', 1)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->get();
            }else if($type == 'notAttended'){
                $typeLeads = DB::table('events')
                                ->select('leads.id')
                                ->join('registrations','registrations.event_id','=','events.id')
                                ->join('leads','registrations.lead_id','=','leads.id')
                                ->where('events.event_code', $event_code)
                                ->where('registrations.event_attended_flag', 0)
                                ->where(function($query) {
                                    $query->whereNotNull('registrations.registered_ts')
                                        ->orWhereNotNull('registrations.confirmed_ts');
                                })
                                ->where(function($query) {
                                    $query->where('registrations.ticket_approved', null)
                                        ->orWhere('registrations.ticket_approved',1);
                                })
                                ->whereNull('leads.deleted_at')
                                ->whereNotNull('leads.created_at')
								->distinct()
                                ->get();
            }
            if($action == 'invite'){
                foreach ($typeLeads as $key => $lead) {
					if(is_object($lead)){
						$id = $lead->id;
					} else {
						$id = $lead;
					}
					if(!in_array($id,$already_invited)){
						DB::table('mailings')
						->insert([
							'mailing_activity_id' => $mailing_activity_id[0],
							'lead_id' => $id
						]);
					}
                }

                $mailing_activity_status = DB::table('mailing_activities')
                    ->where('mailing_activity_code', $mailing_activity_code)
                    ->value('is_draft');

                if ($typeLeads && $mailing_activity_status == null) {
                    DB::table('mailing_activities')
                        ->where('mailing_activity_code', $mailing_activity_code)
                        ->update([
                            'is_draft' => 1
                        ]);

                    // New e-mail campaign draft
                    $this->Log(171, $mailing_activity_id[0]);
                }
            }else{
                $app_timezone = DB::table('timezones')
                    ->where('id', env('APP_TIME_ZONE',58))
                    ->value('timezone');

                foreach ($typeLeads as $key => $lead) {
                    $timestamp = Carbon::now()
                    ->setTimezone($app_timezone)
                    ->format('Y-m-d H:i:s');
					if(is_object($lead)){
						$id = $lead->id;
					} else {
						$id = $lead;
					}
                    // soft delete mailings
                    DB::table('mailings')
                    ->where('mailing_activity_id', $mailing_activity_id[0])
                    ->where('lead_id', $id)
                    ->whereNull('deleted_at')
                    ->update([
                        'deleted_at' => $timestamp
                    ]);
                }
            }

		//treba za excel
        } elseif($request->input('save') == "Select" || $return_send || $save_draft) {
            foreach ($leads as $key => $lead) {
				if(!in_array($lead->id, $already_invited)){
				DB::table('mailings')->insert([
					'mailing_activity_id' => $mailing_activity_id[0],
					'lead_id' => $lead->id
				]);
				}
            }

            $mailing_activity_status = DB::table('mailing_activities')
                ->where('mailing_activity_code', $mailing_activity_code)
                ->value('is_draft');

            if ($leads && $mailing_activity_status == null) {
                DB::table('mailing_activities')
                    ->where('mailing_activity_code', $mailing_activity_code)
                    ->update([
                        'is_draft' => 1
                    ]);

                // New e-mail campaign draft
                $this->Log(171, $mailing_activity_id[0]);
            }
        } elseif ($request->input('save') == "Deselect") {
            $app_timezone = DB::table('timezones')
                ->where('id', env('APP_TIME_ZONE',58))
                ->value('timezone');
            foreach ($leads as $key => $lead) {
                $timestamp = Carbon::now()
                    ->setTimezone($app_timezone)
                    ->format('Y-m-d H:i:s');
                DB::table('mailings')
                ->where('mailing_activity_id', $mailing_activity_id[0])
                ->where('lead_id', $lead->id)
                ->whereNull('deleted_at')
                ->update([
                    'deleted_at' => $timestamp
                ]);
            }
        }

		if($return_send){
			return Redirect::route('send', array($event_code,$mailing_activity_code));
		} elseif($save_draft) {
            $mailing_activity_is_draft = DB::table('mailing_activities')
                ->where('mailing_activity_code', $mailing_activity_code)
                ->value('is_draft');

            if(!$mailing_activity_is_draft == 1) {
                // New e-mail campaign draft
                $this->Log(171, $mailing_activity_id[0]);
            }

			DB::table('mailing_activities')
			->where('mailing_activity_code', $mailing_activity_code)
			->update(['is_draft' => 1]);
			return Redirect::route('all-mailings', array($event_code));
		} else {
			View::share('choosen_leads', $choosen_leads);
			return $this->getIndex($event_code, $mailing_activity_code);
		}
    }


    /**
     * Spremi u bazu ili editiraj u bazi ako već postoji design
     * @param $event_code
     * @param $mailing_activity_code
     * @param Request $request
     * @return View
     */
    public function SaveEmailDesign($event_code, $mailing_activity_code, Request $request)
    {
        $event_info = DB::table('events')
          ->where('event_code', $event_code)
          ->first();

        $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info->id);
        View::share('event_has_transfers', $event_has_transfers);

        if ($request->input('edit') != 'no data') {

            $mailing_activity_id = DB::table('mailing_activities')
              ->where('mailing_activity_code', $mailing_activity_code)
              ->pluck('id');

            View::share('event_code', $event_code);
            View::share('mailing_activity_id', $mailing_activity_id[0]);
            $this->UpdateActivity($request, $event_code, $mailing_activity_code);
            View::share('mailing_activity_code', $mailing_activity_code);

            // Updated e-mail campaign
            $this->Log(173, $mailing_activity_id[0]);

            return view('events/mailings/mailing-list');

        } else {
            $mailing_activity_id = $this->SaveActivity($request, $event_code, $mailing_activity_code);

            View::share('event_code', $event_code);
            View::share('mailing_activity_id', $mailing_activity_id);
            View::share('mailing_activity_code', $mailing_activity_code);

            return $this->getIndex($event_code, $mailing_activity_code);
        }

    }

    /**
     * Uploadaj logo ako već ne postoji
     * @param  forma  $request
     *                            @param  string $event_code
     * @return string string
     */
    public function UploadLogo($request ,$event_code,$mailing_activity_code){
        if($request->file('upload_logo') && $request->input('logo') == 'upload_logo_cb'){
            $header = $request->file('upload_logo');
            $header->move(public_path() . '/images/mail/' . $event_code, $header->getClientOriginalName());
            $filepath = env('APP_URL') . '/images/mail/' . $event_code . '/' . $header->getClientOriginalName();
        }else if($request->file('upload_logo_update') && $request->input('logo') == 'upload_logo_cb'){
            $header = $request->file('upload_logo_update');
            $header->move(public_path() . '/images/mail/' . $event_code, $header->getClientOriginalName());
            $filepath = env('APP_URL') . '/images/mail/' . $event_code . '/' . $header->getClientOriginalName();
        }else if(!$request->file('upload_logo_update') && $request->input('logo') == 'upload_logo_cb'){
            $logo = DB::table('events')
                    ->join('mailing_activities','events.id', '=', 'mailing_activities.event_id')
                    ->where('events.event_code',$event_code)
                    ->where('mailing_activities.mailing_activity_code',$mailing_activity_code)
                    ->pluck('logo_url');
            $filepath = $logo[0];
        }

        if($request->input('logo') == 'event_logo'){
            //predifined logo url
            $logo = DB::table('events')
                    ->join('event_look_feels','event_look_feels.id', '=', 'events.event_look_and_feel_id')
                    ->where('event_code',$event_code)
                    ->pluck('event_logo_url');
            $filepath = $logo[0];
        }else if($request->input('logo') == 'no_logo'){
            $filepath = NULL;
        }

        return $filepath;
    }


    /**
     * Upload banner
     * @param  forma $request
     * @param  string $event_code
     * @return string
     */
    public function UploadBanner($request,$event_code,$mailing_activity_code){
        if($request->file('upload') && $request->input('mailing_type') == 'upload'){
            $header = $request->file('upload');
            $header->move(public_path() . '/images/mail/'.$event_code, $header->getClientOriginalName());
            $filepath = env('APP_URL') . '/images/mail/' . $event_code . '/' . $request->file('upload')->getClientOriginalName();
        }else if($request->file('upload_update') && $request->input('mailing_type') == 'upload'){
            $header = $request->file('upload_update');
            $header->move(public_path() . '/images/mail/'.$event_code, $header->getClientOriginalName());
            $filepath = env('APP_URL') . '/images/mail/' . $event_code . '/' . $request->file('upload_update')->getClientOriginalName();
        }else if(!$request->file('upload_update') && $request->input('mailing_type') == 'upload'){
            $banner = DB::table('events')
                    ->join('mailing_activities','events.id', '=', 'mailing_activities.event_id')
                    ->where('events.event_code',$event_code)
                    ->where('mailing_activities.mailing_activity_code',$mailing_activity_code)
                    ->pluck('header_img_url');
            $filepath = $banner[0];
        }else{
            $filepath = NULL;
        }
        return $filepath;
    }




    public function SaveActivity($request, $event_code, $mailing_activity_code){
        $event_id = DB::table('events')
                    ->where('event_code', $event_code)
                    ->pluck('id');
        $now = $this->Now();
        
        // Custom HTML
        if ($request->input('custom-html') == 'custom_html') {
            $mailing_activity_id = DB::table('mailing_activities')
                  ->insertGetId([
                       'mailing_activity_code' => $mailing_activity_code,
                       'name'                  => $request->input('activity_name'),
                       'mailing_type_id'       => $request->input('type'),
                       'event_id'              => $event_id[0],
                       'description'           => $request->input('description'),
                       'created_by_id'         => Auth::user()->id,
                       'created_at'            => $now,
                       'ics_included'          => $request->input('ics') == 'ics_included' ? 1 : 0,
                       'custom_html'           => 1,
                       'body_html'             => $request->input('body_html')
            ]);
            
            return $mailing_activity_id;
        }

        if($request->input('mailing_type') == 'choose')
            $filepathLogo   = $this->UploadLogo($request,$event_code,$mailing_activity_code);

        if($request->input('mailing_type') == 'upload')
            $filepathBanner = $this->UploadBanner($request,$event_code,$mailing_activity_code);

    $body_text = str_replace('&nbsp;', ' ',$request->input('body_text'));
    $toFind = '-bordered"';
    $start = 0;
    while( ($pos = strpos(($body_text),$toFind,$start)) != false) {
        if(substr($body_text,$pos + 11,5) != "width"){
            $str_to_insert = ' width="100%" cellpadding="0" cellspacing="0" style="border-collapse: collapse; border: 1px solid #ddd;"';
            $body_text = substr_replace($body_text, $str_to_insert, $pos + 10, 0);
        }
        $start = $pos+1; // start searching from next position.
    }
    $start = 0;
    $toFind = '<td';
    while( ($pos = strpos(($body_text),$toFind,$start)) != false) {
        if(substr($body_text,$pos + 4,5) != "style"){
            $str_to_insert = ' style="padding: 8px; background-color: #FBFBFB; border: 1px solid #ddd;" ';
            $body_text = substr_replace($body_text, $str_to_insert, $pos + 3, 0);
        }
        $start = $pos+1; // start searching from next position.
    }

        $mailing_activity_id = DB::table('mailing_activities')
              ->insertGetId([
                   'mailing_activity_code'=> $mailing_activity_code,
                   'name'                => $request->input('activity_name'),
                   'mailing_type_id'     => $request->input('type'),
                   'event_id'            => $event_id[0],
                   'description'         => $request->input('description'),
                   'created_by_id'       => Auth::user()->id,
                   'created_at'          => $now,
                   'sidebar_included'    => $request->input('sidebar') == 'sidebar_included' ? 1 : 0,
                   'ics_included'        => $request->input('ics') == 'ics_included' ? 1 : 0,
                   'header_img_url'      => $request->input('mailing_type') == 'upload' ? $filepathBanner : NULL,
                   'logo_url'            => $request->input('mailing_type') == 'choose' ? $filepathLogo : NULL,
                   'background_color'    => $request->input('mailing_type') == 'choose' ? (strlen($request->input('bgColor')) > 0 ? $request->input('bgColor') : '#4a4a4a') : NULL,
                   'titles_color'        => $request->input('mailing_type') == 'choose' ? (strlen($request->input('titleColor')) > 0 ? $request->input('titleColor') : '#fff') : NULL,
                   'header_text'         => $request->input('mailing_type') == 'choose' ? $request->input('header_text') : NULL,
                   'body_wysiwyg'        => $body_text,
                   'register_button'     => $request->input('call_to_action') == 'Register' ? 1 : 0,
                   'confirm_button'      => $request->input('call_to_action') == 'Confirm' ? 1 : 0,
                   'unsubscribe_text'    => $request->input('unsub') == 'unsubscribe' ? $request->input('unsubscribe_text') : NULL,
                   'copyright_statement' => $request->input('copy') == 'copyright' ? $request->input('copyright_statement') : NULL
        ]);

        return $mailing_activity_id;
    }

    /**
     * Update ako se radi o već postojećem email activitiju
     * @param  forma $request
     * @param  string $event_code
     * @return int
     */
    public function UpdateActivity($request, $event_code, $mailing_activity_code){
        $now = $this->Now();
        
        // Custom HTML
        if ($request->input('custom-html') == 'custom_html') {
            DB::table('mailing_activities')
            ->where('mailing_activity_code', $mailing_activity_code)
            ->update([
                       'name'                => $request->input('activity_name'),
                       'mailing_type_id'     => $request->input('type'),
                       'description'         => $request->input('description'),
                       'updated_by_id'       => Auth::user()->id,
                       'updated_at'          => $now,
                       'sidebar_included'    => 0,
                       'ics_included'        => $request->input('ics') == 'ics_included' ? 1 : 0,
                       'header_img_url'      => NULL,
                       'logo_url'            => NULL,
                       'background_color'    => NULL,
                       'titles_color'        => NULL,
                       'header_text'         => NULL,
                       'body_wysiwyg'        => NULL,
                       'register_button'     => 0,
                       'confirm_button'      => 0,
                       'unsubscribe_text'    => NULL,
                       'copyright_statement' => NULL,
                       'custom_html'         => 1,
                       'body_html'           => $request->input('body_html')
            ]);
            
            return $this->getIndex($event_code, $mailing_activity_code);
        }

        if($request->input('mailing_type') == 'choose')
            $filepathLogo   = $this->UploadLogo($request,$event_code,$mailing_activity_code);

        if($request->input('mailing_type') == 'upload')
            $filepathBanner = $this->UploadBanner($request,$event_code,$mailing_activity_code);

    $body_text = str_replace('&nbsp;', ' ',$request->input('body_text'));
    $toFind = '-bordered"';
    $start = 0;
    while( ($pos = strpos(($body_text),$toFind,$start)) != false) {
        if(substr($body_text,$pos + 11,5) != "width"){
            $str_to_insert = ' width="100%" cellpadding="0" cellspacing="0" style="border-collapse: collapse; border: 1px solid #ddd;"';
            $body_text = substr_replace($body_text, $str_to_insert, $pos + 10, 0);
        }
        $start = $pos+1; // start searching from next position.
    }
    $start = 0;
    $toFind = '<td';
    while( ($pos = strpos(($body_text),$toFind,$start)) != false) {
        if(substr($body_text,$pos + 4,5) != "style"){
            $str_to_insert = ' style="padding: 8px; background-color: #FBFBFB; border: 1px solid #ddd;" ';
            $body_text = substr_replace($body_text, $str_to_insert, $pos + 3, 0);
        }
        $start = $pos+1; // start searching from next position.
    }

        DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->update([
                   'name'                => $request->input('activity_name'),
                   'mailing_type_id'     => $request->input('type'),
                   'description'         => $request->input('description'),
                   'updated_by_id'       => Auth::user()->id,
                   'updated_at'          => $now,
                   'sidebar_included'    => $request->input('sidebar') == 'sidebar_included' ? 1 : 0,
                   'ics_included'        => $request->input('ics') == 'ics_included' ? 1 : 0,
                   'header_img_url'      => $request->input('mailing_type') == 'upload' ? $filepathBanner : NULL,
                   'logo_url'            => $request->input('mailing_type') == 'choose' ? $filepathLogo : NULL,
                   'background_color'    => $request->input('mailing_type') == 'choose' ? (strlen($request->input('bgColor')) > 0 ? $request->input('bgColor') : '#4a4a4a') : NULL,
                   'titles_color'        => $request->input('mailing_type') == 'choose' ? (strlen($request->input('titleColor')) > 0 ? $request->input('titleColor') : '#fff') : NULL,
                   'header_text'         => $request->input('mailing_type') == 'choose' ? $request->input('header_text') : NULL,
                   'body_wysiwyg'        => $body_text,
                   'register_button'     => $request->input('call_to_action') == 'Register' ? 1 : 0,
                   'confirm_button'      => $request->input('call_to_action') == 'Confirm' ? 1 : 0,
                   'unsubscribe_text'    => $request->input('unsub') == 'unsubscribe' ? $request->input('unsubscribe_text') : NULL,
                   'copyright_statement' => $request->input('copy') == 'copyright' ? $request->input('copyright_statement') : NULL,
                   'custom_html'         => 0,
                   'body_html'           => NULL
        ]);

        return $this->getIndex($event_code, $mailing_activity_code);



    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEventInfo($event_code) {
        $event_info = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
            ->leftJoin('color_schemes', 'event_look_feels.id', '=', 'color_schemes.id')
            ->select('events.id', 'events.name', 'events.start_ts', 'events.type_by_venue', 'events.venue_name', 'color_schemes.background_color', 'color_schemes.titles_color')
            ->where('event_code', '=', $event_code)
            ->first();

        return $event_info;
    }

    public function GetLeadCode(){
       return 'ld' . rand(1000, 10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
   }


    public function InsertImportLead(Request $request, $event_code, $mailing_activity_code) {

      $event_info = $this->GetEventInfo($event_code);
    if(Input::file('upload_excel_invite')) $uploadedFile = Input::file('upload_excel_invite')->move(public_path() . '/excel', Input::file('upload_excel_invite')->getClientOriginalName());
      $excelFile = Excel::load($uploadedFile)->get();
      /*provjera da li je prazna*/
     if($excelFile->first()) {
       $firstrow = $excelFile->first()->toArray();
       $firstrowCount = count(array_values($firstrow));
     } else {
       return redirect()->back()
         ->with('excelfile', 'empty');
     }

     if($firstrowCount === 16)
     {
      $ignoreContacts = collect([]);
      $registerContactsFromExcel = collect([]);
      $importedContacts = collect([]);
      $notValids = collect([]);
      $zeros = collect([]);
      $sameContacts = collect([]);
      //$existsContactExcel = DB::table('leads')->pluck('email');

      $mailing_activity_id = DB::table('mailing_activities')
                             ->where('mailing_activity_code', $mailing_activity_code)
                             ->pluck('id');



         foreach ($excelFile as $row) {
           $row = array_values($row->toArray());
           if (isset($row[0])) {
             $contactGender = $row[0];
           } else {
             $contactGender = null;
           }
           if (isset($row[1])) {
             $contactTitle = $row[1];
           } else {
             $contactTitle = null;
           }
           if (isset($row[2])) {
             $contactFirstName = $row[2];
           } else {
             $contactFirstName = null;
           }
           if (isset($row[3])) {
             $contactLastName= $row[3];
           } else {
             $contactLastName = null;
           }
           if (isset($row[4])) {
             $contactEmail = $row[4];
           } else {
             $contactEmail = null;
           }
           if (isset($row[5])) {
             $contactMobile = $row[5];
           } else {
             $contactMobile = null;
           }
           if (isset($row[6])) {
             $contactPhone = $row[6];
           } else {
             $contactPhone = null;
           }
           if (isset($row[7])) {
             $contactCompanyName = $row[7];
           } else {
             $contactCompanyName = null;
           }
           if (isset($row[8])) {
             $contactJobFunction = $row[8];
           } else {
             $contactJobFunction = null;
           }
           if (isset($row[9])) {
             $contactCompanyAddress = $row[9];
           } else {
             $contactCompanyAddress = null;
           }
           if (isset($row[10])) {
             $contactCompanyCity = $row[10];
           } else {
             $contactCompanyCity = null;
           }
           if (isset($row[11])) {
             $contactCompanyPostalCode = $row[11];
           } else {
             $contactCompanyPostalCode = null;
           }
           if (isset($row[12])) {
             $contactCompanyCountry = $row[12];
           } else {
             $contactCompanyCountry = null;
           }
            $contactCompanyCountryId = DB::table('countries')->leftJoin('leads', 'countries.id', '=', 'leads.company_country')
                                      ->where('countries.country_name', '=', $contactCompanyCountry)
                                      ->pluck('countries.id');
            $contactCompanyCountryId = last($contactCompanyCountryId);
            $contactCompanyCountryName = DB::table('countries')
                                      ->where('countries.id', '=', $contactCompanyCountryId)
                                      ->pluck('countries.country_name');
            $contactCompanyCountryName = last($contactCompanyCountryName);
            if (isset($row[13])) {
              $contactNote = $row[13];
            } else {
              $contactNote = null;
            }
            
            // Lead type
            if (isset($row[14])) {
                $contactType = $row[14];
            } else {
                $contactType = null;
            }
            if ($contactType) {
                $contactTypeId = DB::table('lead_types')
                    ->where('name', $contactType)
                    ->first();
                if ($contactTypeId) {
                    $contactTypeId = $contactTypeId->id;
                } else {
                    $contactTypeId = DB::table('lead_types')
                        ->insertGetId([
                            'name' => $contactType
                        ]);
                }
            } else {
                $contactTypeId = null;
            }
            
            // Lead type descriptions
            if (isset($row[15])) {
                $contactTypeDesriptions = $row[15];
            } else {
                $contactTypeDesriptions = null;
            }
            
            
            $contactFirstName = trim($contactFirstName);
            $contactLastName = trim($contactLastName);
            $contactEmail = strtolower(preg_replace('/\s+/', '', $contactEmail));

            if($contactTitle !== null) {
                $titleString = substr($contactTitle, -1);

                if (!($titleString === '.' || $titleString === '')) {
                    $contactTitle = $contactTitle . '.';
                }
            }

            $checkContactExcel = Lead::firstOrNew(['email' => $contactEmail, 'deleted_at' => NULL]);

            if(!$checkContactExcel->exists)
            {
                $checkContactExcel->gender = $contactGender;
                $checkContactExcel->title = $contactTitle;
                if(!isset($contactTitle)){
                  $checkContactExcel->title = '';
                }
                $checkContactExcel->first_name = $contactFirstName;
                $checkContactExcel->last_name = $contactLastName;
                $checkContactExcel->email = $contactEmail;
                $checkContactExcel->mobile = $contactMobile;
                $checkContactExcel->phone = $contactPhone;
                $checkContactExcel->company_name = $contactCompanyName;
                $checkContactExcel->job_function = $contactJobFunction;
                $checkContactExcel->company_address = $contactCompanyAddress;
                $checkContactExcel->company_city = $contactCompanyCity;
                $checkContactExcel->company_post_code = $contactCompanyPostalCode;
                $checkContactExcel->company_country = $contactCompanyCountryId;
                $checkContactExcel->note = $contactNote;
                $checkContactExcel->lead_type_id = $contactTypeId;
                $checkContactExcel->lead_code = $this->GetLeadCode();
                $checkContactExcel->opt_in = 'Yes';
                $checkContactExcel->opt_in_method = 'email';
                $checkContactExcel->created_at = $this->Now();
                $checkContactExcel->updated_at = NULL;
                if ((EXCEL_FIRSTNAME == false || EXCEL_LASTNAME == false) && filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
                  $checkContactExcel->save();
                  $checkContactExcel->company_country = $contactCompanyCountryName;
                  $checkContactExcel->lead_type_id = $contactType;
                  $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                  $importedContacts->push($checkContactExcel);
                  
                  if ($contactTypeDesriptions) {
                      $typeDescriptions = explode(',', trim($contactTypeDesriptions));
                      
                      foreach($typeDescriptions as $key => $typeDescription) {
                          $lead_type_description_exists = DB::table('lead_type_descriptions')
                              ->where('name', trim($typeDescription))
                              ->first();
                              
                          if (!$lead_type_description_exists) {
                              $new_lead_type_description_id = DB::table('lead_type_descriptions')
                                  ->insertGetId([
                                      'name' => trim($typeDescription),
                                  ]);
                              
                              DB::table('lead_has_type_descriptions')
                                  ->insert(array(
                                      'lead_id' => $checkContactExcel->id,
                                      'lead_type_description_id' => $new_lead_type_description_id
                                  ));
                          } else {
                              DB::table('lead_has_type_descriptions')
                                  ->insert(array(
                                      'lead_id' => $checkContactExcel->id,
                                      'lead_type_description_id' => $lead_type_description_exists->id
                                  ));
                          }
                      }
                  }
                  
                  $leads = DB::table('leads')
                              ->where('email', $contactEmail)
                              ->whereNull('deleted_at')
                              ->get();
                  foreach ($leads as $key => $lead) {
                      DB::table('mailings')->insert([
                          'mailing_activity_id' => $mailing_activity_id[0],
                          'lead_id' => $lead->id
                      ]);
                  }
                }else {
                  if(!filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
                      if(filter_var($contactEmail, FILTER_VALIDATE_INT) === 0){
                        $checkContactExcel->company_country = $contactCompanyCountryName;
                        $checkContactExcel->lead_type_id = $contactType;
                        $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                        $zeros->push($checkContactExcel);
                      }else{
                        $checkContactExcel->company_country = $contactCompanyCountryName;
                        $checkContactExcel->lead_type_id = $contactType;
                        $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                        $notValids->push($checkContactExcel);
                      }
                      if(filter_var($contactEmail, FILTER_VALIDATE_INT) === 0 && isset($contactFirstName) && isset($contactFirstName)){
                        $checkContactExcel->company_country = $contactCompanyCountryName;
                        $checkContactExcel->lead_type_id = $contactType;
                        $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                        $notValids->push($checkContactExcel);
                      }
                   }
                   elseif (empty($contactFirstName)) {
                     $checkContactExcel->company_country = $contactCompanyCountryName;
                     $checkContactExcel->lead_type_id = $contactType;
                     $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                     $notValids->push($checkContactExcel);
                   }elseif (empty($contactLastName)) {
                     $checkContactExcel->company_country = $contactCompanyCountryName;
                     $checkContactExcel->lead_type_id = $contactType;
                     $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                     $notValids->push($checkContactExcel);
                   }
                   else {
                       $checkContactExcel->save();
                       $checkContactExcel->company_country = $contactCompanyCountryName;
                       $checkContactExcel->lead_type_id = $contactType;
                       $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                       $importedContacts->push($checkContactExcel);
                       
                       if ($contactTypeDesriptions) {
                           $typeDescriptions = explode(',', trim($contactTypeDesriptions));
                           
                           foreach($typeDescriptions as $key => $typeDescription) {
                               $lead_type_description_exists = DB::table('lead_type_descriptions')
                                   ->where('name', trim($typeDescription))
                                   ->first();
                                   
                               if (!$lead_type_description_exists) {
                                   $new_lead_type_description_id = DB::table('lead_type_descriptions')
                                       ->insertGetId([
                                           'name' => trim($typeDescription),
                                       ]);
                                   
                                   DB::table('lead_has_type_descriptions')
                                       ->insert(array(
                                           'lead_id' => $checkContactExcel->id,
                                           'lead_type_description_id' => $new_lead_type_description_id
                                       ));
                               } else {
                                   DB::table('lead_has_type_descriptions')
                                       ->insert(array(
                                           'lead_id' => $checkContactExcel->id,
                                           'lead_type_description_id' => $lead_type_description_exists->id
                                       ));
                               }
                           }
                       }
                       
                       $leads = DB::table('leads')
                                   ->where('email', $contactEmail)
                                   ->whereNull('deleted_at')
                                   ->get();
                       foreach ($leads as $key => $lead) {
                           DB::table('mailings')->insert([
                               'mailing_activity_id' => $mailing_activity_id[0],
                               'lead_id' => $lead->id
                           ]);
                       }
                   }
                }

            }
            else
            {
              if (empty($contactFirstName) && empty($contactLastName) && filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
                $checkContactExcel->company_country = $contactCompanyCountryName;
                $checkContactExcel->lead_type_id = $contactType;
                $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                $ignoreContacts->push($checkContactExcel);
                $leads = DB::table('leads')
                            ->where('email', $contactEmail)
                            ->whereNull('deleted_at')
                            ->get();
                foreach ($leads as $key => $lead) {
                    $alreadyInvited = DB::table('mailings')
                                        ->where([
                                          'lead_id' => $lead->id, 'mailing_activity_id' => $mailing_activity_id[0]
                                        ])
                                        ->whereNull('deleted_at')
                                        ->first();
                    if ($alreadyInvited==null){
                      DB::table('mailings')
                        ->insert([
                          'mailing_activity_id' => $mailing_activity_id[0],
                          'lead_id' => $lead->id
                      ]);
                    }
                }
              }

              elseif($checkContactExcel->first_name != $contactFirstName) {
                $checkContactExcel->first_name = $contactFirstName;
                $checkContactExcel->last_name = $contactLastName;
                $checkContactExcel->company_country = $contactCompanyCountryName;
                $checkContactExcel->lead_type_id = $contactType;
                $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                $sameContacts->push($checkContactExcel);
              }
              elseif ($checkContactExcel->last_name != $contactLastName) {
                $checkContactExcel->first_name = $contactFirstName;
                $checkContactExcel->last_name = $contactLastName;
                $checkContactExcel->company_country = $contactCompanyCountryName;
                $checkContactExcel->lead_type_id = $contactType;
                $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                $sameContacts->push($checkContactExcel);
              }
              else {
                $checkContactExcel->first_name = $contactFirstName;
                $checkContactExcel->last_name = $contactLastName;
                $checkContactExcel->company_country = $contactCompanyCountryName;
                $checkContactExcel->lead_type_id = $contactType;
                $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                
                  $leads = DB::table('leads')
                              ->where('email', $contactEmail)
                              ->whereNull('deleted_at')
                              ->get();
                    $app_timezone = DB::table('timezones')
                        ->where('id', env('APP_TIME_ZONE',58))
                        ->value('timezone');
                  foreach ($leads as $key => $lead) {
                      $timestamp = Carbon::now()
                        ->setTimezone($app_timezone)
                        ->format('Y-m-d H:i:s');
                      DB::table('mailings')
                          ->where('mailing_activity_id', $mailing_activity_id[0])
                          ->where('lead_id', $lead->id)
                          ->whereNull('deleted_at')
                          ->update([
                            'deleted_at' => $timestamp
                        ]);
                  }
            
                  foreach ($leads as $key => $lead) {
                      DB::table('mailings')->insert([
                          'mailing_activity_id' => $mailing_activity_id[0],
                          'lead_id' => $lead->id
                      ]);
                  }
                $ignoreContacts->push($checkContactExcel);
              }
            }
            /*ako je već regan*/
              $alreadyRegistratedContatcs = DB::table('events')
                                       ->join('registrations','registrations.event_id','=','events.id')
                                       ->join('leads','registrations.lead_id','=','leads.id')
                                       ->join('mailings','leads.id', '=', 'mailings.lead_id')
                                       ->join('mailing_activities','mailing_activities.id', '=', 'mailings.mailing_activity_id')
                                       ->where('events.event_code', $event_code)
                                       ->where('leads.email', $contactEmail)
                                       ->where(function($query) {
                                            $query->whereNotNull('registrations.registered_ts')
                                                ->orWhereNotNull('registrations.confirmed_ts');
                                        })
                                       ->whereNull('mailings.deleted_at')
                                       ->whereNull('leads.deleted_at')
                                       ->whereNotNull('leads.created_at')
                                       ->distinct()
                                       ->pluck('leads.email');

             $leads = DB::table('leads')
                         ->where('email', $contactEmail)
                         ->whereNull('deleted_at')
                         ->get();
               foreach ($alreadyRegistratedContatcs as $alreadyRegistratedContatc) {
                      if ($alreadyRegistratedContatc === $contactEmail) {

                      if (Input::get('already_registrated_contacts') == true) {
                        $app_timezone = DB::table('timezones')
                            ->where('id', env('APP_TIME_ZONE',58))
                            ->value('timezone');
                        foreach ($leads as $key => $lead) {
                             $timestamp = Carbon::now()
                                ->setTimezone($app_timezone)
                                ->format('Y-m-d H:i:s');
                            $alreadyInvited = DB::table('mailings')
                                                ->where([
                                                  'lead_id' => $lead->id, 'mailing_activity_id' => $mailing_activity_id[0]
                                                ])
                                                ->whereNull('deleted_at')
                                                ->first();
                            if ($alreadyInvited !== null){
                              DB::table('mailings')
                                  ->where('mailing_activity_id', $mailing_activity_id[0])
                                  ->where('lead_id', $lead->id)
                                  ->whereNull('deleted_at')
                                  ->update([
                                      'deleted_at' => $timestamp
                                  ]);
                            }
                            else{
                              DB::table('mailings')->insert([
                                  'mailing_activity_id' => $mailing_activity_id[0],
                                  'lead_id' => $lead->id
                              ]);
                            }
                        }
                      }
                    }
                    
                    $checkContactExcel->company_country = $contactCompanyCountryName;
                    $checkContactExcel->lead_type_id = $contactType;
                    $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                    
                      $registerContactsFromExcel->push($checkContactExcel);
               }
        }

      }
      else {
        return redirect()->back()
          ->with('excelfile', 'wrong');
      }
          File::delete($uploadedFile);
          $registerContactsFromExcel->toArray();
          $importedContacts->toArray();
          $ignoreContacts->toArray();
          $notValids->toArray();
          $sameContacts->toArray();
          $numberRegisterContact = $registerContactsFromExcel->count();
          $numberNewContact = $importedContacts->count();
          $numberExistsContact = $ignoreContacts->count();
          $numberNotValids = $notValids->count();
          $numberSameContact = $sameContacts->count();
          if ($numberNewContact > 0) {
            $this->Log(114, $numberNewContact);
          }

          session(['newContactExcelImports' => $importedContacts]);
          session(['numberNewContacts' => $numberNewContact]);
          session(['numberExistsContacts' => $numberExistsContact]);
          session(['existsContactExcels' => $ignoreContacts]);
          session(['notValids' => $notValids]);
          session(['numberNotValids' => $numberNotValids]);
          session(['sameContacts' => $sameContacts]);
          session(['numberSameContact' =>$numberSameContact]);
          session(['registerContactsFromExcel' => $registerContactsFromExcel]);
          session(['numberRegisterContactsFromExcel' => $numberRegisterContact]);
          session(['vrijednost' => Input::get('already_registrated_contacts')]);

          return Redirect::back();
  }
}
