<?php

namespace App\Http\Controllers\Events\Mailings;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Response;
use Datatables;

class PeopleEmailedSingleController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'

        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',

        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Pokaži popis svih leadova kojima su poslani mailing pozivi
     */
    public function PeopleEmailed($event_code, $mailing_activity_code) {
        $singleEvent = $this->GetEvent($event_code);

        if($singleEvent) {

            $singleActivity = $this->GetActivity($mailing_activity_code);

            if($singleActivity) {

                View::share('singleEvent', $singleEvent);
                View::share('event_code', $event_code);
                View::share('singleActivity', $singleActivity);
                View::share('mailing_activity_code', $mailing_activity_code);
                View::share('title', 'People emailed - ' . $singleEvent->name);

                $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
                View::share('event_has_accommodations', $event_has_accommodations);

                $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
                View::share('event_has_transfers', $event_has_transfers);

                return view('events/mailings/people-emailed-single');

            } else {

                return redirect()->route('home');

            }

        } else {

            return redirect()->route('home');

        }
    }


    /**
     * Dohvat podataka aod strane datatables dodatka
     * Dohvaćamo popis svih leadova na zatraženom eventu kojima je bio slan određeni mailing activity
     */
    public function anyData(Request $request) {
        $mailing_activity_code = $request->input('mailing_activity_code');

        $emailed_leads = DB::table('leads')
            ->join('mailings', 'leads.id', '=', 'mailings.lead_id')
            ->join('mailing_activities', 'mailings.mailing_activity_id', '=', 'mailing_activities.id')
            ->join('mailing_types', 'mailing_activities.mailing_type_id', '=', 'mailing_types.id')
            ->selectRaw('CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
                leads.email AS lead_email,
                DATE_FORMAT(leads.opt_out_ts, "%Y-%m-%d %H:%i") AS opt_out,
                mailing_activities.name AS activity_name,
                mailing_types.name AS activity_type,
                DATE_FORMAT(mailings.sent_ts, "%Y-%m-%d %H:%i") AS mailing_sent,
                DATE_FORMAT(mailings.email_opened_ts, "%Y-%m-%d %H:%i") AS mailing_opened')
            ->where('mailing_activities.mailing_activity_code', '=', $mailing_activity_code)
            ->where('mailing_activities.is_draft', 0)
            ->whereNull('mailings.deleted_at');

        return Datatables::of($emailed_leads)
          ->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
          ->filterColumn('opt_out', 'whereRaw', "DATE_FORMAT(leads.opt_out_ts, '%Y-%m-%d %H:%i') like ? ", ["$1"])
          ->filterColumn('mailing_sent', 'whereRaw', "DATE_FORMAT(mailings.sent_ts, '%Y-%m-%d %H:%i') like ? ", ["$1"])
          ->filterColumn('mailing_opened', 'whereRaw', "DATE_FORMAT(mailings.email_opened_ts, '%Y-%m-%d %H:%i') like ? ", ["$1"])
          ->make(true);

    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('events.event_code', '=', $event_code)
            ->first();

        return $singleEvent;
    }


    /**
     * Vrati podatke o zatraženom mailing activitiju
     */
    private function GetActivity($mailing_activity_code) {
        $singleActivity = DB::table('mailing_activities')
            ->where('mailing_activities.mailing_activity_code', '=', $mailing_activity_code)
            ->first();

        return $singleActivity;
    }
}
