<?php

namespace App\Http\Controllers\Events\Mailings;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use Auth;
use DB;
use Mail;
use Carbon\Carbon;
use Response;
use File;
use Image;
use Crypt;

class SendController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
            'global/plugins/bower_components/summernote/dist/summernote.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/moment/min/moment.min.js',
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.js'
        ];

        $this->js['additionalScripts'] = [
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Send');
        View::share('extraClasses', 'mailing_activity');
    }


    /**
     * Glavni view i postavljanje kontakata za js
     * @param $event_code
     * @param $mailing_activity_code
     * @param Request $request
     * @return View
     */
    public function GetSend($event_code, $mailing_activity_code, Request $request) {

        $mailing_list =  DB::table('mailing_activities')
                         ->join('mailings', 'mailings.mailing_activity_id', '=', 'mailing_activities.id')
                         ->join('leads', 'leads.id', '=', 'mailings.lead_id')
                         ->where('mailing_activities.mailing_activity_code', $mailing_activity_code)
                         ->whereNull('mailings.sent_ts')
                         ->whereNull('mailings.deleted_at')
                         ->select(array('leads.lead_code as code',
                                        'leads.title as title',
                                        'leads.first_name as f_name',
                                        'leads.last_name as l_name',
                                        'leads.email as mail',
                                        'leads.company_name as company',
                                        'leads.job_function as job',
                                        'leads.opt_in as opt',
                                        'opt_in_method as method'))
                         ->get();

        $event_info = DB::table('events')
            ->select(array('type_by_venue as venue',
                'venue_name as v_name',
                'venue_address as address',
                'venue_city as city',
                'venue_postal_code as postal',
                'countries.country_name as country',
                'start_ts as start',
                'end_ts as end',
                'name',
		        		'email_name',
                'email_sender',
                'events.id'))
            ->leftJoin('countries','countries.id','=','events.venue_country_id')
            ->where('event_code', $event_code)
            ->get();

        $event_has_accommodations = $this->eventHasAccommodations($event_info[0]->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($event_info[0]->id);
        View::share('event_has_transfers', $event_has_transfers);

        $event_info = json_decode(json_encode($event_info[0]),true);

        $mailing_activity = DB::table('mailing_activities')
          ->where('mailing_activity_code', $mailing_activity_code)
          ->first();
        View::share('mailing_activity', $mailing_activity);

        View::share('event_info', $event_info);
        View::share('mailing_list', $mailing_list);
        View::share('event_code', $event_code);
        View::share('mailing_activity_code', $mailing_activity_code);
        View::share('title', 'Send - ' . $event_info['name']);

        return view('events/mailings/send');
    }

    public function SetScheduledOrDraft($event_code, $mailing_activity_code, Request $request){
    $is_draft = $request->draft ? true : false;

    $mailing_activity_id = DB::table('mailing_activities')
      ->where('mailing_activity_code', $mailing_activity_code)
      ->value('id');

    if(!$is_draft){
      DB::table('mailing_activities')
      ->where('mailing_activity_code', $mailing_activity_code)
      ->update([
        "email_subject" => $request->subject,
        "email_from_name" => $request->from_name,
        "email_from_email" => $request->from_email,
        "email_replyto_email" => $request->replay_to,
        "mailing_process" => 4,
        "scheduled_ts" => Carbon::createFromFormat('d/m/Y H:i', $request->datetime)->toDateTimeString(),
        "is_draft" => 0
      ]);

      // New e-mail campaign
      $this->Log(172, $mailing_activity_id);
    }else{
      $mailing_activity_is_draft = DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->value('is_draft');

      if(!$mailing_activity_is_draft == 1) {
          // New e-mail campaign draft
          $this->Log(171, $mailing_activity_id);
      }

      DB::table('mailing_activities')
      ->where('mailing_activity_code', $mailing_activity_code)
      ->update([
        "email_subject" => $request->subject,
        "email_from_name" => $request->from_name,
        "email_from_email" => $request->from_email,
        "email_replyto_email" => $request->replay_to,
        "is_draft" => 1
      ]);
    }

        return 'Success';
    }


    /**
     * Slanje previewa
     * @param $event_code
     * @param $mailing_activity_code
     * @param Request $request
     * @return string
     */
    public function SendPreview($event_code, $mailing_activity_code, Request $request) {

      $mail_table = DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->get();

      $mail_table = json_decode(json_encode($mail_table[0]),true);
      
      $data['others'] = $request->input('others');
      $data['subject'] = $request->input('subject');
      $data['from_name'] = $request->input('from_name');
      $data['from_email'] = $request->input('from_email');
      $data['reply_to'] = $request->input('replay_to');
      $data['ics_included'] = $mail_table['ics_included'];

      $data['lang'] = DB::table('events')->where('event_code', $event_code)->value('lang');
      
      // Custom HTML
      if($mail_table['custom_html']) {
          $body_html = $mail_table['body_html'];
          $body_html = str_replace('{registration_link}', '#', $body_html);
    	  $body_html = str_replace('{confirmation_link}', '#', $body_html);
          $body_html = str_replace('{tracking_link}', '#', $body_html);
          $body_html = str_replace('{unsubscribe_link}', '#', $body_html);
          
          if(count($data['others']) > 0) {
    
            foreach($data['others'] as $email) {
    
              $lead = DB::table('leads')
                ->where('email', $email)
                ->first();
    
              if($lead) {
                $body_html = str_replace('{lead_title}', $lead->title, $body_html);
                $body_html = str_replace('{lead_first_name}', $lead->first_name, $body_html);
                $body_html = str_replace('{lead_last_name}', $lead->last_name, $body_html);
                $body_html = str_replace('{lead_email}', $lead->email, $body_html);
    
    			// Variacije pozdrava u pravom licu
    			$body_html = $this->leadAlias($body_html, $lead);
                
                // Lead barcode
                $leadRregistration = DB::table('leads')
                    ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
                    ->where('leads.email', $email)
                    ->where('registrations.event_id', $mail_table['event_id'])
                    ->whereNull('registrations.deleted_at')
                    ->groupBy('leads.email')
                    ->first();
                if ($leadRregistration) $body_html = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_html);
              }
              
              $data['html'] = $body_html;
              
              // Ics privitak
              $data['ics'] = $this->IcsAttachment($mailing_activity_code);
    
              Mail::queue('mail-templates.template_custom', $data, function ($message) use ($data, $email) {
                if ($data['ics_included'] == 1) {
                    $message->from($data['from_email'], $data['from_name'])
                        ->to($email)
                        ->replyTo($data['reply_to'])
                        ->subject($data['subject'])
                        ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
                } else {
                    $message->from($data['from_email'], $data['from_name'])
                        ->to($email)
                        ->replyTo($data['reply_to'])
                        ->subject($data['subject']);
                }
                
              });
    
            }
    
        } else {
            
            $lead = DB::table('leads')
              ->where('email', Auth::user()->email)
              ->first();
    
            $body_html = str_replace('{lead_title}', $lead->title, $body_html);
            $body_html = str_replace('{lead_first_name}', $lead->first_name, $body_html);
            $body_html = str_replace('{lead_last_name}', $lead->last_name, $body_html);
            $body_html = str_replace('{lead_email}', $lead->email, $body_html);
            
            // Lead barcode
            $leadRregistration = DB::table('leads')
                ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
                ->where('leads.email', Auth::user()->email)
                ->where('registrations.event_id', $mail_table['event_id'])
                ->whereNull('registrations.deleted_at')
                ->groupBy('leads.email')
                ->first();
            if ($leadRregistration) $body_html = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_html);
            
            // Variacije pozdrava u pravom licu
            $data['html'] = $this->leadAlias($body_html, $lead);
            
            // Ics privitak
            $data['ics'] = $this->IcsAttachment($mailing_activity_code);
    
            Mail::queue('mail-templates.template_custom', $data, function ($message) use ($data) {
                if ($data['ics_included'] == 1) {
                    $message->from($data['from_email'], $data['from_name'])
                      ->to(Auth::user()->email)
                      ->replyTo(Auth::user()->email)
                      ->subject($data['subject'])
                      ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
                } else {
                    $message->from($data['from_email'], $data['from_name'])
                      ->to(Auth::user()->email)
                      ->replyTo(Auth::user()->email)
                      ->subject($data['subject']);
                }
            });
            
        }
        
        return 'Success';
      }

      $event_colors = DB::table('events')
        ->leftJoin('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->select('background_color', 'titles_color')
        ->where('events.id', $mail_table['event_id'])
        ->first();

      if($mail_table['background_color'] == NULL) {
        if ($mail_table['header_text'] == NULL) {
          $bg_color = '#8e8e8e';
        } else if ($event_colors) {
          $bg_color = $event_colors->background_color;
        } else {
          $bg_color = '#8e8e8e';
        }
      } else {
        $bg_color = $mail_table['background_color'];
      }

      if($mail_table['titles_color'] == NULL) {
        if ($mail_table['header_text'] == NULL) {
          $title_color = '#fff';
        } else if($event_colors) {
          $title_color = $event_colors->titles_color;
        } else {
          $title_color = '#fff';
        }
      } else {
        $title_color = $mail_table['titles_color'];
      }

      $data['title'] = $mail_table['header_text'];
      $data['register'] = $mail_table['register_button'];
      $data['confirm'] = $mail_table['confirm_button'];
      $data['banner'] = $mail_table['header_img_url'];
      $data['logo'] = $mail_table['logo_url'];
      $data['bgColor'] = $bg_color;
      $data['titleColor'] = $title_color;
      $data['unsub'] = $mail_table['unsubscribe_text'];
      $data['copyright'] = $mail_table['copyright_statement'];
      $data['preview'] = 1;
      $data['calendar_icon'] = env('APP_URL') . '/assets/images/mail-icons/mail-calendar-icon.png';
      $data['location_icon'] = env('APP_URL') . '/assets/images/mail-icons/mail-location-icon.png';
      $mail_template = $mail_table['sidebar_included'] == 1 ? 'mail-templates.template_720' : 'mail-templates.template_600';

      $body_wysiwyg = $mail_table['body_wysiwyg'];
      $body_wysiwyg = str_replace('{registration_link}', '#', $body_wysiwyg);
	  $body_wysiwyg = str_replace('{confirmation_link}', '#', $body_wysiwyg);
      $body_wysiwyg = str_replace('{tracking_link}', '#', $body_wysiwyg);
      $body_wysiwyg = str_replace('{unsubscribe_link}', '#', $body_wysiwyg);

      if ($mail_table['sidebar_included'] == 1) {
        $event_info = DB::table('events')
          ->select(array('type_by_venue as venue',
            'venue_name as v_name',
            'venue_address as address',
            'venue_city as city',
            'venue_postal_code as postal',
            'countries.country_name as country',
            'start_ts as start',
            'end_ts as end'))
          ->leftJoin('countries','countries.id','=','events.venue_country_id')
          ->where('event_code', $event_code)
          ->get();

        $event_info = json_decode(json_encode($event_info[0]),true);
        if ($data['lang'] == 'hr') {
          $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d.m.Y. H:m');
          $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d.m.Y. H:m');
        } else {
          $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d/m/Y h:i a');
          $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d/m/Y h:i a');
        }
        $data['v_name'] = $event_info['v_name'];
        $data['address'] = $event_info['address'];
        $data['city'] = $event_info['city'];
        $data['postal'] = $event_info['postal'];
        $data['country'] = $event_info['country'];
        $data['start'] = $event_info['start'];
        $data['end'] = $event_info['end'];
        $data['show_location'] = $event_info['venue'] == 'online' ? false : true;
      }

      if(is_array($data['others'])) {

        foreach($data['others'] as $email) {

          $lead = DB::table('leads')
            ->where('email', $email)
            ->first();

          if($lead) {
            $body_content = str_replace('{lead_title}', $lead->title, $body_wysiwyg);
            $body_content = str_replace('{lead_first_name}', $lead->first_name, $body_content);
            $body_content = str_replace('{lead_last_name}', $lead->last_name, $body_content);
            $body_content = str_replace('{lead_email}', $lead->email, $body_content);

			// Variacije pozdrava u pravom licu
			$body_content = $this->leadAlias($body_content, $lead);
            
            // Lead barcode
            $leadRregistration = DB::table('leads')
                ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
                ->where('leads.email', $email)
                ->where('registrations.event_id', $mail_table['event_id'])
                ->whereNull('registrations.deleted_at')
                ->groupBy('leads.email')
                ->first();
            if ($leadRregistration) $body_content = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_content);
            
            $data['body_content'] = $body_content;
          } else {
            $data['body_content'] = $body_wysiwyg;
          }
          
          // Ics privitak
          $data['ics'] = $this->IcsAttachment($mailing_activity_code);

          Mail::queue($mail_template, $data, function ($message) use ($data, $email) {
            if ($data['ics_included'] == 1) {
                $message->from($data['from_email'], $data['from_name'])
                    ->to($email)
                    ->replyTo($data['reply_to'])
                    ->subject($data['subject'])
                    ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
            } else {
                $message->from($data['from_email'], $data['from_name'])
                    ->to($email)
                    ->replyTo($data['reply_to'])
                    ->subject($data['subject']);
            }
            
          });

        }

      } else {

        $lead = DB::table('leads')
          ->where('email', Auth::user()->email)
          ->first();

        $body_wysiwyg = str_replace('{lead_title}', $lead->title, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_first_name}', $lead->first_name, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_last_name}', $lead->last_name, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_email}', $lead->email, $body_wysiwyg);
        
        // Variacije pozdrava u pravom licu
        $data['body_content'] = $this->leadAlias($body_wysiwyg, $lead);
        
        // Lead barcode
        $leadRregistration = DB::table('leads')
            ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
            ->where('leads.email', Auth::user()->email)
            ->where('registrations.event_id', $mail_table['event_id'])
            ->whereNull('registrations.deleted_at')
            ->groupBy('leads.email')
            ->first();
        if ($leadRregistration) $body_wysiwyg = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_wysiwyg);
        
        // Ics privitak
        $data['ics'] = $this->IcsAttachment($mailing_activity_code);

        Mail::queue($mail_template, $data, function ($message) use ($data) {
            if ($data['ics_included'] == 1) {
                $message->from($data['from_email'], $data['from_name'])
                  ->to(Auth::user()->email)
                  ->replyTo(Auth::user()->email)
                  ->subject($data['subject'])
                  ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
            } else {
                $message->from($data['from_email'], $data['from_name'])
                  ->to(Auth::user()->email)
                  ->replyTo(Auth::user()->email)
                  ->subject($data['subject']);
            }
        });

      }

      return 'Success';
    }


    /**
     * Pošalji mail
     * @param  string $event_code
     * @param  string $mail
     * @param  int $id
     * @param  boolean $opt
     * @param  forma Request $request
     * @return string
     */
    public function SendMail($event_code, $mailing_activity_code, $mail, $code, $opt, $method, Request $request) {

      $now = $this->Now();

      $mail_table = DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->get();

      $mail_table = json_decode(json_encode($mail_table[0]), true);

      $data['subject'] = $request->input('subject');
      $data['from_name'] = $request->input('from_name');
      $data['from_email'] = $request->input('from_email');
      $data['reply_to'] = $request->input('replay_to');
      $data['ics_included'] = $mail_table['ics_included'];

      $data['lang'] = DB::table('events')->where('event_code', $event_code)->value('lang');

      DB::table('mailing_activities')
        ->where('mailing_activity_code', $mailing_activity_code)
        ->update([
          "email_subject" => $data['subject'],
          "email_from_name" => $data['from_name'],
          "email_from_email" => $data['from_email'],
          "email_replyto_email" => $data['reply_to']
        ]);

      $lead = DB::table('leads')
        ->where('lead_code', $code)
        ->first();
        
        $url = env('APP_URL');
        $registration_link = $url . '/registration/' . $event_code . '/' . $mail;
        $confirmation_link = $url . '/confirmation/' . $event_code . '/' . $code;
        $tracking_link = $url . '/mail-image/' . $mailing_activity_code . '/' . $code;
        $unsubscribe_link = $url . '/unsubscribe/' . $mailing_activity_code . '/' . Crypt::encrypt($code);

      if ($opt && (strpos($method, 'email') !== false)) {
          
          // Custom HTML
          if($mail_table['custom_html']) {
                $body_html = $mail_table['body_html'];
                $body_html = str_replace('{registration_link}', $registration_link, $body_html);
                $body_html = str_replace('{confirmation_link}', $confirmation_link, $body_html);
                $body_html = str_replace('{tracking_link}', $tracking_link, $body_html);
                $body_html = str_replace('{unsubscribe_link}', $unsubscribe_link, $body_html);
              
              $lead = DB::table('leads')
                ->where('email', $mail)
                ->first();
      
              $body_html = str_replace('{lead_title}', $lead->title, $body_html);
              $body_html = str_replace('{lead_first_name}', $lead->first_name, $body_html);
              $body_html = str_replace('{lead_last_name}', $lead->last_name, $body_html);
              $body_html = str_replace('{lead_email}', $lead->email, $body_html);
              
              // Lead barcode
              $leadRregistration = DB::table('leads')
                  ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
                  ->where('leads.email', $mail)
                  ->where('registrations.event_id', $mail_table['event_id'])
                  ->whereNull('registrations.deleted_at')
                  ->groupBy('leads.email')
                  ->first();
              if ($leadRregistration) $body_html = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_html);
              
              // Variacije pozdrava u pravom licu
              $data['html'] = $this->leadAlias($body_html, $lead);
              
              // Ics privitak
              $data['ics'] = $this->IcsAttachment($mailing_activity_code);
              
              Mail::queue('mail-templates.template_custom', $data, function ($message) use ($data, $mail) {
                  if ($data['ics_included'] == 1) {
                      $message->from($data['from_email'], $data['from_name'])
                          ->to($mail)
                          ->replyTo($data['reply_to'])
                          ->subject($data['subject'])
                          ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
                  } else {
                      $message->from($data['from_email'], $data['from_name'])
                          ->to($mail)
                          ->replyTo($data['reply_to'])
                          ->subject($data['subject']);
                  }
              });
              
                DB::table('mailings')
                    ->where('mailing_activity_id', $mail_table['id'])
                    ->where('lead_id', $lead->id)
                    ->whereNull('deleted_at')
                    ->update([
                        "sent_ts" => $now
                    ]);

                $already_registered_or_attended = DB::table('leads_on_events_insights')
                    ->where('lead_id', $lead->id)
                    ->value("event_id_" . $mail_table['event_id']);

                if($already_registered_or_attended != 'did not come' && $already_registered_or_attended != 'attended') {

                    DB::table('leads_on_events_insights')
                        ->where('lead_id', $lead->id)
                        ->update([
                            "event_id_" . $mail_table['event_id'] => 'not responded'
                        ]);

                }
            
            return 'Success';
          }

        $event_colors = DB::table('events')
          ->leftJoin('event_look_feels', 'events.event_look_and_feel_id', '=', 'event_look_feels.id')
          ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
          ->select('background_color', 'titles_color')
          ->where('events.id', $mail_table['event_id'])
          ->first();

        if($mail_table['background_color'] == NULL) {
          if ($mail_table['header_text'] == NULL) {
            $bg_color = '#8e8e8e';
          } else if ($event_colors) {
            $bg_color = $event_colors->background_color;
          } else {
            $bg_color = '#8e8e8e';
          }
        } else {
          $bg_color = $mail_table['background_color'];
        }

        if($mail_table['titles_color'] == NULL) {
          if ($mail_table['header_text'] == NULL) {
            $title_color = '#fff';
          } else if($event_colors) {
            $title_color = $event_colors->titles_color;
          } else {
            $title_color = '#fff';
          }
        } else {
          $title_color = $mail_table['titles_color'];
        }

        $data['title'] = $mail_table['header_text'];
        $data['register'] = $mail_table['register_button'];
        $data['confirm'] = $mail_table['confirm_button'];
        $data['banner'] = $mail_table['header_img_url'];
        $data['logo'] = $mail_table['logo_url'];
        $data['bgColor'] = $bg_color;
        $data['titleColor'] = $title_color;
        $data['unsub'] = $mail_table['unsubscribe_text'];
        $data['copyright'] = $mail_table['copyright_statement'];
        $data['lead_code_encrypted'] = Crypt::encrypt($code);
        $data['calendar_icon'] = $url . '/assets/images/mail-icons/mail-calendar-icon.png';
        $data['location_icon'] = $url . '/assets/images/mail-icons/mail-location-icon.png';
        $data['tracking_img_url'] = $tracking_link;
        $data['mailing_activity_code'] = $mailing_activity_code;
        $data['registration_link'] = $registration_link;
        $data['confirmation_link'] = $confirmation_link;
        $data['unsubscribe_link'] = $unsubscribe_link;
        $data['url'] = $url;

        $body_wysiwyg = $mail_table['body_wysiwyg'];
        $body_wysiwyg = str_replace('{lead_title}', $lead->title, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_first_name}', $lead->first_name, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_last_name}', $lead->last_name, $body_wysiwyg);
        $body_wysiwyg = str_replace('{lead_email}', $lead->email, $body_wysiwyg);
        $body_wysiwyg = str_replace('{registration_link}', $registration_link, $body_wysiwyg);
		$body_wysiwyg = str_replace('{confirmation_link}', $confirmation_link, $body_wysiwyg);
        $body_wysiwyg = str_replace('{tracking_link}', $tracking_link, $body_wysiwyg);
        $body_wysiwyg = str_replace('{unsubscribe_link}', $unsubscribe_link, $body_wysiwyg);
        
        // Variacije pozdrava u pravom licu
        $body_wysiwyg = $this->leadAlias($body_wysiwyg, $lead);
        
        // Lead barcode
        $leadRregistration = DB::table('leads')
          ->leftJoin('registrations', 'registrations.lead_id', '=', 'leads.id')
          ->where('leads.email', $lead->email)
          ->where('registrations.event_id', $mail_table['event_id'])
          ->whereNull('registrations.deleted_at')
          ->groupBy('leads.email')
          ->first();
        if ($leadRregistration) $body_wysiwyg = str_replace('{lead_barcode}', $leadRregistration->barcode, $body_wysiwyg);
        
        $data['body_content'] = $body_wysiwyg;

        $mail_template = $mail_table['sidebar_included'] == 1 ? 'mail-templates.template_720' : 'mail-templates.template_600';

        if ($mail_table['sidebar_included'] == 1) {
          $event_info = DB::table('events')
            ->select(array(
              'type_by_venue as venue',
              'venue_name as v_name',
              'venue_address as address',
              'venue_city as city',
              'venue_postal_code as postal',
              'countries.country_name as country',
              'start_ts as start',
              'end_ts as end'
              ))
            ->leftJoin('countries','countries.id','=','events.venue_country_id')
            ->where('event_code', $event_code)
            ->get();

          $event_info = json_decode(json_encode($event_info[0]), true);

          if ($data['lang'] == 'hr') {
            $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d.m.Y. H:m');
            $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d.m.Y. H:m');
          } else {
            $event_info['start'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['start'])->format('d/m/Y h:i a');
            $event_info['end'] = Carbon::createFromFormat('Y-m-d H:i:s', $event_info['end'])->format('d/m/Y h:i a');
          }
          $data['v_name'] = $event_info['v_name'];
          $data['address'] = $event_info['address'];
          $data['city'] = $event_info['city'];
          $data['postal'] = $event_info['postal'];
          $data['country'] = $event_info['country'];
          $data['start'] = $event_info['start'];
          $data['end'] = $event_info['end'];
          $data['show_location'] = $event_info['venue'] == 'online' ? false : true;
        }
        
        // Ics privitak
        $data['ics'] = $this->IcsAttachment($mailing_activity_code);

        Mail::queue($mail_template, $data, function ($message) use ($data, $mail) {
            if ($data['ics_included'] == 1) {
                $message->from($data['from_email'], $data['from_name'])
                    ->to($mail)
                    ->replyTo($data['reply_to'])
                    ->subject($data['subject'])
                    ->attach(public_path() . '/ics/' . $data['ics'], array('mime' => "text/calendar"));
            } else {
                $message->from($data['from_email'], $data['from_name'])
                    ->to($mail)
                    ->replyTo($data['reply_to'])
                    ->subject($data['subject']);
            }
        });

  			DB::table('mailings')
    			->where('mailing_activity_id', $mail_table['id'])
    			->where('lead_id', $lead->id)
          ->whereNull('deleted_at')
    			->update([
    				"sent_ts" => $now
    			]);

        $already_registered_or_attended = DB::table('leads_on_events_insights')
          ->where('lead_id', $lead->id)
          ->value("event_id_" . $mail_table['event_id']);

        if($already_registered_or_attended != 'did not come' && $already_registered_or_attended != 'attended') {

          DB::table('leads_on_events_insights')
            ->where('lead_id', $lead->id)
            ->update([
              "event_id_" . $mail_table['event_id'] => 'not responded'
            ]);

        }

      } else {

        DB::table('mailings')
          ->where('mailing_activity_id', $mail_table['id'])
          ->where('lead_id', $lead->id)
          ->whereNull('deleted_at')
          ->update([
            "sent_ts" => '1970-01-01 00:00:00'
          ]);

      }

      return 'Success';
    }


    /**
     * Postavljanje progresa slanja emaila
     * @param $event_code
     * @param $mailing_activity_code
     * @param $mailing_activity_id
     * @param $event_code
     * @param $code
     */
    public function SetProgress($event_code, $mailing_activity_code, $code) {
			if($code != 1) {
				if($code == 3) {
					$is_sending = DB::table('mailing_activities')
						->where('mailing_activity_code', $mailing_activity_code)
						->value('mailing_process');

					if($is_sending == 1) {
						DB::table('mailing_activities')
							->where('mailing_activity_code', $mailing_activity_code)
							->update([
								"mailing_process" => $code
							]);
					}
				} else {
					DB::table('mailing_activities')
						->where('mailing_activity_code', $mailing_activity_code)
						->update([
							"mailing_process" => $code
						]);
				}
			} else {
				DB::table('mailing_activities')
					->where('mailing_activity_code', $mailing_activity_code)
					->update([
						"mailing_process" => $code,
						"is_draft" => 0
					]);

        $mailing_activity_id = DB::table('mailing_activities')
          ->where('mailing_activity_code', $mailing_activity_code)
          ->value('id');

        // New e-mail campaign
        $this->Log(172, $mailing_activity_id);
			}
    }
    
    /**
     * Variacije pozdrava u pravom licu
     */
    private function leadAlias($body_wysiwyg, $lead) {
        if($lead->gender == 'Mr.') {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovani', $body_wysiwyg);
        } else if($lead->gender == 'Ms.') {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovana', $body_wysiwyg);
        } else {
            $body_wysiwyg = str_replace('{lead_alias}', 'Poštovani', $body_wysiwyg);
        }
        
        $offset = 0;
        $occurrences = array();
        
        while(($position = strpos($body_wysiwyg, '{lead_alias', $offset)) !== FALSE) {
            $offset = $position + 1;
            $occurrences[] = $position;
        }
        
        $occurrences = array_reverse($occurrences);
        
        foreach($occurrences as $key => $occurrence) {
            $equal = substr($body_wysiwyg, ($occurrence + 11), 1);

            if($equal == '=') {
                $comma = strpos($body_wysiwyg, ',', $occurrence);
                $end = strpos($body_wysiwyg, '}', $occurrence);
                
                if($comma && $end) {
                    $male = substr($body_wysiwyg, $occurrence + 12, ($comma - ($occurrence + 12)));
                    $female = substr($body_wysiwyg, $comma + 1, ($end - $comma - 1));
                    
                    if($lead->gender == 'Mr.') {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $male, $occurrence, ($end - $occurrence + 1));
                    } else if($lead->gender == 'Ms.') {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $female, $occurrence, ($end - $occurrence + 1));
                    } else {
                        $body_wysiwyg = substr_replace($body_wysiwyg, $male, $occurrence, ($end - $occurrence + 1));
                    }
                }
            }
        }
        
        return $body_wysiwyg;
    }
    
    /**
     * Generiranje ICS privitka
     */
    private function IcsAttachment($mailing_activity_code)
    {
        $event = DB::table('mailing_activities')
            ->leftjoin('events', 'mailing_activities.event_id', '=', 'events.id')
            ->where('mailing_activity_code', $mailing_activity_code)
            ->first();
        
        if ($event->ics_included == 1) {
            $attach = $event->name . ".ics";
            $ics[0] = "BEGIN:VCALENDAR";
            $ics[1] = "PRODID:-//Krikstudio//KrikEM//EN";
            $ics[2] = "VERSION:2.0";
            $ics[3] = "METHOD:REQUEST";
            $ics[4] = "BEGIN:VEVENT";
            if (date("I")) {
                $ics[5] = "DTSTART:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->start_ts)->format('Ymd\THis\Z'); 
                $ics[6] = "DTEND:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->end_ts)->format('Ymd\THis\Z');
            } else {
                $ics[5] = "DTSTART:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->start_ts)->subHour(1)->format('Ymd\THis\Z'); 
                $ics[6] = "DTEND:" . Carbon::createFromFormat('Y-m-d H:i:s', $event->end_ts)->subHour(1)->format('Ymd\THis\Z');
            }
            $ics[7] = "DTSTAMP:" . gmdate('Ymd\THis\Z', time() + 3600 * (1 + date("I")));
            $ics[8] = "UID:" . date('YmdHis') . '-' . rand();
            $ics[9] = "ORGANIZER;CN=" . $event->email_name . ":" . $event->email_sender;
            $ics[10] = "DESCRIPTION:" . $event->description;
            if ($event->type_by_venue == 'physical') $ics[11] = "LOCATION:" . $event->venue_name . ", " . $event->venue_address . ', ' . $event->venue_city;
            $ics[12] = "SUMMARY:" . $event->name;
            $ics[13] = "END:VEVENT";
            $ics[14] = "END:VCALENDAR";
            $ics = implode("\r\n", $ics);
            file_put_contents(public_path() . '/ics/' . $attach, $ics);
            
            return $attach;
        } else {
            return false;
        }
    }
}
