<?php

namespace App\Http\Controllers\Events\Reports;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Leads as Leads;
use App\Event as Event;
use View;
use DB;
use Response;
use Auth;
use Datatables;
use Redirect;
use PDF;

class ReportAccommodationsController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prikaz podataka o accommodations
     */
    public function GetAccommodations($event_code)
    {
        // Dohvati podatke o eventu
        $singleEvent = $this->GetEvent($event_code);

        if($singleEvent) {

          View::share('singleEvent', $singleEvent);
          View::share('event_code', $event_code);
          View::share('title', 'Accommodations - ' . $singleEvent->name);

          $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
          View::share('event_has_transfers', $event_has_transfers);

          View::share('pro_forma_invoice', MODULE_PROFORMA_INVOICE);

          return view('events/reports/report-accommodations');

        } else {

          return redirect()->route('home');

        }

    }


    /**
     * Promijeni status registracije
     */
    public function UpdateRegistrationStatus(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');
      $status = $request->input('status');
      $form_type = $request->input('form_type');

      if($form_type == 'change_registration') {
        $selected_type = $request->input('selected_option');
        $ids = $request->input('registration_checkbox');

        if ($selected_type == 'confirmed') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'accomodation_approved' => 1,
                'status_accomodation' => 'Confirmed'
              ));
          }
        }

        if ($selected_type == 'canceled') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'accomodation_approved' => 0,
                'status_accomodation' => 'Canceled'
              ));
          }
        }

        if ($selected_type == 'delete') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'accomodation_room_id' => NULL,
                'accomodation_note' => NULL,
                'accomodation_payer_id' => NULL,
                'accomodation_approved' => NULL,
                'accomodation_roomy_name' => NULL,
                'accomodation_arrival_date' => NULL,
                'accomodation_departure_date' => NULL
              ));
          }
        }

        return Redirect::back();
      }

      if(!$registration_id || $type != 'accomodation') {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      if($status == 'confirmed') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'accomodation_approved' => 1,
            'status_accomodation' => 'Confirmed'
          ));

      } elseif($status == 'canceled') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'accomodation_approved' => 0,
            'status_accomodation' => 'Canceled'
          ));

      }

      // Updated registration accommodation status
      $this->Log(182, $registration_id);

      return Response::json([
        'msg' => 'status_changed'
      ]);
    }


    /**
     * Genneriranje invoicea
     */
    public function GenerateInvoice(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $invoice_type = $request->input('type');

      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      // Dohvati podatke o look & feelu eventa
      $singleEventLookFeel = $this->GetEventLookFeel($singleEvent->id);

      if($invoice_type == 'accomodation') {

        if($registration_id) {

          $registration = DB::table('registrations')
            ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
            ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries as leadCountries', 'leads.company_country', '=', 'leadCountries.id')
            ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
            ->leftJoin('countries as accomodationCountries', 'accomodation.country', '=', 'accomodationCountries.id')
            ->selectRaw('room_types.type AS accomodationRoomName,
              room_types.price_without_vat AS accomodationPriceNoVat,
              room_types.vat AS accomodationPriceVat,
              accommodations.name AS accomodationName,
              leads.title AS leadTitle,
              leads.first_name AS leadFirstName,
              leads.last_name AS leadLastName,
              leads.email AS leadEmail,
              leads.mobile AS leadMobile,
              leads.phone AS leadPhone,
              leads.company_name AS leadCompanyName,
              leads.job_function AS leadJobFunction,
              leads.company_address AS leadCompanyAddress,
              leads.company_city AS leadCompanyCity,
              leads.company_post_code AS leadCompanyPostalCode,
              leadCountries.country_name AS leadCompanyCountry,
              leads.note AS leadNote,
              accomodation.type AS accomodationType,
              accomodation.personal_id AS accomodationPersonalId,
              accomodation.id AS accomodationId,
              accomodation.company_name AS accomodationCompanyName,
              accomodation.vat AS accomodationVat,
              accomodation.address AS accomodationAddress,
              accomodation.city AS accomodationCity,
              accomodation.post_code AS accomodationPostalCode,
              accomodationCountries.country_name AS accomodationCountry,
              accomodation.first_name AS accomodationFirstName,
              accomodation.last_name AS accomodationLastName,
              accomodation.email AS accomodationEmail,
              accomodation.phone AS accomodationPhone,
              registrations.invoice_ticket AS invoiceTicket,
              registrations.invoice_accomodation AS invoiceAccomodation,
              registrations.invoice_transfer AS invoiceTransfer,
              registrations.order_ticket AS orderTicket,
              registrations.order_accomodation AS orderAccomodation,
              registrations.order_transfer AS orderTransfer,
              registrations.accomodation_arrival_date AS accomodationArrivalData,
              registrations.accomodation_departure_date AS accomodationDepartureData')
            ->where('registrations.id', '=', $registration_id)
            ->first();

          $payment = DB::table('invoice_froms')
            ->where('id', '=', $singleEvent->accomodation_invoice_from_id)
            ->first();

        } else {

          return Redirect::back();

        }

        $accomodationArrivalData = strtotime($registration->accomodationArrivalData);
        $accomodationDepartureData = strtotime($registration->accomodationDepartureData);
        $accomodationDays = $accomodationDepartureData - $accomodationArrivalData;
        $accomodationDays = floor($accomodationDays/(60*60*24));

        $accomodation_total_no_vat = $registration->accomodationPriceNoVat * $accomodationDays;

        $accomodation_total_only_vat = $accomodation_total_no_vat / 100 * $registration->accomodationPriceVat;

        $accomodation_total_with_vat = $accomodation_total_no_vat + $accomodation_total_only_vat;

        $accomodation_total_no_vat = number_format((float)$accomodation_total_no_vat, 2);
        $accomodation_total_only_vat = number_format((float)$accomodation_total_only_vat, 2);
        $accomodation_total_with_vat = number_format((float)$accomodation_total_with_vat, 2);

        $currency = $this->getCurrency($singleEvent->id);

        $pdf = PDF::loadView('invoices/accomodations', [
          'registration' => $registration,
          'event' => $singleEvent,
          'event_logo' => $singleEventLookFeel->event_logo_url,
          'bg_color' => $singleEventLookFeel->background_color,
          'title_color' => $singleEventLookFeel->titles_color,
          'accomodation_total_no_vat' => $accomodation_total_no_vat,
          'accomodation_total_only_vat' => $accomodation_total_only_vat,
          'accomodation_total_with_vat' => $accomodation_total_with_vat,
          'currency' => $currency,
          'payment' => $payment,
          'accomodationDays' => $accomodationDays
        ])->setPaper('a4');

        if ($pdf) {

          return $pdf->download('accommodation-proforma-invoice-' . $registration->invoiceAccomodation . '.pdf');

        }

      } else {

        return Redirect::back();

      }

    }


    /**
     * Brisanje registracija
     */
    public function DeleteRegistration(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');

      if(!$registration_id || $type != 'accomodation') {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      DB::table('registrations')
        ->where('id', '=', $registration_id)
        ->update(array(
          'accomodation_room_id' => NULL,
          'accomodation_note' => NULL,
          'accomodation_payer_id' => NULL,
          'accomodation_approved' => NULL,
          'accomodation_roomy_name' => NULL,
          'accomodation_arrival_date' => NULL,
          'accomodation_departure_date' => NULL
        ));

      // Deleted registration accommodation
      $this->Log(185, $registration_id);

      return Response::json([
        'msg' => 'accomm_deleted'
      ]);

    }


    /**
     * Dohvat podataka aod strane datatables dodatka
     * Dohvaćamo popis svih leadova na zatraženom eventu koji su odabrali accommodations
     */
    public function anyData(Request $request) {
      $event_code = $request->input('event_code');

      $singleEvent = $this->GetEvent($event_code);

      $accommodations = DB::table('registrations')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('room_types', 'registrations.accomodation_room_id', '=', 'room_types.id')
        ->leftJoin('accommodations', 'room_types.accommodation_id', '=', 'accommodations.id')
        ->selectRaw('
          CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
          accommodations.name AS accommodation,
          room_types.type AS room_type,
          DATE_FORMAT(registrations.accomodation_arrival_date, "%Y-%m-%d") AS accomodation_arrival_date,
          DATE_FORMAT(registrations.accomodation_departure_date, "%Y-%m-%d") AS accomodation_departure_date,
          registrations.status_accomodation,
          registrations.id,
          DATE_FORMAT(registrations.registered_ts, "%Y-%m-%d %H:%i") AS registered_ts')
        ->where('registrations.event_id', '=', $singleEvent->id)
        ->whereNotNull('registrations.registered_ts')
        ->whereNull('registrations.deleted_at');

      return Datatables::of($accommodations)
        ->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
        ->make(true);

    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('events.event_code', '=', $event_code)
                            ->first();

        return $singleEvent;
    }


    /**
     * Vrati podatke o look & feelu eventa
     */
    private function GetEventLookFeel($event_id) {
      $singleEventLookFeel = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->select('event_look_feels.event_logo_url', 'color_schemes.background_color', 'color_schemes.titles_color')
        ->where('events.id', '=', $event_id)
        ->firstOrFail();

      return $singleEventLookFeel;
    }


    /**
     * Dohvati currency code za zatraženi event
     */
    private function getCurrency($eventId) {
      $currency = DB::table('events')
        ->join('currencies', 'events.currency_id', '=', 'currencies.id')
        ->selectRaw('currencies.code as code')
        ->where('events.id', '=', $eventId)
        ->get();

      $eventCurrency = 0;
      foreach ($currency as $item) {
        $eventCurrency = $item->code;
      }

      return $eventCurrency;
    }
}
