<?php

namespace App\Http\Controllers\Events\Reports;

use Illuminate\Http\Request;

use App\Http\Requests;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Response;
use Auth;
use Datatables;
use Redirect;
use PDF;
use Excel;
use DNS1D;
use Mail;

class ReportPromoCodesController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prikaz podataka o registracijama
     */
    public function GetPromoCodes($event_code, $ticket_id)
    {
        // Dohvati podatke o eventu
        $singleEvent = $this->GetEvent($event_code);

        $ticket = $this->GetTicket($ticket_id);

        if($singleEvent) {

          View::share('singleEvent', $singleEvent);
          View::share('event_code', $event_code);
          View::share('title', 'Promotional Codes - ' . $ticket->name);

          $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
          View::share('event_has_transfers', $event_has_transfers);


          View::share('ticket', $ticket);


          return view('events/reports/report-promo-code');

        } else {

          return redirect()->route('home');

        }
    }

    /**
     * Dohvat podataka od strane datatables dodatka
     * Dohvaćamo popis svih promo kodova na zatraženom eventu
     */
    public function anyData(Request $request) {
      $ticket_id = $request->input('ticket_id');

      $promocodes = DB::table('promo_codes')
        ->leftJoin('registrations', 'promo_codes.registration_id', '=', 'registrations.id')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->selectRaw('
          promo_codes.code AS promocode,
          CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
          leads.email AS email,
          DATE_FORMAT(registrations.registered_ts, "%Y-%m-%d %H:%i") AS registered_ts')
        ->where('promo_codes.ticket_id', '=', $ticket_id);
    
      return Datatables::of($promocodes)
        ->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
        ->make(true);
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('event_code', $event_code)
	        ->first();

        return $singleEvent;
    }



    private function GetTicket($ticket_id) {
      return DB::table('tickets')->where('id', $ticket_id)->first();
    }


    /**
     * Export svih podataka iz registracije u Excel tablicu
     */
    public function ExportAll(Request $request, $event_code, $ticket_id) {
      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      $ticket = $this->GetTicket($ticket_id);

      $promocodes = DB::table('promo_codes')
        ->leftJoin('registrations', 'promo_codes.registration_id', '=', 'registrations.id')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->selectRaw("
          promo_codes.code AS 'Promotional Code',
          leads.title AS 'Lead Title',
          leads.first_name AS 'Lead First Name',
          leads.last_name AS 'Lead Last Name',
          leads.email AS 'Lead E-mail',
          DATE_FORMAT(registrations.registered_ts, '%Y-%m-%d %H:%i') AS 'Register Time'")
        ->where('promo_codes.ticket_id', '=', $ticket_id)
        ->get();
			
		$data = array();
        foreach($promocodes as $promocode) {
			    $data[] = (array)$promocode;
        }
			
		Excel::create('Promo Codes - ' . $ticket->name, function($excel) use($data, $ticket, $promocodes) {
          $excel->setTitle('Promo Codes - ' . $ticket->name);
          $excel->sheet('Report', function($sheet) use($data) {
            $sheet->setOrientation('landscape');
            $sheet->fromArray($data, null, '', true);
          });
        })->download('xlsx');
    }
}
