<?php

namespace App\Http\Controllers\Events\Reports;

use Illuminate\Http\Request;

use App\Http\Requests;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Response;
use Auth;
use Datatables;
use Redirect;
use PDF;
use Excel;
use DNS1D;
use Mail;

class ReportRegistrationsController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prikaz podataka o registracijama
     */
    public function GetRegistrations($event_code)
    {
        // Dohvati podatke o eventu
        $singleEvent = $this->GetEvent($event_code);

        if($singleEvent) {

          View::share('singleEvent', $singleEvent);
          View::share('event_code', $event_code);
          View::share('title', 'Registrations - ' . $singleEvent->name);

          $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
          View::share('event_has_transfers', $event_has_transfers);

          return view('events/reports/report-registrations');

        } else {

          return redirect()->route('home');

        }
    }


    /**
     * Promijeni status registracije
     */
    public function UpdateRegistrationStatus(Request $request, $event_code) {

      $registration_id = $request->input('id');
      $type = $request->input('type');
      $status = $request->input('status');
      $form_type = $request->input('form_type');

      if($form_type == 'change_registration') {
        $selected_type = $request->input('selected_option');
        $ids = $request->input('registration_checkbox');

        if ($selected_type == 'confirmed') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'ticket_approved' => 1,
                'status_registration' => 'Confirmed'
              ));
          }
        }

        if ($selected_type == 'canceled') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'ticket_approved' => 0,
                'status_registration' => 'Canceled',
                'accomodation_approved' => 0,
                'status_accomodation' => 'Canceled',
                'transfer_approved' => 0,
                'status_transfer' => 'Canceled'
              ));
          }
        }

          if ($selected_type == 'attended') {
            foreach ($ids as $id) {
              $registration = DB::table('registrations')
                ->where('id', '=', $id)
                ->first();

              DB::table('registrations')
                ->where('id', '=', $id)
                ->update(array(
                  'attended_ts' => $this->Now(),
                  'event_attended_flag' => 1
                ));

              DB::table('leads_on_events_insights')
                ->where('lead_id', $registration->lead_id)
                ->update([
                  "event_id_" . $registration->event_id => 'attended'
                ]);
            }
          }

          if ($selected_type == 'not-attended') {
            foreach ($ids as $id) {
              $registration = DB::table('registrations')
                ->where('id', '=', $id)
                ->first();

              DB::table('registrations')
                ->where('id', '=', $id)
                ->update(array(
                  'attended_ts' => null,
                  'event_attended_flag' => 0
                ));

              DB::table('leads_on_events_insights')
                ->where('lead_id', $registration->lead_id)
                ->update([
                  "event_id_" . $registration->event_id => 'did not come'
                ]);
            }
          }


          if ($selected_type == 'delete') {
            foreach ($ids as $id) {
              DB::table('registrations')
                ->where('id', $id)
                ->update([
                  'deleted_at' => $this->Now()
                ]);
            }
          }


        return Redirect::back();
      }

      if(!$registration_id) {
        return Response::json([
          'msg' => 'no_registration_id'
        ]);
      }

      if($type == 'registration') {

        if($status == 'confirmed') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'ticket_approved' => 1,
              'status_registration' => 'Confirmed'
            ));

        } elseif($status == 'canceled') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'ticket_approved' => 0,
              'status_registration' => 'Canceled',
              'accomodation_approved' => 0,
              'status_accomodation' => 'Canceled',
              'transfer_approved' => 0,
              'status_transfer' => 'Canceled'
            ));

        }

        // Updated registration status
        $this->Log(181, $registration_id);

      }

      if($type == 'attending') {

        $registration = DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->first();

        if($status == 'attended') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'attended_ts' => $this->Now(),
              'event_attended_flag' => 1
            ));

          DB::table('leads_on_events_insights')
            ->where('lead_id', $registration->lead_id)
            ->update([
              "event_id_" . $registration->event_id => 'attended'
            ]);

        } elseif($status == 'not-attended') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'attended_ts' => null,
              'event_attended_flag' => 0
            ));

          DB::table('leads_on_events_insights')
            ->where('lead_id', $registration->lead_id)
            ->update([
              "event_id_" . $registration->event_id => 'did not come'
            ]);

        }

        // Updated attending status
        $this->Log(187, $registration_id);

      }

      return Response::json([
        'msg' => 'status_changed'
      ]);

    }



    /**
     * Invoices & coupons
     */
    public function Actions(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');

      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      // Dohvati podatke o look & feelu eventa
      $singleEventLookFeel = $this->GetEventLookFeel($singleEvent->id);

      if(!$registration_id) return Redirect::back();

      if($type == 'tickets') {

            $registration = DB::table('registrations')
                ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
                ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
                ->leftJoin('countries as leadCountries', 'leads.company_country', '=', 'leadCountries.id')
                ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=', 'ticket.id')
                ->leftJoin('countries as ticketCountries', 'ticket.country', '=', 'ticketCountries.id')
                ->selectRaw('tickets.name AS ticketName,
                    tickets.price_without_VAT AS ticketPriceNoVat,
                    tickets.VAT AS ticketsVat,
                    leads.title AS leadTitle,
                    leads.first_name AS leadFirstName,
                    leads.last_name AS leadLastName,
                    leads.email AS leadEmail,
                    leads.mobile AS leadMobile,
                    leads.phone AS leadPhone,
                    leads.company_name AS leadCompanyName,
                    leads.job_function AS leadJobFunction,
                    leads.company_address AS leadCompanyAddress,
                    leads.company_city AS leadCompanyCity,
                    leads.company_post_code AS leadCompanyPostalCode,
                    leadCountries.country_name AS leadCompanyCountry,
                    leads.note AS leadNote,
                    ticket.id AS ticketId,
                    ticket.company_name AS ticketCompanyName,
                    ticket.vat AS ticketVat,
                    ticket.address AS ticketAddress,
                    ticket.city AS ticketCity,
                    ticket.post_code AS ticketPostalCode,
                    ticketCountries.country_name AS ticketCountry,
                    ticket.first_name AS ticketFirstName,
                    ticket.last_name AS ticketLastName,
                    ticket.email AS ticketEmail,
                    ticket.phone AS ticketPhone,
                    ticket.type AS ticketType,
                    ticket.personal_id AS ticketPersonalId,
                    registrations.invoice_ticket AS invoiceTicket,
                    registrations.invoice_accomodation AS invoiceAccomodation,
                    registrations.invoice_transfer AS invoiceTransfer,
                    registrations.order_ticket AS orderTicket,
                    registrations.order_accomodation AS orderAccomodation,
                    registrations.order_transfer AS orderTransfer')
                ->where('registrations.id', '=', $registration_id)
                ->first();

            $payment = DB::table('invoice_froms')
                ->where('id', '=', $singleEvent->tickets_invoice_from_id)
                ->first();

            $tax = $registration->ticketPriceNoVat / 100 * $registration->ticketsVat;
            $tax = number_format((float)$tax, 2);
            $total = $registration->ticketPriceNoVat + $tax;
            $total = number_format((float)$total, 2);

            $currency = $this->getCurrency($singleEvent->id);

            $pdf = PDF::loadView('invoices/tickets', [
                'registration' => $registration,
                'event' => $singleEvent,
                'event_logo' => $singleEventLookFeel->event_logo_url,
                'bg_color' => $singleEventLookFeel->background_color,
                'title_color' => $singleEventLookFeel->titles_color,
                'tax' => $tax,
                'total' => $total,
                'currency' => $currency,
                'payment' => $payment
            ])->setPaper('a4');

            return $pdf->download('ticket-proforma-invoice-' . $registration->invoiceTicket . '.pdf');

        }
        
        if ($type == 'download-voucher' || $type == 'send-voucher') {

            $registration = DB::table('registrations')
            ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries as leadCountries', 'leads.company_country', '=', 'leadCountries.id')
            ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
            ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
            ->selectRaw('tickets.name AS ticketName,
                leads.gender AS leadGender,
                leads.first_name AS leadFirstName,
                leads.last_name AS leadLastName,
                leads.email AS leadEmail,
                leads.company_name AS leadCompanyName,
                leads.company_address AS leadCompanyAddress,
                leads.company_city AS leadCompanyCity,
                leads.company_post_code AS leadCompanyPostalCode,
                leadCountries.country_name AS leadCompanyCountry,
                registrations.order_ticket AS orderTicket,
                registrations.order_accomodation AS orderAccomodation,
                registrations.order_transfer AS orderTransfer,
                registrations.barcode AS orderBarcode,
                room_types.type AS accomodationRoomName,
                room_types.price_without_vat AS accomodationPriceNoVat,
                room_types.vat AS accomodationPriceVat,
                accommodations.name AS accomodationName,
                registrations.accomodation_arrival_date AS accomodationArrival,
                registrations.accomodation_departure_date AS accomodationDeparture,
                registrations.accomodation_arrival_date AS accomodationArrivalData,
                registrations.accomodation_departure_date AS accomodationDepartureData,
                registrations.transfer_payer_id,
                registrations.accomodation_room_id')
            ->where('registrations.id', $registration_id)
            ->first();

            if ($registration->accomodationArrivalData && $registration->accomodationDepartureData) {
                $accomodationArrivalData = strtotime($registration->accomodationArrivalData);
                $accomodationDepartureData = strtotime($registration->accomodationDepartureData);
                $accomodationDays = $accomodationDepartureData - $accomodationArrivalData;
                $accomodationDays = floor($accomodationDays/(60*60*24));
            } else {
                $accomodationDays = false;
            }

            if ($registration->transfer_payer_id) {
                $transfers = DB::table('registrations')
                    ->join('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
                    ->join('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
                    ->selectRaw('transfers.description as description,
                        registration_has_transfers.transfer_start_ts as start')
                    ->where('registrations.id', $registration_id)
                    ->get();
            } else {
                $transfers = false;
            }

            $social_events = DB::table('registrations')
                ->join('registration_has_social_events', 'registrations.id', '=','registration_has_social_events.registration_id')
                ->join('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
                ->selectRaw('social_events.name, social_events.time')
                ->where('registrations.id', '=', $registration_id)
                ->whereNull('registrations.deleted_at')
                ->groupBy('social_events.id')
                ->get();
        }

        if ($type == 'download-voucher') {
            $pdf = PDF::loadView('vouchers/voucher-pdf', [
                'registration' => $registration,
                'event' => $singleEvent,
                'event_logo' => $singleEventLookFeel->event_logo_url,
                'bg_color' => $singleEventLookFeel->background_color,
                'title_color' => $singleEventLookFeel->titles_color,
                'accomodationDays' => $accomodationDays,
                'transfers' => $transfers,
                'social_events' => $social_events
            ])->setPaper('a4');

            return $pdf->download('voucher-' . $registration->orderBarcode .  '.pdf');
        }
        
        if ($type == 'send-voucher') {

            $email_data['event'] = $singleEvent;
            $email_data['registration'] = $registration;
            $email_data['event_logo'] = $singleEventLookFeel->event_logo_url;
            $email_data['bg_color'] = $singleEventLookFeel->background_color;
            $email_data['title_color'] = $singleEventLookFeel->titles_color;
            $email_data['accomodationDays'] = $accomodationDays;
            $email_data['transfers'] = $transfers;
            $email_data['social_events'] = $social_events;
            $email_data['orderBarcode'] = $registration->orderBarcode;
            $email_data['from_email'] = $singleEvent->email_sender;
            $email_data['from_name'] = $singleEvent->email_name;
            $email_data['reply_to'] = $singleEvent->email_sender;
            $email_data['send_to'] = $registration->leadEmail;
            if ($singleEvent->lang == 'hr') {
                if ($registration->leadGender == 'Ms.') {
                    $title = 'Draga ';
                } elseif($registration->leadGender == 'Mr.') {
                    $title = 'Dragi ';
                } else {
                    $title = 'Dragi/a ';
                }
                $email_data['title'] = 'Voucher za ' . $singleEvent->name;
                $email_data['content'] =
                    "<p style='font-size: 14px'>" . $title . $registration->leadFirstName . ",</p>
                    <p style='font-size: 14px'>U prilogu se nalazi voucher za " . $singleEvent->name . ". Molim Vas predočite ga prilikom posjeta.</p>
                    <p style='font-size: 14px'>Radujemo se Vašem dolasku, <br>" . $singleEvent->email_name . "</p>";
            } else {
                $email_data['title'] = 'Voucher for ' . $singleEvent->name;
                $email_data['content'] =
                    "<p style='font-size: 14px'>Dear " . $registration->leadFirstName . ",</p>
                    <p style='font-size: 14px'>The voucher for " . $singleEvent->name . " is in attachment. Please bring it to the event.</p>
                    <p style='font-size: 14px'>Looking forward to seeing You, <br>" . $singleEvent->email_name . "</p>";
            }

            Mail::queue('vouchers.voucher-mail', $email_data, function ($message) use ($email_data) {

				$pdf = PDF::loadView('vouchers/voucher-pdf', [
                    'registration' =>  $email_data['registration'],
                    'event' => $email_data['event'],
                    'event_logo' => $email_data['event_logo'],
                    'bg_color' => $email_data['bg_color'],
                    'title_color' =>  $email_data['title_color'],
                    'accomodationDays' => $email_data['accomodationDays'],
                    'transfers' => $email_data['transfers'],
                    'social_events' => $email_data['social_events'],
                ])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($pdf->output(), 'voucher-' . $email_data['orderBarcode'] . '.pdf');

            });

            DB::table('registrations')
                ->where('id', $registration_id)
                ->update([
                    'voucher_sent_ts' => $this->Now()
                ]);
            
            return 'sent';

        }

        return Redirect::back();
    }


    /**
     * Brisanje registracija
     */
    public function DeleteRegistration(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');

      if(!$registration_id || $type != 'registration') {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      DB::table('registrations')
        ->where('id', $registration_id)
        ->update([
          'deleted_at' => $this->Now()
        ]);

      // Deleted registration
      $this->Log(184, $registration_id);

      return Response::json([
        'msg' => 'registration_deleted'
      ]);

    }


    /**
     * Dohvat podataka aod strane datatables dodatka
     * Dohvaćamo popis svih registriranih leadova na zatraženom eventu
     */
    public function anyData(Request $request) {
      $event_code = $request->input('event_code');

      $singleEvent = $this->GetEvent($event_code);

      $registrations = DB::table('leads')
        ->leftJoin('registrations', 'leads.id', '=', 'registrations.lead_id')
        ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
        ->selectRaw('
          CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
          leads.company_name,
          leads.email,
          COALESCE(NULLIF(leads.phone, ""), leads.mobile) AS phone,
          tickets.name AS ticket_name,
          registrations.payment_option AS payment_option,
          DATE_FORMAT(registrations.registered_ts, "%Y-%m-%d %H:%i") AS registered_ts,
		  DATE_FORMAT(registrations.confirmed_ts, "%Y-%m-%d %H:%i") AS confirmed_ts,
          registrations.event_attended_flag,
          registrations.status_registration,
          registrations.id,
          registrations.voucher_sent_ts')
        ->where('registrations.event_id', '=', $singleEvent->id)
		->whereNull('registrations.deleted_at')
		->where(function($query) {
			$query->whereNotNull('registrations.registered_ts')
                ->orWhereNotNull('registrations.confirmed_ts');
		});

      return Datatables::of($registrations)
        ->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
        ->make(true);
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('event_code', $event_code)
	        ->first();

        return $singleEvent;
    }


    /**
     * Vrati podatke o look & feelu eventa
     */
    private function GetEventLookFeel($event_id) {
      $singleEventLookFeel = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->select('event_look_feels.event_logo_url', 'color_schemes.background_color', 'color_schemes.titles_color')
        ->where('events.id', '=', $event_id)
        ->firstOrFail();

      return $singleEventLookFeel;
    }


    /**
     * Dohvati currency code za zatraženi event
     */
    private function getCurrency($eventId) {
      $currency = DB::table('events')
        ->join('currencies', 'events.currency_id', '=', 'currencies.id')
        ->selectRaw('currencies.code as code')
        ->where('events.id', '=', $eventId)
        ->get();

      $eventCurrency = 0;
      foreach ($currency as $item) {
        $eventCurrency = $item->code;
      }

      return $eventCurrency;
    }


    /**
     * Export svih podataka iz registracije u Excel tablicu
     */
    public function ExportAll(Request $request, $event_code) {
      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
      $event_has_transfers = $this->eventHasTransfers($singleEvent->id);

      if ($event_has_accommodations == true && $event_has_transfers == true) {

        $exportData = DB::table('registrations')
          ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
          ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
          ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
          ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
		  ->leftJoin('countries', 'leads.company_country', '=','countries.id')
          ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
          ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
          ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
          ->leftJoin('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
          ->leftJoin('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
          ->leftJoin('registration_has_social_events', 'registration_has_social_events.registration_id', '=','registrations.id')
          ->leftJoin('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
          ->leftJoin('promo_codes', 'registrations.id', '=','promo_codes.registration_id')
          ->selectRaw("leads.title AS 'Lead Title',
                       leads.first_name AS 'Lead First Name',
                       leads.last_name AS 'Lead Last Name',
                       leads.email AS 'Lead E-mail',
                       leads.mobile AS 'Lead Mobile',
                       leads.phone AS 'Lead Phone',
                       leads.company_name AS 'Lead Company Name',
                       leads.job_function AS 'Lead Job Function',
                       leads.company_address AS 'Lead Company Address',
                       leads.company_city AS 'Lead Company City',
                       leads.company_post_code AS 'Lead Company Postal Code',
                       countries.country_name AS 'Lead Company Country',
                       leads.note AS 'Lead Note',
                       tickets.name AS 'Ticket Name',
                       tickets.accompany_persons AS 'Accompanying Person',
                       GROUP_CONCAT(DISTINCT social_events.name SEPARATOR ', ') AS 'Social Events',
                       tickets.price_without_VAT AS 'Ticket Price Without VAT',
                       tickets.VAT AS 'Ticket VAT',
                       promo_codes.code AS 'Ticket Promo Code',
                       registrations.payment_option AS 'Payment Option',
                       registrations.payment_cart AS 'Payment Cart',
                       registrations.payment_successful AS 'Payment Successful',
                       room_types.type AS 'Accommodation Type',
                       room_types.price_without_vat AS 'Accommodation Price Without VAT',
                       room_types.vat AS 'Accommodation VAT',
                       accommodations.name AS 'Accommodation Name',
                       registrations.accomodation_arrival_date AS 'Accomodation Arrival Data',
                       registrations.accomodation_departure_date AS 'Accomodation Departure Data',
                       registrations.accomodation_roomy_name AS 'Accomodation Roommate',
                       registrations.accomodation_note AS 'Accomodation Note',
                       GROUP_CONCAT(DISTINCT transfers.description SEPARATOR ', ') AS 'Transfer Type',
                       GROUP_CONCAT(DISTINCT registration_has_transfers.transfer_start_ts SEPARATOR ', ') AS 'Transfer Time',
                       GROUP_CONCAT(DISTINCT registration_has_transfers.flight_number SEPARATOR ', ') AS 'Transfer Flight Number',
                       GROUP_CONCAT(DISTINCT transfers.price_without_vat SEPARATOR ', ') AS 'Transfer Price Without VAT',
                       GROUP_CONCAT(DISTINCT transfers.vat SEPARATOR ', ') AS 'Transfer VAT',
                       registrations.invoice_ticket AS 'Ticket Invoice',
                       registrations.order_ticket AS 'Ticket Order',
                       ticket.company_name AS 'Ticket Invoice Company Name',
                       ticket.vat AS 'Ticket Invoice VAT',
                       ticket.address AS 'Ticket Invoice Address',
                       ticket.city AS 'Ticket Invoice City',
                       ticket.post_code AS 'Ticket Invoice Postal Code',
                       ticket.country AS 'Ticket Invoice Country',
                       ticket.first_name AS 'Ticket Invoice First Name',
                       ticket.last_name AS 'Ticket Invoice Last Name',
                       ticket.email AS 'Ticket Invoice E-mail',
                       ticket.phone AS 'Ticket Invoice Phone',
                       registrations.invoice_accomodation AS 'Accommodation Invoice',
                       registrations.order_accomodation AS 'Accommodation Order',
                       accomodation.company_name AS 'Accommodation Invoice Company Name',
                       accomodation.vat AS 'Accommodation Invoice VAT',
                       accomodation.address AS 'Accommodation Invoice Address',
                       accomodation.city AS 'Accommodation Invoice City',
                       accomodation.post_code AS 'Accommodation Invoice Postal Code',
                       accomodation.country AS 'Accommodation Invoice Country',
                       accomodation.first_name AS 'Accommodation Invoice First Name',
                       accomodation.last_name AS 'Accommodation Invoice Last Name',
                       accomodation.email AS 'Accommodation Invoice E-mail',
                       accomodation.phone AS 'Accommodation Invoice Phone',
                       registrations.invoice_transfer AS 'Transfer Invoice',
                       registrations.order_transfer AS 'Transfer Order',
                       transfer.company_name AS 'Transfer Invoice Company Name',
                       transfer.vat AS 'Transfer Invoice VAT',
                       transfer.address AS 'Transfer Address Invoice',
                       transfer.city AS 'Transfer Invoice City',
                       transfer.post_code AS 'Transfer Invoice Postal Code',
                       transfer.country AS 'Transfer Invoice Country',
                       transfer.first_name AS 'Transfer Invoice First Name',
                       transfer.last_name AS 'Transfer Invoice Last Name',
                       transfer.email AS 'Transfer Invoice E-mail',
                       transfer.phone AS 'Transfer Invoice Phone',
                       registrations.status_registration AS 'Registration Status',
                       registrations.status_accomodation AS 'Accommodation Status',
                       registrations.status_transfer AS 'Transfer Status',
                       registrations.accomodation_approved AS 'Accommodation Approved',
                       registrations.transfer_approved AS 'Transfer Approved',
                       IFNULL(registrations.registered_ts, registrations.confirmed_ts) AS 'Registered Timestamp',
                       registrations.event_attended_flag AS 'Attended',
                       registrations.attended_ts AS 'Attended Timestamp',
                       registrations.gifts_ts AS 'Gift Timestamp',
                       registrations.barcode AS 'Barcode',
                       registrations.nametag_generated AS 'Nametag Generated'")
            ->where('registrations.event_id', '=', $singleEvent->id)
            ->whereNull('registrations.deleted_at')
            ->whereNull('leads.deleted_at')
            ->where(function($query) {
    			$query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
    		})
            ->groupBy('registrations.lead_id')
            ->orderBy('registrations.registered_ts', 'desc')
            ->orderBy('registrations.confirmed_ts', 'desc')
            ->get();

      } elseif ($event_has_accommodations == true) {

        $exportData = DB::table('registrations')
          ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
          ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
          ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
          ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
		  ->leftJoin('countries', 'leads.company_country', '=','countries.id')
          ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
          ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
          ->leftJoin('registration_has_social_events', 'registration_has_social_events.registration_id', '=','registrations.id')
          ->leftJoin('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
          ->leftJoin('promo_codes', 'registrations.id', '=','promo_codes.registration_id')
          ->selectRaw("leads.title AS 'Lead Title',
                       leads.first_name AS 'Lead First Name',
                       leads.last_name AS 'Lead Last Name',
                       leads.email AS 'Lead E-mail',
                       leads.mobile AS 'Lead Mobile',
                       leads.phone AS 'Lead Phone',
                       leads.company_name AS 'Lead Company Name',
                       leads.job_function AS 'Lead Job Function',
                       leads.company_address AS 'Lead Company Address',
                       leads.company_city AS 'Lead Company City',
                       leads.company_post_code AS 'Lead Company Postal Code',
                       countries.country_name AS 'Lead Company Country',
                       leads.note AS 'Lead Note',
                       tickets.name AS 'Ticket Name',
                       tickets.accompany_persons AS 'Accompanying Person',
                       GROUP_CONCAT(DISTINCT social_events.name SEPARATOR ', ') AS 'Social Events',
                       tickets.price_without_VAT AS 'Ticket Price Without VAT',
                       tickets.VAT AS 'Ticket VAT',
                       promo_codes.code AS 'Ticket Promo Code',
                       registrations.payment_option AS 'Payment Option',
                       registrations.payment_cart AS 'Payment Cart',
                       registrations.payment_successful AS 'Payment Successful',
                       room_types.type AS 'Accommodation Type',
                       room_types.price_without_vat AS 'Accommodation Price Without VAT',
                       room_types.vat AS 'Accommodation VAT',
                       accommodations.name AS 'Accommodation Name',
                       registrations.accomodation_arrival_date AS 'Accomodation Arrival Data',
                       registrations.accomodation_departure_date AS 'Accomodation Departure Data',
                       registrations.accomodation_roomy_name AS 'Accomodation Roommate',
                       registrations.accomodation_note AS 'Accomodation Note',
                       registrations.invoice_ticket AS 'Ticket Invoice',
                       registrations.order_ticket AS 'Ticket Order',
                       ticket.company_name AS 'Ticket Invoice Company Name',
                       ticket.vat AS 'Ticket Invoice VAT',
                       ticket.address AS 'Ticket Invoice Address',
                       ticket.city AS 'Ticket Invoice City',
                       ticket.post_code AS 'Ticket Invoice Postal Code',
                       ticket.country AS 'Ticket Invoice Country',
                       ticket.first_name AS 'Ticket Invoice First Name',
                       ticket.last_name AS 'Ticket Invoice Last Name',
                       ticket.email AS 'Ticket Invoice E-mail',
                       ticket.phone AS 'Ticket Invoice Phone',
                       registrations.invoice_accomodation AS 'Accommodation Invoice',
                       registrations.order_accomodation AS 'Accommodation Order',
                       accomodation.company_name AS 'Accommodation Invoice Company Name',
                       accomodation.vat AS 'Accommodation Invoice VAT',
                       accomodation.address AS 'Accommodation Invoice Address',
                       accomodation.city AS 'Accommodation Invoice City',
                       accomodation.post_code AS 'Accommodation Invoice Postal Code',
                       accomodation.country AS 'Accommodation Invoice Country',
                       accomodation.first_name AS 'Accommodation Invoice First Name',
                       accomodation.last_name AS 'Accommodation Invoice Last Name',
                       accomodation.email AS 'Accommodation Invoice E-mail',
                       accomodation.phone AS 'Accommodation Invoice Phone',
                       registrations.status_registration AS 'Registration Status',
                       registrations.status_accomodation AS 'Accommodation Status',
                       registrations.accomodation_approved AS 'Accommodation Approved',
                       IFNULL(registrations.registered_ts, registrations.confirmed_ts) AS 'Registered Timestamp',
                       registrations.event_attended_flag AS 'Attended',
                       registrations.attended_ts AS 'Attended Timestamp',
                       registrations.gifts_ts AS 'Gift Timestamp',
                       registrations.barcode AS 'Barcode',
                       registrations.nametag_generated AS 'Nametag Generated'")
            ->where('registrations.event_id', '=', $singleEvent->id)
            ->whereNull('registrations.deleted_at')
            ->whereNull('leads.deleted_at')
            ->where(function($query) {
    			$query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
    		})
            ->groupBy('registrations.lead_id')
            ->orderBy('registrations.registered_ts', 'desc')
            ->orderBy('registrations.confirmed_ts', 'desc')
            ->get();

      } elseif ($event_has_transfers == true) {

        $exportData = DB::table('registrations')
          ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
          ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
		  ->leftJoin('countries', 'leads.company_country', '=','countries.id')
          ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
          ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
          ->leftJoin('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
          ->leftJoin('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
          ->leftJoin('registration_has_social_events', 'registration_has_social_events.registration_id', '=','registrations.id')
          ->leftJoin('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
          ->leftJoin('promo_codes', 'registrations.id', '=','promo_codes.registration_id')
          ->selectRaw("leads.title AS 'Lead Title',
                       leads.first_name AS 'Lead First Name',
                       leads.last_name AS 'Lead Last Name',
                       leads.email AS 'Lead E-mail',
                       leads.mobile AS 'Lead Mobile',
                       leads.phone AS 'Lead Phone',
                       leads.company_name AS 'Lead Company Name',
                       leads.job_function AS 'Lead Job Function',
                       leads.company_address AS 'Lead Company Address',
                       leads.company_city AS 'Lead Company City',
                       leads.company_post_code AS 'Lead Company Postal Code',
                       countries.country_name AS 'Lead Company Country',
                       leads.note AS 'Lead Note',
                       tickets.name AS 'Ticket Name',
                       tickets.accompany_persons AS 'Accompanying Person',
                       GROUP_CONCAT(DISTINCT social_events.name SEPARATOR ', ') AS 'Social Events',
                       tickets.price_without_VAT AS 'Ticket Price Without VAT',
                       tickets.VAT AS 'Ticket VAT',
                       promo_codes.code AS 'Ticket Promo Code',
                       registrations.payment_option AS 'Payment Option',
                       registrations.payment_cart AS 'Payment Cart',
                       registrations.payment_successful AS 'Payment Successful',
                       GROUP_CONCAT(DISTINCT transfers.description SEPARATOR ', ') AS 'Transfer Type',
                       GROUP_CONCAT(DISTINCT registration_has_transfers.transfer_start_ts SEPARATOR ', ') AS 'Transfer Time',
                       GROUP_CONCAT(DISTINCT registration_has_transfers.flight_number SEPARATOR ', ') AS 'Transfer Flight Number',
                       GROUP_CONCAT(DISTINCT transfers.price_without_vat SEPARATOR ', ') AS 'Transfer Price Without VAT',
                       GROUP_CONCAT(DISTINCT transfers.vat SEPARATOR ', ') AS 'Transfer VAT',
                       registrations.invoice_ticket AS 'Ticket Invoice',
                       registrations.order_ticket AS 'Ticket Order',
                       ticket.company_name AS 'Ticket Invoice Company Name',
                       ticket.vat AS 'Ticket Invoice VAT',
                       ticket.address AS 'Ticket Invoice Address',
                       ticket.city AS 'Ticket Invoice City',
                       ticket.post_code AS 'Ticket Invoice Postal Code',
                       ticket.country AS 'Ticket Invoice Country',
                       ticket.first_name AS 'Ticket Invoice First Name',
                       ticket.last_name AS 'Ticket Invoice Last Name',
                       ticket.email AS 'Ticket Invoice E-mail',
                       ticket.phone AS 'Ticket Invoice Phone',
                       registrations.invoice_transfer AS 'Transfer Invoice',
                       registrations.order_transfer AS 'Transfer Order',
                       transfer.company_name AS 'Transfer Invoice Company Name',
                       transfer.vat AS 'Transfer Invoice VAT',
                       transfer.address AS 'Transfer Address Invoice',
                       transfer.city AS 'Transfer Invoice City',
                       transfer.post_code AS 'Transfer Invoice Postal Code',
                       transfer.country AS 'Transfer Invoice Country',
                       transfer.first_name AS 'Transfer Invoice First Name',
                       transfer.last_name AS 'Transfer Invoice Last Name',
                       transfer.email AS 'Transfer Invoice E-mail',
                       transfer.phone AS 'Transfer Invoice Phone',
                       registrations.status_registration AS 'Registration Status',
                       registrations.status_transfer AS 'Transfer Status',
                       registrations.transfer_approved AS 'Transfer Approved',
                       IFNULL(registrations.registered_ts, registrations.confirmed_ts) AS 'Registered Timestamp',
                       registrations.event_attended_flag AS 'Attended',
                       registrations.attended_ts AS 'Attended Timestamp',
                       registrations.gifts_ts AS 'Gift Timestamp',
                       registrations.barcode AS 'Barcode',
                       registrations.nametag_generated AS 'Nametag Generated'")
            ->where('registrations.event_id', '=', $singleEvent->id)
            ->whereNull('registrations.deleted_at')
            ->whereNull('leads.deleted_at')
            ->where(function($query) {
    			$query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
    		})
            ->groupBy('registrations.lead_id')
            ->orderBy('registrations.registered_ts', 'desc')
            ->orderBy('registrations.confirmed_ts', 'desc')
            ->get();

      } else {

        $exportData = DB::table('registrations')
          ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
          ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
		  ->leftJoin('countries', 'leads.company_country', '=','countries.id')
          ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
          ->leftJoin('registration_has_social_events', 'registration_has_social_events.registration_id', '=','registrations.id')
          ->leftJoin('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
          ->leftJoin('promo_codes', 'registrations.id', '=','promo_codes.registration_id')
          ->selectRaw("leads.title AS 'Lead Title',
                       leads.first_name AS 'Lead First Name',
                       leads.last_name AS 'Lead Last Name',
                       leads.email AS 'Lead E-mail',
                       leads.mobile AS 'Lead Mobile',
                       leads.phone AS 'Lead Phone',
                       leads.company_name AS 'Lead Company Name',
                       leads.job_function AS 'Lead Job Function',
                       leads.company_address AS 'Lead Company Address',
                       leads.company_city AS 'Lead Company City',
                       leads.company_post_code AS 'Lead Company Postal Code',
                       countries.country_name AS 'Lead Company Country',
                       leads.note AS 'Lead Note',
                       tickets.name AS 'Ticket Name',
                       tickets.accompany_persons AS 'Accompanying Person',
                       GROUP_CONCAT(DISTINCT social_events.name SEPARATOR ', ') AS 'Social Events',
                       tickets.price_without_VAT AS 'Ticket Price Without VAT',
                       tickets.VAT AS 'Ticket VAT',
                       promo_codes.code AS 'Ticket Promo Code',
                       registrations.payment_option AS 'Payment Option',
                       registrations.payment_cart AS 'Payment Cart',
                       registrations.payment_successful AS 'Payment Successful',
                       registrations.invoice_ticket AS 'Ticket Invoice',
                       registrations.order_ticket AS 'Ticket Order',
                       ticket.company_name AS 'Ticket Invoice Company Name',
                       ticket.vat AS 'Ticket Invoice VAT',
                       ticket.address AS 'Ticket Invoice Address',
                       ticket.city AS 'Ticket Invoice City',
                       ticket.post_code AS 'Ticket Invoice Postal Code',
                       ticket.country AS 'Ticket Invoice Country',
                       ticket.first_name AS 'Ticket Invoice First Name',
                       ticket.last_name AS 'Ticket Invoice Last Name',
                       ticket.email AS 'Ticket Invoice E-mail',
                       ticket.phone AS 'Ticket Invoice Phone',
                       registrations.status_registration AS 'Registration Status',
                       IFNULL(registrations.registered_ts, registrations.confirmed_ts) AS 'Registered Timestamp',
                       registrations.event_attended_flag AS 'Attended',
                       registrations.attended_ts AS 'Attended Timestamp',
                       registrations.gifts_ts AS 'Gift Timestamp',
                       registrations.barcode AS 'Barcode',
                       registrations.nametag_generated AS 'Nametag Generated'")
            ->where('registrations.event_id', '=', $singleEvent->id)
            ->whereNull('registrations.deleted_at')
            ->whereNull('leads.deleted_at')
            ->where(function($query) {
    			$query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
    		})
            ->groupBy('registrations.lead_id')
            ->orderBy('registrations.registered_ts', 'desc')
            ->orderBy('registrations.confirmed_ts', 'desc')
            ->get();

      }

      $data = array();
      foreach($exportData as $result) {
        $data[] = (array)$result;
      }

      Excel::create('Registrations Report - ' . $singleEvent->name, function($excel) use($data, $singleEvent) {

        $excel->setTitle('Registrations Report - ' . $singleEvent->name);

        $excel->sheet('Report', function($sheet) use($data) {

          $sheet->setOrientation('landscape');

          $sheet->fromArray($data, null, '', true);

        });

      })->download('xlsx');
    }
}
