<?php

namespace App\Http\Controllers\Events\Reports;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Leads as Leads;
use App\Event as Event;
use View;
use DB;
use Response;
use Auth;
use Datatables;
use Redirect;
use PDF;

class ReportTransfersController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prikaz podataka o transfers
     */
    public function GetTransfers($event_code) {
        // Dohvati podatke o eventu
        $singleEvent = $this->GetEvent($event_code);

        if($singleEvent) {

          View::share('singleEvent', $singleEvent);
          View::share('event_code', $event_code);
          View::share('title', 'Transfers - ' . $singleEvent->name);

          $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
          View::share('event_has_transfers', $event_has_transfers);

          View::share('pro_forma_invoice', MODULE_PROFORMA_INVOICE);

          return view('events/reports/report-transfers');

        } else {

          return redirect()->route('home');

        }
    }


    /**
     * Promijeni status registracije
     */
    public function UpdateRegistrationStatus(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');
      $status = $request->input('status');
      $form_type = $request->input('form_type');

      if($form_type == 'change_registration') {
        $selected_type = $request->input('selected_option');
        $ids = $request->input('registration_checkbox');
        $transfer_ids = $request->input('transfer_checkbox');

        if ($selected_type == 'confirmed') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'transfer_approved' => 1,
                'status_transfer' => 'Confirmed'
              ));
          }
        }

        if ($selected_type == 'canceled') {
          foreach ($ids as $id) {
            DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'transfer_approved' => 0,
                'status_transfer' => 'Canceled'
              ));
          }
        }

        if ($selected_type == 'delete') {
          $counter = 0;

          foreach ($ids as $id) {
            $nmb_registration_transfers = DB::table('registration_has_transfers')
            ->where('registration_id', '=', $id)
            ->count();

            DB::table('registration_has_transfers')
            ->where('id', '=', $transfer_ids[$counter])
            ->delete();

            if($nmb_registration_transfers == 1) {
              DB::table('registrations')
              ->where('id', '=', $id)
              ->update(array(
                'transfer_payer_id' => NULL,
                'transfer_approved' => NULL
              ));
            }
            $counter++;
          }
        }

        return Redirect::back();
      }

      if(!$registration_id || $type != 'transfer') {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      if($status == 'confirmed') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'transfer_approved' => 1,
            'status_transfer' => 'Confirmed'
          ));

      } elseif($status == 'canceled') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'transfer_approved' => 0,
            'status_transfer' => 'Canceled'
          ));

      }

      // Updated registration transfer status
      $this->Log(183, $registration_id);

      return Response::json([
        'msg' => 'status_changed'
      ]);
    }


    /**
     * Genneriranje invoicea
     */
    public function GenerateInvoice(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $invoice_type = $request->input('type');

      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      // Dohvati podatke o look & feelu eventa
      $singleEventLookFeel = $this->GetEventLookFeel($singleEvent->id);

      if($invoice_type == 'transfers') {

        if ($registration_id) {

          $registration = DB::table('registrations')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries as leadCountries', 'leads.company_country', '=', 'leadCountries.id')
            ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
            ->leftJoin('countries as transferCountries', 'transfer.country', '=', 'transferCountries.id')
            ->selectRaw('leads.title AS leadTitle,
              leads.first_name AS leadFirstName,
              leads.last_name AS leadLastName,
              leads.email AS leadEmail,
              leads.mobile AS leadMobile,
              leads.phone AS leadPhone,
              leads.company_name AS leadCompanyName,
              leads.job_function AS leadJobFunction,
              leads.company_address AS leadCompanyAddress,
              leads.company_city AS leadCompanyCity,
              leads.company_post_code AS leadCompanyPostalCode,
              leadCountries.country_name AS leadCompanyCountry,
              leads.note AS leadNote,
              transfer.id AS transferId,
              transfer.type AS transferType,
              transfer.personal_id AS transferPersonalId,
              transfer.company_name AS transferCompanyName,
              transfer.vat AS transferVat,
              transfer.address AS transferAddress,
              transfer.city AS transferCity,
              transfer.post_code AS transferPostalCode,
              transferCountries.country_name AS transferCountry,
              transfer.first_name AS transferFirstName,
              transfer.last_name AS transferLastName,
              transfer.email AS transferEmail,
              transfer.phone AS transferPhone,
              registrations.invoice_ticket AS invoiceTicket,
              registrations.invoice_accomodation AS invoiceAccomodation,
              registrations.invoice_transfer AS invoiceTransfer,
              registrations.order_ticket AS orderTicket,
              registrations.order_accomodation AS orderAccomodation,
              registrations.order_transfer AS orderTransfer')
            ->where('registrations.id', '=', $registration_id)
            ->first();

          $payment = DB::table('invoice_froms')
            ->where('id', '=', $singleEvent->accomodation_invoice_from_id)
            ->first();

          $transfers = DB::table('registrations')
                        ->join('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
                        ->join('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
                        ->selectRaw('transfers.description as description,
                                     transfers.price_without_vat as priceNoVat,
                                     transfers.vat as vat')
                        ->where('registrations.id', '=', $registration_id)
                        ->get();

        } else {

          return Redirect::back();

        }

        $transfer_total_no_vat = 0;
        $transfer_total_only_vat = 0;

        foreach($transfers as $transfer) {

          $transfer_total_no_vat = $transfer_total_no_vat + $transfer->priceNoVat;

          $transfer_total_only_vat = $transfer_total_only_vat + $transfer->priceNoVat / 100 * $transfer->vat;

        }

        $transfer_total_with_vat = $transfer_total_no_vat + $transfer_total_only_vat;

        $transfer_total_no_vat = number_format((float)$transfer_total_no_vat, 2);
        $transfer_total_only_vat = number_format((float)$transfer_total_only_vat, 2);
        $transfer_total_with_vat = number_format((float)$transfer_total_with_vat, 2);

        $currency = $this->getCurrency($singleEvent->id);

        $pdf = PDF::loadView('invoices/transfers', [
          'registration' => $registration,
          'event' => $singleEvent,
          'event_logo' => $singleEventLookFeel->event_logo_url,
          'bg_color' => $singleEventLookFeel->background_color,
          'title_color' => $singleEventLookFeel->titles_color,
          'transfer_total_no_vat' => $transfer_total_no_vat,
          'transfer_total_only_vat' => $transfer_total_only_vat,
          'transfer_total_with_vat' => $transfer_total_with_vat,
          'currency' => $currency,
          'payment' => $payment,
          'transfers' => $transfers
        ])->setPaper('a4');

        if ($pdf) {

          return $pdf->download('transfer-proforma-invoice-' . $registration->invoiceTransfer . '.pdf');

        }

      } else {

        return Redirect::back();

      }

    }


    /**
     * Brisanje registracija
     */
    public function DeleteRegistration(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $transfer_id = $request->input('transfer_id');
      $type = $request->input('type');

      if(!$registration_id || !$transfer_id || $type != 'transfer') {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      $nmb_registration_transfers = DB::table('registration_has_transfers')
        ->where('registration_id', '=', $registration_id)
        ->count();

      if($nmb_registration_transfers == 1) {
        DB::table('registrations')
        ->where('id', '=', $registration_id)
        ->update(array(
          'transfer_payer_id' => NULL,
          'transfer_approved' => NULL
        ));
      }

      DB::table('registration_has_transfers')
        ->where('id', '=', $transfer_id)
        ->delete();

      // Deleted registration transfer
      $this->Log(186, $registration_id);

      return Response::json([
        'msg' => 'transfer_deleted'
      ]);
    }


    /**
     * Dohvat podataka aod strane datatables dodatka
     * Dohvaćamo popis svih leadova na zatraženom eventu koji su odabrali transfers
     */
    public function anyData(Request $request) {
      $event_code = $request->input('event_code');

      $singleEvent = $this->GetEvent($event_code);

      $transfers = DB::table('registrations')
        ->join('leads', 'registrations.lead_id', '=', 'leads.id')
        ->join('registration_has_transfers', 'registrations.id', '=', 'registration_has_transfers.registration_id')
        ->join('transfers', 'registration_has_transfers.transfer_id', '=', 'transfers.id')
        ->selectRaw('
          CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
          DATE_FORMAT(registration_has_transfers.transfer_start_ts, "%Y-%m-%d %H:%i") AS date,
          transfers.description AS description,
          registrations.status_transfer,
          registrations.id,
          registration_has_transfers.id AS transfer_id,
          DATE_FORMAT(registrations.registered_ts, "%Y-%m-%d %H:%i") AS registered_ts')
        ->where('transfers.event_id', '=', $singleEvent->id)
        ->whereNotNull('registrations.registered_ts')
        ->whereNull('registrations.deleted_at');

      return Datatables::of($transfers)
        ->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
        ->make(true);
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
        $singleEvent = Event::where('events.event_code', '=', $event_code)
                            ->first();

        return $singleEvent;
    }


    /**
     * Vrati podatke o look & feelu eventa
     */
    private function GetEventLookFeel($event_id) {
      $singleEventLookFeel = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->select('event_look_feels.event_logo_url', 'color_schemes.background_color', 'color_schemes.titles_color')
        ->where('events.id', '=', $event_id)
        ->firstOrFail();

      return $singleEventLookFeel;
    }


    /**
     * Dohvati currency code za zatraženi event
     */
    private function getCurrency($eventId) {
      $currency = DB::table('events')
        ->join('currencies', 'events.currency_id', '=', 'currencies.id')
        ->selectRaw('currencies.code as code')
        ->where('events.id', '=', $eventId)
        ->get();

      $eventCurrency = 0;
      foreach ($currency as $item) {
        $eventCurrency = $item->code;
      }

      return $eventCurrency;
    }
}
