<?php

namespace App\Http\Controllers\Events\Sessions;

use Illuminate\Http\Request;
use App\Http\Requests;

// Krik
use App\Http\Controllers\MainController as MainController;
use View;
use DB;
use Carbon\Carbon;
use Redirect;
use Response;
use Datatables;
use Excel;
use App\Event as Event;

class SessionsController extends MainController {
	public function __construct() {
		parent::__construct();

		// CSS i JS assets for page
		$this->css['pages'] = [
			'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
			'global/plugins/bower_components/animate.css/animate.min.css',
			'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.css',
			'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css'
		];
		$this->css['themes'] = [
			'admin/css/reset.css',
			'admin/css/layout.css',
			'admin/css/components.css',
			'admin/css/plugins.css',
			'admin/css/themes/laravel.theme.css',
			'admin/css/custom.css',
		];
		$this->js['plugins'] = [
          'global/plugins/bower_components/bootstrap-datepicker-vitalets/js/bootstrap-datepicker.js',
          'global/plugins/bower_components/moment/min/moment.min.js',
          'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.js',
		  'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
		  'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
		  'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
		  'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
		  'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
		  'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
		  'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
		  'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js'
        ];
		$this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js'
        ];

		View::share('css', $this->css);
		View::share('js', $this->js);
		View::share('title', 'Sessions');
	}
	
	/**
     * Prikaži sve sessione za event
     */
	public function GetSessions($event_code) {
		$this->PreparePage($event_code);
		
		return view('events/sessions/sessions');
	}
	
	/**
     * Prikaži sessione za event za uređivanje
     */
	public function GetManageSessions($event_code) {
		$this->PreparePage($event_code);
		
		return view('events/sessions/manage');
	}
	
	/**
     * Dodaj novi session za event
     */
	public function AddSession($event_code) {
		$this->PreparePage($event_code);
		
		return view('events/sessions/new');
	}
	
	/**
     * Spremi novi session za event
     */
	public function CreateSession($event_code, Request $request) {
		$this->PreparePage($event_code);

		$this->validate($request, [
			'name' => 'required|string',
			'location' => 'required|string',
			'start' => 'required|date_format:"d/m/Y H:i"',
			'end' => 'required|date_format:"d/m/Y H:i"'
		]);
		
		$session_id = DB::table('sessions')
			->insertGetId([
				'name' => $request->input('name'),
				'location' => $request->input('location'),
				'start_ts' => Carbon::createFromFormat('d/m/Y H:i', $request->input('start'))->toDateTimeString(),
				'end_ts' => Carbon::createFromFormat('d/m/Y H:i', $request->input('end'))->toDateTimeString(),
				'description' => $request->input('description'),
				'event_id' => Event::where('event_code', $event_code)->first()->id,
				'session_code' => $this->GenerateSessionCode()
			]);
			
		// New session
		$this->Log(191, $session_id);
		
		return Redirect::route('sessions-manage', array($event_code));
	}
	
	/**
     * Prikaži polje za evidenciju dolaska leada na session za event
     */
	public function GetSession($event_code, $session_code) {
		$this->PreparePage($event_code);
		
		View::share('session', $this->GetSessionData($session_code));
		
		View::share('status', null);
		View::share('lead', null);
		
		return view('events/sessions/session');
	}
	
	/**
     * Spremi evidenciju dolaska leada na session za event
     */
	public function SaveSession($event_code, $session_code, Request $request) {
		$this->PreparePage($event_code);
		
		$event = $this->GetEventData($event_code);
		
		$session = $this->GetSessionData($session_code);
		View::share('session', $session);

		$registration = DB::table('registrations')
			->where('barcode', $request->input('barcode'))
			->first();
		
		// Provjeri da li registracija s unesenim barcodom postoji
		if ($registration) {
			
			// Pazi da barcode mora odgovarati eventu na kojem ga unosimo
            if($registration->event_id != $event->id) {

                  View::share('status', 'wrong');
                  View::share('lead', 'nope');

                  return view('events/sessions/session');

            }
			
			$lead = DB::table('leads')
				->where('id', $registration->lead_id)
				->first();
			
			$session_attended = DB::table('session_has_leads')
				->where([
					'lead_id' => $registration->lead_id,
					'session_id' => $session->id
				])
				->first();
			
			// Pazi da barcode nije već registriran
            if ($session_attended) {
				
				View::share('status', 'registered');
				View::share('lead', $lead);

				return view('events/sessions/session');

			}
			
			// Spremi dolazak
			$attendence_id = DB::table('session_has_leads')
				->insertGetId([
					'lead_id' => $registration->lead_id,
					'session_id' => $session->id,
					'attended_ts' => $this->Now()
				]);
				
			// Updated session status
            $this->Log(190, $attendence_id);
				
			View::share('status', 'new');
			View::share('lead', $lead);
			
		} else {
			
			View::share('lead', 'nope');
            View::share('status', 'nope');
			
		}
		
		return view('events/sessions/session');
	}
	
	/**
     * Prikaži report dolaznosti za session za event
     */
	public function GetReportSession($event_code, $session_code) {
		$this->PreparePage($event_code);
		
		$session = $this->GetSessionData($session_code);
		View::share('session', $session);
		
		return view('events/sessions/report');
	}
	
	/**
     * Export dolaznosti na session
     */
	public function ExportReportSession($event_code, $session_code) {
		$session = $this->GetSessionData($session_code);
		
		$attendees = DB::table('session_has_leads')
			->leftJoin('leads', 'session_has_leads.lead_id', '=', 'leads.id')
			->leftJoin('countries', 'leads.company_country', '=','countries.id')
			->leftJoin('sessions', 'session_has_leads.session_id', '=', 'sessions.id')
			->selectRaw("
				leads.title AS 'Lead Title',
				leads.first_name AS 'Lead First Name',
				leads.last_name AS 'Lead Last Name',
				leads.email AS 'Lead E-mail',
				leads.mobile AS 'Lead Mobile',
				leads.phone AS 'Lead Phone',
				leads.company_name AS 'Lead Company Name',
				leads.job_function AS 'Lead Job Function',
				leads.company_address AS 'Lead Company Address',
				leads.company_city AS 'Lead Company City',
				leads.company_post_code AS 'Lead Company Postal Code',
				countries.country_name AS 'Lead Company Country',
				leads.note AS 'Lead Note',
				DATE_FORMAT(session_has_leads.attended_ts, '%Y-%m-%d %H:%i') AS 'Attended At'")
			->where('sessions.session_code', $session_code)
			->whereNull('sessions.deleted_at')
			->groupBy('leads.id')
			->orderBy('session_has_leads.attended_ts')
			->get();
			
		$data = array();
        foreach($attendees as $attendee) {
			$data[] = (array)$attendee;
        }
			
		Excel::create('Session Attendees - ' . $session->name, function($excel) use($data, $session) {
          $excel->setTitle('Session Attendees - ' . $session->name);
          $excel->sheet('Report', function($sheet) use($data) {
            $sheet->setOrientation('landscape');
            $sheet->fromArray($data, null, '', true);
          });
        })->download('xlsx');
	}
	
	/**
     * Uredi podatke za session za event
     */
	public function EditSession($event_code, $session_code) {
		$this->PreparePage($event_code);
		
		$session = $this->GetSessionData($session_code);
		View::share('session', $session);
		
		return view('events/sessions/edit');
	}
	
	/**
     * Spremi uređene podatke za session za event
     */
	public function UpdateSession($event_code, $session_code, Request $request) {
		$this->PreparePage($event_code);

		$this->validate($request, [
			'name' => 'required|string',
			'location' => 'required|string',
			'start' => 'required|date_format:"d/m/Y H:i"',
			'end' => 'required|date_format:"d/m/Y H:i"'
		]);
		
		DB::table('sessions')
			->where('session_code', $session_code)
			->update([
				'name' => $request->input('name'),
				'location' => $request->input('location'),
				'start_ts' => Carbon::createFromFormat('d/m/Y H:i', $request->input('start'))->toDateTimeString(),
				'end_ts' => Carbon::createFromFormat('d/m/Y H:i', $request->input('end'))->toDateTimeString(),
				'description' => $request->input('description')
			]);
			
		$session_id = DB::table('sessions')
			->where('session_code', $session_code)
			->value('id');
			
		// Updated session
		$this->Log(192, $session_id);
		
		return Redirect::route('sessions-manage', array($event_code));
	}
	
	/**
     * Obriši session za event
     */
	public function DeleteSession($event_code, Request $request) {
		$session_id = $request->input('id');
		
		if(!$session_id) return Response::json(['message' => 'error']);
		
		DB::table('sessions')
          ->where('id', $session_id)
          ->update(array(
            'deleted_at' => $this->Now()
          ));
		  
	  // Deleted session
	  $this->Log(193, $session_id);
	  
	  return Response::json(['message' => 'deletad']);
	}
	
	/**
     * Dohvat podataka od strane datatables dodatka
     * Dohvaćamo popis svih sessiona na zatraženom eventu
     */
    public function anySessionsData(Request $request) {
		$sessions = DB::table('sessions')
			->leftJoin('session_has_leads', 'session_has_leads.session_id', '=', 'sessions.id')
			->selectRaw('
				sessions.id AS id,
				sessions.session_code AS session_code,
				sessions.name AS name,
				sessions.location AS location,
				DATE_FORMAT(sessions.start_ts, "%Y-%m-%d %H:%i") AS start_ts,
				DATE_FORMAT(sessions.end_ts, "%Y-%m-%d %H:%i") AS end_ts,
				COUNT(session_has_leads.id) AS attendees')
			->where('event_id', Event::where('event_code', $request->input('event_code'))->first()->id)
			->whereNull('sessions.deleted_at')
			->groupBy('sessions.id')
			->orderBy('sessions.start_ts');

		return Datatables::of($sessions)
			->make(true);
    }
	
	/**
     * Dohvat podataka od strane datatables dodatka
     * Dohvaćamo popis svih leadova koji su attendali session
     */
    public function anySessionReportData(Request $request) {
		$attendees = DB::table('session_has_leads')
			->leftJoin('leads', 'session_has_leads.lead_id', '=', 'leads.id')
			->leftJoin('sessions', 'session_has_leads.session_id', '=', 'sessions.id')
			->selectRaw('
				CONCAT(leads.title, " ", leads.first_name, " ", leads.last_name) AS name,
				leads.company_name AS company,
	            leads.email AS email,
	            leads.phone AS phone,
	            DATE_FORMAT(session_has_leads.attended_ts, "%Y-%m-%d %H:%i") AS attended_ts')
			->where('sessions.session_code', $request->input('session_code'))
			->whereNull('sessions.deleted_at')
			->groupBy('leads.id')
			->orderBy('session_has_leads.attended_ts');

		return Datatables::of($attendees)
			->filterColumn('name', 'whereRaw', "CONCAT(leads.title, ' ', leads.first_name, ' ', leads.last_name) like ? ", ["$1"])
			->make(true);
    }
	
	/**
	 * Pripremi stranicu za prikaz session stranica
	 */
	private function PreparePage($event_code) {
		$event_info = Event::where('event_code', $event_code)
			->first();
			
        View::share('event_info', $event_info);
        View::share('event_code', $event_code);

        if($event_info) {

          $event_has_accommodations = $this->eventHasAccommodations($event_info->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($event_info->id);
          View::share('event_has_transfers', $event_has_transfers);
		  
		  View::share('title', 'Sessions - ' . $event_info->name);

        } else {

          return redirect()->action('Events\All\AllEventsController@AllEvents');

        }
	}
	
	/**
     * Generiranje session koda
     */
    private function GenerateSessionCode() {
      return 'ss' . rand(1000, 10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }
	
	/**
	 * Dohvati event
	 */
	private function GetEventData($event_code) {
		$event = Event::where('event_code', $event_code)
			->first();
			
		// Provjeri da li event postoji
		if(!$event) return redirect()->action('Events\All\AllEventsController@AllEvents');
		
		return $event;
	}
	
	/**
	 * Dohvati session
	 */
	private function GetSessionData($session_code) {
		$session = DB::table('sessions')->where('session_code', $session_code)->first();
		
		if(!$session) return redirect()->action('Events\All\AllEventsController@AllEvents');
		
		return $session;
	}
}