<?php

namespace App\Http\Controllers\Events\Single;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Event as Event;
use View;
use DB;
use Response;
use Auth;
use Carbon\Carbon;
use DateTime;
use PDF;
use Redirect;
use Session;
use Spatie\Permission\Models\Permission;

class SingleEventsController extends MainController
{
    public function __construct() {
        parent::__construct();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/jquery.easy-pie-chart/dist/jquery.easypiechart.min.js',
            'global/plugins/bower_components/gmap3/dist/gmap3.min.js',
            'global/plugins/bower_components/raphael/raphael-min.js',
            'global/plugins/bower_components/morrisjs/morris.min.js',
        ];
        $this->js['additionalScripts'] = [
            '//maps.googleapis.com/maps/api/js?key=AIzaSyBVFzto_UHtwhxWd03BoffjuFWofh85HWM',
        ];
        $this->js['scripts'] = [

        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
    }


    /**
     * Prebacivanje na prikaz svih evenata
     */
    public function RedirectToAllEvents() {
        return redirect()->action('Events\All\AllEventsController@AllEvents');
    }


    /**
     * Prikaz pojedinačnog eventa
     * Prvo provjeri da li zatraženi event postoji u bazi
     * Ukoliko postoji, prikaži ga, ukoliko ne, prebaci korisnika na prikaz svih evenata
     */
    public function SingleEvent(Request $request, $event_code) {
        $singleEvent = Event::leftJoin('countries', 'events.venue_country_id', '=', 'countries.id')
          ->selectRaw('events.id as id,
            events.name,
            events.description,
            events.created_at,
            events.updated_at,
            events.created_by_id,
            events.updated_by_id,
            events.event_look_and_feel_id,
            events.timezone_id,
            events.start_ts,
            events.end_ts,
            events.event_code,
            events.registration_start_ts,
            events.registration_end_ts,
            events.type_by_venue,
            events.venue_name,
            events.venue_address,
            events.venue_city,
            events.venue_postal_code,
            events.venue_country_id,
            countries.country_code,
            events.access,
            events.currency_id,
            events.email_sender,
            events.tickets_invoice_from_id,
            events.accomodation_invoice_from_id,
            events.transfer_invoice_from_id,
            events.is_draft')
          ->where('events.event_code', '=', $event_code)
          ->first();

        if($singleEvent) {

          View::share('singleEvent', $singleEvent);

          // Adresa eventa
          if($singleEvent->type_by_venue == 'physical') {
            $singleEventAddress = $singleEvent->venue_address;
            if($singleEvent->venue_city && $singleEvent->venue_postal_code) {
              $singleEventAddress = $singleEventAddress . ', ' . $singleEvent->venue_postal_code;
              $singleEventAddress = $singleEventAddress . ' ' . $singleEvent->venue_city;
            }
            if($singleEvent->country_code) {
              $singleEventAddress = $singleEventAddress . ', ' . $singleEvent->country_code;
            }
          } else {
            $singleEventAddress = 'online';
          }
          View::share('singleEventAddress', $singleEventAddress);

          // Vremenska zona za event
          $eventTimezoneName = $this->getTimezoneName($singleEvent->timezone_id);
          View::share('eventTimezoneName', $eventTimezoneName->name);

          // TODO Vremenska prognoza - http://openweathermap.org/forecast16

          // Dohvati collected unit now te valute za event
          $collectedUntilNow = $this->getCollectedUnitNow($singleEvent->id);
          View::share('collectedUntilNow', $collectedUntilNow);
          $eventCurrency = $this->getEventCurrency($singleEvent->id);
          View::share('eventCurrency', $eventCurrency);

          // Dohvati broj leadova koji su se registrirali na event i registracija im nije poništena
          $countRegisteredLeads = $this->GetCountRegisteredLeads($singleEvent->id);
          View::share('countRegisteredLeads', $countRegisteredLeads);

          // Dohvati broj ticketa za event
          $countTickets = $this->GetCountTickets($singleEvent->id);
          View::share('countTickets', $countTickets);

          // Izračunaj postotak registracija u odnosu na broj ticketa
          if($countTickets == 0 && $countRegisteredLeads == 0) {
            $registeredTicketsProgress = 0;
          } elseif($countTickets == $countRegisteredLeads) {
            $registeredTicketsProgress = 100;
          } elseif($countRegisteredLeads == 0) {
            $registeredTicketsProgress = 0;
          } else {
            $registeredTicketsProgress = $countRegisteredLeads / $countTickets;
            $registeredTicketsProgress = $registeredTicketsProgress * 100;
          }
          View::share('registeredTicketsProgress', $registeredTicketsProgress);

          // Dohvati broj leadova koji su se registrirali na event
          $countAppliedRegisteredLeads = $this->GetCountAppliedRegisteredLeads($singleEvent->id);
          View::share('countAppliedRegisteredLeads', $countAppliedRegisteredLeads);

          // Dohvati broj approved ticketa za event
          $countApprovedTickets = $this->GetCountApprovedTickets($singleEvent->id);
          View::share('countApprovedTickets', $countApprovedTickets);

          // Izračunaj postotak odobrenih ticketa (registracija) u odnosu na ukupan broj registracija
          if($countApprovedTickets == 0 && $countAppliedRegisteredLeads == 0) {
            $approvedTicketsProgress = 0;
          } elseif($countApprovedTickets == $countAppliedRegisteredLeads) {
            $approvedTicketsProgress = 100;
          } else {
            $approvedTicketsProgress = $countApprovedTickets / $countAppliedRegisteredLeads;
            $approvedTicketsProgress = $approvedTicketsProgress * 100;
          }
          View::share('approvedTicketsProgress', $approvedTicketsProgress);

          // Dohvati broj attended na event
          $countAttended = $this->GetCountAttended($singleEvent->id);
          View::share('countAttended', $countAttended);

          // Izračunaj postotak attended na event u odnosu na ukupan broj approved
          if($countAttended == 0 && $countApprovedTickets == 0) {
            $attendedProgress = 0;
          } elseif($countAttended == $countApprovedTickets) {
            $attendedProgress = 100;
          } else {
            if($countApprovedTickets !== 0){
              $attendedProgress = $countAttended / $countApprovedTickets;
              $attendedProgress = $attendedProgress * 100;
            }
            else {
              $attendedProgress = 0;
            }
          }
          View::share('attendedProgress', $attendedProgress);

          // Dohvati podatke za registrations progress graf
          $registrationsChartsData = $this->GetRegistrationsChartData($singleEvent->id);

            if($registrationsChartsData) {
              // Obradi podatke za registrations progress graf prema želji plugina
              $dataForRegistrationsChart = $this->GenerateRegistrationsChartData($registrationsChartsData);

              View::share('dataForRegistrationsChart', $dataForRegistrationsChart);
            } else {
              View::share('dataForRegistrationsChart', 'nope');
            }

          // Dohvati podatke za recent registrants tablicu
          $recentRegistrationsTableData = $this->GetRecentRegistrationsTableData($singleEvent->id);

            if($recentRegistrationsTableData) {
              View::share('recentRegistrationsTableData', $recentRegistrationsTableData);
            } else {
              View::share('recentRegistrationsTableData', 'nope');
            }

          // Dohvati podatke za recent hotel reservations tablicu
          $recentHotelReservationsTableData = $this->GetRecentHotelReservationsTableData($singleEvent->id);

            if($recentHotelReservationsTableData) {
              View::share('recentHotelReservationsTableData', $recentHotelReservationsTableData);
            } else {
              View::share('recentHotelReservationsTableData', 'nope');
            }

          // Dohvati podatke o nazivu accomodationsa i broju soba
          $accommodations = $this->GetAccommodationsGraphData($singleEvent->id);

            if($accommodations) {
              View::share('accommodations', $accommodations);
            } else {
              View::share('accommodations', 'nope');
            }

          // Dohvati podatke za recent transfers reservations tablicu
          $recentTransfersTableData = $this->GetRecentTransfersTableData($singleEvent->id);

            // TODO Date kada želimo transfer

            if($recentTransfersTableData) {
              View::share('recentTransfersTableData', $recentTransfersTableData);
            } else {
              View::share('recentTransfersTableData', 'nope');
            }

          // Dohvati podatke za Transfers By Days graf i obradi ih prema želji plugina
          $transfersByDayChartData = DB::table('registration_has_transfers')
            ->join('registrations', 'registration_has_transfers.registration_id', '=', 'registrations.id')
            ->join('transfers', 'registration_has_transfers.transfer_id', '=', 'transfers.id')
            ->selectRaw('DATE(registration_has_transfers.transfer_start_ts) AS dates, transfers.description AS description, COUNT(*) AS counts')
            ->where('registrations.event_id', '=', $singleEvent->id)
            ->whereNotNull('registration_has_transfers.transfer_start_ts')
            ->whereNotNull('registrations.registered_ts')
            ->where(function ($query) {
                $query->where('registrations.transfer_approved', 1)
                  ->orWhereNull('registrations.transfer_approved');
              })
            ->groupBy('dates')
            ->groupBy('description')
            ->get();
          $transfersByDayChartData = $this->GenerateTransfersByDaysChartData($transfersByDayChartData);
          View::share('transfersByDayChartData', $transfersByDayChartData);

          // Dohvati podatke o nazivu i broju karata
          $tickets = $this->GetAvailableTickets($singleEvent->id);
          View::share('tickets', $tickets);
         

          // Dohvati To-Do listu vezanu uz event
          $toDoTasks = $this->getToDoList($singleEvent->id);
          View::share('toDoTasks', $toDoTasks);

          // Dohvati Recent Activities
          $recentActivities = $this->getRecentActivities($singleEvent->id);
          View::share('recentActivities', $recentActivities);

          // Naziv eventa koji ide u browser title
          $pageTitle = 'Event - ' . $singleEvent->name;
          View::share('title', $pageTitle);

          View::share('pro_forma_invoice', MODULE_PROFORMA_INVOICE);

          View::share('event_code', $event_code);

          $event_has_accommodations = $this->eventHasAccommodations($singleEvent->id);
          View::share('event_has_accommodations', $event_has_accommodations);

          $event_has_transfers = $this->eventHasTransfers($singleEvent->id);
          View::share('event_has_transfers', $event_has_transfers);

          $now = $this->Now();
          View::share('now', $now);

          return view('events/single/single-event');

        } else {

          return redirect()->action('Events\All\AllEventsController@AllEvents');

        }
   }


    /**
     * Genneriranje invoicea
     */
    public function GenerateInvoice(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $invoice_type = $request->input('type');

      // Dohvati podatke o eventu
      $singleEvent = $this->GetEvent($event_code);

      // Dohvati podatke o look & feelu eventa
      $singleEventLookFeel = $this->GetEventLookFeel($singleEvent->id);

      if($invoice_type == 'tickets') {

        if($registration_id) {

          $registration = DB::table('registrations')
            ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
            ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=', 'ticket.id')
            ->leftJoin('countries as payer_country', 'ticket.country', '=', 'payer_country.id')
            ->selectRaw('tickets.name AS ticketName,
              tickets.price_without_VAT AS ticketPriceNoVat,
              tickets.VAT AS ticketsVat,
              leads.title AS leadTitle,
              leads.first_name AS leadFirstName,
              leads.last_name AS leadLastName,
              leads.email AS leadEmail,
              leads.mobile AS leadMobile,
              leads.phone AS leadPhone,
              leads.company_name AS leadCompanyName,
              leads.job_function AS leadJobFunction,
              leads.company_address AS leadCompanyAddress,
              leads.company_city AS leadCompanyCity,
              leads.company_post_code AS leadCompanyPostalCode,
              leads.note AS leadNote,
              countries.country_name AS leadCompanyCountry,
              ticket.id AS ticketId,
              ticket.company_name AS ticketCompanyName,
              ticket.vat AS ticketVat,
              ticket.address AS ticketAddress,
              ticket.city AS ticketCity,
              ticket.post_code AS ticketPostalCode,
              payer_country.country_name AS ticketCountry,
              ticket.first_name AS ticketFirstName,
              ticket.last_name AS ticketLastName,
              ticket.email AS ticketEmail,
              ticket.phone AS ticketPhone,
              ticket.type AS ticketType,
              ticket.personal_id AS ticketPersonalId,
              registrations.invoice_ticket AS invoiceTicket,
              registrations.invoice_accomodation AS invoiceAccomodation,
              registrations.invoice_transfer AS invoiceTransfer,
              registrations.order_ticket AS orderTicket,
              registrations.order_accomodation AS orderAccomodation,
              registrations.order_transfer AS orderTransfer')
            ->where('registrations.id', '=', $registration_id)
            ->first();

          $payment = DB::table('invoice_froms')
            ->where('id', '=', $singleEvent->tickets_invoice_from_id)
            ->first();

        } else {

          return Redirect::back();

        }

        $tax = $registration->ticketPriceNoVat / 100 * $registration->ticketsVat;
        $tax = number_format((float)$tax, 2);
        $total = $registration->ticketPriceNoVat + $tax;
        $total = number_format((float)$total, 2);

        $currency = $this->getCurrency($singleEvent->id);

        $pdf = PDF::loadView('invoices/tickets', [
          'registration' => $registration,
          'event' => $singleEvent,
          'event_logo' => $singleEventLookFeel->event_logo_url,
          'bg_color' => $singleEventLookFeel->background_color,
          'title_color' => $singleEventLookFeel->titles_color,
          'tax' => $tax,
          'total' => $total,
          'currency' => $currency,
          'payment' => $payment
        ])->setPaper('a4');

        if ($pdf) {

          return $pdf->download('ticket-proforma-invoice-' . $registration->invoiceTicket . '.pdf');

        }

      } elseif($invoice_type == 'accomodation') {

        if ($registration_id) {

          $registration = DB::table('registrations')
            ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
            ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
            ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
            ->leftJoin('countries as payer_country', 'accomodation.country', '=', 'payer_country.id')
            ->selectRaw('room_types.type AS accomodationRoomName,
               room_types.price_without_vat AS accomodationPriceNoVat,
               room_types.vat AS accomodationPriceVat,
               accommodations.name AS accomodationName,
               leads.title AS leadTitle,
               leads.first_name AS leadFirstName,
               leads.last_name AS leadLastName,
               leads.email AS leadEmail,
               leads.mobile AS leadMobile,
               leads.phone AS leadPhone,
               leads.company_name AS leadCompanyName,
               leads.job_function AS leadJobFunction,
               leads.company_address AS leadCompanyAddress,
               leads.company_city AS leadCompanyCity,
               leads.company_post_code AS leadCompanyPostalCode,
               leads.note AS leadNote,
               countries.country_name AS leadCompanyCountry,
               accomodation.id AS accomodationId,
               accomodation.company_name AS accomodationCompanyName,
               accomodation.vat AS accomodationVat,
               accomodation.address AS accomodationAddress,
               accomodation.city AS accomodationCity,
               accomodation.post_code AS accomodationPostalCode,
               payer_country.country_name AS accomodationCountry,
               accomodation.first_name AS accomodationFirstName,
               accomodation.last_name AS accomodationLastName,
               accomodation.email AS accomodationEmail,
               accomodation.phone AS accomodationPhone,
               accomodation.type AS accomodationType,
               accomodation.personal_id AS accomodationPersonalId,
               registrations.invoice_ticket AS invoiceTicket,
               registrations.invoice_accomodation AS invoiceAccomodation,
               registrations.invoice_transfer AS invoiceTransfer,
               registrations.order_ticket AS orderTicket,
               registrations.order_accomodation AS orderAccomodation,
               registrations.order_transfer AS orderTransfer,
               registrations.accomodation_arrival_date AS accomodationArrivalData,
               registrations.accomodation_departure_date AS accomodationDepartureData')
            ->where('registrations.id', '=', $registration_id)
            ->first();

          $payment = DB::table('invoice_froms')
            ->where('id', '=', $singleEvent->accomodation_invoice_from_id)
            ->first();

        } else {

          return Redirect::back();

        }

        $accomodationArrivalData = strtotime($registration->accomodationArrivalData);
        $accomodationDepartureData = strtotime($registration->accomodationDepartureData);
        $accomodationDays = $accomodationDepartureData - $accomodationArrivalData;
        $accomodationDays = floor($accomodationDays/(60*60*24));

        $accomodation_total_no_vat = $registration->accomodationPriceNoVat * $accomodationDays;

        $accomodation_total_only_vat = $accomodation_total_no_vat / 100 * $registration->accomodationPriceVat;

        $accomodation_total_with_vat = $accomodation_total_no_vat + $accomodation_total_only_vat;

        $accomodation_total_no_vat = number_format((float)$accomodation_total_no_vat, 2);
        $accomodation_total_only_vat = number_format((float)$accomodation_total_only_vat, 2);
        $accomodation_total_with_vat = number_format((float)$accomodation_total_with_vat, 2);

        $currency = $this->getCurrency($singleEvent->id);

        $pdf = PDF::loadView('invoices/accomodations', [
          'registration' => $registration,
          'event' => $singleEvent,
          'event_logo' => $singleEventLookFeel->event_logo_url,
          'bg_color' => $singleEventLookFeel->background_color,
          'title_color' => $singleEventLookFeel->titles_color,
          'accomodation_total_no_vat' => $accomodation_total_no_vat,
          'accomodation_total_only_vat' => $accomodation_total_only_vat,
          'accomodation_total_with_vat' => $accomodation_total_with_vat,
          'currency' => $currency,
          'payment' => $payment,
          'accomodationDays' => $accomodationDays
        ])->setPaper('a4');

        if ($pdf) {

          return $pdf->download('accommodation-proforma-invoice-' . $registration->invoiceAccomodation . '.pdf');

        }

      } elseif($invoice_type == 'transfers') {

        if ($registration_id) {

          $registration = DB::table('registrations')
            ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
            ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
            ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
            ->leftJoin('countries as payer_country', 'transfer.country', '=', 'payer_country.id')
            ->selectRaw('leads.title AS leadTitle,
              leads.first_name AS leadFirstName,
              leads.last_name AS leadLastName,
              leads.email AS leadEmail,
              leads.mobile AS leadMobile,
              leads.phone AS leadPhone,
              leads.company_name AS leadCompanyName,
              leads.job_function AS leadJobFunction,
              leads.company_address AS leadCompanyAddress,
              leads.company_city AS leadCompanyCity,
              leads.company_post_code AS leadCompanyPostalCode,
              leads.note AS leadNote,
              countries.country_name AS leadCompanyCountry,
              transfer.id AS transferId,
              transfer.company_name AS transferCompanyName,
              transfer.vat AS transferVat,
              transfer.address AS transferAddress,
              transfer.city AS transferCity,
              transfer.post_code AS transferPostalCode,
              payer_country.country_name AS transferCountry,
              transfer.first_name AS transferFirstName,
              transfer.last_name AS transferLastName,
              transfer.email AS transferEmail,
              transfer.phone AS transferPhone,
              transfer.type AS transferType,
              transfer.personal_id AS transferPersonalId,
              registrations.invoice_ticket AS invoiceTicket,
              registrations.invoice_accomodation AS invoiceAccomodation,
              registrations.invoice_transfer AS invoiceTransfer,
              registrations.order_ticket AS orderTicket,
              registrations.order_accomodation AS orderAccomodation,
              registrations.order_transfer AS orderTransfer')
            ->where('registrations.id', '=', $registration_id)
            ->first();

          $payment = DB::table('invoice_froms')
            ->where('id', '=', $singleEvent->accomodation_invoice_from_id)
            ->first();

          $transfers = DB::table('registrations')
                        ->join('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
                        ->join('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
                        ->selectRaw('transfers.description as description,
                                     transfers.price_without_vat as priceNoVat,
                                     transfers.vat as vat')
                        ->where('registrations.id', '=', $registration_id)
                        ->get();

        } else {

          return Redirect::back();

        }

        $transfer_total_no_vat = 0;
        $transfer_total_only_vat = 0;

        foreach($transfers as $transfer) {

          $transfer_total_no_vat = $transfer_total_no_vat + $transfer->priceNoVat;

          $transfer_total_only_vat = $transfer_total_only_vat + $transfer->priceNoVat / 100 * $transfer->vat;

        }

        $transfer_total_with_vat = $transfer_total_no_vat + $transfer_total_only_vat;

        $transfer_total_no_vat = number_format((float)$transfer_total_no_vat, 2);
        $transfer_total_only_vat = number_format((float)$transfer_total_only_vat, 2);
        $transfer_total_with_vat = number_format((float)$transfer_total_with_vat, 2);

        $currency = $this->getCurrency($singleEvent->id);

        $pdf = PDF::loadView('invoices/transfers', [
          'registration' => $registration,
          'event' => $singleEvent,
          'event_logo' => $singleEventLookFeel->event_logo_url,
          'bg_color' => $singleEventLookFeel->background_color,
          'title_color' => $singleEventLookFeel->titles_color,
          'transfer_total_no_vat' => $transfer_total_no_vat,
          'transfer_total_only_vat' => $transfer_total_only_vat,
          'transfer_total_with_vat' => $transfer_total_with_vat,
          'currency' => $currency,
          'payment' => $payment,
          'transfers' => $transfers
        ])->setPaper('a4');

        if ($pdf) {

          return $pdf->download('transfer-proforma-invoice-' . $registration->invoiceTransfer . '.pdf');

        }

      } else {

        return Redirect::back();

      }

    }


    /**
     * Brisanje registracija
     */
    public function DeleteRegistration(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');

      if(!$registration_id) {
        return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      if($type == 'registration') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update([
            'deleted_at' => $this->Now()
          ]);

        // Deleted registration
        $this->Log(184, $registration_id);

        return Response::json([
          'msg' => 'registration_deleted'
        ]);

      } elseif($type == 'accomodation') {

        DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'accomodation_room_id' => NULL,
            'accomodation_note' => NULL,
            'accomodation_payer_id' => NULL,
            'accomodation_approved' => NULL,
            'accomodation_roomy_name' => NULL,
            'accomodation_arrival_date' => NULL,
            'accomodation_departure_date' => NULL
          ));

        // Deleted registration accommodation
        $this->Log(185, $registration_id);

        return Response::json([
          'msg' => 'accomm_deleted'
        ]);

      } elseif($type == 'transfer') {

        $transfer_id = $request->input('transfer_id');

        if(!$transfer_id) {
          return Response::json([
            'msg' => 'invalid_request'
          ]);
        }

        $nmb_registration_transfers = DB::table('registration_has_transfers')
          ->where('id', '=', $transfer_id)
          ->count();

        if($nmb_registration_transfers == 1) {
          DB::table('registrations')
          ->where('id', '=', $registration_id)
          ->update(array(
            'transfer_payer_id' => NULL,
            'transfer_approved' => NULL
          ));
        }

        DB::table('registration_has_transfers')
          ->where('id', '=', $transfer_id)
          ->delete();

        // Deleted registration transfer
        $this->Log(186, $registration_id);

        return Response::json([
          'msg' => 'transfer_deleted'
        ]);

      }

      return Response::json([
        'msg' => 'invalid_request'
      ]);
    }


    /**
     * Promijeni status registracije
     */
    public function UpdateRegistrationStatus(Request $request, $event_code) {
      $registration_id = $request->input('id');
      $type = $request->input('type');
      $status = $request->input('status');

      if(!$registration_id) {
         return Response::json([
          'msg' => 'invalid_request'
        ]);
      }

      if($type == 'registration') {

        if($status == 'confirmed') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'ticket_approved' => 1,
              'status_registration' => 'Confirmed'
            ));

        } elseif($status == 'canceled') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'ticket_approved' => 0,
              'status_registration' => 'Canceled',
              'accomodation_approved' => 0,
              'status_accomodation' => 'Canceled',
              'transfer_approved' => 0,
              'status_transfer' => 'Canceled'
            ));

        }

        // Updated registration status
        $this->Log(181, $registration_id);

      } elseif($type == 'accomodation') {

        if($status == 'confirmed') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'accomodation_approved' => 1,
              'status_accomodation' => 'Confirmed'
            ));

        } elseif($status == 'canceled') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'accomodation_approved' => 0,
              'status_accomodation' => 'Canceled'
            ));

        }

        // Updated registration accommodation status
        $this->Log(182, $registration_id);

      } elseif($type == 'transfer') {

        if($status == 'confirmed') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'transfer_approved' => 1,
              'status_transfer' => 'Confirmed'
            ));

        } elseif($status == 'canceled') {

          DB::table('registrations')
            ->where('id', '=', $registration_id)
            ->update(array(
              'transfer_approved' => 0,
              'status_transfer' => 'Canceled'
            ));

        }

        // Updated registration transfer status
        $this->Log(183, $registration_id);

      }

      return Response::json([
        'msg' => 'status_changed'
      ]);
    }


    /**
     * Prikaži registracijsku formu administratoru
     */
    public function PreviewRegistration(Request $request, $event_code) {

      $user_email = $request->user()->email;

      $lead = DB::table('leads')
        ->where('email', '=', $user_email)
        ->first();

      $now = $this->Now();

      if(!$lead) {
        $leadId = DB::table('leads')
          ->insertGetId([
            'lead_code' => $this->GenerateLeadCode(),
            'email' => $user_email,
            'created_at' => $now,
            'opt_in' => 'Yes',
            'opt_in_method' => 'email'
          ]);

        $lead = DB::table('leads')
          ->where('id', '=', $leadId)
          ->first();
      }

      $event = $this->GetEvent($event_code);

      $registration = DB::table('registrations')
        ->where([
          ['lead_id', '=', $lead->id],
          ['event_id', '=', $event->id]
        ])
        ->whereNull('deleted_at')
        ->first();

      if(!$registration) {
        $registration_id = DB::table('registrations')
          ->insertGetId(array(
            'event_id' => $event->id,
            'lead_id' => $lead->id,
            'status_registration' => 'Waiting',
            'status_accomodation' => 'Waiting',
            'status_transfer' => 'Waiting'
          ));
      } else {
        $registration_id = $registration->id;
      }

      Session::put('registration_id', $registration_id);
      Session::put('preview_registration', true);

      return redirect('/registration/' . $event_code . '/' . $lead->lead_code . '/general-information');

    }


    /**
     * Stvori lead code
     */
    public function GenerateLeadCode(){
        return 'ld' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }


     /**
      * Zatvori regitraciju
      */
      public function CloseRegistration(Request $request) {
        $event_id = $request->input('id');

        Event::where('id', '=', $event_id)
         ->update(array(
           'registration_end_ts' => $this->Now()
         ));

        return $this->AllEvents();
      }


    /**
     * Spremi event i otvori preview
     * @param string $event_code
     * @param forma $request
     * @return view
     */
    public function SaveRegistrationSingleEvent($event_code, Request $request) {
        $currency_id = DB::table('currencies')
          ->where('code', $request->input('currency'))
          ->pluck('id');

        //get datetime
        $startTime = substr($request->input('registration_duration'), 0, 16);
        $endtime   = substr($request->input('registration_duration'), -16);

        //parse time to db time
        $startTime = Carbon::createFromFormat('d/m/Y H:i', $startTime)->toDateTimeString();
        $endtime   = Carbon::createFromFormat('d/m/Y H:i', $endtime)->toDateTimeString();

        $now = $this->Now();

        $data = DB::table('events')
                ->where('event_code', $event_code)
                ->get();

        if($data[0]->is_draft == null || $data[0]->is_draft == 1) {
          DB::statement('
            ALTER TABLE leads_on_events_insights
            ADD event_id_' . $data[0]->id . ' VARCHAR(50) DEFAULT "not invited"
            AFTER lead_id
          ');

          Permission::create(['name' => $data[0]->id]);

          // New event
          $this->Log(122, $data[0]->id);
        }

        $event = DB::table('events')
            ->where('event_code', $event_code)
            ->first();

        if ((int)$event->is_draft === 0 && !is_null($event->is_draft) ) {
            // Updated event
            $this->Log(123, $event->id);
        }

        if($request->input('update')){
            $values = ['email_sender'                 => $request->input('email_sender'),
                       'email_name'                   => $request->input('email_sender_name'),
                       'currency_id'                  => $currency_id[0],
                       'tickets_invoice_from_id'      => empty($request->input('ticket_invoice')) ? $data[0]->tickets_invoice_from_id : $request->input('ticket_invoice') ,
                       'accomodation_invoice_from_id' => empty($request->input('acc_invoice')) ? $data[0]->accomodation_invoice_from_id : $request->input('acc_invoice'),
                       'transfer_invoice_from_id'     => empty($request->input('transfer_invoice')) ? $data[0]->transfer_invoice_from_id : $request->input('transfer_invoice'),
                       'registration_start_ts'        => $startTime,
                       'registration_end_ts'          => $endtime,
                       'updated_at'                   => $now,
                       'updated_by_id'                => Auth::user()->id,
                       'is_draft'                     => 0,
                       'registration_notification' => $request->input('registration_notification'),
            ];
        }else{
            $values = ['email_sender'                 => $request->input('email_sender'),
                       'email_name'                   => $request->input('email_sender_name'),
                       'currency_id'                  => $currency_id[0],
                       'tickets_invoice_from_id'      => empty($request->input('ticket_invoice')) ? $data[0]->tickets_invoice_from_id : $request->input('ticket_invoice') ,
                       'accomodation_invoice_from_id' => empty($request->input('acc_invoice')) ? $data[0]->accomodation_invoice_from_id : $request->input('acc_invoice'),
                       'transfer_invoice_from_id'     => empty($request->input('transfer_invoice')) ? $data[0]->transfer_invoice_from_id : $request->input('transfer_invoice'),
                       'registration_start_ts'        => $startTime,
                       'registration_end_ts'          => $endtime,
                       'is_draft'                     => 0,
                       'registration_notification' => $request->input('registration_notification'),
            ];
        }

        DB::table('events')
        ->where('event_code', $event_code)
        ->update($values);

        $event_info = DB::table('events')
                      ->where('event_code', $event_code)
                      ->get();

        View::share('event_info', $event_info);
        View::share('event_code', $event_code);

        $event_has_accommodations = $this->eventHasAccommodations($data[0]->id);
        View::share('event_has_accommodations', $event_has_accommodations);

        $event_has_transfers = $this->eventHasTransfers($data[0]->id);
        View::share('event_has_transfers', $event_has_transfers);

        if($request->input('update'))
          return Redirect::route('dashboard', array($event_code));
        else
          return view('events/create/complete');
    }


    /**
     * Dohvati naziv timezone za zatraženi event
     */
    private function getTimezoneName($singleEventTimezoneID) {
        $eventTimezoneName = DB::table('timezones')
            ->select('name')
            ->where('id', '=', $singleEventTimezoneID)
            ->first();

        return $eventTimezoneName;
    }


    /**
     * Dohvati popis to-do taskova za zatraženi event
     */
    private function getToDoList($singleEventId) {
        $toDoList = DB::table('todos')
            ->where('event_id', '=', $singleEventId)
            ->orderBy('id', 'desc')
            ->get();

        return $toDoList;
    }


    /**
     * Unos novih to-do taskova
     * Vežemo to-do uz event (te korisnika)
     */
    public function AddItemToDo(Request $request) {
        $user_id = $request->input('user_id');
        $event_id = $request->input('event_id');
        $name = $request->input('name');

        $todo_id = DB::table('todos')
            ->insertGetId(
            array(
                'user_id' => $user_id,
                'event_id' => $event_id,
                'name' => $name
            )
        );

        $todo_task = DB::table('todos')
            ->where('id', '=', $todo_id)
            ->get();

        return Response::json($todo_task);
    }


    /**
     * Spremanje novog stanja to-do taska
     */
    public function UpdateItemToDo(Request $request) {
        $todo_id = $request->input('todo_id');
        $checked_state = $request->input('checked_state');

        if($checked_state == 'true') {

            DB::table('todos')
                ->where('id', '=', $todo_id)
                ->update(
                array(
                    'done_flag' => 1
                )
            );

        } elseif($checked_state == 'false') {

            DB::table('todos')
                ->where('id', '=', $todo_id)
                ->update(
                array(
                    'done_flag' => 0
                )
            );

        } else {

            DB::table('todos')
                ->where('id', '=', $todo_id)
                ->delete();

        }

        return Response::json($todo_id);
    }


    /**
     * Dohvati popis posljednjih događaja na eventu
     * Sva logika se obavlja u viewu DBMS-a
     */
    private function getRecentActivities($singleEventId) {
        $recentActivities = DB::table('recent_activity')
                            ->where('eventId', '=', $singleEventId)
                            ->orderBy('time', 'desc')
                            ->get();

        return $recentActivities;
    }


    /**
     * Vrati collacted unit now sumu za zatraženi event
     * Cijena je cijena karte * VAT
     * Spajamo registracije i tickete
     * Ticket mora biti approved
     */
    private function getCollectedUnitNow($eventId) {
        $collected = DB::select('
          SELECT SUM(tickets.VAT/100 * tickets.price_without_VAT + tickets.price_without_VAT) as collected FROM registrations
          JOIN tickets ON registrations.ticket_type_id = tickets.id
          WHERE registrations.ticket_approved = 1 AND registrations.deleted_at IS NULL AND tickets.event_id = ?', array($eventId));

        $collectedUntilNow = 0;
        foreach ($collected as $item) {
          $collectedUntilNow = $item->collected;
        }

        $collectedUntilNow = number_format((float)$collectedUntilNow, 2);

        return $collectedUntilNow;
    }


    /**
     * Dohvati currency code za zatraženi event
     */
    private function getEventCurrency($eventId) {
        $currency = DB::table('events')
                          ->join('currencies', 'events.currency_id', '=', 'currencies.id')
                          ->selectRaw('currencies.code as code')
                          ->where('events.id', '=', $eventId)
                          ->get();

        $eventCurrency = 0;
        foreach ($currency as $item) {
          $eventCurrency = $item->code;
        }

        return $eventCurrency;
    }


    /**
     * Ukupan broj leadova koji su se registrirali na zatraženi event i registracija im nije poništena
     */
    private function GetCountRegisteredLeads($eventId) {
        $countRegisteredLeads = DB::table('registrations')
            ->where('event_id', $eventId)
            ->whereNull('deleted_at')
            ->where(function ($query) {
                $query->where('ticket_approved', 1)
                    ->orWhereNull('ticket_approved');
            })
            ->where(function($query) {
                $query->whereNotNull('registered_ts')
                    ->orWhereNotNull('confirmed_ts');
            })
            ->count();

        return $countRegisteredLeads;
    }


    /**
     * Ukupan broj leadova koji su se registrirali na zatraženi event
     */
    private function GetCountAppliedRegisteredLeads($eventId) {
        $countRegisteredLeads = DB::table('registrations')
          ->where('event_id', $eventId)
          ->whereNull('deleted_at')
          ->where(function($query) {
              $query->whereNotNull('registered_ts')
                  ->orWhereNotNull('confirmed_ts');
          })
          ->count();

        return $countRegisteredLeads;
    }


    /**
     * Ukupan broj ticketa za zatraženi event
     */
    private function GetCountTickets($eventId) {
        $countTickets = DB::table('tickets')
                        ->where('event_id', '=', $eventId)
                        ->whereNull('deleted_at')
                        ->sum('quantity');

        return $countTickets;
    }


    /**
     * Ukupan broj odobrenih ticketa (registracija) za zatraženi event
     */
    private function GetCountApprovedTickets($eventId) {
        $countApprovedTickets = DB::table('registrations')
          ->where('event_id', $eventId)
          ->where('ticket_approved', 1)
          ->whereNull('deleted_at')
          ->where(function($query) {
              $query->whereNotNull('registered_ts')
                  ->orWhereNotNull('confirmed_ts');
          })
          ->count();

        return $countApprovedTickets;
    }

    /**
     * Ukupan broj attended za zatraženi event
     */
    private function GetCountAttended($eventId) {
        $countAttended = DB::table('registrations')
          ->where('event_id', $eventId)
          ->where('event_attended_flag', 1)
          ->whereNull('deleted_at')
          ->count();

        return $countAttended;
    }

    /**
     * Dohvati podatke za registrations progress graf
     */
    private function GetRegistrationsChartData($eventId) {
        $registrationsChartData = DB::select('SELECT IFNULL(DATE(registrations.registered_ts), DATE(registrations.confirmed_ts)) AS dates, COUNT(*) AS counts FROM registrations
        	JOIN leads ON registrations.lead_id = leads.id
        	WHERE registrations.event_id = ?
        	AND (registrations.registered_ts IS NOT NULL OR registrations.confirmed_ts IS NOT NULL)
        	AND registrations.deleted_at IS NULL
          GROUP BY dates
        	ORDER BY dates', array($eventId));

        // if($registrationsChartData[0]->dates == null) return null;

        return $registrationsChartData;
    }


    /**
     * Vrati podatke za registrations progress graf u obliku koji plugin to želji
     */
    private function GenerateRegistrationsChartData($registrationsChartsData) {
        $dataForRegistrationsChart = collect([]);

        // Saznaj kada će biti zadnji datum
        $keys = array_keys($registrationsChartsData);
        $lastKey = array_pop($keys);

        $skip_next = false;

        foreach ($registrationsChartsData as $key => $registrationChartsData) {
          if($key == 0) {
            $firstDate = new DateTime($registrationChartsData->dates);
            date_sub($firstDate, date_interval_create_from_date_string('1 days'));
            $dataString = "{ y: '" .  date_format($firstDate, 'Y-m-d') . "', a: 0 },";
            $dataForRegistrationsChart->push($dataString);
          }

          if($skip_next == true) {
              $skip_next = false;

              if($key == $lastKey) {
                  $lastDate = new DateTime($registrationChartsData->dates);
                  date_add($lastDate, date_interval_create_from_date_string('1 days'));
                  $dataString = "{ y: '" .  date_format($lastDate, 'Y-m-d') . "', a: 0 },";
                  $dataForRegistrationsChart->push($dataString);
              }

              continue;
          }

          if(array_key_exists($key+1, $registrationsChartsData)) {
              if($registrationChartsData->dates == $registrationsChartsData[$key+1]->dates) {
                  $count = $registrationChartsData->counts + $registrationsChartsData[$key+1]->counts;
                  $dataString = "{ y: '" .  $registrationChartsData->dates . "', a: " . $count . ' },';
                  $dataForRegistrationsChart->push($dataString);
                  $skip_next = true;
                  continue;
              }
          }

          $dataString = "{ y: '" .  $registrationChartsData->dates . "', a: " . $registrationChartsData->counts . ' },';
          $dataForRegistrationsChart->push($dataString);

          // Broj dana između dva dana u nizu da dodamo 0 za sve datume između
          // Pazi da to ne radimo na zadnjem datumu
          if($key != $lastKey) {
            $dateStart = new DateTime($registrationChartsData->dates);
            $dateEnd  = new DateTime($registrationsChartsData[$key+1]->dates);
            $dateDiff = $dateStart->diff($dateEnd);

            if($dateDiff->days > 1) {
      			$dateStartPlus = $dateStart;
      			date_add($dateStartPlus, date_interval_create_from_date_string('1 days'));
      			$dataString = "{ y: '" .  date_format($dateStartPlus, 'Y-m-d') . "', a: 0 },";
      			$dataForRegistrationsChart->push($dataString);

      			$dateEndMinus = $dateEnd;
      			date_add($dateEndMinus, date_interval_create_from_date_string('-1 days'));
      			$dataString = "{ y: '" .  date_format($dateEndMinus, 'Y-m-d') . "', a: 0 },";
      			$dataForRegistrationsChart->push($dataString);
            }
          } else {
            $lastDate = new DateTime($registrationChartsData->dates);
            date_add($lastDate, date_interval_create_from_date_string('1 days'));

            $dataString = "{ y: '" .  date_format($lastDate, 'Y-m-d') . "', a: 0 },";
            $dataForRegistrationsChart->push($dataString);
          }
        }

        return $dataForRegistrationsChart;
    }


    /**
     * Vrati podatke o leadovima za sve one koji su se registrirali na zatraženi event
     */
    private function GetRecentRegistrationsTableData($eventId) {
        $recentRegistrationsTableData = DB::table('leads')
          ->join('registrations', 'leads.id', '=', 'registrations.lead_id')
          ->selectRaw('leads.*,
            DATE_FORMAT(registered_ts, "%d.%m.%Y. %H:%i") AS registered_ts,
			DATE_FORMAT(confirmed_ts, "%d.%m.%Y. %H:%i") AS confirmed_ts,
            registrations.id,
            registrations.status_registration')
          ->where('registrations.event_id', '=', $eventId)
          ->whereNull('registrations.deleted_at')
          ->where(function($query) {
            $query->whereNotNull('registrations.registered_ts')
                ->orWhereNotNull('registrations.confirmed_ts');
          })
          ->orderBy('registrations.registered_ts', 'desc')
          ->orderBy('registrations.confirmed_ts', 'desc')
          ->take(10)
          ->get();

        return $recentRegistrationsTableData;
    }


    /**
     * Vrati podatke o posljednim registracijama na zatraženi event
     */
    private function GetRecentHotelReservationsTableData($eventId) {
        $recentHotelReservationsTableData = DB::table('registrations')
          ->join('leads', 'registrations.lead_id', '=', 'leads.id')
          ->join('room_types', 'registrations.accomodation_room_id', '=', 'room_types.id')
          ->join('accommodations', 'room_types.accommodation_id', '=', 'accommodations.id')
          ->selectRaw('DATE_FORMAT(registrations.accomodation_arrival_date, "%d.%m.%Y.") AS accomodation_arrival_date,
            DATE_FORMAT(registrations.accomodation_departure_date, "%d.%m.%Y.") AS accomodation_departure_date,
            accommodations.name,
            leads.title,
            leads.first_name,
            leads.last_name,
            registrations.id,
            registrations.status_accomodation AS status_accomodation')
          ->where('registrations.event_id', '=', $eventId)
          ->whereNotNull('registrations.registered_ts')
          ->whereNull('registrations.deleted_at')
          ->orderBy('registrations.registered_ts', 'desc')
          ->take(5)
          ->get();

        return $recentHotelReservationsTableData;
    }


    /**
     * Vrati podatke o nazivu accomodationa, broju registracija s tim accomodationom te broju soba za zatraženi event
     */
    private function GetAccommodationsGraphData($eventId) {
        $accommodations = DB::table('registrations')
          ->join('room_types', 'registrations.accomodation_room_id', '=', 'room_types.id')
          ->join('accommodations', 'room_types.accommodation_id', '=', 'accommodations.id')
          ->selectRaw('accommodations.name as name,COUNT(*) as count, accommodations.no_of_rooms as rooms')
          ->where('accommodations.event_id', '=', $eventId)
          ->whereNotNull('registrations.registered_ts')
          ->whereNull('registrations.deleted_at')
          ->where(function ($query) {
            $query->where('registrations.accomodation_approved', 1)
              ->orWhereNull('registrations.accomodation_approved');
          })
          ->groupBy('accommodations.name')
          ->get();

        return $accommodations;
    }


    /**
     * Vrati podatke o posljednim transferima na zatraženi event
     */
    private function GetRecentTransfersTableData($eventId) {
        $recentTransfersTableData = DB::table('registrations')
          ->join('leads', 'registrations.lead_id', '=', 'leads.id')
          ->join('registration_has_transfers', 'registrations.id', '=', 'registration_has_transfers.registration_id')
          ->join('transfers', 'registration_has_transfers.transfer_id', '=', 'transfers.id')
          ->selectRaw('leads.title,
            leads.first_name,
            leads.last_name,
            transfers.description,
            DATE_FORMAT(registration_has_transfers.transfer_start_ts, "%d.%m.%Y. %H:%i") AS transfer_start_ts,
            registrations.id,
            registration_has_transfers.id AS transfer_id,
            registrations.status_transfer AS status_transfer')
          ->where('transfers.event_id', '=', $eventId)
          ->whereNotNull('registrations.registered_ts')
          ->whereNull('registrations.deleted_at')
          ->orderBy('registrations.registered_ts', 'desc')
          ->take(5)
          ->get();

        return $recentTransfersTableData;
    }


    /**
     * Obradi dobivene podatke za Transfers By Days graf prema želji plugina
     */
    private function GenerateTransfersByDaysChartData($chartsData) {
        $dataForChartPlugin = array();
        $dataForChartPlugin_subarray = array([]);

        foreach($chartsData as $key => $chartData) {
          $pos = array_search($chartData->dates, array_column($dataForChartPlugin, 'date'));

          if($pos !== false) {

            if($chartData->description == 'Transfer from Airport to Venue') {
              $dataForChartPlugin[$pos]['a'] = $chartData->counts;
            } else if($chartData->description == 'Transfer from Venue to Airport') {
              $dataForChartPlugin[$pos]['b'] = $chartData->counts;
            }

          } else {
            $dataForChartPlugin_subarray = array("date" => $chartData->dates);

            if($chartData->description == 'Transfer from Airport to Venue') {
              $dataForChartPlugin_subarray['a'] = $chartData->counts;
            } else if($chartData->description == 'Transfer from Venue to Airport') {
              $dataForChartPlugin_subarray['b'] = $chartData->counts;
            }

            array_push($dataForChartPlugin, $dataForChartPlugin_subarray);
          }
        }

        $dataForChart = collect([]);

        foreach ($dataForChartPlugin as $key => $data) {
          $dataString = "{ y: '" .  $data['date'] . "'";

          if(array_key_exists('a', $data)) {
            $dataString = $dataString . ', a: ' . $data['a'];
          } else {
            $dataString = $dataString . ', a: 0';
          }
          if(array_key_exists('b', $data)) {
            $dataString = $dataString . ', b: ' . $data['b'];
          } else {
            $dataString = $dataString . ', b: 0';
          }

          $dataString = $dataString . ' },';

          $dataForChart->push($dataString);
        }

        return $dataForChart;
    }


    /**
     * Vrati podatke o zatraženom eventu
     */
    private function GetEvent($event_code) {
      $singleEvent = Event::where('events.event_code', '=', $event_code)
        ->first();

      return $singleEvent;
    }


    /**
     * Vrati podatke o look & feelu eventa
     */
    private function GetEventLookFeel($event_id) {
      $singleEventLookFeel = Event::join('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->select('event_look_feels.event_logo_url', 'color_schemes.background_color', 'color_schemes.titles_color')
        ->where('events.id', '=', $event_id)
        ->firstOrFail();

      return $singleEventLookFeel;
    }


    /**
     * Dohvati currency code za zatraženi event
     */
    private function getCurrency($eventId) {
      $currency = DB::table('events')
        ->join('currencies', 'events.currency_id', '=', 'currencies.id')
        ->selectRaw('currencies.code as code')
        ->where('events.id', '=', $eventId)
        ->get();

      $eventCurrency = 0;
      foreach ($currency as $item) {
        $eventCurrency = $item->code;
      }

      return $eventCurrency;
    }


  /**
   * Dostupne karte za event
   */
  protected function GetAvailableTickets($eventId)
  {

    $tickets = DB::table('tickets')
      ->leftJoin('registrations', 'registrations.ticket_type_id', '=', 'tickets.id')
      ->selectRaw('COUNT(ticket_type_id) AS used,
          tickets.quantity,
          tickets.name,
          tickets.id,
          tickets.valid_until_ts')
      ->selectRaw('COUNT(registrations.deleted_at) AS deleteTicket')
      ->where('tickets.event_id', $eventId)     
      ->whereNull('tickets.deleted_at')
      ->where(function ($query) {
          $query->where('registrations.ticket_approved', 1)
                ->orWhereNull('registrations.ticket_approved');
        })
      ->groupBy('tickets.id')
      ->get();
    return $tickets;

  }

}
