<?php

namespace App\Http\Controllers\Leads;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;

use App\Http\Requests;
use App\Http\Controllers\Controller;


// Krik
use App\Http\Controllers\MainController as MainController;
use App\Lead as Lead;
use App\Countries as Countries;
use View;
use DB;
use Datatables;
use Excel;
use App\DataTables\UsersDataTable;
use File;
use Redirect;
use Illuminate\Support\Facades\Cache;


class AllLeadsController extends MainController
{
    public function __construct() {
        parent::__construct();

        $this->setApp();

        // CSS i JS assets for page
        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/datatables/css/jquery.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/buttons.dataTables.min.css',
            'global/plugins/bower_components/datatables/css/select.dataTables.min.css',
            'global/plugins/bower_components/select2/dist/css/select2.css'
        ];
        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/css/jasny-bootstrap-fileinput.min.css'
        ];
        $this->js['plugins'] = [
            'global/plugins/bower_components/datatables/js/jquery.dataTables.min.js',
            'global/plugins/bower_components/datatables.net-responsive/js/dataTables.responsive.js',
            'global/plugins/bower_components/datatables.net-select/js/dataTables.select.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/dataTables.buttons.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.flash.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.html5.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.print.min.js',
            'global/plugins/bower_components/datatables.net-buttons/js/buttons.colVis.min.js',
            'global/plugins/bower_components/jasny-bootstrap-fileinput/js/jasny-bootstrap-fileinput.js',
        ];
        $this->js['additionalScripts'] = [
            '//cdnjs.cloudflare.com/ajax/libs/jszip/2.5.0/jszip.min.js',
            '//cdn.datatables.net/colreorder/1.3.1/js/dataTables.colReorder.min.js',
            '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/js/select2.min.js',
            '//cdnjs.cloudflare.com/ajax/libs/yadcf/0.9.4/jquery.dataTables.yadcf.min.js',
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'All Leads');
        View::share('extraClasses', 'fixRadio');
    }

    public function getIndex()
    {
        return view('leads/all-leads');
    }

    public function anyData()
    {
        return Cache::remember('leads-table', 1440, function () {
            $leads = DB::table('leads')
            ->leftJoin('countries', 'countries.id', '=', 'leads.company_country')
            ->leftJoin('lead_types', 'leads.lead_type_id', '=', 'lead_types.id')
            ->leftJoin('lead_has_type_descriptions', 'leads.id', '=', 'lead_has_type_descriptions.lead_id')
            ->leftJoin('lead_type_descriptions', 'lead_has_type_descriptions.lead_type_description_id', '=', 'lead_type_descriptions.id')
            ->selectRaw('
                leads.id,
                leads.lead_code,
                leads.company_name,
                leads.gender,
                leads.title,
                leads.first_name,
                leads.last_name,
                leads.email,
                leads.mobile,
                leads.phone,
                leads.job_function,
                lead_types.name AS type,
                GROUP_CONCAT(DISTINCT lead_type_descriptions.name SEPARATOR ", ") AS type_description,
                leads.company_address,
                leads.company_city,
                leads.company_post_code,
                countries.country_name,
                leads.note,
                leads.self_registrated,
                leads.opt_in,
                leads.opt_in_method,
                DATE_FORMAT(leads.opt_out_ts, "%Y-%m-%d %H:%i") AS opt_out_ts,
                DATE_FORMAT(leads.created_at, "%Y-%m-%d %H:%i") AS created_at,
                DATE_FORMAT(leads.updated_at, "%Y-%m-%d %H:%i") AS updated_at
            ')
            ->whereNull('leads.deleted_at')
            ->whereNotNull('leads.created_at')
            ->groupBy('leads.id');

          return Datatables::of($leads)
            ->addColumn('action', function ($lead) {
              return '<a href="' . env('APP_URL') . '/leads/create/' . $lead->lead_code . '"  data-toggle="tooltip" data-placement="top" title="Edit" data-original-title="edit"><i class="fa fa-edit" data-info="tooltip" data-placement="top" title="Edit lead"></i></a><button type="button" class="krik-lead-delete krik-button-transparent" data-lead-id="' . $lead->id . '" data-toggle="modal" data-target=".krik-delete-lead"><i class="fa fa-trash-o" data-info="tooltip" data-placement="top" title="Delete lead"></i></button> ';
            })
            ->editColumn('opt_in_method', '<span class="opt_in_method">{{ $opt_in_method }}</span>')
            ->make(true);
        });
    }


    public function ImportLead() {
        return view('leads/import');
    }


    public function GetLeadCode(){
       return 'ld' . rand(1000, 10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
   }



   public function InsertImportLead(Request $request) {

      if(Input::file('upload_excel')) $uploadedFile = Input::file('upload_excel')->move(public_path() . '/excel', Input::file('upload_excel')->getClientOriginalName());
       $excelFile = Excel::load($uploadedFile)->get();
        /*provjera da li je prazna*/
       if($excelFile->first()) {    
         $firstrow = $excelFile->first()->toArray();
         $firstrowCount = count(array_values($firstrow));
       } else {
         return redirect()->back()
           ->with('excelfile', 'empty');
       }
       if($firstrowCount === 16)
       {
         $ignoreContacts = collect([]);
         $importedContacts = collect([]);
         $notValids = collect([]);
         $zeros = collect([]);
         $sameContacts = collect([]);
         $existsContactExcel = DB::table('leads')->pluck('email');
            foreach ($excelFile as $row) {
              $row = array_values($row->toArray());
              if (isset($row[0])) {
                $contactGender = $row[0];
              } else {
                $contactGender = null;
              }
              if (isset($row[1])) {
                $contactTitle = $row[1];
              } else {
                $contactTitle = null;
              }
              if (isset($row[2])) {
                $contactFirstName = $row[2];
              } else {
                $contactFirstName = null;
              }
              if (isset($row[3])) {
                $contactLastName= $row[3];
              } else {
                $contactLastName = null;
              }
              if (isset($row[4])) {
                $contactEmail = $row[4];
              } else {
                $contactEmail = null;
              }
              if (isset($row[5])) {
                $contactMobile = $row[5];
              } else {
                $contactMobile = null;
              }
              if (isset($row[6])) {
                $contactPhone = $row[6];
              } else {
                $contactPhone = null;
              }
              if (isset($row[7])) {
                $contactCompanyName = $row[7];
              } else {
                $contactCompanyName = null;
              }
              if (isset($row[8])) {
                $contactJobFunction = $row[8];
              } else {
                $contactJobFunction = null;
              }
              if (isset($row[9])) {
                $contactCompanyAddress = $row[9];
              } else {
                $contactCompanyAddress = null;
              }
              if (isset($row[10])) {
                $contactCompanyCity = $row[10];
              } else {
                $contactCompanyCity = null;
              }
              if (isset($row[11])) {
                $contactCompanyPostalCode = $row[11];
              } else {
                $contactCompanyPostalCode = null;
              }
              if (isset($row[12])) {
                $contactCompanyCountry = $row[12];
              } else {
                $contactCompanyCountry = null;
              }
               $contactCompanyCountryId = DB::table('countries')->leftJoin('leads', 'countries.id', '=', 'leads.company_country')
                                         ->where('countries.country_name', '=', $contactCompanyCountry)
                                         ->pluck('countries.id');
               $contactCompanyCountryId = last($contactCompanyCountryId);
               $contactCompanyCountryName = DB::table('countries')
                                         ->where('countries.id', '=', $contactCompanyCountryId)
                                         ->pluck('countries.country_name');
               $contactCompanyCountryName = last($contactCompanyCountryName);
               if (isset($row[13])) {
                 $contactNote = $row[13];
               } else {
                 $contactNote = null;
               }

                // Lead type
                if (isset($row[14])) {
                    $contactType = $row[14];
                } else {
                    $contactType = null;
                }
                if ($contactType) {
                    $contactTypeId = DB::table('lead_types')
                        ->where('name', $contactType)
                        ->first();
                    if ($contactTypeId) {
                        $contactTypeId = $contactTypeId->id;
                    } else {
                        $contactTypeId = DB::table('lead_types')
                            ->insertGetId([
                                'name' => $contactType
                            ]);
                    }
                } else {
                    $contactTypeId = null;
                }
                
                // Lead type descriptions
                if (isset($row[15])) {
                    $contactTypeDesriptions = $row[15];
                } else {
                    $contactTypeDesriptions = null;
                }

               $contactEmail = strtolower(preg_replace('/\s+/', '', $contactEmail));
               $contactFirstName = trim($contactFirstName);
               $contactLastName = trim($contactLastName);

               if($contactTitle !== null) {
                $titleString = substr($contactTitle, -1);

                if (!($titleString === '.' || $titleString === '')) {
                  $contactTitle = $contactTitle . '.';
                }
               }

               $checkContactExcel = Lead::firstOrNew(['email' => $contactEmail, 'deleted_at' => NULL]);
               if(!$checkContactExcel->exists)
               {
                   $checkContactExcel->gender = $contactGender;
                   $checkContactExcel->title = $contactTitle;
                     if(!isset($contactTitle)){
                       $checkContactExcel->title = '';
                     }
                   $checkContactExcel->first_name = $contactFirstName;
                   $checkContactExcel->last_name = $contactLastName;
                   $checkContactExcel->email= $contactEmail;
                   $checkContactExcel->mobile = $contactMobile;
                   $checkContactExcel->phone = $contactPhone;
                   $checkContactExcel->company_name = $contactCompanyName;
                   $checkContactExcel->job_function = $contactJobFunction;
                   $checkContactExcel->company_address = $contactCompanyAddress;
                   $checkContactExcel->company_city = $contactCompanyCity;
                   $checkContactExcel->company_post_code = $contactCompanyPostalCode;
                   $checkContactExcel->company_country = $contactCompanyCountryId;
                   $checkContactExcel->note = $contactNote;
                   $checkContactExcel->lead_type_id = $contactTypeId;
                   $checkContactExcel->lead_code = $this->GetLeadCode();
                   $checkContactExcel->opt_in = 'Yes';
                   $checkContactExcel->opt_in_method = 'email';
                   $checkContactExcel->created_at = $this->Now();
                   $checkContactExcel->updated_at = NULL;
                   /*if petlja kroz koju se spremaju kontakti ako oni zadovoljavaju formu u kojoj jedino mail mora biti validan.
                   U env. datoteci potrebno je vrijednosti EXCEL_FIRSTNAME i EXCEL_LASTNAME staviti na false*/
                   if ((EXCEL_FIRSTNAME == false || EXCEL_LASTNAME == false) && filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
                     $checkContactExcel->save();
                     $checkContactExcel->company_country = $contactCompanyCountryName;
                     $checkContactExcel->lead_type_id = $contactType;
                     $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                     $importedContacts->push($checkContactExcel);
                     
                     if ($contactTypeDesriptions) {
                         $typeDescriptions = explode(',', trim($contactTypeDesriptions));
                         
                         foreach($typeDescriptions as $key => $typeDescription) {
                             $lead_type_description_exists = DB::table('lead_type_descriptions')
                                 ->where('name', trim($typeDescription))
                                 ->first();
                                 
                             if (!$lead_type_description_exists) {
                                 $new_lead_type_description_id = DB::table('lead_type_descriptions')
                                     ->insertGetId([
                                         'name' => trim($typeDescription),
                                     ]);
                                 
                                 DB::table('lead_has_type_descriptions')
                                     ->insert(array(
                                         'lead_id' => $checkContactExcel->id,
                                         'lead_type_description_id' => $new_lead_type_description_id
                                     ));
                             } else {
                                 DB::table('lead_has_type_descriptions')
                                     ->insert(array(
                                         'lead_id' => $checkContactExcel->id,
                                         'lead_type_description_id' => $lead_type_description_exists->id
                                     ));
                             }
                         }
                     }
                   }else {
                     if(!filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
                         if(filter_var($contactEmail, FILTER_VALIDATE_INT) === 0){
                           $checkContactExcel->company_country = $contactCompanyCountryName;
                           $checkContactExcel->lead_type_id = $contactType;
                           $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                           $zeros->push($checkContactExcel);
                         }else{
                           $checkContactExcel->company_country = $contactCompanyCountryName;
                           $checkContactExcel->lead_type_id = $contactType;
                           $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                           $notValids->push($checkContactExcel);
                         }
                        //  if (EXCEL_FIRSTNAME == false || EXCEL_LASTNAME == false) {
                        //    print_r("5");
                        //    print_r("<br>");
                        //    $checkContactExcel->save();
                        //    $checkContactExcel->company_country = $contactCompanyCountryName;
                        //    $importedContacts->push($checkContactExcel);
                        //  }
                         if(filter_var($contactEmail, FILTER_VALIDATE_INT) === 0 && isset($contactFirstName) && isset($contactLastName)){
                           $checkContactExcel->company_country = $contactCompanyCountryName;
                           $checkContactExcel->lead_type_id = $contactType;
                           $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                           $notValids->push($checkContactExcel);
                         }
                      }
                    elseif (empty($contactFirstName)) {
                      $checkContactExcel->company_country = $contactCompanyCountryName;
                      $checkContactExcel->lead_type_id = $contactType;
                      $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                      $notValids->push($checkContactExcel);
                    }elseif (empty($contactLastName)) {
                      $checkContactExcel->company_country = $contactCompanyCountryName;
                      $checkContactExcel->lead_type_id = $contactType;
                      $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                      $notValids->push($checkContactExcel);
                    }
                    else{
                      $checkContactExcel->save();
                      $checkContactExcel->company_country = $contactCompanyCountryName;
                      $checkContactExcel->lead_type_id = $contactType;
                      $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                      $importedContacts->push($checkContactExcel);
                      
                      if ($contactTypeDesriptions) {
                          $typeDescriptions = explode(',', trim($contactTypeDesriptions));
                          
                          foreach($typeDescriptions as $key => $typeDescription) {
                              $lead_type_description_exists = DB::table('lead_type_descriptions')
                                  ->where('name', trim($typeDescription))
                                  ->first();
                                  
                              if (!$lead_type_description_exists) {
                                  $new_lead_type_description_id = DB::table('lead_type_descriptions')
                                      ->insertGetId([
                                          'name' => trim($typeDescription),
                                      ]);
                                  
                                  DB::table('lead_has_type_descriptions')
                                      ->insert(array(
                                          'lead_id' => $checkContactExcel->id,
                                          'lead_type_description_id' => $new_lead_type_description_id
                                      ));
                              } else {
                                  DB::table('lead_has_type_descriptions')
                                      ->insert(array(
                                          'lead_id' => $checkContactExcel->id,
                                          'lead_type_description_id' => $lead_type_description_exists->id
                                      ));
                              }
                          }
                      }
                    }
                   }
               }
               else
               {
                 if($checkContactExcel->first_name != $contactFirstName) {
                   $checkContactExcel->first_name = $contactFirstName;
                   $checkContactExcel->last_name = $contactLastName;
                   $checkContactExcel->company_country = $contactCompanyCountryName;
                   $checkContactExcel->lead_type_id = $contactType;
                   $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                   $sameContacts->push($checkContactExcel);
                 } elseif ($checkContactExcel->last_name != $contactLastName) {
                   $checkContactExcel->first_name = $contactFirstName;
                   $checkContactExcel->last_name = $contactLastName;
                   $checkContactExcel->company_country = $contactCompanyCountryName;
                   $checkContactExcel->lead_type_id = $contactType;
                   $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                   $sameContacts->push($checkContactExcel);
                 } else {
                   $checkContactExcel->first_name = $contactFirstName;
                   $checkContactExcel->last_name = $contactLastName;
                   $checkContactExcel->company_country = $contactCompanyCountryName;
                   $checkContactExcel->lead_type_id = $contactType;
                   $checkContactExcel->lead_type_descriptions = $contactTypeDesriptions;
                   $ignoreContacts->push($checkContactExcel);
                 }
               }
           }
         }
         else {
            return redirect()->back()
    					->with('excelfile', 'wrong');
          }
           File::delete($uploadedFile);
           $importedContacts->toArray();
           $ignoreContacts->toArray();
           $notValids->toArray();
           $zeros->toArray();
           $sameContacts->toArray();
           $numberNewContact = $importedContacts->count();
           $numberExistsContact = $ignoreContacts->count();
           $numberNotValids = $notValids->count();
           $numberSameContact = $sameContacts->count();
           if ($numberNewContact > 0) {
             $this->Log(114, $numberNewContact);
           }

           Cache::forget('leads-table');
           Cache::forget('mailings-table');

           return view('leads/import-done', ['newContactExcelImports' => $importedContacts,
                                             'numberNewContacts' => $numberNewContact,
                                             'numberExistsContacts' => $numberExistsContact,
                                             'existsContactExcels' => $ignoreContacts,
                                             'notValids' => $notValids,
                                             'zeros' => $zeros,
                                             'numberNotValids' => $numberNotValids,
                                             'sameContacts' => $sameContacts,
                                             'numberSameContact' =>$numberSameContact
                                             ]);
      }

}
