<?php

namespace App\Http\Controllers\Leads;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use DB;
use View;
use Carbon\Carbon;
use Cache;
use Session;
use Mail;
use Crypt;
use App\Http\Requests\Leads\PublicLead;

class PublicNewLeads extends Controller
{
    public function __construct() {
        parent::__construct();
    }

    /**
     * Dohvati novog leada
     */
    public function GetNewLead()
    {
        if ((env('APP_ID') == '04')) {
            $types = DB::table('lead_type_descriptions')
                ->where('name', '!=', 'Miadria 01/2018')
                ->where('name', '!=', 'Arhiva')
                ->orderBy('name')
                ->get();
        } else {
            $types = DB::table('lead_type_descriptions')->orderBy('name')->get();
        }

        return view('leads/public-new-lead', [
            'type_descriptions' =>  $types
        ]);
    }

    /**
     * Spremi novog leada
     */
    public function SaveNewLead(PublicLead $request)
    {
        if (env('GDPR', false) == false) return redirect()->back()
            ->with('message', 'Došlo je do pogreške');

        $email = trim($request->input('email'));

        $lead_exists = DB::table('leads')
            ->where('email', $email)
            ->whereNull('deleted_at')
            ->first();

        if ($lead_exists) {
            if ($lead_exists->opt_in == 'No') {
                $this->SendSubscribeMail($lead_exists->lead_code);
                return redirect()->back()
                    ->with('message', 'Na vašu e-mail adresu je poslana verifikacijska poveznica putem koje ćete uspješno potvrditi prijavu!');
            }

            return redirect()->back()
                ->with('message', 'Žao nam je, ali korisnik već postoji s unesenom e-mail adresom!');
        }

        $lead_code = $this->GetHash();

        $lead_id = DB::table('leads')
            ->insertGetId([
                'lead_code' => $lead_code,
                'email' => $email,
                'first_name' => trim($request->input('first_name')),
                'last_name' => trim($request->input('last_name')),
                'company_name' => trim($request->input('company')),
                'created_at' => $this->Now(),
                'self_registrated' => 'Yes',
                'opt_in' => 'No' ,
                'opt_in_method' => NULL,
                'lead_type_id' => (env('APP_ID') == '04') ? 7 : NULL
            ]);
        
        $lead_type_descriptions = $request->input('lead_type_descriptions');

        if ($lead_type_descriptions) {
            foreach($lead_type_descriptions as $key => $new_lead_type_description) {
                DB::table('lead_has_type_descriptions')
                    ->insert(array(
                        'lead_id' => $lead_id,
                        'lead_type_description_id' => $new_lead_type_description
                    ));
            }
        }

        $this->SendSubscribeMail($lead_code);
        $this->SendEmailToAdminEveryRegistration();

        Cache::forget('leads-table');
        Cache::forget('mailings-table');

        return redirect()->back()
            ->with('message', 'Na vašu e-mail adresu je poslana verifikacijska poveznica putem koje ćete uspješno potvrditi prijavu!');
    }

    /**
     * Generiraj jedinstveni ID
     */
    protected function GetHash(){
        return 'ld' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }

    /**
     * Trenutačno vrijeme eventa ili aplikacije
     */
    protected function Now($timezone_id = APP_TIME_ZONE) {
        $time_zone = DB::table('timezones')
            ->where('id', $timezone_id)
            ->value('timezone');

        if (!$time_zone) {
            $time_zone = DB::table('timezones')
                ->where('id', APP_TIME_ZONE)
                ->value('timezone');
        }

        return Carbon::now()
            ->setTimezone($time_zone)
            ->toDateTimeString();
    }

    /**
     * Pošalji mail korisniku da potvrdi
     */
    private function SendSubscribeMail($lead_code)
    {
        $subscribe_link = env('APP_URL') . '/subscribe/' . Crypt::encrypt($lead_code);

        $lead = DB::table('leads')
            ->where('lead_code', $lead_code)
            ->first();

        $email_data['from_email'] = env('GDPR_MAIL');
        $email_data['from_name'] = env('GDPR_NAME');
        $email_data['send_to'] = $lead->email;
        $email_data['subscribe_link'] = $subscribe_link;
        $email_data['title'] = 'Please give consent';

        Mail::queue('mail-templates.template_consent', $email_data, function ($message) use ($email_data) {
            $message->from($email_data['from_email'], $email_data['from_name'])
                ->to($email_data['send_to'])
                ->subject($email_data['title']);
        });
    }

    /**
	 * Pošalji mail event administratoru za svaku registraciju
	 */
	public function SendEmailToAdminEveryRegistration()
	{
		$email_data['from_email'] = env('GDPR_MAIL');
        $email_data['from_name'] = env('GDPR_NAME');
        $email_data['send_to'] = env('NEW_LEAD_MAIL');
        $email_data['title'] = 'New lead has been registered via web form';

        Mail::queue('mail-templates.template_public_new_lead', $email_data, function ($message) use ($email_data) {
            $message->from($email_data['from_email'], $email_data['from_name'])
                ->to($email_data['send_to'])
                ->subject($email_data['title']);
        });
    }
}
