<?php

namespace App\Http\Controllers\Leads;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use App\Http\Controllers\MainController as MainController;
use App\Lead as Lead;
use View;
use DB;
use Carbon\Carbon;
use Crypt;
use Mail;
use Illuminate\Support\Facades\Cache;

class SingleLeadController extends MainController
{

    public function __construct() {
        parent::__construct();

        $this->css['pages'] = [
            'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
            'global/plugins/bower_components/animate.css/animate.min.css',
            'global/plugins/bower_components/select2/dist/css/select2.css'
        ];

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css' => ['id' => ''],
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [
            'global/plugins/bower_components/moment/min/moment.min.js',
            'global/plugins/bower_components/select2/dist/js/select2.js',
        ];

        $this->js['additionalScripts'] = [
          '//cdnjs.cloudflare.com/ajax/libs/jquery.matchHeight/0.6.0/jquery.matchHeight-min.js',
          getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
        ];

        View::share('css', $this->css);
        View::share('js', $this->js);
        View::share('title', 'Create lead');
        View::share('extraClasses', 'singleLead');
    }


    public function AllLeads() {
        $leads = Lead::all();
        return view('leads/all-leads', ['leads' => $leads]);
    }


    public function GetSingleLead($lead_code = '') {
        View::share('lead_code', $lead_code);
        $countries = $this->GetCountries();
        View::share('countries', $countries);
        $lead_types = $this->GetLeadTypes();
        View::share('lead_types', $lead_types);
        $lead_type_descriptions = $this->GetLeadTypeDescriptions();
        View::share('type_descriptions', $lead_type_descriptions);
        return view('leads/single-lead');
    }


    public function InsertLead(Request $request) {
        $lead_code         = $this->GetHash();
        $gender            = $request->input('gender');
        $title             = $request->input('title');
        $first_name        = $request->input('first_name');
        $last_name         = $request->input('last_name');
        $email             = $request->input('email');
        $mobile            = $request->input('mobile');
        $phone             = $request->input('phone');
        $lead_type         = $request->input('lead_type');
        $lead_type_descriptions = $request->input('lead_type_descriptions');
        $company_name      = $request->input('company_name');
        $job_function      = $request->input('job_function');
        $company_address   = $request->input('company_address');
        $company_city      = $request->input('company_city');
        $company_post_code = $request->input('company_post_code');
        $company_country   = $request->input('company_country');
        $note              = $request->input('note');
    if(!empty($request->input('opt-in-method'))){
      $opt_in        = 'Yes';
      $opt_in_method = str_replace(',',', ', implode(",", $request->input('opt-in-method')));
    }else{
      $opt_in        = 'No';
      $opt_in_method = NULL;
    }

        $now = $this->Now();

        $first_name = trim($first_name);
        $last_name = trim($last_name);
        $email = trim($email);
        $email = strtolower($email);

        if ($this->LeadExistsWithEmail($email)) {
            $countries = $this->GetCountries();
            View::share('countries', $countries);
            $lead_types = $this->GetLeadTypes();
            View::share('lead_types', $lead_types);
            $lead_type_descriptions = $this->GetLeadTypeDescriptions();
            View::share('type_descriptions', $lead_type_descriptions);
            View::share('existing_lead_email_at_insert', $email);
            return $this->GetSingleLead();
        }
        else {
            if ($lead_type == null || $lead_type == '') {
                $lead_type = null;
            } else {
                $lead_type_exists = DB::table('lead_types')
                    ->where('id', $lead_type)
                    ->orWhere('name', $lead_type)
                    ->first();
                    
                if (!$lead_type_exists) {
                    $lead_type = DB::table('lead_types')
                        ->insertGetId([
                            'name' => $lead_type,
                        ]);
                }
            }
            
            $lead_id = DB::table('leads')
                ->insertGetId([
                    'lead_code'         => $lead_code,
                    'gender'            => $gender,
                    'title'             => $title,
                    'first_name'        => $first_name,
                    'last_name'         => $last_name,
                    'email'             => $email,
                    'mobile'            => $mobile,
                    'phone'             => $phone,
                    'lead_type_id'      => $lead_type,
                    'company_name'      => $company_name,
                    'job_function'      => $job_function,
                    'company_address'   => $company_address,
                    'company_city'      => $company_city,
                    'company_post_code' => $company_post_code,
                    'company_country'   => $company_country,
                    'note'              => $note,
                    'created_at'        => $now,
                    'opt_in' => (GDPR) ? 'No' : $opt_in,
                    'opt_in_method' => (GDPR) ? NULL : $opt_in_method
                ]);
                
                DB::table('lead_has_type_descriptions')
                    ->where('lead_id', $lead_id)
                    ->delete();
                
                if ($lead_type_descriptions) {
                    foreach($lead_type_descriptions as $key => $new_lead_type_description) {
                        $lead_type_description_exists = DB::table('lead_type_descriptions')
                            ->where('id', $new_lead_type_description)
                            ->orWhere('name', $new_lead_type_description)
                            ->first();
                            
                        if (!$lead_type_description_exists) {
                            $new_lead_type_description_id = DB::table('lead_type_descriptions')
                                ->insertGetId([
                                    'name' => $new_lead_type_description,
                                ]);
                            
                            DB::table('lead_has_type_descriptions')
                                ->insert(array(
                                    'lead_id' => $lead_id,
                                    'lead_type_description_id' => $new_lead_type_description_id
                                ));
                        } else {
                            DB::table('lead_has_type_descriptions')
                                ->insert(array(
                                    'lead_id' => $lead_id,
                                    'lead_type_description_id' => $new_lead_type_description
                                ));
                        }
                    }
                }

            if(GDPR) $this->SendSubscribeMail($lead_code);

            // New lead
            $this->Log(111, $lead_id);

            Cache::forget('leads-table');
            Cache::forget('mailings-table');

            return redirect()->action('Leads\AllLeadsController@getIndex');
        }
    }


    public function UpdateLead(Request $request) {
        $lead_code         = $request->input('lead_code');
        $gender            = $request->input('gender');
        $title             = $request->input('title');
        $first_name        = $request->input('first_name');
        $last_name         = $request->input('last_name');
        $email             = $request->input('email');
        $mobile            = $request->input('mobile');
        $phone             = $request->input('phone');
        $lead_type         = $request->input('lead_type');
        $lead_type_descriptions = $request->input('lead_type_descriptions');
        $company_name      = $request->input('company_name');
        $job_function      = $request->input('job_function');
        $company_address   = $request->input('company_address');
        $company_city      = $request->input('company_city');
        $company_post_code = $request->input('company_post_code');
        $company_country   = $request->input('company_country');
        $note              = $request->input('note');

    if(!empty($request->input('opt-in-method'))){
      $opt_in        = 'Yes';
      $opt_in_method = str_replace(',',', ', implode(",", $request->input('opt-in-method')));
    }else{
      $opt_in        = 'No';
      $opt_in_method = NULL;
    }

        $now = $this->Now();

        $first_name = trim($first_name);
        $last_name = trim($last_name);
        $email = trim($email);
        $email = strtolower($email);

        if ($this->LeadExistsWithEmailWithAnotherCode($email, $lead_code)) {
            $countries = $this->GetCountries();
            View::share('countries', $countries);
            $lead_types = $this->GetLeadTypes();
            View::share('lead_types', $lead_types);
            $lead_type_descriptions = $this->GetLeadTypeDescriptions();
            View::share('type_descriptions', $lead_type_descriptions);
            View::share('existing_lead_email_at_update', $email);
            $this->GetLeadDataByCode($lead_code);
            View::share('lead_code', $lead_code);
            return view('leads/single-lead');
        }
        else {
            if ($lead_type == null || $lead_type == '') {
                $lead_type = null;
            } else {
                $lead_type_exists = DB::table('lead_types')
                    ->where('id', $lead_type)
                    ->orWhere('name', $lead_type)
                    ->first();
                    
                if (!$lead_type_exists) {
                    $lead_type = DB::table('lead_types')
                        ->insertGetId([
                            'name' => $lead_type,
                        ]);
                }
            }
            
            DB::table('leads')
                ->where('lead_code', '=', $lead_code)
                ->update([
                    'gender'            => $gender,
                    'title'             => $title,
                    'first_name'        => $first_name,
                    'last_name'         => $last_name,
                    'email'             => $email,
                    'mobile'            => $mobile,
                    'phone'             => $phone,
                    'lead_type_id'      => $lead_type,
                    'company_name'      => $company_name,
                    'job_function'      => $job_function,
                    'company_address'   => $company_address,
                    'company_city'      => $company_city,
                    'company_post_code' => $company_post_code,
                    'company_country'   => $company_country,
                    'note'              => $note,
                    'updated_at'        => $now,
                    'opt_in'            => $opt_in,
                    'opt_in_method'     => $opt_in_method
                ]);
                
            $lead_id = DB::table('leads')
                 ->where('lead_code', $lead_code)
                 ->value('id');
                 
             DB::table('lead_has_type_descriptions')
                 ->where('lead_id', $lead_id)
                 ->delete();
                
            if ($lead_type_descriptions) {
                foreach($lead_type_descriptions as $key => $new_lead_type_description) {
                    $lead_type_description_exists = DB::table('lead_type_descriptions')
                        ->where('id', $new_lead_type_description)
                        ->orWhere('name', $new_lead_type_description)
                        ->first();
                        
                    if (!$lead_type_description_exists) {
                        $new_lead_type_description_id = DB::table('lead_type_descriptions')
                            ->insertGetId([
                                'name' => $new_lead_type_description,
                            ]);
                        
                        DB::table('lead_has_type_descriptions')
                            ->insert(array(
                                'lead_id' => $lead_id,
                                'lead_type_description_id' => $new_lead_type_description_id
                            ));
                    } else {
                        DB::table('lead_has_type_descriptions')
                            ->insert(array(
                                'lead_id' => $lead_id,
                                'lead_type_description_id' => $new_lead_type_description
                            ));
                    }
                }
            }

            // Updated lead
            $this->Log(112, $lead_id);
            $this->Now();
            View::share('lead_code', $lead_code);
            $this->GetLeadDataByCode($lead_code);
            $countries = $this->GetCountries();
            View::share('countries', $countries);
            $lead_types = $this->GetLeadTypes();
            View::share('lead_types', $lead_types);
            $lead_type_descriptions = $this->GetLeadTypeDescriptions();
            View::share('type_descriptions', $lead_type_descriptions);
            View::share('lead_saved', 'Save successful!');

            Cache::forget('leads-table');
            Cache::forget('mailings-table');

            return view('leads/single-lead');
        }

    }


    /**
     *  Vrati popis država
     */
    private function GetCountries() {
        $countries = DB::table('countries')
            ->get();

        return $countries;
    }
    
    /**
     *  Vrati popis tipova
     */
    private function GetLeadTypes()
    {
        $lead_types = DB::table('lead_types')
            ->get();

        return $lead_types;
    }
    
    /**
     *  Vrati popis opisa tipova
     */
    private function GetLeadTypeDescriptions()
    {
        $lead_type_descriptions = DB::table('lead_type_descriptions')
            ->get();

        return $lead_type_descriptions;
    }

    public function LeadExistsWithEmail($email){
        $lead_exists = Lead::where('email', $email)
            ->whereNull('deleted_at')
            ->count();
        if($lead_exists) {
            return 1;
        }
        else {
            return 0;
        }
    }

    public function LeadExistsWithEmailWithAnotherCode($email, $code){
        $lead_exists = Lead::where([
                ['email', $email],
                ['lead_code','<>', $code],
            ])
            ->whereNull('deleted_at')
            ->count();
        if($lead_exists) {
            return 1;
        }
        else {
            return 0;
        }
    }

    public function GetLeadCodeByEmail($email){
        $lead_code = DB::table('lead')->select('lead_code')->where('email', $email);
        return $lead_code;
    }

    public function DeleteLead(Request $request) {
        $lead_id = $request->input('id');

        if($lead_id) {
            DB::table('registrations')
                ->where('lead_id', $lead_id)
                ->update([
                    'deleted_at' => $this->Now()
                ]);

            Lead::where('id', '=', $lead_id)
                ->update([
                    'deleted_at' => $this->Now()
                ]);

            // Deleted lead
            $this->Log(113, $lead_id);

            Cache::forget('leads-table');
            Cache::forget('mailings-table');
        }
        return redirect()->action('Leads\AllLeadsController@getIndex');
    }

    public function GetLeadInfo($lead_code = ''){
        if($lead_code != ''){
            View::share('hash', $lead_code);
            $this->GetLeadDataByCode($lead_code);
        }
        View::share('lead_code', $lead_code);
        $countries = $this->GetCountries();
        View::share('countries', $countries);
        $lead_types = $this->GetLeadTypes();
        View::share('lead_types', $lead_types);
        $lead_type_descriptions = $this->GetLeadTypeDescriptions();
        View::share('type_descriptions', $lead_type_descriptions);
        return view('leads/single-lead');
    }

    /* Dohvati i podijeli podatke o leadu po zadanom kodu*/
    public function GetLeadDataByCode($lead_code){
        //type of event
        $lead_info = DB::table('leads')
            ->where('lead_code', $lead_code)
            ->first();
        if ($lead_info) {
            $lead_type_descriptions = DB::table('lead_has_type_descriptions')
                ->where('lead_id', $lead_info->id)
                ->get();
            View::share('lead_type_descriptions', $lead_type_descriptions);
                
            $lead_info = json_decode(json_encode($lead_info, true));
            View::share('lead_info', $lead_info);
        }
    }

    public function GetLeadDataByEmail($lead_email){
        //type of event
        $lead_info = DB::table('leads')
            ->where('email', $lead_email)
            ->get();
        if ($lead_info) {
            $lead_info = json_decode(json_encode($lead_info[0],true));
            View::share('lead_info', $lead_info);
        }
    }

    public function GetHash(){
        return 'ld' . rand(1000,10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }

    private function SendSubscribeMail($lead_code)
    {
        $subscribe_link = env('APP_URL') . '/subscribe/' . Crypt::encrypt($lead_code);

        $lead = DB::table('leads')
            ->where('lead_code', $lead_code)
            ->first();

        $email_data['from_email'] = env('GDPR_MAIL');
		$email_data['from_name'] = env('GDPR_NAME');
		$email_data['send_to'] = $lead->email;
        $email_data['subscribe_link'] = $subscribe_link;
        $email_data['title'] = 'Please give consent';

		Mail::queue('mail-templates.template_consent', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->subject($email_data['title']);
		});
    }

}
