<?php

namespace App\Http\Controllers;

use App\Http\Requests;
use App\Http\Controllers\Controller;

use View;
use DB;
use Auth;
use Request;

class MainController extends Controller
{
    public $assetUrl;
    public $css = [];
    public $js = [];

    public $bodyClass = "krik page-sidebar-fixed animated fadeIn";
    public $sidebarClass = "sidebar-circle";

    public function __construct() {
      parent::__construct();

      $this->middleware('auth');
      $this->setApp();
    }

    public function setApp() {
      $this->assetUrl = getenv('APP_URL') . '/assets/theme/';

      $this->css = [
        'globals' => ['global/plugins/bower_components/bootstrap/dist/css/bootstrap.min.css'],
        'cssKrik' => [getenv('APP_URL') . '/assets/css/style.min.css']
      ];
      $this->js = [
        'cores' => $this->getCoresJs(),
        'ies' => $this->getIesJs(),
        'jsKrik' => [getenv('APP_URL') . '/assets/js/scripts.min.js']
      ];

      View::share('assetUrl', $this->assetUrl);
      View::share('title', 'Krikem');
      View::share('bodyClass', $this->bodyClass);
      View::share('sidebarClass', $this->sidebarClass);
      View::share('css', $this->css);
      View::share('js', $this->js);
    }

    private function getCoresJs() {
      return [
        'global/plugins/bower_components/jquery/dist/jquery.min.js',
        'global/plugins/bower_components/jquery-cookie/jquery.cookie.js',
        'global/plugins/bower_components/bootstrap/dist/js/bootstrap.min.js',
        'global/plugins/bower_components/jquery-nicescroll/jquery.nicescroll.min.js',
        'global/plugins/bower_components/bootstrap-session-timeout/dist/bootstrap-session-timeout.min.js'
      ];
    }

    private function getIesJs() {
      return [
        'global/plugins/bower_components/html5shiv/dist/html5shiv.min.js',
        'global/plugins/bower_components/respond-minmax/dest/respond.min.js'
      ];
    }

    /**
     * Provjera da li event ima dostupan accommodations
     */
    protected function eventHasAccommodations($event_id) {
      $event_has_accommodations = DB::table('accommodations')
        ->where('event_id', $event_id)
        ->first();

      if($event_has_accommodations) {
        return true;
      } else {
        return false;
      }
    }

    /**
     * Provjera da li event ima dostupan transfers
     */
    protected function eventHasTransfers($event_id) {
      $event_has_transfers = DB::table('transfers')
        ->where('event_id', $event_id)
        ->first();

      if($event_has_transfers) {
        return true;
      } else {
        return false;
      }
    }

    /**
     * Zapis u log
     */
    protected function Log($log_type_id, $entity = NULL) {

      $user = Auth::user();

      DB::table('logs')
        ->insert([
          'user_id' => $user->id,
          'log_type_id' => $log_type_id,
          'entity' => $entity,
          'ip' => Request::getClientIp(),
          'created_at' => $this->Now()
        ]);

    }


    /**
     * Keep logged in user alive
     */
    public function KeepAlive() {
      return 'Yes';
    }
}
