<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use App\Event as Event;
use Session;
use Redirect;

class AttendingController extends RegistrationController
{
    public function __construct() {
      parent::__construct();

      $this->setApp();

      $this->css['pages'] = [
        'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
      ];

      $this->css['themes'] = [
        'admin/css/reset.css',
        'admin/css/layout.css',
        'admin/css/components.css',
        'admin/css/plugins.css',
        'admin/css/themes/laravel.theme.css' => ['id' => ''],
        'admin/css/custom.css',
      ];

      $this->js['scripts'] = [];

      View::share('css', $this->css);
      View::share('js', $this->js);
      View::share('title', 'Event Confirmation');
    }


    /**
     * Spremanje confirma
     */
    public function ConfirmComing($event_code, $lead_code) {
      // Dohvati podatke o eventu
      $event = $this->GetEvent($event_code);
      
      // Provjera da li je event draft
      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }
      
      // Provjera da li su registracije otvorene
      $registration_opened = $this->CheckRegistrationOpened($event_code);
      if($registration_opened == false) {
        return view('registration.messages.closed')
          ->with('event', $event);
      }
      
      // Provjera da li ima slobodnih karata
      $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      // Dohvat podataka o leadu
      $lead = DB::table('leads')
        ->where('lead_code', $lead_code)
        ->first();

      if($event && $lead) {
        // Provjera da li je korisnik uopće dobio poziv za confirm coming
        $lead_invited = DB::table('mailing_activities')
          ->join('mailings', 'mailing_activities.id', '=', 'mailings.mailing_activity_id')
          ->where([
            ['mailing_activities.event_id', $event->id],
            ['mailings.lead_id', $lead->id]
          ])
          ->whereNull('mailings.deleted_at')
          ->first();

          if($lead_invited) {

            // Provjeri da li korisnik već ima registraciju za taj event
            $lead_registration = DB::table('registrations')
              ->where([
                ['event_id', '=', $event->id],
                ['lead_id', '=', $lead->id]
              ])
              ->whereNull('deleted_at')
              ->first();

            if(!$lead_registration) {
                
                // TODO Provjera da li karata ima

                $registration_id = DB::table('registrations')
                    ->insertGetId(array(
                        'event_id' => $event->id,
                        'lead_id' => $lead->id,
                        'confirmed_ts' => $this->Now(),
                        'status_registration' => 'Waiting'
                    ));
                    
                $lead_registration = DB::table('registrations')->where('id', $registration_id)->first();
                
                DB::table('registrations')
                    ->where('id', $registration_id)
                    ->update([
                        'barcode' => $this->Barcode($event, $lead_registration)
                    ]);

                DB::table('leads_on_events_insights')
                    ->where('lead_id', $lead_registration->lead_id)
                    ->update([
                        "event_id_" . $event->id => 'registered'
                    ]);
                    
                return view('registration/messages/confirm-coming-done')
                    ->with('event', $event);

            } else {
                
                return view('registration/messages/confirm-coming-again')
                    ->with('event', $event);

            }

          } else {

            return view('registration/messages/confirm-coming-nope')
              ->with('event', $event);

          }

      } else {

        return redirect()->route('home');

      }
    }

}
