<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Redirect;
use Carbon\Carbon;
use Session;

class RegistrationAccommodationTransferController extends RegistrationController {

    public function __construct() {
      parent::__construct();
    }

    /**
     * Prikaz Accommodation/Transfer
     */
    public function GetAccommodationTransfer(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $accommodations_available = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);
      if($accommodations_available == false && $transfers == false) {
        return Redirect::route('general-information', array($event_code, $lead_code));
      }

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $select_past_time = 1;
      } else {
        $select_past_time = 0;
      }

      $accommodations = $this->GetAvailableAccommodations($event);
      
      $transfers = $this->GetTransfers($event);

      $leads_transfers_ids = $this->GetLeadsTransfersIds($event, $lead);
      $leads_transfers = $this->GetLeadsTransfers($event, $lead);

      $currency = $this->GetEventCurrency($event_code);

      return view('registration.steps.accommodation-transfer')
        ->with('event', $event)
        ->with('lead', $lead)
        ->with('lead_registration', $lead_registration)
        ->with('accommodations_available', $accommodations_available)
        ->with('accommodations', $accommodations)
        ->with('transfers', $transfers)
        ->with('leads_transfers_ids', $leads_transfers_ids)
        ->with('leads_transfers', $leads_transfers)
        ->with('currency', $currency)
        ->with('select_past_time', $select_past_time);
    }


    /**
     * Spremanje Accommodation/Transfer
     */
    public function SaveAccommodationTransfer(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $accomodation_reservation = $request->input('accomodation_reservation');
      $transfer_reservation = $request->input('transfer_reservation');

      // Accommodation

      if($accomodation_reservation == 1) {

        $accomodation_room_id = $request->input('accomodation_room_id');
        $accomodation_roomy_name = $request->input('accomodation_roomy_name');
        $accomodation_note = $request->input('accomodation_note');

        $accomodation_arrival_departure_date = $request->input('accomodation_arrival_departure_date');
        $accomodation_arrival_date = substr($accomodation_arrival_departure_date, 0, 10);
        $accomodation_departure_date = substr($accomodation_arrival_departure_date, -10);
        $accomodation_arrival_date = Carbon::createFromFormat('d/m/Y', $accomodation_arrival_date)
          ->toDateString();
        $accomodation_departure_date = Carbon::createFromFormat('d/m/Y', $accomodation_departure_date)
          ->toDateString();

        if($accomodation_arrival_date == $accomodation_departure_date) {
            $accomodation_departure_date = Carbon::createFromFormat('d/m/Y',  substr($accomodation_arrival_departure_date, -10))
                ->addDay()
                ->toDateString();
        }

        $accomodation_note = $request->input('accomodation_note');

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'accomodation_room_id' => $accomodation_room_id,
            'accomodation_roomy_name' => $accomodation_roomy_name,
            'accomodation_note' => $accomodation_note,
            'accomodation_arrival_date' => $accomodation_arrival_date,
            'accomodation_departure_date' => $accomodation_departure_date
          ));

      } else {

        $this->DeleteAccommodationPayer($lead_registration);
        $this->DeleteAccommodation($lead_registration);

      }

      // Transfers

      if($transfer_reservation == 1) {

        $this->DeleteTransfers($lead_registration);

        $transfer_0 = $request->input('transfer_type_0');
        $transfer_1 = $request->input('transfer_type_1');

        if($transfer_0) {
          $transfer_start_ts_0 = $request->input('transfer_start_ts_0');
          $transfer_start_ts_0 = Carbon::createFromFormat('d/m/Y H:i', $transfer_start_ts_0)
            ->toDateTimeString();

          $flight_number_0 = $request->input('flight_number_0');

          $transfer_0_id = DB::table('registration_has_transfers')
            ->insertGetId(array(
              'registration_id' => $lead_registration->id,
              'transfer_id' => $transfer_0,
              'transfer_start_ts' => $transfer_start_ts_0,
              'flight_number' => $flight_number_0
            ));
        }

        if($transfer_1) {
          $transfer_start_ts_1 = $request->input('transfer_start_ts_1');
          $transfer_start_ts_1 = Carbon::createFromFormat('d/m/Y H:i', $transfer_start_ts_1)
            ->toDateTimeString();

          $flight_number_1 = $request->input('flight_number_1');

          $transfer_1_id = DB::table('registration_has_transfers')
            ->insertGetId(array(
              'registration_id' => $lead_registration->id,
              'transfer_id' => $transfer_1,
              'transfer_start_ts' => $transfer_start_ts_1,
              'flight_number' => $flight_number_1
            ));
        }

      } else {

        $this->DeleteTransferPayer($lead_registration);
        $this->DeleteTransfers($lead_registration);

      }

      return Redirect::route('payment', array($event_code, $lead_code));

    }

}
