<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Carbon\Carbon;
use Auth;
use Mail;
use Route;
use Redirect;
use PDF;
use Session;
use Illuminate\Support\Facades\Input;
use App\Http\Controllers\MainPublicController as MainPublicController;

class RegistrationController extends MainPublicController {

    public function __construct() {
      parent::__construct();

      $this->css['pages'] = [
        'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
        'global/plugins/bower_components/animate.css/animate.min.css',
        'global/plugins/bower_components/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.min.css',
        'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.css',
        'global/plugins/bower_components/select2/dist/css/select2.css'
      ];

      $this->css['themes'] = [
        'admin/css/reset.css',
        'admin/css/layout.css',
        'admin/css/components.css',
        'admin/css/plugins.css',
        'admin/css/themes/laravel.theme.css',
        'admin/css/custom.css'
      ];

      $this->js['plugins'] = [
        'global/plugins/bower_components/bootstrap-datepicker-vitalets/js/bootstrap-datepicker.js',
        'global/plugins/bower_components/moment/min/moment.min.js',
        'global/plugins/bower_components/bootstrap-switch/dist/js/bootstrap-switch.min.js',
        'global/plugins/bower_components/bootstrap-daterangepicker/daterangepicker.js',
        'global/plugins/bower_components/select2/dist/js/select2.js'
      ];

      $this->js['additionalScripts'] = [
        getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
      ];

      View::share('css', $this->css);
      View::share('js', $this->js);
    }


    /**
     * Dohvati event
     */
    protected function GetEvent($event_code) {
      $event = DB::table('events')
        ->leftJoin('event_look_feels', 'event_look_and_feel_id', '=', 'event_look_feels.id')
        ->leftJoin('color_schemes', 'event_look_feels.color_scheme_id', '=', 'color_schemes.id')
        ->selectRaw('events.id,
          events.event_code,
          events.name,
          events.lang,
          events.registration_start_ts,
          events.registration_end_ts,
          events.access,
          events.currency_id,
          events.email_name,
          events.email_sender,
          events.email_footer,
          events.venue_name,
          events.venue_address,
          events.venue_city,
          events.venue_postal_code,
          events.venue_country_id,
          events.tickets_invoice_from_id,
          events.accomodation_invoice_from_id,
          events.transfer_invoice_from_id,
          events.wspay,
          events.is_draft,
          events.timezone_id,
          events.deleted_at,
          events.registration_notification,
          events.registration_starting_existing_leads_en,
          events.registration_starting_existing_leads_hr,
          events.registration_starting_new_leads_en,
          events.registration_starting_new_leads_hr,
          events.registration_completed_with_invoices_en,
          events.registration_completed_with_invoices_hr,
          events.registration_completed_without_invoices_en,
          events.registration_completed_without_invoices_hr,
          events.registration_email_signature_en,
          events.registration_email_signature_hr,
          event_look_feels.event_logo_url,
          color_schemes.background_color,
          color_schemes.titles_color')
        ->where('events.event_code', $event_code)
        ->whereNull('events.deleted_at')
        ->first();

      return $event;
    }


    /**
     * Provjera postojanosti eventa
     */
    protected function CheckEvent($event_code) {
      $event = $this->GetEvent($event_code);

      if($event) {
        return $event;
      }

      Redirect::to('/')->send();
    }


    /**
     * Dohvati lead putem lead coda
     */
    protected function GetLead($lead_code) {
      $lead = DB::table('leads')
        ->where('lead_code', $lead_code)
        ->whereNull('deleted_at')
        ->first();

      return $lead;
    }


    /**
     * Provjera postojanosti leada
     */
    protected function CheckLead($event_code, $lead_code) {
      $lead = $this->GetLead($lead_code);

      if($lead) {
        return $lead;
      }

      Redirect::to('/registration/' . $event_code)->send();
    }


    /**
     * Provjera postojanosti leada ovisno o emailu
     */
    protected function CheckLeadByEmail($email) {
      $lead = DB::table('leads')
        ->where('email', $email)
        ->whereNull('deleted_at')
        ->first();

      if($lead) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjera registracije da li je zatvorena ili prošla
     */
    protected function CheckRegistrationOpened($event_code) {
      $event = $this->GetEvent($event_code);

      $registration_start = $event->registration_start_ts;
      $registration_end = $event->registration_end_ts;

      if($registration_start <= $this->Now() && $registration_end >= $this->Now()) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjera slobodnih karata
     */
    protected function CheckIfAvailableTicketsExists($event_code, $validate_time = true) {
      $event = $this->GetEvent($event_code);

      $tickets = DB::table('tickets')
        ->leftJoin('registrations', 'registrations.ticket_type_id', '=', 'tickets.id')
        ->selectRaw('COUNT(ticket_type_id) AS used,
          tickets.quantity,
          tickets.valid_from_ts,
          tickets.valid_until_ts,
          tickets.id')
        ->where('tickets.event_id', $event->id)
        ->whereNull('tickets.deleted_at')
        ->whereNull('registrations.deleted_at')
        ->where(function ($query) {
          $query->where('registrations.ticket_approved', 1)
            ->orWhereNull('registrations.ticket_approved');
        })
        ->where(function($query) {
			$query->whereNotNull('registrations.registered_ts')
                ->orWhereNotNull('registrations.confirmed_ts');
		})
        ->groupBy('tickets.id')
        ->get();

      foreach ($tickets as $key => $ticket) {
        if($ticket->used >= $ticket->quantity) {
          unset($tickets[$key]);
        }

        if($validate_time == true) {
          if($ticket->valid_from_ts >= $this->Now($event->timezone_id)) {
            unset($tickets[$key]);
          }

          if($ticket->valid_until_ts <= $this->Now($event->timezone_id)) {
            unset($tickets[$key]);
          }
        }
      }

      $tickets_on_event = DB::table('tickets')
        ->where('tickets.event_id', $event->id)
        ->whereNull('tickets.deleted_at')
        ->select('id')
        ->get();

      // Slušaj kada postoji samo jedna obrisana registracija za ticket
      // Gornja projekcija u tom slučaju neće vraiti kartu kao validnu
      foreach ($tickets_on_event as $key => $ticket_on_event) {
        $number_of_registrations_with_ticket = DB::table('registrations')
          ->where('ticket_type_id', $ticket_on_event->id)
          ->count();

        $number_deleted_not_complited_canceled_registrations_with_ticket = DB::table('registrations')
          ->where('ticket_type_id', $ticket_on_event->id)
          ->where(function ($query) {
            $query->whereNotNull('registrations.deleted_at')
              ->orWhereNull('registrations.registered_ts')
              ->orWhere('registrations.ticket_approved', 0);
          })
          ->count();

        if($number_of_registrations_with_ticket == $number_deleted_not_complited_canceled_registrations_with_ticket) {

          $new_ticket = DB::table('tickets')
            ->select(
              'name',
              'price_without_VAT',
              'VAT',
              'id',
              'quantity',
              'valid_from_ts',
              'valid_until_ts')
            ->where('id', $ticket_on_event->id)
            ->first();

          if($number_of_registrations_with_ticket - $number_deleted_not_complited_canceled_registrations_with_ticket >= $new_ticket->quantity) {
            continue;
          }

          if($validate_time == true) {
            if($new_ticket->valid_from_ts >= $this->Now($event->timezone_id)) {
              continue;
            }

            if($new_ticket->valid_until_ts <= $this->Now($event->timezone_id)) {
              continue;
            }
          }

          array_push($tickets, $new_ticket);
        }
      }

      $tickets_count = count($tickets);

      if($tickets_count > 0) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Dostupne karte za event
     */
    protected function GetAvailableTickets($event_code, $validate_time = true) {
      $event = $this->GetEvent($event_code);

      $tickets = DB::table('tickets')
        ->leftJoin('registrations', 'registrations.ticket_type_id', '=', 'tickets.id')
        ->selectRaw('COUNT(ticket_type_id) AS used,
          tickets.quantity,
          tickets.name,
          tickets.price_without_VAT,
          tickets.VAT,
          tickets.valid_from_ts,
          tickets.valid_until_ts,
          tickets.accompany_persons,
          tickets.has_promo_codes,
          tickets.id')
        ->where('tickets.event_id', $event->id)
        ->whereNull('tickets.deleted_at')
        ->whereNull('registrations.deleted_at')
        ->whereNotNull('registrations.registered_ts')
        ->where(function ($query) {
          $query->where('registrations.ticket_approved', 1)
            ->orWhereNull('registrations.ticket_approved');
        })
        ->groupBy('tickets.id')
        ->get();

      foreach ($tickets as $key => $ticket) {
        if($ticket->used >= $ticket->quantity) {
          unset($tickets[$key]);
        }

        if($validate_time == true) {
          if($ticket->valid_from_ts >= $this->Now($event->timezone_id)) {
            unset($tickets[$key]);
          }

          if($ticket->valid_until_ts <= $this->Now($event->timezone_id)) {
            unset($tickets[$key]);
          }
        }
      }

      // Slušaj kada postoji samo jedna obrisana registracija za ticket
      // Gornja projekcija u tom slučaju neće vraiti kartu kao validnu

      $tickets_on_event = DB::table('tickets')
        ->where('tickets.event_id', $event->id)
        ->whereNull('tickets.deleted_at')
        ->select('id')
        ->get();

      foreach ($tickets_on_event as $key => $ticket_on_event) {
        $number_of_registrations_with_ticket = DB::table('registrations')
          ->where('ticket_type_id', $ticket_on_event->id)
          ->count();

        $number_deleted_not_complited_canceled_registrations_with_ticket = DB::table('registrations')
          ->where('ticket_type_id', $ticket_on_event->id)
          ->where(function ($query) {
            $query->whereNotNull('registrations.deleted_at')
              ->orWhereNull('registrations.registered_ts')
              ->orWhere('registrations.ticket_approved', 0);
          })
          ->count();

        if($number_of_registrations_with_ticket == $number_deleted_not_complited_canceled_registrations_with_ticket) {

          $new_ticket = DB::table('tickets')
            ->select(
              'name',
              'price_without_VAT',
              'VAT',
              'id',
              'quantity',
              'valid_from_ts',
              'valid_until_ts',
              'accompany_persons',
              'has_promo_codes')
            ->where('id', $ticket_on_event->id)
            ->first();

          if($number_of_registrations_with_ticket - $number_deleted_not_complited_canceled_registrations_with_ticket >= $new_ticket->quantity) {
            continue;
          }

          if($validate_time == true) {
            if($new_ticket->valid_from_ts >= $this->Now($event->timezone_id)) {
              continue;
            }

            if($new_ticket->valid_until_ts <= $this->Now($event->timezone_id)) {
              continue;
            }
          }

          array_push($tickets, $new_ticket);
        }
      }

      return $tickets;
    }


    /**
     * Dohvati lead putem emaila
     */
    protected function GetLeadByEmail($email) {
      $lead = DB::table('leads')
        ->where('email', $email)
        ->whereNull('deleted_at')
        ->first();

      return $lead;
    }


    /**
     * Generiranje lead koda
     */
    protected function GenerateLeadCode(){
      return 'ld' . rand(1000, 10000) . substr(str_shuffle('adfgrtFGHAerzaADFGearzagfhADGeqg'), 0, 6) . time();
    }


    /**
     * Kreiranje novog leada
     */
    protected function CreateLead($email) {
      $lead_id = DB::table('leads')
        ->insertGetId(array(
          'email' => $email,
          'created_at' => $this->Now(),
          'lead_code' => $this->GenerateLeadCode()
        ));

      $lead = DB::table('leads')
        ->where('id', $lead_id)
        ->first();

      return $lead;
    }


    /**
     * Kreiranje nove registracije za leada
     */
    protected function CreateRegistration($event, $lead) {
      $registration_not_complited = DB::table('registrations')
        ->where([
          ['event_id', '=', $event->id],
          ['lead_id', '=', $lead->id]
        ])
        ->where(function($query) {
			$query->whereNull('registrations.registered_ts')
                ->orWhereNull('registrations.confirmed_ts');
		})
        ->whereNull('deleted_at')
        ->first();

      if($registration_not_complited) {
        $registration_id = $registration_not_complited->id;
      } else {
        $registration_id = DB::table('registrations')
          ->insertGetId(array(
            'event_id' => $event->id,
            'lead_id' => $lead->id,
            'status_registration' => 'Waiting',
            'status_accomodation' => 'Waiting',
            'status_transfer' => 'Waiting'
          ));
      }

      return $registration_id;
    }


    /**
     * Generiranje jedinstvene verifikacijske poveznice
     */
    protected function GenerateVerificationLink($event, $lead) {
      // Enkripcija
      // $time_code = mcrypt_encrypt(MCRYPT_RIJNDAEL_256, hash('sha256', 'krik', true), time(), MCRYPT_MODE_ECB, mcrypt_create_iv(32));
      $cipher = 'AES-128-CBC';
      $iv = substr(hash('sha256', 'studio'), 0, 16);
      $time_code = openssl_encrypt(time(), $cipher, 'krik', 0, $iv); // PHP 7.1+

      // Pretvaranje u base64 format
      // Napomena: base64 znakovi su ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=
      // +/= je potrebno zamijeniti s URL prijateljskim znakovima
      $time_code = base64_encode($time_code);
      $time_code = strtr($time_code, '+/=', '-_~');

      // Pretvaranje u URL prijeteljski zapis
      $time_code = urlencode($time_code);

      // Kreiranje verifikacijske poveznice
      $verification_link = env('APP_URL') . '/registration/' . $event->event_code . '/' . $lead->lead_code . '/' . $time_code;

      return $verification_link;
    }


    /**
     * Provjera kriptiranog vremena da li je validno i da li je unutar dva sata
     */
    protected function CheckVerificationTime($time_code, $lead) {

      // Vraćanje iz base64 formata
      // Uz napomenu da prvo moramo vratiti i +/=
      $time_code = strtr($time_code, '-_~', '+/=');
      $time_code = base64_decode($time_code);

      // Dekripcija
      // Uz napomenu da moramo maknuti \0 znak s kraja
      // $time_code = mcrypt_decrypt(MCRYPT_RIJNDAEL_256, hash('sha256', 'krik', true), $time_code, MCRYPT_MODE_ECB, mcrypt_create_iv(32));
      $cipher = 'AES-128-CBC';
      $iv = substr(hash('sha256', 'studio'), 0, 16);
      $time_code = openssl_decrypt($time_code, $cipher, 'krik', 0, $iv); // PHP 7.1+
      $time_code = rtrim($time_code, "\0");
     
      // Provjera da li je unutar prošla dva sata
      if($time_code >= strtotime("-2 hours") && $time_code <= time() && strlen($time_code) == 10) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjera da li je lead već registriran na event
     */
    protected function CheckLeadsRegistration($event, $lead) {
      $registration = DB::table('registrations')
        ->where([
          ['event_id', '=', $event->id],
          ['lead_id', '=', $lead->id]
        ])
        ->where(function($query) {
			$query->whereNotNull('registrations.registered_ts')
                ->orWhereNotNull('registrations.confirmed_ts');
		})
        ->whereNull('deleted_at')
        ->first();

      if($registration) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjera da li lead ima nedovršenu registraciju
     */
    protected function CheckLeadsRegistrationInProgress($event, $lead) {
      $lead_registration = DB::table('registrations')
        ->where([
          ['event_id', '=', $event->id],
          ['lead_id', '=', $lead->id]
        ])
        ->where(function($query) {
			$query->whereNull('registrations.registered_ts')
                ->orWhereNull('registrations.confirmed_ts');
		})
        ->whereNull('deleted_at')
        ->first();

      if($lead_registration) {
        return true;
      } else {
        return Redirect::route('registration', array($event->event_code));
      }
    }


		/**
     * Vrati leadovu završenu registraciju
     */
    protected function GetLeadsRegistrationDone($event, $lead) {
      $lead_registration = DB::table('registrations')
        ->where([
          ['event_id', '=', $event->id],
          ['lead_id', '=', $lead->id]
        ])
        ->where(function($query) {
			$query->whereNotNull('registrations.registered_ts')
                ->orWhereNotNull('registrations.confirmed_ts');
		})
        ->whereNull('deleted_at')
        ->first();

      if($lead_registration) {
        return $lead_registration;
      } else {
        return false;
      }
    }


    /**
     * Provjara da li je event privatan, ukoliko je, da li je lead dobio poziv na njega
     */
    protected function CheckPrivateInvitation($event_code, $lead_code) {
      $event = $this->GetEvent($event_code);
      $lead = $this->GetLead($lead_code);

      if($event->access == 'private') {
        $lead_invite = DB::table('mailing_activities')
          ->join('mailings', 'mailing_activities.id', '=', 'mailings.mailing_activity_id')
          ->where([
            ['mailing_activities.event_id', '=', $event->id],
            ['mailings.lead_id', '=', $lead->id]
          ])
          ->whereNull('mailings.deleted_at')
          ->first();

        if(!$lead_invite) {
          return false;
				}
      }

      return true;
    }


    /**
     * Provjera da li je lead ovlašten da pristupa koracima registracije
     * Ovlaštanje dobiva u uspješnom prvom koraku
     */
    protected function CheckRegistrationVerification($event_code) {
      $registration_id = Session::get('registration_id');

      if($registration_id) {
        return true;
      } else {
        return Redirect::to('/registration/' . $event_code)->send();
      }
    }


    /**
     * Popis država
     */
    protected function GetCountries() {
        $countries = DB::table('countries')
            ->lists('country_name');

        array_unshift($countries, "");
        unset($countries[0]);

        return $countries;
    }

    /**
     * Popis država HR
     */
    protected function GetCountriesHr() {
        $countries = DB::table('countries')
            ->lists('country_name_hr');

        array_unshift($countries, "");
        unset($countries[0]);

        return $countries;
    }
    
    
    /**
     * Popis opisa
     */
    protected function GetTypes() {
        $lead_types = DB::table('lead_types')
            ->get();

        return $lead_types;
    }
    
    
    /**
     * Popis opisa tipova
     */
    protected function GetTypeDescriptions()
    {
        $type_descriptions = DB::table('lead_type_descriptions')
            ->get();

        return $type_descriptions;
    }
    
    
    /**
     * Lead tipovi osoba
     */
    protected function GetTypeDescriptionsForLead($lead_id)
    {
        $lead_type_descriptions = DB::table('lead_has_type_descriptions')
            ->where('lead_id', $lead_id)
            ->get();
        
        return $lead_type_descriptions;
    }
    

    /**
     * Naziv valute za event
     */
    protected function GetEventCurrency($event_code) {
      $event = $this->GetEvent($event_code);

      $event_currency = DB::table('currencies')
        ->where('id', '=', $event->currency_id)
        ->pluck('code');

      $event_currency = $event_currency[0];

       return $event_currency;
    }


    /**
     * Broj accommodation mjesta
     */
    protected function NumberOfAccommodation($event_code) {
      $event = $this->GetEvent($event_code);

      $number_of_accommodation = DB::table('accommodations')
        ->where('event_id', '=', $event->id)
        ->whereNull('deleted_at')
        ->sum('no_of_rooms');

      return $number_of_accommodation;
    }


    /**
     * Broj slobodnih accommodation mjesta
     */
    protected function NumberOfUsedAccommodations($event_code) {
      $event = $this->GetEvent($event_code);

      $number_of_used_accommodations = DB::table('registrations')
        ->where('event_id', $event->id)
        ->whereNotNull('accomodation_room_id')
        ->whereNotNull('registered_ts')
        ->whereNull('deleted_at')
        ->where(function ($query) {
            $query->where('accomodation_approved', 1)
              ->orWhereNull('accomodation_approved');
          })
        ->count('accomodation_room_id');

      return $number_of_used_accommodations;
    }


    /**
     * Provjeri da li ima još slobodnih accommodation mjesta
     */
    protected function CheckIfAvailableAccommodationExists($event_code) {
      $number_of_accommodation = $this->NumberOfAccommodation($event_code);
      $number_of_used_accommodations = $this->NumberOfUsedAccommodations($event_code);

      $event = DB::table('events')
        ->where('event_code', $event_code)
        ->first();

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      $accommodations = $this->GetAccommodations($event);

      if(!$accommodations) {
        return false;
      }

      if($number_of_accommodation > $number_of_used_accommodations) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjeri da li ima transfera
     */
    protected function CheckIfTransfersExists($event_code) {
      $event = $this->GetEvent($event_code);

      $transfers = DB::table('transfers')
        ->where('event_id', $event->id)
        ->whereNull('deleted_at')
        ->get();

      if($transfers) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjera slučaja da li postoji samo ticket(a) koji je(su) besplatan(i)
     * I ujedno da nema accommodationa ni transfera
     */
    protected function CheckIfFreeTicketWithoutAccommTrans($event_code) {
      $event = $this->GetEvent($event_code);

      $accommodations = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);

      if($accommodations == false && $transfers == false) {
        $tickets = $this->GetAvailableTickets($event_code);

        foreach($tickets as $ticket) {
          if($ticket->price_without_VAT > 0) {
            return false;
          }
        }

        return true;

      }

      return false;
    }


    /**
     * Dohvati ID registracije od leada za event
     */
    protected function GetLeadsRegistrationId($event, $lead) {
      $lead_registration_id = DB::table('registrations')
        ->where([
          ['event_id', '=', $event->id],
          ['lead_id', '=', $lead->id]
        ])
        ->whereNull('deleted_at')
        ->pluck('id');

      $lead_registration_id = $lead_registration_id[0];

      return $lead_registration_id;
    }


    /**
     * Dohvati registraciju od leada za event
     */
    protected function GetLeadsRegistration($event, $lead) {
      $lead_registration = DB::table('registrations')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
        ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
        ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
        ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
        ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
        ->leftJoin('promo_codes', 'registrations.id', '=','promo_codes.registration_id')
        ->selectRaw('registrations.id,
          registrations.ticket_type_id,
          registrations.accomodation_room_id,
          registrations.accomodation_note,
          registrations.accomodation_arrival_date,
          registrations.accomodation_departure_date,
          registrations.accomodation_roomy_name,
          registrations.tickets_payer_id,
          registrations.accomodation_payer_id,
          registrations.transfer_payer_id,
          registrations.payment_option,
          registrations.payment_cart,
          room_types.type,
          tickets.accompany_persons,
          tickets.has_promo_codes,
          promo_codes.code AS ticket_promo_code,
          registrations.event_id AS event_id,
          leads.id AS lead_id,
          leads.gender,
          leads.title,
          leads.first_name,
          leads.last_name,
          leads.email,
          leads.mobile,
          leads.phone,
          leads.company_name,
          leads.job_function,
          leads.company_address,
          leads.company_city,
          leads.company_post_code,
          leads.company_country,
          leads.note,
          leads.lead_type_id,
          ticket.type AS ticket_payment_type,
          ticket.company_name AS ticket_payment_company_name,
          ticket.vat AS ticket_payment_vat,
          ticket.address AS ticket_payment_address,
          ticket.city AS ticket_payment_city,
          ticket.post_code AS ticket_payment_postal_code,
          ticket.country AS ticket_payment_country,
          ticket.first_name AS ticket_payment_first_name,
          ticket.last_name AS ticket_payment_last_name,
          ticket.email AS ticket_payment_email,
          ticket.phone AS ticket_payment_phone,
          ticket.personal_id AS ticket_payment_personal_id,
          accomodation.type AS accomodation_payment_type,
          accomodation.company_name AS accomodation_payment_company_name,
          accomodation.vat AS accomodation_payment_vat,
          accomodation.address AS accomodation_payment_address,
          accomodation.city AS accomodation_payment_city,
          accomodation.post_code AS accomodation_payment_postal_code,
          accomodation.country AS accomodation_payment_country,
          accomodation.first_name AS accomodation_payment_first_name,
          accomodation.last_name AS accomodation_payment_last_name,
          accomodation.email AS accomodation_payment_email,
          accomodation.phone AS accomodation_payment_phone,
          accomodation.personal_id AS accomodation_payment_personal_id,
          transfer.type AS transfer_payment_type,
          transfer.company_name AS transfer_payment_company_name,
          transfer.vat AS transfer_payment_vat,
          transfer.address AS transfer_payment_address,
          transfer.city AS transfer_payment_city,
          transfer.post_code AS transfer_payment_postal_code,
          transfer.country AS transfer_payment_country,
          transfer.first_name AS transfer_payment_first_name,
          transfer.last_name AS transfer_payment_last_name,
          transfer.email AS transfer_payment_email,
          transfer.phone AS transfer_payment_phone,
          transfer.personal_id AS transfer_payment_personal_id')
        ->where([
          ['registrations.event_id', '=', $event->id],
          ['registrations.lead_id', '=', $lead->id]
        ])
        ->whereNull('registrations.deleted_at')
        ->groupBy('registrations.id')
        ->first();

      return $lead_registration;
    }


    /**
     * Dohvati transfer ids registracije za leada
     */
    protected function GetLeadsTransfersIds($event, $lead) {
      $leads_transfers_ids = DB::table('registrations')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
        ->where([
          ['registrations.event_id', '=', $event->id],
          ['registrations.lead_id', '=', $lead->id]
        ])
        ->whereNull('registrations.deleted_at')
        ->groupBy('registration_has_transfers.transfer_id')
        ->pluck('registration_has_transfers.transfer_id');

      return $leads_transfers_ids;
    }


    /**
     * Dohvati transfer registracije za leada
     */
    protected function GetLeadsTransfers($event, $lead) {
      $leads_transfers = DB::table('registrations')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
        ->select('registration_has_transfers.transfer_id',
          'registration_has_transfers.transfer_start_ts',
          'registration_has_transfers.flight_number')
        ->where([
          ['registrations.event_id', '=', $event->id],
          ['registrations.lead_id', '=', $lead->id]
        ])
        ->whereNull('registrations.deleted_at')
        ->groupBy('registration_has_transfers.transfer_id')
        ->get();

      return $leads_transfers;
    }


    /**
     * Dohvati social event ids registracije za leada
     */
    protected function GetLeadsSocialEventsIds($event, $lead) {
        $leads_sosial_events_ids = DB::table('registrations')
          ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
          ->leftJoin('registration_has_social_events', 'registrations.id', '=','registration_has_social_events.registration_id')
          ->where([
            ['registrations.event_id', '=', $event->id],
            ['registrations.lead_id', '=', $lead->id]
          ])
          ->whereNull('registrations.deleted_at')
          ->groupBy('registration_has_social_events.social_event_id')
          ->pluck('registration_has_social_events.social_event_id');
  
        return $leads_sosial_events_ids;
      }


    /**
     * Obriši ticket payer details ukoliko je ranije bilo odabarana ne free karta, a sada je
     */
    protected function DeleteTicketPayerIfFree($ticket_type_id, $lead_registration_id) {
      $ticket_price = DB::table('tickets')
        ->where('id', $ticket_type_id)
        ->value('price_without_VAT');

      if($ticket_price == 0) {
        $ticket_payer_id = DB::table('registrations')
          ->where('id', $lead_registration_id)
          ->value('tickets_payer_id');

        if($ticket_payer_id) {
          DB::table('registrations')
            ->where('id', $lead_registration_id)
            ->update(array(
              'tickets_payer_id' => null
            ));

          DB::table('payer_details')
            ->where('id', $ticket_payer_id)
            ->update([
              'deleted_at' => $this->Now()
            ]);

          return true;
        }
      }

      return false;
    }


    /**
     * Dohvati accommodations za event
     */
    protected function GetAccommodations($event) {
      $accommodations = DB::table('room_types')
        ->leftJoin('accommodations', 'accommodations.id', '=', 'room_types.accommodation_id')
        ->selectRaw('accommodations.name,
           accommodations.details,
           accommodations.available_from,
           accommodations.available_until,
           room_types.type,
           room_types.price_without_vat,
           room_types.vat,
           room_types.accommodation_id,
           room_types.id')
        ->where('accommodations.event_id', '=', $event->id)
        ->whereNull('accommodations.deleted_at')
        ->get();

      return $accommodations;
    }


    /**
     * Dohvati dostupne accommodations za event
     */
    protected function GetAvailableAccommodations($event) {
        $used_accommodations = DB::table('accommodations')
            ->leftJoin('room_types', 'accommodations.id', '=', 'room_types.accommodation_id')
            ->leftJoin('registrations', 'registrations.accomodation_room_id', '=', 'room_types.id')
            ->selectRaw('accommodations.id AS accommodation_id,
                COUNT(registrations.accomodation_room_id) AS no_of_used_rooms,
                accommodations.no_of_rooms AS no_of_rooms')
            ->where('accommodations.event_id', '=', $event->id)
            ->whereNull('accommodations.deleted_at')
            ->whereNull('registrations.deleted_at')
            ->where(function($query) {
                $query->whereNotNull('registrations.registered_ts')
                    ->orWhereNotNull('registrations.confirmed_ts');
            })
            ->groupBy('accommodations.id')
            ->get();

        foreach($used_accommodations as $key => $used_accommodation) {
            if ($used_accommodation->no_of_used_rooms < $used_accommodation->no_of_rooms) unset($used_accommodations[$key]);
        }

        $used_accommodation_ids = collect($used_accommodations)->pluck('accommodation_id')->toArray();

        $accommodations = DB::table('room_types')
            ->leftJoin('accommodations', 'accommodations.id', '=', 'room_types.accommodation_id')
            ->selectRaw('accommodations.name,
                accommodations.details,
                accommodations.available_from,
                accommodations.available_until,
                room_types.type,
                room_types.price_without_vat,
                room_types.vat,
                room_types.accommodation_id,
                room_types.id')
            ->where('accommodations.event_id', '=', $event->id)
            ->whereNotIn('accommodations.id', $used_accommodation_ids)
            ->whereNull('accommodations.deleted_at')
            ->get();

        return $accommodations;
    }


    /**
     * Dohvati transfere za event
     */
    protected function GetTransfers($event) {
      $transfers = DB::table('transfers')
        ->where('event_id', '=', $event->id)
        ->whereNull('deleted_at')
        ->get();

      return $transfers;
    }


    /**
     * Dohvati social evente za event
     */
    protected function GetSocialEvents($event) {
        $social_events = DB::table('social_events')
          ->where('event_id', '=', $event->id)
          ->whereNull('deleted_at')
          ->get();
  
        return $social_events;
      }


    /**
     * Obriši accommodation
     */
    protected function DeleteAccommodation($lead_registration) {
      DB::table('registrations')
       ->where('id', $lead_registration->id)
       ->update(array(
         'accomodation_room_id' => null,
         'accomodation_roomy_name' => null,
         'accomodation_note' => null,
         'accomodation_arrival_date' => null,
         'accomodation_departure_date' => null,
         'accomodation_payer_id' => null
       ));

      return true;
    }


    /**
     * Obriši transfers
     */
    protected function DeleteTransfers($lead_registration) {
      DB::table('registration_has_transfers')
        ->where('registration_id', $lead_registration->id)
        ->delete();

      return true;
    }


    /**
     * Obriši ticket payer
     */
    protected function DeleteTicketPayer($lead_registration) {
      DB::table('payer_details')
        ->where('id', $lead_registration->tickets_payer_id)
        ->update([
          'deleted_at' => $this->Now()
        ]);

      DB::table('registrations')
        ->where('id', '=', $lead_registration->id)
        ->update(array(
          'tickets_payer_id' => null
        ));

      return true;
    }


    /**
     * Obriši accommodation payer
     */
    protected function DeleteAccommodationPayer($lead_registration) {
      if($lead_registration->tickets_payer_id != $lead_registration->accomodation_payer_id) {
        DB::table('payer_details')
        ->where('id', $lead_registration->accomodation_payer_id)
        ->update([
          'deleted_at' => $this->Now()
        ]);
      }

      DB::table('registrations')
        ->where('id', '=', $lead_registration->id)
        ->update(array(
          'accomodation_payer_id' => null
        ));

      return true;
    }


    /**
     * Obriši transfer payer
     */
    protected function DeleteTransferPayer($lead_registration) {
      if($lead_registration->tickets_payer_id != $lead_registration->transfer_payer_id) {
        DB::table('payer_details')
        ->where('id', '=', $lead_registration->transfer_payer_id)
        ->update([
          'deleted_at' => $this->Now()
        ]);
      }

      DB::table('registrations')
        ->where('id', '=', $lead_registration->id)
        ->update(array(
          'transfer_payer_id' => null
        ));

      return true;
    }


    /**
     * Provjeri da li lead ima odabran free ticket
     */
    protected function CheckLeadHasFreeTicket($lead_registration) {
      $lead_has_free_ticket = DB::table('tickets')
        ->select('price_without_VAT')
        ->where('id', $lead_registration->ticket_type_id)
        ->first();

      if($lead_has_free_ticket->price_without_VAT == 0) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjeri da li lead ima odabran accommodation
     */
    protected function CheckLeadHasAccommodation($lead_registration) {
      $lead_has_accommodation = DB::table('registrations')
        ->select('accomodation_room_id')
        ->where('id', $lead_registration->id)
        ->first();

      if($lead_has_accommodation->accomodation_room_id != null) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Provjeri da li lead ima odabran transfer
     */
    protected function CheckLeadHasTransfers($lead_registration) {
      $lead_has_transfer = DB::table('registration_has_transfers')
        ->where('registration_id', $lead_registration->id)
        ->count('id');

      if($lead_has_transfer > 0) {
        return true;
      } else {
        return false;
      }
    }


    /**
     * Registracijski podaci za lead (osim transfera)
     */
    protected function GetLeadsSummaryRegistration($lead_registration) {
      $lang = DB::table('events')->where('id', '=', $lead_registration->event_id)->value('lang');

      if($lang == 'hr') {
        $registration_summary = DB::table('registrations')
        ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
        ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
        ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
        ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
        ->leftJoin('countries as leads_country', 'leads.company_country', '=', 'leads_country.id')
        ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
	    ->leftJoin('countries as ticket_country', 'ticket.country', '=', 'ticket_country.id')
        ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
	    ->leftJoin('countries as accomodation_country', 'accomodation.country', '=', 'accomodation_country.id')
        ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
	    ->leftJoin('countries as transfer_country', 'transfer.country', '=', 'transfer_country.id')
        ->leftJoin('lead_types', 'leads.lead_type_id', '=', 'lead_types.id')
        ->leftJoin('lead_has_type_descriptions', 'leads.id', '=', 'lead_has_type_descriptions.lead_id')
        ->leftJoin('lead_type_descriptions', 'lead_has_type_descriptions.lead_type_description_id', '=', 'lead_type_descriptions.id')
        ->selectRaw('tickets.name AS ticketName,
            tickets.price_without_VAT AS ticketPriceNoVat,
            tickets.VAT AS ticketsVat,
            room_types.type AS roomType,
            room_types.price_without_vat AS roomPriceNoVat,
            room_types.vat AS roomVat,
            accommodations.name AS accommodationName,
            registrations.accomodation_arrival_date AS accomodationArrivalData,
            registrations.accomodation_departure_date AS accomodationDepartureData,
            registrations.payment_option AS paymentOption,
            registrations.payment_cart AS paymentCart,
            leads.gender AS leadGender,
            leads.title AS leadTitle,
            leads.first_name AS leadFirstName,
            leads.last_name AS leadLastName,
            leads.email AS leadEmail,
            leads.mobile AS leadMobile,
            leads.phone AS leadPhone,
            leads.company_name AS leadCompanyName,
            leads.job_function AS leadJobFunction,
            lead_types.name AS leadType,
            GROUP_CONCAT(DISTINCT lead_type_descriptions.name SEPARATOR ", ") AS leadTypeDescription,
            leads.company_address AS leadCompanyAddress,
            leads.company_city AS leadCompanyCity,
            leads.company_post_code AS leadCompanyPostalCode,
            leads.note AS leadNote,
            leads_country.country_name_hr AS leadCompanyCountry,
            ticket.id AS ticketId,
            ticket.company_name AS ticketCompanyName,
            ticket.vat AS ticketVat,
            ticket.address AS ticketAddress,
            ticket.city AS ticketCity,
            ticket.post_code AS ticketPostalCode,
            ticket_country.country_name_hr AS ticketCountry,
            ticket.first_name AS ticketFirstName,
            ticket.last_name AS ticketLastName,
            ticket.email AS ticketEmail,
            ticket.phone AS ticketPhone,
            accomodation.id AS accomodationId,
            accomodation.company_name AS accomodationCompanyName,
            accomodation.vat AS accomodationVat,
            accomodation.address AS accomodationAddress,
            accomodation.city AS accomodationCity,
            accomodation.post_code AS accomodationPostalCode,
            accomodation_country.country_name_hr AS accomodationCountry,
            accomodation.first_name AS accomodationFirstName,
            accomodation.last_name AS accomodationLastName,
            accomodation.email AS accomodationEmail,
            accomodation.phone AS accomodationPhone,
            transfer.id AS transferId,
            transfer.company_name AS transferCompanyName,
            transfer.vat AS transferVat,
            transfer.address AS transferAddress,
            transfer.city AS transferCity,
            transfer.post_code AS transferPostalCode,
            transfer_country.country_name_hr AS transferCountry,
            transfer.first_name AS transferFirstName,
            transfer.last_name AS transferLastName,
            transfer.email AS transferEmail,
            transfer.phone AS transferPhone,
            ticket.type AS ticketPaymentType,
            ticket.personal_id AS ticketPaymentPersonalId,
            accomodation.type AS accomodationPaymentType,
            accomodation.personal_id AS accomodationPaymentPersonalId,
            transfer.type AS transferPaymentType,
            transfer.personal_id AS transferPaymentPersonalId')
        ->where('registrations.id', '=', $lead_registration->id)
        ->groupBy('leads.id')
        ->first();
      } else {
        $registration_summary = DB::table('registrations')
        ->leftJoin('tickets', 'registrations.ticket_type_id', '=','tickets.id')
        ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
        ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
        ->leftJoin('leads', 'registrations.lead_id', '=','leads.id')
        ->leftJoin('countries as leads_country', 'leads.company_country', '=', 'leads_country.id')
        ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=','ticket.id')
        ->leftJoin('countries as ticket_country', 'ticket.country', '=', 'ticket_country.id')
        ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
        ->leftJoin('countries as accomodation_country', 'accomodation.country', '=', 'accomodation_country.id')
        ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
        ->leftJoin('countries as transfer_country', 'transfer.country', '=', 'transfer_country.id')
        ->leftJoin('lead_types', 'leads.lead_type_id', '=', 'lead_types.id')
        ->leftJoin('lead_has_type_descriptions', 'leads.id', '=', 'lead_has_type_descriptions.lead_id')
        ->leftJoin('lead_type_descriptions', 'lead_has_type_descriptions.lead_type_description_id', '=', 'lead_type_descriptions.id')
        ->selectRaw('tickets.name AS ticketName,
            tickets.price_without_VAT AS ticketPriceNoVat,
            tickets.VAT AS ticketsVat,
            room_types.type AS roomType,
            room_types.price_without_vat AS roomPriceNoVat,
            room_types.vat AS roomVat,
            accommodations.name AS accommodationName,
            registrations.accomodation_arrival_date AS accomodationArrivalData,
            registrations.accomodation_departure_date AS accomodationDepartureData,
            registrations.payment_option AS paymentOption,
            registrations.payment_cart AS paymentCart,
            leads.gender AS leadGender,
            leads.title AS leadTitle,
            leads.first_name AS leadFirstName,
            leads.last_name AS leadLastName,
            leads.email AS leadEmail,
            leads.mobile AS leadMobile,
            leads.phone AS leadPhone,
            leads.company_name AS leadCompanyName,
            leads.job_function AS leadJobFunction,
            lead_types.name AS leadType,
            GROUP_CONCAT(DISTINCT lead_type_descriptions.name SEPARATOR ", ") AS leadTypeDescription,
            leads.company_address AS leadCompanyAddress,
            leads.company_city AS leadCompanyCity,
            leads.company_post_code AS leadCompanyPostalCode,
            leads.note AS leadNote,
            leads_country.country_name AS leadCompanyCountry,
            ticket.id AS ticketId,
            ticket.company_name AS ticketCompanyName,
            ticket.vat AS ticketVat,
            ticket.address AS ticketAddress,
            ticket.city AS ticketCity,
            ticket.post_code AS ticketPostalCode,
            ticket_country.country_name AS ticketCountry,
            ticket.first_name AS ticketFirstName,
            ticket.last_name AS ticketLastName,
            ticket.email AS ticketEmail,
            ticket.phone AS ticketPhone,
            accomodation.id AS accomodationId,
            accomodation.company_name AS accomodationCompanyName,
            accomodation.vat AS accomodationVat,
            accomodation.address AS accomodationAddress,
            accomodation.city AS accomodationCity,
            accomodation.post_code AS accomodationPostalCode,
            accomodation_country.country_name AS accomodationCountry,
            accomodation.first_name AS accomodationFirstName,
            accomodation.last_name AS accomodationLastName,
            accomodation.email AS accomodationEmail,
            accomodation.phone AS accomodationPhone,
            transfer.id AS transferId,
            transfer.company_name AS transferCompanyName,
            transfer.vat AS transferVat,
            transfer.address AS transferAddress,
            transfer.city AS transferCity,
            transfer.post_code AS transferPostalCode,
            transfer_country.country_name AS transferCountry,
            transfer.first_name AS transferFirstName,
            transfer.last_name AS transferLastName,
            transfer.email AS transferEmail,
            transfer.phone AS transferPhone,
            ticket.type AS ticketPaymentType,
            ticket.personal_id AS ticketPaymentPersonalId,
            accomodation.type AS accomodationPaymentType,
            accomodation.personal_id AS accomodationPaymentPersonalId,
            transfer.type AS transferPaymentType,
            transfer.personal_id AS transferPaymentPersonalId')
        ->where('registrations.id', '=', $lead_registration->id)
        ->groupBy('leads.id')
        ->first();
      }

      return $registration_summary;
    }


    /**
     * Registracijski transfer podaci za lead
     */
    protected function GetLeadsSummaryTransfers($lead_registration) {
      $transfer_summary = DB::table('registrations')
        ->join('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
        ->join('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
        ->selectRaw('transfers.description as description,
          transfers.price_without_vat as priceNoVat,
          transfers.vat as vat')
        ->where('registrations.id', '=', $lead_registration->id)
        ->whereNull('registrations.deleted_at')
        ->get();

      return $transfer_summary;
    }


    /**
     * Registracijski social event podaci za lead
     */
    protected function GetLeadsSummarySocialEvents($lead_registration) {
        $social_events_summary = DB::table('registrations')
          ->join('registration_has_social_events', 'registrations.id', '=','registration_has_social_events.registration_id')
          ->join('social_events', 'registration_has_social_events.social_event_id', '=','social_events.id')
          ->selectRaw('social_events.name,
            social_events.time')
          ->where('registrations.id', '=', $lead_registration->id)
          ->whereNull('registrations.deleted_at')
          ->groupBy('social_events.id')
          ->get();
  
        return $social_events_summary;
      }


    /**
     * Prikaz broja odabranih accommodation dana
     */
    protected function CalculateAccommodationDays($accomodation_registration) {
      $accomodation_arrival_date = strtotime($accomodation_registration->accomodationArrivalData);
      $accomodation_departure_date = strtotime($accomodation_registration->accomodationDepartureData);
      $accommodation_days = $accomodation_departure_date - $accomodation_arrival_date;
      $accommodation_days = floor($accommodation_days/(60*60*24));

      return $accommodation_days;
    }


    /**
     * Izračunaj ukupnu sumu VATa
     */
    protected function CalculateTotalVAT($summary_registration, $summary_transfers, $accommodation_days)  {
        $total_vat = 0.00;
  
        if($summary_registration->ticketPriceNoVat) {
          $total_vat = ($summary_registration->ticketsVat/100 * $summary_registration->ticketPriceNoVat);
        }
  
        if($summary_registration->roomPriceNoVat) {
          $total_vat = $total_vat + ((($summary_registration->roomVat/100 * $summary_registration->roomPriceNoVat)) * $accommodation_days);
        }
  
        if($summary_transfers) {
          foreach ($summary_transfers as $transfer) {
            $total_vat = $total_vat + (($transfer->vat/100 * $transfer->priceNoVat));
          }
        }
  
        $total_vat = number_format($total_vat, 2, ',', '.');
  
        return $total_vat;
      }


    /**
     * Izračunaj ukupnu sumu odabranih troškova s VATom
     */
    protected function CalculateTotalPriceWithVAT($summary_registration, $summary_transfers, $accommodation_days)  {
      $total_price = 0.00;

      if($summary_registration->ticketPriceNoVat) {
        $total_price = ($summary_registration->ticketsVat/100 * $summary_registration->ticketPriceNoVat) + $summary_registration->ticketPriceNoVat;
      }

      if($summary_registration->roomPriceNoVat) {
        $total_price = $total_price + ((($summary_registration->roomVat/100 * $summary_registration->roomPriceNoVat) + $summary_registration->roomPriceNoVat) * $accommodation_days);
      }

      if($summary_transfers) {
        foreach ($summary_transfers as $transfer) {
          $total_price = $total_price + (($transfer->vat/100 * $transfer->priceNoVat) + $transfer->priceNoVat);
        }
      }

      $total_price = number_format($total_price, 2, ',', '.');

      return $total_price;
    }


    /**
     * Izračunaj ukupnu sumu odabranih troškova s VATom u HRK (za WSPay)
     */
    protected function CalculateTotalPriceWithVATInHRK($summary_registration, $summary_transfers, $accommodation_days)  {
        $total_price = 0.00;
  
        if($summary_registration->ticketPriceNoVat) {
          $total_price = ($summary_registration->ticketsVat/100 * $summary_registration->ticketPriceNoVat) + $summary_registration->ticketPriceNoVat;
        }
  
        if($summary_registration->roomPriceNoVat) {
          $total_price = $total_price + ((($summary_registration->roomVat/100 * $summary_registration->roomPriceNoVat) + $summary_registration->roomPriceNoVat) * $accommodation_days);
        }
  
        if($summary_transfers) {
          foreach ($summary_transfers as $transfer) {
            $total_price = $total_price + (($transfer->vat/100 * $transfer->priceNoVat) + $transfer->priceNoVat);
          }
        }

        $eur_hrk = json_decode(file_get_contents('http://api.hnb.hr/tecajn/v1?valuta=EUR'), true);
        if ($eur_hrk == null) {
            $total_price = $total_price * floatval(env('WSPAY_RATE_EUR_HRK'));
        } else {
            $total_price = $total_price * floatval(str_replace(',', '.', $eur_hrk[0]['Srednji za devize']));
        }
        
        $total_price = number_format($total_price, 2, ',', '.');
  
        return $total_price;
      }


    /**
     * Generiranje WSPay potpisa
     */
    protected function wspayGenerateSignature($cart, $amount) {
        $shop = env('WSPAY_SHOP', false);
        $key = env('WSPAY_KEY', false);

        $amount = str_replace('.', '', $amount);
        $amount = str_replace(',', '', $amount);

        $signature = $shop . $key . $cart . $key . $amount . $key;
        $signature = md5($signature);

        return $signature;
    }

    /**
     * Provjera WSPay potpisa
     */
    protected function WspayVerifySignature($request, $cart) {
        $shop = env('WSPAY_SHOP', false);
        $key = env('WSPAY_KEY', false);
        $signature_wspay = $request->input('Signature');
        $success = $request->input('Success');
        $code = $request->input('ApprovalCode');

        $signature_krik = $shop . $key . $cart . $key . $success . $key . $code . $key;
        $signature_krik = md5($signature_krik);

        if ($signature_krik == $signature_wspay) {
            return true;
        } else {
            return Redirect::to('/registration/' . $event_code)->send();
        }
    }


    /**
     * Generiranje barcodea
     */
    protected function Barcode($event, $lead_registration) {
      // App id (nula na početku ukoliko je jadnoznamenkasti broj)
      $app = str_pad(APP_ID, 2, "0", STR_PAD_LEFT);

      // Zadnje dvije znamenke godine početka eventa
      $year = substr(date("Y", strtotime($event->registration_start_ts)), 2, 2);

      // ID eventa (nule na početku ukoliko su jednoznamenkasti ili dvoznamenkasti brojevi)
      $event = str_pad($event->id, 3, "0", STR_PAD_LEFT);

      // ID leada (nule na početku ukoliko su jednoznamenkasti, dvoznamenkasti, troznamenkasti ili četveroznamenkasti brojevi)
      $registration = DB::table('registrations')
        ->select('lead_id')
        ->where('id', '=', $lead_registration->id)
        ->first();
      $lead = str_pad($registration->lead_id, 5, "0", STR_PAD_LEFT);

      return $app . $year . $event . $lead;
    }


    /**
     * Generiranje broja za ticket invoice
     */
    private function TicketInvoiceNumber($event) {
      // Prva slova iz naziva eventa
      $words = explode(" ", $event->name);
      $first_letters = "";
      foreach ($words as $word) {
        $first_letters .= $word[0];
      }

      // Ukoliko imamo 3 ili više slova koristimo njih za kreiranje broja
      // U suprotnom uzmemo iz prve riječi tri slova
      if(strlen($first_letters) >= 3) {
        $name_code = substr($first_letters, 0, 3);
      } else {
        $name_code = substr($event->name, 0, 3);
      }

      // Tri slova iz event naziva
      $ticket_invoice_number = $name_code;

      // ID eventa
      $ticket_invoice_number = $ticket_invoice_number . '-' . $event->id;

      // Tip (1 = ticket)
      $ticket_invoice_number = $ticket_invoice_number . '-1';

      // Zadnji ticket invoice koji je zapisan u bazu
      $last_ticket_registered_ts = DB::table('registrations')
        ->where('event_id', '=', $event->id)
        ->whereNotNull('invoice_ticket')
        ->max('registered_ts');

      $last_ticket_invoice = DB::table('registrations')
        ->where('registered_ts', $last_ticket_registered_ts)
        ->value('invoice_ticket');

      if($last_ticket_invoice) {

        // Vrati broj koji se nalazi na kraju stringa (iza zadnjeg -)
        $last_ticket_invoice_number = strrchr($last_ticket_invoice, '-');

        // Makni - s početka da ostane samo broj
        $last_ticket_invoice_number = substr($last_ticket_invoice_number, 1);

        // Pretvori string u broj
        $last_ticket_invoice_number = intval($last_ticket_invoice_number);

        $ticket_invoice_number = $ticket_invoice_number . '-' . strval($last_ticket_invoice_number+1);

      } else {

        $ticket_invoice_number = $ticket_invoice_number . '-1';

      }

      return $ticket_invoice_number;
    }


    /**
     * Generiranje broja za accomodation invoice
     */
    private function AccomodationInvoiceNumber($event) {
      // Prva slova iz naziva eventa
      $words = explode(" ", $event->name);
      $first_letters = "";
      foreach ($words as $word) {
        $first_letters .= $word[0];
      }

      // Ukoliko imamo 3 ili više slova koristimo njih za kreiranje broja
      // U suprotnom uzmemo iz prve riječi tri slova
      if(strlen($first_letters) >= 3) {
        $name_code = substr($first_letters, 0, 3);
      } else {
        $name_code = substr($event->name, 0, 3);
      }

      // Tri slova iz event naziva
      $accomodation_invoice_number = $name_code;

      // ID eventa
      $accomodation_invoice_number = $accomodation_invoice_number . '-' . $event->id;

      // Tip (2 = accomodation)
      $accomodation_invoice_number = $accomodation_invoice_number . '-2';

      // Zadnji accomodation invoice koji je zapisan u bazu
      $last_accomodation_registered_ts = DB::table('registrations')
        ->where('event_id', '=', $event->id)
        ->whereNotNull('invoice_accomodation')
        ->max('registered_ts');

      $last_accomodation_invoice = DB::table('registrations')
        ->where('registered_ts', $last_accomodation_registered_ts)
        ->value('invoice_accomodation');

      if($last_accomodation_invoice) {

        // Vrati broj koji se nalazi na kraju stringa (iza zadnjeg -)
        $last_accomodation_invoice_number = strrchr($last_accomodation_invoice, '-');

        // Makni - s početka da ostane samo broj
        $last_accomodation_invoice_number = substr($last_accomodation_invoice_number, 1);

        // Pretvori string u broj
        $last_accomodation_invoice_number = intval($last_accomodation_invoice_number);

        $accomodation_invoice_number = $accomodation_invoice_number . '-' . strval($last_accomodation_invoice_number+1);

      } else {

        $accomodation_invoice_number = $accomodation_invoice_number . '-1';

      }

      return $accomodation_invoice_number;
    }


    /**
     * Generiranje broja za transfer invoice
     */
    private function TransferInvoiceNumber($event) {
      // Prva slova iz naziva eventa
      $words = explode(" ", $event->name);
      $first_letters = "";
      foreach ($words as $word) {
        $first_letters .= $word[0];
      }

      // Ukoliko imamo 3 ili više slova koristimo njih za kreiranje broja
      // U suprotnom uzmemo iz prve riječi tri slova
      if(strlen($first_letters) >= 3) {
        $name_code = substr($first_letters, 0, 3);
      } else {
        $name_code = substr($event->name, 0, 3);
      }

      // Tri slova iz event naziva
      $transfer_invoice_number = $name_code;

      // ID eventa
      $transfer_invoice_number = $transfer_invoice_number . '-' . $event->id;

      // Tip (3 = transfer)
      $transfer_invoice_number = $transfer_invoice_number . '-3';

      // Zadnji transfer invoice koji je zapisan u bazu
      $last_transfer_registered_ts = DB::table('registrations')
        ->where('event_id', '=', $event->id)
        ->whereNotNull('invoice_transfer')
        ->max('registered_ts');

      $last_transfer_invoice = DB::table('registrations')
        ->where('registered_ts', $last_transfer_registered_ts)
        ->value('invoice_transfer');

      if($last_transfer_invoice) {

        // Vrati broj koji se nalazi na kraju stringa (iza zadnjeg -)
        $last_transfer_invoice_number = strrchr($last_transfer_invoice, '-');

        // Makni - s početka da ostane samo broj
        $last_transfer_invoice_number = substr($last_transfer_invoice_number, 1);

        // Pretvori string u broj
        $last_transfer_invoice_number = intval($last_transfer_invoice_number);

        $transfer_invoice_number = $transfer_invoice_number . '-' . strval($last_transfer_invoice_number+1);

      } else {

        $transfer_invoice_number = $transfer_invoice_number . '-1';

      }

      return $transfer_invoice_number;
    }


    /**
     * Generiranje broja ordera
     * Dohvati sve najveće order brojeve uključujući i tickets i accomodations i transfers
     * Najveći broj od njih povečaj za jedan
     */
    private function OrderNumber() {
      $last_order_ticket = DB::table('registrations')
        ->max('order_ticket');

      if(!$last_order_ticket) {
        $last_order_ticket = 0;
      }

      $last_order_accomodation = DB::table('registrations')
        ->max('order_accomodation');

      if(!$last_order_accomodation) {
        $last_order_accomodation = 0;
      }

      $last_order_transfer = DB::table('registrations')
        ->max('order_transfer');

      if(!$last_order_transfer) {
        $last_order_transfer = 0;
      }

      $max_order = max($last_order_ticket, $last_order_accomodation, $last_order_transfer);

      if($max_order == 0) {
        return 1;
      } else {
        return $max_order+1;
      }
    }


    /**
     * Spremanje zadnjeg koraka registracije
     */
    protected function SaveLeadsRegistration($event, $lead_registration, $lead_has_accommodation, $lead_has_transfers) {

      // Lead nije odabrao ni accommodation ni transfer
      if($lead_has_accommodation == false && $lead_has_transfers == false) {

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'registered_ts' => $this->Now(),
            'barcode' => $this->Barcode($event, $lead_registration),
            'invoice_ticket' => $this->TicketInvoiceNumber($event),
            'order_ticket' => $this->OrderNumber()
          ));

      // Lead je odabrao i accommodation i transfer
      } else if($lead_has_accommodation == true && $lead_has_transfers == true) {

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'registered_ts' => $this->Now(),
            'barcode' => $this->Barcode($event, $lead_registration),
            'invoice_ticket' => $this->TicketInvoiceNumber($event),
            'invoice_accomodation' => $this->AccomodationInvoiceNumber($event),
            'invoice_transfer' => $this->TransferInvoiceNumber($event),
            'order_ticket' => $this->OrderNumber(),
            'order_accomodation' => $this->OrderNumber()+1,
            'order_transfer' => $this->OrderNumber()+2
          ));

      // Lead je odabrao accommodation
      } else if($lead_has_accommodation == true) {

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'registered_ts' => $this->Now(),
            'barcode' => $this->Barcode($event, $lead_registration),
            'invoice_ticket' => $this->TicketInvoiceNumber($event),
            'invoice_accomodation' => $this->AccomodationInvoiceNumber($event),
            'order_ticket' => $this->OrderNumber(),
            'order_accomodation' => $this->OrderNumber()+1,
          ));

      // Lead je odabrao transfer
      } else if($lead_has_transfers == true) {

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'registered_ts' => $this->Now(),
            'barcode' => $this->Barcode($event, $lead_registration),
            'invoice_ticket' => $this->TicketInvoiceNumber($event),
            'invoice_transfer' => $this->TransferInvoiceNumber($event),
            'order_ticket' => $this->OrderNumber(),
            'order_transfer' => $this->OrderNumber()+1
          ));

      }

      DB::table('leads_on_events_insights')
        ->where('lead_id', $lead_registration->lead_id)
        ->update([
          "event_id_" . $event->id => 'registered'
        ]);

        DB::table('leads')
            ->where('id', $lead_registration->lead_id)
            ->update([
                'opt_in_ts' => $this->Now()
            ]);

    }


    /**
     * Spremi WSPay payment
     */
    protected function WspayPayment($request, $lead_registration, $successful) {
        if ($successful) {
            $success = $request->input('Success');
            $code = $request->input('ApprovalCode');
            if ($success != 1 || $code == '') return Redirect::to('/registration/' . $event_code)->send();
    
            DB::table('registrations')
              ->where('id', $lead_registration->id)
              ->update(array(
                'payment_successful' => 1
              ));
        } else {
            DB::table('registrations')
              ->where('id', $lead_registration->id)
              ->update(array(
                'payment_successful' => 0
              ));
        }
    }


    /**
     * Dohvati ticket registration
     */
    protected function GetTicketRegistration($lead_registration) {
      $ticket_registration = DB::table('registrations')
        ->leftJoin('tickets', 'registrations.ticket_type_id', '=', 'tickets.id')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
        ->leftJoin('payer_details as ticket', 'registrations.tickets_payer_id', '=', 'ticket.id')
        ->leftJoin('countries as payer_country', 'ticket.country', '=', 'payer_country.id')
        ->selectRaw('tickets.name AS ticketName,
          tickets.price_without_VAT AS ticketPriceNoVat,
          tickets.VAT AS ticketsVat,
          leads.title AS leadTitle,
          leads.first_name AS leadFirstName,
          leads.last_name AS leadLastName,
          leads.email AS leadEmail,
          leads.mobile AS leadMobile,
          leads.phone AS leadPhone,
          leads.company_name AS leadCompanyName,
          leads.job_function AS leadJobFunction,
          leads.company_address AS leadCompanyAddress,
          leads.company_city AS leadCompanyCity,
          leads.company_post_code AS leadCompanyPostalCode,
          leads.note AS leadNote,
          countries.country_name AS leadCompanyCountry,
          ticket.type AS ticketType,
          ticket.personal_id AS ticketPersonalId,
          ticket.id AS ticketId,
          ticket.company_name AS ticketCompanyName,
          ticket.vat AS ticketVat,
          ticket.address AS ticketAddress,
          ticket.city AS ticketCity,
          ticket.post_code AS ticketPostalCode,
          payer_country.country_name AS ticketCountry,
          ticket.first_name AS ticketFirstName,
          ticket.last_name AS ticketLastName,
          ticket.email AS ticketEmail,
          ticket.phone AS ticketPhone,
          registrations.invoice_ticket AS invoiceTicket,
          registrations.invoice_accomodation AS invoiceAccomodation,
          registrations.invoice_transfer AS invoiceTransfer,
          registrations.order_ticket AS orderTicket,
          registrations.order_accomodation AS orderAccomodation,
          registrations.order_transfer AS orderTransfer')
        ->where('registrations.id', '=', $lead_registration->id)
        ->first();

      return $ticket_registration;
    }


    /**
     * Dohvati ticket payment
     */
    protected function GetTicketPayment($event) {
      $ticket_payment = DB::table('invoice_froms')
        ->where('id', '=', $event->tickets_invoice_from_id)
        ->first();

      return $ticket_payment;
    }


    /**
     * Izračunaj tax za ticket
     */
    protected function CalculateTicketTax($ticket_registration) {
      $ticket_tax = $ticket_registration->ticketPriceNoVat / 100 * $ticket_registration->ticketsVat;

      return $ticket_tax;
    }


    /**
     * Izračunaj total za ticket
     */
    protected function CalculateTicketTotal($ticket_registration, $ticket_tax) {
      $ticket_total = $ticket_registration->ticketPriceNoVat + $ticket_tax;

      return $ticket_total;
    }


    /**
     * Dohvati accommodation registration
     */
    protected function GetAccommodationRegistration($lead_registration) {
      $accomodation_registration = DB::table('registrations')
        ->leftJoin('room_types', 'registrations.accomodation_room_id', '=','room_types.id')
        ->leftJoin('accommodations', 'room_types.accommodation_id', '=','accommodations.id')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
        ->leftJoin('payer_details as accomodation', 'registrations.accomodation_payer_id', '=','accomodation.id')
        ->leftJoin('countries as payer_country', 'accomodation.country', '=', 'payer_country.id')
        ->selectRaw('room_types.type AS accomodationRoomName,
          room_types.price_without_vat AS accomodationPriceNoVat,
          room_types.vat AS accomodationPriceVat,
          accommodations.name AS accomodationName,
          leads.title AS leadTitle,
          leads.first_name AS leadFirstName,
          leads.last_name AS leadLastName,
          leads.email AS leadEmail,
          leads.mobile AS leadMobile,
          leads.phone AS leadPhone,
          leads.company_name AS leadCompanyName,
          leads.job_function AS leadJobFunction,
          leads.company_address AS leadCompanyAddress,
          leads.company_city AS leadCompanyCity,
          leads.company_post_code AS leadCompanyPostalCode,
          leads.note AS leadNote,
          countries.country_name AS leadCompanyCountry,
          accomodation.type AS accomodationType,
          accomodation.personal_id AS accomodationPersonalId,
          accomodation.id AS accomodationId,
          accomodation.company_name AS accomodationCompanyName,
          accomodation.vat AS accomodationVat,
          accomodation.address AS accomodationAddress,
          accomodation.city AS accomodationCity,
          accomodation.post_code AS accomodationPostalCode,
          payer_country.country_name AS accomodationCountry,
          accomodation.first_name AS accomodationFirstName,
          accomodation.last_name AS accomodationLastName,
          accomodation.email AS accomodationEmail,
          accomodation.phone AS accomodationPhone,
          registrations.invoice_ticket AS invoiceTicket,
          registrations.invoice_accomodation AS invoiceAccomodation,
          registrations.invoice_transfer AS invoiceTransfer,
          registrations.order_ticket AS orderTicket,
          registrations.order_accomodation AS orderAccomodation,
          registrations.order_transfer AS orderTransfer,
          registrations.accomodation_arrival_date AS accomodationArrivalData,
          registrations.accomodation_departure_date AS accomodationDepartureData')
        ->where('registrations.id', '=', $lead_registration->id)
        ->first();

      return $accomodation_registration;
    }


    /**
     * Dohvati accommodation payment
     */
    protected function GetAccommodationPayment($event) {
      $accomodation_payment = DB::table('invoice_froms')
        ->where('id', '=', $event->accomodation_invoice_from_id)
        ->first();

      return $accomodation_payment;
    }


    /**
     * Izračunaj total za accommodation bez VAT-a
     */
    protected function CalculateAccommodationTotalNoVAT($accommodation_registration, $accommodation_days) {
      $accomodation_total_no_vat = $accommodation_registration->accomodationPriceNoVat * $accommodation_days;

      return $accomodation_total_no_vat;
    }


    /**
     * Izračunaj total za accommodation, ali samo VAT
     */
    protected function CalculateAccommodationTotalOnlyVAT($accommodation_registration, $accomodation_total_no_vat) {
      $accomodation_total_only_vat = $accomodation_total_no_vat / 100 * $accommodation_registration->accomodationPriceVat;

      return $accomodation_total_only_vat;
    }


    /**
     * Izračunaj total za accommodation s VAT-om
     */
    protected function CalculateAccommodationTotalWithVAT($accomodation_total_no_vat, $accomodation_total_only_vat) {
      $accomodation_total_with_vat = $accomodation_total_no_vat + $accomodation_total_only_vat;

      return $accomodation_total_with_vat;
    }


    /**
     * Pretvaranje broja u decimalan
     */
    protected function ToDecimal($number) {
      return number_format((float)$number, 2, ',', '.');;
    }


    /**
     * Dohvati transfer registration
     */
    protected function GetTransferRegistration($lead_registration) {
      $transfer_registration = DB::table('registrations')
        ->leftJoin('leads', 'registrations.lead_id', '=', 'leads.id')
        ->leftJoin('countries', 'leads.company_country', '=', 'countries.id')
        ->leftJoin('payer_details as transfer', 'registrations.transfer_payer_id', '=','transfer.id')
        ->leftJoin('countries as payer_country', 'transfer.country', '=', 'payer_country.id')
        ->selectRaw('leads.title AS leadTitle,
          leads.first_name AS leadFirstName,
          leads.last_name AS leadLastName,
          leads.email AS leadEmail,
          leads.mobile AS leadMobile,
          leads.phone AS leadPhone,
          leads.company_name AS leadCompanyName,
          leads.job_function AS leadJobFunction,
          leads.company_address AS leadCompanyAddress,
          leads.company_city AS leadCompanyCity,
          leads.company_post_code AS leadCompanyPostalCode,
          leads.note AS leadNote,
          countries.country_name AS leadCompanyCountry,
          transfer.type AS transferType,
          transfer.personal_id AS transferPersonalId,
          transfer.id AS transferId,
          transfer.company_name AS transferCompanyName,
          transfer.vat AS transferVat,
          transfer.address AS transferAddress,
          transfer.city AS transferCity,
          transfer.post_code AS transferPostalCode,
          payer_country.country_name AS transferCountry,
          transfer.first_name AS transferFirstName,
          transfer.last_name AS transferLastName,
          transfer.email AS transferEmail,
          transfer.phone AS transferPhone,
          registrations.invoice_ticket AS invoiceTicket,
          registrations.invoice_accomodation AS invoiceAccomodation,
          registrations.invoice_transfer AS invoiceTransfer,
          registrations.order_ticket AS orderTicket,
          registrations.order_accomodation AS orderAccomodation,
          registrations.order_transfer AS orderTransfer')
        ->where('registrations.id', '=', $lead_registration->id)
        ->first();

      return $transfer_registration;
    }


    /**
     * Dohvati transfer payment
     */
    protected function GetTransferPayment($event) {
      $transfer_payment = DB::table('invoice_froms')
        ->where('id', '=', $event->transfer_invoice_from_id)
        ->first();


      return $transfer_payment;
    }


    /**
     * Dohvati transfer registracije od leada
     */
    protected function GetRegistrationTransfers($lead_registration) {
      $transfers = DB::table('registrations')
        ->join('registration_has_transfers', 'registrations.id', '=','registration_has_transfers.registration_id')
        ->join('transfers', 'registration_has_transfers.transfer_id', '=','transfers.id')
        ->selectRaw('transfers.description as description,
          transfers.price_without_vat as priceNoVat,
          transfers.vat as vat')
        ->where('registrations.id', '=', $lead_registration->id)
        ->get();

      return $transfers;
    }


    /**
     * Izračunaj total za transfers bez VAT-a
     */
    protected function CalculateTransferTotalNoVAT($transfers) {
      $transfer_total_no_vat = 0;

      foreach($transfers as $transfer) {
        $transfer_total_no_vat = $transfer_total_no_vat + $transfer->priceNoVat;
      }

      return $transfer_total_no_vat;
    }


    /**
     * Izračunaj total za transfers, ali samo VAT
     */
    protected function CalculateTransferTotalOnlyVAT($transfers, $transfer_total_no_vat) {
      $transfer_total_only_vat = 0;

      foreach($transfers as $transfer) {
        $transfer_total_only_vat = $transfer_total_only_vat + $transfer->priceNoVat / 100 * $transfer->vat;
      }

      return $transfer_total_only_vat;
    }


    /**
     * Izračunaj total za transfers s VAT-om
     */
    protected function CalculateTransferTotalWithVAT($transfer_total_no_vat, $transfer_total_only_vat) {
      $transfer_total_with_vat = $transfer_total_no_vat + $transfer_total_only_vat;

      return $transfer_total_with_vat;
    }


		/**
		 * Zatvaranje registracije
		 */
		protected function CloseEventRegistration($event) {
			DB::table('events')
				->where('id', '=', $event->id)
	      ->update(array(
	        'registration_end_ts' => $this->Now()
	      ));
		}


    /**
     * Obriši registraciju kreiranu kao preview
     */
    protected function DeletePreviewRegistration($lead_registration) {
      DB::table('registrations')
        ->where('id', '=', $lead_registration->id)
        ->update([
          'deleted_at' => $this->Now()
        ]);
    }


    /**
     * Dohvati settings content
     */
    protected function GetSettingsContent($type) {
        $content = null;

        if($type == 'about-us') {
            $content = DB::table('settings')
                ->select('payment_about_us', 'payment_about_us_hr')
                ->first();
        } elseif($type == 'terms-of-sale') {
            $content = DB::table('settings')
                ->select('payment_terms_of_sale', 'payment_terms_of_sale_hr')
                ->first();
        } elseif($type == 'security') {
            $content = DB::table('settings')
                ->select('payment_security', 'payment_security_hr')
                ->first();
        } elseif($type == 'privacy') {
            $content = DB::table('settings')
                ->select('payment_privacy', 'payment_privacy_hr')
                ->first();
        } elseif($type == 'conversion') {
            $content = DB::table('settings')
                ->select('payment_conversion', 'payment_conversion_hr')
                ->first();
        }

        return $content;
      }


      /**
       * Dohvati settings payment cards
       */
      protected function getPaymentCards()
      {
          return DB::table('settings')
            ->select('payment_visa', 'payment_mastercard', 'payment_maestro', 'payment_american_express', 'payment_diners')
            ->first();
      }

    /**
     * Provjera i spremanje promocijskog koda
     */
    protected function CheckTicketPromoCode($lead_registration_id, $ticket_type_id, $ticket_promo_code)
    {
        $existing_promo_code = DB::table('promo_codes')
            ->where([
                'registration_id' => $lead_registration_id
            ])
            ->first();
        
        if ($existing_promo_code) {
            DB::table('promo_codes')
                ->where([
                    'registration_id' => $lead_registration_id
                ])
                ->update([
                    'registration_id' => null
                ]);
        }

        $ticket = DB::table('tickets')
            ->where('id', $ticket_type_id)
            ->first();

        if ($ticket->has_promo_codes != 1) return true;

        $valid_promo_code = DB::table('promo_codes')
            ->where([
                'ticket_id' => $ticket_type_id,
                'code' => $ticket_promo_code,
                'registration_id' => null
            ])
            ->first();
        
        if (!$valid_promo_code) return Redirect::back()->withErrors(['invalid-promo-code'])->send();

        DB::table('promo_codes')
            ->where([
                'ticket_id' => $ticket_type_id,
                'code' => $ticket_promo_code
            ])
            ->update([
                'registration_id' => $lead_registration_id
            ]);
    }

    /**
     * Dohvati postavke
     */
    protected function GetSettings()
    {
        return DB::table('settings')
            ->first();
    }
}
