<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use Session;
use Redirect;
use Auth;

class RegistrationEmailController extends RegistrationController {

    // Slanje e-mailova i invoiceova
    use RegistrationEmailsAndInvoicesController;

    public function __construct() {
      parent::__construct();
    }


    /**
     * Prikaz koraka registracije - email
     */
    public function GetRegistrationEmail(Request $request, $event_code) {
      $event = $this->CheckEvent($event_code);

      Session::forget('registration_id');
      Session::forget('preview_registration');
      Session::forget('manual_registration');

      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }

      $registration_opened = $this->CheckRegistrationOpened($event_code);
      if($registration_opened == false) {
        return view('registration.messages.closed')
          ->with('event', $event);
      }

      $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      return view('registration.steps.email')
        ->with('event', $event)
        ->with('registration_type', 'normal');
    }


    /**
     * Spreamnje koraka registracije - email
     */
    public function SaveRegistrationEmail(Request $request, $event_code) {
      $email = trim($request->input('email'));

      $event = $this->CheckEvent($event_code);
      $lead = $this->GetLeadByEmail($email);

      $manual_registration = Session::get('manual_registration');

      // Ručna registracija od strane administratora

      if($manual_registration == true) {

        if($lead) {
          $lead_registration = $this->CheckLeadsRegistration($event, $lead);

          if($lead_registration) {
            return view('registration.messages.already-registrated')
              ->with('event', $event)
              ->with('lead', $lead)
              ->with('registration_type', 'manual');
          }
        } else {
          $lead = $this->CreateLead($email);
        }

        $registration_id = $this->CreateRegistration($event, $lead);

        Session::put('registration_id', $registration_id);

        return Redirect::route('general-information', array($event_code, $lead->lead_code));

      }

      // Normalna registracija putem javno dostupne stranice
      // Ako imamo leada u bazi šaljemo personaliziranu pozivnicu na mail
      // Ako nemamo šaljemo nepersonaliziranu
      // Da li je event privatan i potrebne zapise u bazi radimo nakon klika u mailu

      if($lead) {

        $verification_link = $this->GenerateVerificationLink($event, $lead);

        if($lead->first_name != null) {
          $this->SendPersonalizedEmailWithVerificationLink($event, $lead, $verification_link);
        } else {
          $this->SendUnpersonalizedEmailWithVerificationLink($event, $lead, $verification_link);
        }

      } else {

				if($event->access == 'private') {

					return view('registration.messages.private')
            ->with('event', $event);

				} else {

					$lead = $this->CreateLead($email);

          $verification_link = $this->GenerateVerificationLink($event, $lead);
          $this->SendUnpersonalizedEmailWithVerificationLink($event, $lead, $verification_link);

				}

      }

      return view('registration.messages.verification-email-sent')
        ->with('event', $event)
        ->with('lead', $lead);

    }


    /**
     * Provjera verifikacijske poveznice postojećeg leada
     */
    public function CheckVerificationLink(Request $request, $event_code, $lead_code, $time_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      Session::forget('registration_id');
      Session::forget('registration_preview');
      Session::forget('manual_registration');

      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }

      $verification_valid = $this->CheckVerificationTime($time_code, $lead);
      if($verification_valid == false) {
        return view('registration.messages.invalid-verification')
          ->with('event', $event);
      }

			$lead_registration = $this->GetLeadsRegistrationDone($event, $lead);
            
            
      if($lead_registration) {
          
            if($lead_registration->confirmed_ts) {
                $this->SendEmailRegistrationCompletedWithNoInvoice($event, $lead);

                return view('registration.messages.already-registrated')
                    ->with('event', $event)
                    ->with('lead', $lead)
                    ->with('registration_type', 'normal');
            }
          
        // Slanje emaila

				$lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);
	      $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);
	      $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

				if(MODULE_PROFORMA_INVOICE == false) {

	        $this->SendEmailRegistrationCompletedWithNoInvoice($event, $lead);

	      } else {

	        $currency = $this->GetEventCurrency($event_code);

	        $ticket_registration = $this->GetTicketRegistration($lead_registration);
	        $ticket_payment = $this->GetTicketPayment($event);
	        $ticket_tax = $this->CalculateTicketTax($ticket_registration);
	        $ticket_total = $this->CalculateTicketTotal($ticket_registration, $ticket_tax);
	        $ticket_tax = $this->ToDecimal($ticket_tax);
	        $ticket_total = $this->ToDecimal($ticket_total);

	        if($lead_has_accommodation == false && $lead_has_transfers == false) {

	          $this->SendEmailRegistrationCompletedWithTicketInvoice($event,
	            $lead, $currency,
	            $ticket_registration, $ticket_payment,
	            $ticket_tax, $ticket_total);

	        } else if($lead_has_accommodation == true && $lead_has_transfers == true) {

	          $accommodation_registration = $this->GetAccommodationRegistration($lead_registration);
	          $accommodation_payment = $this->GetAccommodationPayment($event);
	          $accommodation_days = $this->CalculateAccommodationDays($accommodation_registration);
	          $accomodation_total_no_vat = $this->CalculateAccommodationTotalNoVAT($accommodation_registration, $accommodation_days);
	          $accomodation_total_only_vat = $this->CalculateAccommodationTotalOnlyVAT($accommodation_registration, $accomodation_total_no_vat);
	          $accomodation_total_with_vat = $this->CalculateAccommodationTotalWithVAT($accomodation_total_no_vat, $accomodation_total_only_vat);
	          $accomodation_total_no_vat = $this->ToDecimal($accomodation_total_no_vat);
	          $accomodation_total_only_vat = $this->ToDecimal($accomodation_total_only_vat);
	          $accomodation_total_with_vat = $this->ToDecimal($accomodation_total_with_vat);

	          $transfer_registration = $this->GetTransferRegistration($lead_registration);
	          $transfer_payment = $this->GetTransferPayment($event);
	          $transfers = $this->GetRegistrationTransfers($lead_registration);
	          $transfer_total_no_vat = $this->CalculateTransferTotalNoVAT($transfers);
	          $transfer_total_only_vat = $this->CalculateTransferTotalOnlyVAT($transfers, $transfer_total_no_vat);
	          $transfer_total_with_vat = $this->CalculateTransferTotalWithVAT($transfer_total_no_vat, $transfer_total_only_vat);
	          $transfer_total_no_vat = $this->ToDecimal($transfer_total_no_vat);
	          $transfer_total_only_vat = $this->ToDecimal($transfer_total_only_vat);
	          $transfer_total_with_vat = $this->ToDecimal($transfer_total_with_vat);

	          $this->SendEmailRegistrationCompletedWithAccommodationAndTransferInvoice($event,
	            $lead, $currency,
	            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
	            $accommodation_registration, $accommodation_payment, $accommodation_days,
	            $accomodation_total_no_vat, $accomodation_total_only_vat, $accomodation_total_with_vat,
	            $transfer_registration, $transfer_payment, $transfers,
	            $transfer_total_no_vat, $transfer_total_only_vat, $transfer_total_with_vat);

	        } else if($lead_has_accommodation == true) {

	          $accommodation_registration = $this->GetAccommodationRegistration($lead_registration);
	          $accommodation_payment = $this->GetAccommodationPayment($event);
	          $accommodation_days = $this->CalculateAccommodationDays($accommodation_registration);
	          $accomodation_total_no_vat = $this->CalculateAccommodationTotalNoVAT($accommodation_registration, $accommodation_days);
	          $accomodation_total_only_vat = $this->CalculateAccommodationTotalOnlyVAT($accommodation_registration, $accomodation_total_no_vat);
	          $accomodation_total_with_vat = $this->CalculateAccommodationTotalWithVAT($accomodation_total_no_vat, $accomodation_total_only_vat);
	          $accomodation_total_no_vat = $this->ToDecimal($accomodation_total_no_vat);
	          $accomodation_total_only_vat = $this->ToDecimal($accomodation_total_only_vat);
	          $accomodation_total_with_vat = $this->ToDecimal($accomodation_total_with_vat);

	          $this->SendEmailRegistrationCompletedWithAccommodationInvoice($event,
	            $lead, $currency,
	            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
	            $accommodation_registration, $accommodation_payment, $accommodation_days,
	            $accomodation_total_no_vat, $accomodation_total_only_vat, $accomodation_total_with_vat);

	        } else if($lead_has_transfers == true) {

	          $transfer_registration = $this->GetTransferRegistration($lead_registration);
	          $transfer_payment = $this->GetTransferPayment($event);
	          $transfers = $this->GetRegistrationTransfers($lead_registration);
	          $transfer_total_no_vat = $this->CalculateTransferTotalNoVAT($transfers);
	          $transfer_total_only_vat = $this->CalculateTransferTotalOnlyVAT($transfers, $transfer_total_no_vat);
	          $transfer_total_with_vat = $this->CalculateTransferTotalWithVAT($transfer_total_no_vat, $transfer_total_only_vat);
	          $transfer_total_no_vat = $this->ToDecimal($transfer_total_no_vat);
	          $transfer_total_only_vat = $this->ToDecimal($transfer_total_only_vat);
	          $transfer_total_with_vat = $this->ToDecimal($transfer_total_with_vat);

	          $this->SendEmailRegistrationCompletedWithTransfersInvoice($event,
	            $lead, $currency,
	            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
	            $transfer_registration, $transfer_payment, $transfers,
	            $transfer_total_no_vat, $transfer_total_only_vat, $transfer_total_with_vat);

	        }

	      }

				return view('registration.messages.already-registrated')
          ->with('event', $event)
          ->with('lead', $lead)
          ->with('registration_type', 'normal');

      }

			$registration_opened = $this->CheckRegistrationOpened($event_code);
      if($registration_opened == false) {
        return view('registration.messages.closed')
          ->with('event', $event);
      }

      $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      if($available_tickets == false) {

				// Slanje obavijesti administratoru eventa
				// $this->SendEmailToEventAdminNoTickets($event);

        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $lead_invited = $this->CheckPrivateInvitation($event_code, $lead_code);
      if($lead_invited == false) {
        return view('registration.messages.private')
          ->with('event', $event);
      }

      $registration_id = $this->CreateRegistration($event, $lead);
      Session::put('registration_id', $registration_id);

      return Redirect::route('general-information', array($event_code, $lead_code));
    }


    /**
     * Prikaži nulti korak s email adresom
     */
    public function GetRegistrationWithEmail(Request $request, $event_code, $email) {
      $event = $this->CheckEvent($event_code);

      Session::forget('registration_id');
      Session::forget('preview_registration');
      Session::forget('manual_registration');

      if(filter_var($email, FILTER_VALIDATE_EMAIL) === false) {
        return Redirect::route('registration', array($event_code));
      }

      $lead_exists = $this->CheckLeadByEmail($email);
      if($lead_exists == false) {
        return Redirect::route('registration', array($event_code));
      }

      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }

      $registration_opened = $this->CheckRegistrationOpened($event_code);
      if($registration_opened == false) {
        return view('registration.messages.closed')
          ->with('event', $event);
      }

      $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      return view('registration.steps.email')
        ->with('event', $event)
        ->with('email', $email)
        ->with('registration_type', 'email');
    }


    /**
     * Ručno kreiranje registracije od strane administratora
     */
    public function ManuallyCreateRegistration(Request $request, $event_code) {
      $event = $this->CheckEvent($event_code);

      Session::forget('registration_id');
      Session::forget('preview_registration');
      Session::forget('manual_registration');

      if(!Auth::check()) {
        Redirect::to('/registration/' . $event_code)->send();
      }

      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }

      $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      Session::put('manual_registration', true);

      return view('registration.steps.email')
        ->with('event', $event)
        ->with('registration_type', 'manual');
    }

}
