<?php

namespace App\Http\Controllers\Registration;

use Mail;
use PDF;

trait RegistrationEmailsAndInvoicesController
{

	/**
	 * Početak registracije s vertifikacijskim kodom (personalizirano)
	 */
	public function SendPersonalizedEmailWithVerificationLink($event, $lead, $verification_link)
	{
		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Započni registraciju za ' . $event->name;
		} else {
			$email_data['title'] = 'Start registration for ' . $event->name;
		}
		$email_data['registration_link'] = $verification_link;
		if ($event->lang == 'hr') {
            $email_data['content_before_link'] = $this->ConvertSpecialEmailTags($event->registration_starting_existing_leads_hr, $event, $lead);
            $email_data['content_after_link'] = $this->ConvertSpecialEmailTags($event->registration_email_signature_hr, $event, $lead);
		} else {
            $email_data['content_before_link'] = $this->ConvertSpecialEmailTags($event->registration_starting_existing_leads_en, $event, $lead);
            $email_data['content_after_link'] = $this->ConvertSpecialEmailTags($event->registration_email_signature_en, $event, $lead);
		}

		Mail::queue('registration.emails.email-verification-code', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
        });
        
	}

	/**
	 * Početak registracije s vertifikacijskim kodom (nepersonalizirano)
	 */
	public function SendUnpersonalizedEmailWithVerificationLink($event, $lead, $verification_link)
	{

		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Započni registraciju za ' . $event->name;
		} else {
			$email_data['title'] = 'Start registration for ' . $event->name;
		}
		$email_data['registration_link'] = $verification_link;
		if ($event->lang == 'hr') {
            $email_data['content_before_link'] = $event->registration_starting_new_leads_hr;
            $email_data['content_after_link'] = $this->ConvertSpecialEmailTags($event->registration_email_signature_hr, $event, $lead);
		} else {
            $email_data['content_before_link'] = $event->registration_starting_new_leads_en;
            $email_data['content_after_link'] = $this->ConvertSpecialEmailTags($event->registration_email_signature_en, $event, $lead);
		}

		Mail::queue('registration.emails.email-verification-code', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
        });
        
	}


	/**
	 * Gotova registracija bez invoiceova
	 */
	public function SendEmailRegistrationCompletedWithNoInvoice($event, $lead)
	{
		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
            $email_data['title'] = 'Registracija potvrđena za ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_without_invoices_hr, $event, $lead);
		} else {
            $email_data['title'] = 'Registration confirmation for ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_without_invoices_en, $event, $lead);
		}

		Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
        });
        
	}


	/**
	 * Gotova registracija s ticket invoiceom
	 */
	public function SendEmailRegistrationCompletedWithTicketInvoice(
		$event,
		$lead,
		$currency,
		$ticket_registration,
		$ticket_payment,
		$ticket_tax,
		$ticket_total
	) {

		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Registracija potvrđena za ' . $event->name;
		} else {
			$email_data['title'] = 'Registration confirmation for ' . $event->name;
		}
		$email_data['currency'] = $currency;
		$email_data['registration'] = $ticket_registration;
		$email_data['event_logo'] = $event->event_logo_url;
		$email_data['bg_color'] = $event->background_color;
		$email_data['title_color'] = $event->titles_color;
		$email_data['ticket_payment'] = $ticket_payment;
		$email_data['ticket_code'] = $ticket_registration->invoiceTicket;
		$email_data['ticket_tax'] = $ticket_tax;
		$email_data['ticket_total'] = $ticket_total;

		if ($ticket_total > 0) {
			if ($event->lang == 'hr') {
                $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_hr, $event, $lead);
			} else {
				$email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_en, $event, $lead);
			}

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {
				$ticket_pdf = PDF::loadView('invoices.tickets', [
					'registration' => $email_data['registration'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['ticket_payment'],
					'tax' => $email_data['ticket_tax'],
					'total' => $email_data['ticket_total']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($ticket_pdf->output(), 'ticket-proforma-invoice-' . $email_data['ticket_code'] . '.pdf');

			});

		} else {
			if ($event->lang == 'hr') {
                $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_hr, $event, $lead);
			} else {
				$email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_en, $event, $lead);
			}

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title']);
            });
            
        }
        
	}


	/**
	 * Gotova registracija s ticket i accommodation invoiceom
	 */
	public function SendEmailRegistrationCompletedWithAccommodationInvoice(
		$event,
		$lead,
		$currency,
		$ticket_registration,
		$ticket_payment,
		$ticket_tax,
		$ticket_total,
		$accommodation_registration,
		$accommodation_payment,
		$accommodation_days,
		$accomodation_total_no_vat,
		$accomodation_total_only_vat,
		$accomodation_total_with_vat
	) {

		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
       
        if ($event->lang == 'hr') {
            $email_data['title'] = 'Registracija potvrđena za ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_hr, $event, $lead);
        } else {
            $email_data['title'] = 'Registration confirmation for ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_en, $event, $lead);
        }

		$email_data['currency'] = $currency;
		$email_data['registration'] = $ticket_registration;
		$email_data['event_logo'] = $event->event_logo_url;
		$email_data['bg_color'] = $event->background_color;
		$email_data['title_color'] = $event->titles_color;
		$email_data['ticket_payment'] = $ticket_payment;
		$email_data['ticket_code'] = $ticket_registration->invoiceTicket;
		$email_data['ticket_tax'] = $ticket_tax;
		$email_data['ticket_total'] = $ticket_total;
		$email_data['accomodation'] = $accommodation_registration;
		$email_data['accomodation_total_no_vat'] = $accomodation_total_no_vat;
		$email_data['accomodation_total_only_vat'] = $accomodation_total_only_vat;
		$email_data['accomodation_total_with_vat'] = $accomodation_total_with_vat;
		$email_data['accommodation_days'] = $accommodation_days;
		$email_data['accomodation_code'] = $accommodation_registration->invoiceAccomodation;
		$email_data['accomodation_payment'] = $accommodation_payment;

		if ($ticket_total > 0) {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$ticket_pdf = PDF::loadView('invoices.tickets', [
					'registration' => $email_data['registration'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['ticket_payment'],
					'tax' => $email_data['ticket_tax'],
					'total' => $email_data['ticket_total']
				])->setPaper('a4');

				$accomodation_pdf = PDF::loadView('invoices.accomodations', [
					'registration' => $email_data['accomodation'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['accomodation_payment'],
					'accomodation_total_no_vat' => $email_data['accomodation_total_no_vat'],
					'accomodation_total_only_vat' => $email_data['accomodation_total_only_vat'],
					'accomodation_total_with_vat' => $email_data['accomodation_total_with_vat'],
					'accomodationDays' => $email_data['accommodation_days']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($ticket_pdf->output(), 'ticket-proforma-invoice-' . $email_data['ticket_code'] . '.pdf')
					->attachData($accomodation_pdf->output(), 'accommodation-proforma-invoice-' . $email_data['accomodation_code'] . '.pdf');

			});

		} else {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$accomodation_pdf = PDF::loadView('invoices.accomodations', [
					'registration' => $email_data['accomodation'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['accomodation_payment'],
					'accomodation_total_no_vat' => $email_data['accomodation_total_no_vat'],
					'accomodation_total_only_vat' => $email_data['accomodation_total_only_vat'],
					'accomodation_total_with_vat' => $email_data['accomodation_total_with_vat'],
					'accomodationDays' => $email_data['accommodation_days']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($accomodation_pdf->output(), 'accommodation-proforma-invoice-' . $email_data['accomodation_code'] . '.pdf');

			});

		}

	}


	/**
	 * Gotova registracija s ticket i transfers invoiceom
	 */
	public function SendEmailRegistrationCompletedWithTransfersInvoice(
		$event,
		$lead,
		$currency,
		$ticket_registration,
		$ticket_payment,
		$ticket_tax,
		$ticket_total,
		$transfer_registration,
		$transfer_payment,
		$transfers,
		$transfer_total_no_vat,
		$transfer_total_only_vat,
		$transfer_total_with_vat
	) {

		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
        
        if ($event->lang == 'hr') {
            $email_data['title'] = 'Registracija potvrđena za ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_hr, $event, $lead);
        } else {
            $email_data['title'] = 'Registration confirmation for ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_en, $event, $lead);
        }
        
		$email_data['currency'] = $currency;
		$email_data['registration'] = $ticket_registration;
		$email_data['event_logo'] = $event->event_logo_url;
		$email_data['bg_color'] = $event->background_color;
		$email_data['title_color'] = $event->titles_color;
		$email_data['ticket_payment'] = $ticket_payment;
		$email_data['ticket_code'] = $ticket_registration->invoiceTicket;
		$email_data['ticket_tax'] = $ticket_tax;
		$email_data['ticket_total'] = $ticket_total;
		$email_data['transfer'] = $transfer_registration;
		$email_data['transfer_total_no_vat'] = $transfer_total_no_vat;
		$email_data['transfer_total_only_vat'] = $transfer_total_only_vat;
		$email_data['transfer_total_with_vat'] = $transfer_total_with_vat;
		$email_data['transfers'] = $transfers;
		$email_data['transfer_code'] = $transfer_registration->invoiceTransfer;
		$email_data['transfer_payment'] = $transfer_payment;

		if ($ticket_total > 0) {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$ticket_pdf = PDF::loadView('invoices.tickets', [
					'registration' => $email_data['registration'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['ticket_payment'],
					'tax' => $email_data['ticket_tax'],
					'total' => $email_data['ticket_total']
				])->setPaper('a4');

				$transfer_pdf = PDF::loadView('invoices/transfers', [
					'registration' => $email_data['transfer'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['transfer_payment'],
					'transfer_total_no_vat' => $email_data['transfer_total_no_vat'],
					'transfer_total_only_vat' => $email_data['transfer_total_only_vat'],
					'transfer_total_with_vat' => $email_data['transfer_total_with_vat'],
					'transfers' => $email_data['transfers']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($ticket_pdf->output(), 'ticket-proforma-invoice-' . $email_data['ticket_code'] . '.pdf')
					->attachData($transfer_pdf->output(), 'transfer-proforma-invoice-' . $email_data['transfer_code'] . '.pdf');
			});

		} else {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$transfer_pdf = PDF::loadView('invoices/transfers', [
					'registration' => $email_data['transfer'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['transfer_payment'],
					'transfer_total_no_vat' => $email_data['transfer_total_no_vat'],
					'transfer_total_only_vat' => $email_data['transfer_total_only_vat'],
					'transfer_total_with_vat' => $email_data['transfer_total_with_vat'],
					'transfers' => $email_data['transfers']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($transfer_pdf->output(), 'transfer-proforma-invoice-' . $email_data['transfer_code'] . '.pdf');
			});

		}

	}


	/**
	 * Gotova registracija s ticket i transfers invoiceom
	 */
	public function SendEmailRegistrationCompletedWithAccommodationAndTransferInvoice(
		$event,
		$lead,
		$currency,
		$ticket_registration,
		$ticket_payment,
		$ticket_tax,
		$ticket_total,
		$accommodation_registration,
		$accommodation_payment,
		$accommodation_days,
		$accomodation_total_no_vat,
		$accomodation_total_only_vat,
		$accomodation_total_with_vat,
		$transfer_registration,
		$transfer_payment,
		$transfers,
		$transfer_total_no_vat,
		$transfer_total_only_vat,
		$transfer_total_with_vat
	) {

		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $lead->email;
		$email_data['event'] = $event;
        
        if ($event->lang == 'hr') {
            $email_data['title'] = 'Registracija potvrđena za ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_hr, $event, $lead);
        } else {
            $email_data['title'] = 'Registration confirmation for ' . $event->name;
            $email_data['content'] = $this->ConvertSpecialEmailTags($event->registration_completed_with_invoices_en, $event, $lead);
        }

		$email_data['currency'] = $currency;
		$email_data['registration'] = $ticket_registration;
		$email_data['event_logo'] = $event->event_logo_url;
		$email_data['bg_color'] = $event->background_color;
		$email_data['title_color'] = $event->titles_color;
		$email_data['ticket_payment'] = $ticket_payment;
		$email_data['ticket_code'] = $ticket_registration->invoiceTicket;
		$email_data['ticket_tax'] = $ticket_tax;
		$email_data['ticket_total'] = $ticket_total;
		$email_data['accomodation'] = $accommodation_registration;
		$email_data['accomodation_total_no_vat'] = $accomodation_total_no_vat;
		$email_data['accomodation_total_only_vat'] = $accomodation_total_only_vat;
		$email_data['accomodation_total_with_vat'] = $accomodation_total_with_vat;
		$email_data['accommodation_days'] = $accommodation_days;
		$email_data['accomodation_code'] = $accommodation_registration->invoiceAccomodation;
		$email_data['accomodation_payment'] = $accommodation_payment;
		$email_data['transfer'] = $transfer_registration;
		$email_data['transfer_total_no_vat'] = $transfer_total_no_vat;
		$email_data['transfer_total_only_vat'] = $transfer_total_only_vat;
		$email_data['transfer_total_with_vat'] = $transfer_total_with_vat;
		$email_data['transfers'] = $transfers;
		$email_data['transfer_code'] = $transfer_registration->invoiceTransfer;
		$email_data['transfer_payment'] = $transfer_payment;

		if ($ticket_total > 0) {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$ticket_pdf = PDF::loadView('invoices.tickets', [
					'registration' => $email_data['registration'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['ticket_payment'],
					'tax' => $email_data['ticket_tax'],
					'total' => $email_data['ticket_total']
				])->setPaper('a4');

				$accomodation_pdf = PDF::loadView('invoices.accomodations', [
					'registration' => $email_data['accomodation'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['accomodation_payment'],
					'accomodation_total_no_vat' => $email_data['accomodation_total_no_vat'],
					'accomodation_total_only_vat' => $email_data['accomodation_total_only_vat'],
					'accomodation_total_with_vat' => $email_data['accomodation_total_with_vat'],
					'accomodationDays' => $email_data['accommodation_days']
				])->setPaper('a4');

				$transfer_pdf = PDF::loadView('invoices/transfers', [
					'registration' => $email_data['transfer'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['transfer_payment'],
					'transfer_total_no_vat' => $email_data['transfer_total_no_vat'],
					'transfer_total_only_vat' => $email_data['transfer_total_only_vat'],
					'transfer_total_with_vat' => $email_data['transfer_total_with_vat'],
					'transfers' => $email_data['transfers']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($ticket_pdf->output(), 'ticket-proforma-invoice-' . $email_data['ticket_code'] . '.pdf')
					->attachData($accomodation_pdf->output(), 'accommodation-proforma-invoice-' . $email_data['accomodation_code'] . '.pdf')
					->attachData($transfer_pdf->output(), 'transfer-proforma-invoice-' . $email_data['transfer_code'] . '.pdf');
			});

		} else {

			Mail::queue('registration.emails.email-done', $email_data, function ($message) use ($email_data) {

				$accomodation_pdf = PDF::loadView('invoices.accomodations', [
					'registration' => $email_data['accomodation'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['accomodation_payment'],
					'accomodation_total_no_vat' => $email_data['accomodation_total_no_vat'],
					'accomodation_total_only_vat' => $email_data['accomodation_total_only_vat'],
					'accomodation_total_with_vat' => $email_data['accomodation_total_with_vat'],
					'accomodationDays' => $email_data['accommodation_days']
				])->setPaper('a4');

				$transfer_pdf = PDF::loadView('invoices/transfers', [
					'registration' => $email_data['transfer'],
					'event' => $email_data['event'],
					'event_logo' => $email_data['event_logo'],
					'bg_color' => $email_data['bg_color'],
					'title_color' => $email_data['title_color'],
					'currency' => $email_data['currency'],
					'payment' => $email_data['transfer_payment'],
					'transfer_total_no_vat' => $email_data['transfer_total_no_vat'],
					'transfer_total_only_vat' => $email_data['transfer_total_only_vat'],
					'transfer_total_with_vat' => $email_data['transfer_total_with_vat'],
					'transfers' => $email_data['transfers']
				])->setPaper('a4');

				$message->from($email_data['from_email'], $email_data['from_name'])
					->to($email_data['send_to'])
					->replyTo($email_data['reply_to'])
					->subject($email_data['title'])
					->attachData($accomodation_pdf->output(), 'accommodation-proforma-invoice-' . $email_data['accomodation_code'] . '.pdf')
					->attachData($transfer_pdf->output(), 'transfer-proforma-invoice-' . $email_data['transfer_code'] . '.pdf');
			});

		}

	}


	/**
	 * Pošalji mail event administratoru da nema više slobodnih karata
	 */

	public function SendEmailToEventAdminNoTickets($event)
	{
		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $event->email_sender;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Maksimalan broj ulaznica dosegnut za ' . $event->name;
		} else {
			$email_data['title'] = 'Ticket quantity reached on ' . $event->name;
		}


		Mail::queue('registration.emails.email-no-tickets', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
		});
	}


	/**
	 * Pošalji mail event administratoru da nema više accommodation mjesta
	 */

	public function SendEmailToEventAdminNoAccomm($event)
	{
		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $event->email_sender;
		$email_data['event'] = $event;
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Maksimalan broj smještajnih mjesta dosegnut za ' . $event->name;
		} else {
			$email_data['title'] = 'Accommodation quantity reached on ' . $event->name;
		}


		Mail::queue('registration.emails.email-no-accomm', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
		});
    }
    
    /**
	 * Pošalji mail event administratoru za svaku registraciju
	 */
	public function SendEmailToEventAdminEveryRegistration($event)
	{
		$email_data['from_email'] = $event->email_sender;
		$email_data['from_name'] = $event->email_name;
		$email_data['reply_to'] = $event->email_sender;
		$email_data['send_to'] = $event->email_sender;
        $email_data['event'] = $event;
        
		if ($event->lang == 'hr') {
			$email_data['title'] = 'Nova registracija na ' . $event->name;
		} else {
			$email_data['title'] = 'New registration on ' . $event->name;
		}

		Mail::queue('registration.emails.email-new-registration', $email_data, function ($message) use ($email_data) {
			$message->from($email_data['from_email'], $email_data['from_name'])
				->to($email_data['send_to'])
				->replyTo($email_data['reply_to'])
				->subject($email_data['title']);
		});
    }
    
    /**
     * Convert special e-mail tags
     */
    private function ConvertSpecialEmailTags($content, $event, $lead)
    {
        $content = $this->ConvertLeadAliasTags($content, $lead);
        $content = str_replace('{lead_title}', $lead->title, $content);
        $content = str_replace('{lead_first_name}', $lead->first_name, $content);
        $content = str_replace('{lead_last_name}', $lead->last_name, $content);
        $content = str_replace('{event_name}', $event->name, $content);
        $content = str_replace('{lead_email}', $lead->email, $content);
        $content = str_replace('{sender_name}', $event->email_name, $content);
        $content = str_replace('{sender_email}', $event->email_sender, $content);

        return $content;
    }

    /**
     * Variacije pozdrava u pravom licu
     */
    private function ConvertLeadAliasTags($content, $lead) {
        if($lead->gender == 'Mr.') {
            $content = str_replace('{lead_alias}', 'Poštovani', $content);
        } else if($lead->gender == 'Ms.') {
            $content = str_replace('{lead_alias}', 'Poštovana', $content);
        } else {
            $content = str_replace('{lead_alias}', 'Poštovani', $content);
        }
        
        $offset = 0;
        $occurrences = array();
        
        while(($position = strpos($content, '{lead_alias', $offset)) !== FALSE) {
            $offset = $position + 1;
            $occurrences[] = $position;
        }
        
        $occurrences = array_reverse($occurrences);
        
        foreach($occurrences as $key => $occurrence) {
            $equal = substr($content, ($occurrence + 11), 1);

            if($equal == '=') {
                $comma = strpos($content, ',', $occurrence);
                $end = strpos($content, '}', $occurrence);
                
                if($comma && $end) {
                    $male = substr($content, $occurrence + 12, ($comma - ($occurrence + 12)));
                    $female = substr($content, $comma + 1, ($end - $comma - 1));
                    
                    if($lead->gender == 'Mr.') {
                        $content = substr_replace($content, $male, $occurrence, ($end - $occurrence + 1));
                    } else if($lead->gender == 'Ms.') {
                        $content = substr_replace($content, $female, $occurrence, ($end - $occurrence + 1));
                    } else {
                        $content = substr_replace($content, $male, $occurrence, ($end - $occurrence + 1));
                    }
                }
            }
        }
        
        return $content;
    }
}
