<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Redirect;
use Session;  

class RegistrationGeneralInformationController extends RegistrationController {

		// Slanje e-mailova i invoiceova
		use RegistrationEmailsAndInvoicesController;

    public function __construct() {
      parent::__construct();
    }

    /**
     * Prikaz General information
     */
    public function GetGeneralInformation(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      if($event->is_draft == 1) {
        return view('registration.messages.draft')
          ->with('event', $event);
      }

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      if($preview_registration == true || $manual_registration == true) {
        $tickets = $this->GetAvailableTickets($event_code, false);
      } else {
        $tickets = $this->GetAvailableTickets($event_code);
      }

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $accommodations = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);

      $free_ticket_no_accomm_trans = $this->CheckIfFreeTicketWithoutAccommTrans($event_code);

      if($event->lang == 'hr') {
        $countries = $this->GetCountriesHr();
      } else {
        $countries = $this->GetCountries();
      }
	  
	  $types = $this->GetTypes();
	  
	  $type_descriptions = $this->GetTypeDescriptions();
	  $lead_type_descriptions = $this->GetTypeDescriptionsForLead($lead->id);

      $currency = $this->GetEventCurrency($event_code);

      $social_events = $this->GetSocialEvents($event);
      $leads_social_events_ids = $this->GetLeadsSocialEventsIds($event, $lead);

      $settings = $this->GetSettings();

      return view('registration.steps.general-information')
        ->with('event', $event)
        ->with('lead_registration', $lead_registration)
        ->with('tickets', $tickets)
        ->with('social_events', $social_events)
        ->with('leads_social_events_ids', $leads_social_events_ids)
        ->with('accommodations', $accommodations)
        ->with('transfers', $transfers)
        ->with('free_ticket_no_accomm_trans', $free_ticket_no_accomm_trans)
        ->with('countries', $countries)
		->with('types', $types)
		->with('type_descriptions', $type_descriptions)
		->with('lead_type_descriptions', $lead_type_descriptions)
        ->with('currency', $currency)
        ->with('settings', $settings);
    }


    /**
     * Spramanje General information
     */
    public function SaveGeneralInformation(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

	  $gender = $request->input('gender');
      $title = $request->input('title');
      $first_name = $request->input('first_name');
      $last_name = $request->input('last_name');
      $mobile = $request->input('mobile');
      $phone = $request->input('phone');
      $company_name = $request->input('company_name');
      $job_function = $request->input('job_function');
      $company_address = $request->input('company_address');
      $company_city = $request->input('company_city');
      $company_post_code = $request->input('company_post_code');
      $company_country = $request->input('company_country');
	  $lead_type = $request->input('lead_type');
	  $lead_type_descriptions = $request->input('lead_type_descriptions');
      $note = $request->input('note');
      $social_events = $request->input('social_event');

      $ticket_type_id = $request->input('ticket_type_id');
      $ticket_promo_code = $request->input('ticket_promo_code');

      DB::table('leads')
        ->where('id', $lead->id)
        ->update(array(
		  'gender' => $gender,
          'title' => $title,
          'first_name' => $first_name,
          'last_name' => $last_name,
          'mobile' => $mobile,
          'phone' => $phone,
          'company_name' => $company_name,
          'job_function' => $job_function,
          'company_address' => $company_address,
          'company_city' => $company_city,
          'company_post_code' => $company_post_code,
          'company_country' => $company_country,
		  'lead_type_id' => $lead_type,
          'note' => $note,
          'opt_in' => 'Yes',
          'opt_in_method' => 'email',
          'self_registrated' => 'Yes',
          'updated_at' => $this->Now()
        ));
		
		DB::table('lead_has_type_descriptions')
			->where('lead_id', $lead->id)
            ->delete();
		
		if ($lead_type_descriptions) {
			foreach($lead_type_descriptions as $key => $new_lead_type_description) {
				$lead_type_description_exists = DB::table('lead_type_descriptions')
					->where('id', $new_lead_type_description)
					->orWhere('name', $new_lead_type_description)
					->first();
					
				if (!$lead_type_description_exists) {
					$new_lead_type_description_id = DB::table('lead_type_descriptions')
						->insertGetId([
							'name' => $new_lead_type_description,
						]);
					
					DB::table('lead_has_type_descriptions')
						->insert(array(
							'lead_id' => $lead->id,
							'lead_type_description_id' => $new_lead_type_description_id
						));
				} else {
					DB::table('lead_has_type_descriptions')
						->insert(array(
							'lead_id' => $lead->id,
							'lead_type_description_id' => $new_lead_type_description
						));
				}
			}
		}

      $lead_registration_id = $this->GetLeadsRegistrationId($event, $lead);

      $this->CheckTicketPromoCode($lead_registration_id, $ticket_type_id, $ticket_promo_code);

      DB::table('registrations')
        ->where('id', $lead_registration_id)
        ->update(array(
          'ticket_type_id' => $ticket_type_id
        ));

        DB::table('registration_has_social_events')
            ->where('registration_id', $lead_registration_id)
            ->delete();

        if ($social_events) {
            foreach($social_events as $key => $social_event_id) {
                DB::table('registration_has_social_events')
                    ->insert(array(
                        'registration_id' => $lead_registration_id,
                        'social_event_id' => $social_event_id
                    ));
            }
        }

      $this->DeleteTicketPayerIfFree($ticket_type_id, $lead_registration_id);

      $accommodations = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);

			$number_of_accommodation = $this->NumberOfAccommodation($event_code);
      $number_of_used_accommodations = $this->NumberOfUsedAccommodations($event_code);

			if($number_of_accommodation == $number_of_used_accommodations+1) {
				$event = $this->GetEvent($event_code);

				$this->SendEmailToEventAdminNoAccomm($event);
			}

      $free_ticket_no_accomm_trans = $this->CheckIfFreeTicketWithoutAccommTrans($event_code);

      if($free_ticket_no_accomm_trans == true) {
        return Redirect::route('summary', array($event_code, $lead_code));
      }

      if($accommodations == true || $transfers == true) {
        return Redirect::route('accommodation-transfer', array($event_code, $lead_code));
      } else {
        return Redirect::route('payment', array($event_code, $lead_code));
      }

    }

}
