<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Redirect;
use Session; 

class RegistrationPaymentController extends RegistrationController {

    public function __construct() {
      parent::__construct();
    }


    /**
     * Prikaz Payment
     */
    public function GetPayment(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $accommodations = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);

      $free_ticket_no_accomm_trans = $this->CheckIfFreeTicketWithoutAccommTrans($event_code);
      if($free_ticket_no_accomm_trans == true) {
        return Redirect::route('general-information', array($event_code, $lead_code));
      }

      if($event->lang == 'hr') {
        $countries = $this->GetCountriesHr();
      } else {
        $countries = $this->GetCountries();
      }

      $lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);
      $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);
      $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

      return view('registration.steps.payment')
        ->with('event', $event)
        ->with('lead', $lead)
        ->with('lead_registration', $lead_registration)
        ->with('accommodations', $accommodations)
        ->with('transfers', $transfers)
        ->with('free_ticket_no_accomm_trans', $free_ticket_no_accomm_trans)
        ->with('countries', $countries)
        ->with('lead_has_free_ticket', $lead_has_free_ticket)
        ->with('lead_has_accommodation', $lead_has_accommodation)
        ->with('lead_has_transfers', $lead_has_transfers);
    }


    /**
     * Spremanje Payment
     */
    public function SavePayment(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      // Payment
      if ($lead_registration->payment_cart == null) {
        $payment_cart_last = DB::table('registrations')->max('payment_cart');
        if (!$payment_cart_last) $payment_cart_last = 0;
        $payment_cart_last += 1;
      } else {
        $payment_cart_last = $lead_registration->payment_cart;
      }
      DB::table('registrations')
        ->where('id', $lead_registration->id)
        ->update(array(
            'payment_option' => $request->input('payment_option'),
            'payment_cart' => $payment_cart_last
        ));

      // Ticket

      $lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);

      if($lead_has_free_ticket == false) {

        $ticket_payment_type = $request->input('ticket_payment_type');
        $ticket_payment_company_name = $request->input('ticket_payment_company_name');
        $ticket_payment_address = $request->input('ticket_payment_address');
        $ticket_payment_city = $request->input('ticket_payment_city');
        $ticket_payment_postal_code = $request->input('ticket_payment_postal_code');
        $ticket_payment_country = $request->input('ticket_payment_country');
        $ticket_payment_first_name = $request->input('ticket_payment_first_name');
        $ticket_payment_last_name = $request->input('ticket_payment_last_name');
        $ticket_payment_email = $request->input('ticket_payment_email');
        $ticket_payment_phone = $request->input('ticket_payment_phone');

        $this->DeleteTicketPayer($lead_registration);

        if($ticket_payment_type == 'person') {

          $ticket_payment_personal_id = $request->input('ticket_payment_personal_id');

          $ticket_payer_id = DB::table('payer_details')
            ->insertGetId(array(
                'type' => 'person',
                'company_name' => $ticket_payment_company_name,
                'address' => $ticket_payment_address,
                'city' => $ticket_payment_city,
                'post_code' => $ticket_payment_postal_code,
                'country' => $ticket_payment_country,
                'first_name' => $ticket_payment_first_name,
                'last_name' => $ticket_payment_last_name,
                'email' => $ticket_payment_email,
                'phone' => $ticket_payment_phone,
                'personal_id' => $ticket_payment_personal_id
              ));

        } else {

          $ticket_payment_vat = $request->input('ticket_payment_vat');

          $ticket_payer_id = DB::table('payer_details')
            ->insertGetId(array(
                'type' => 'company',
                'company_name' => $ticket_payment_company_name,
                'vat' => $ticket_payment_vat,
                'address' => $ticket_payment_address,
                'city' => $ticket_payment_city,
                'post_code' => $ticket_payment_postal_code,
                'country' => $ticket_payment_country,
                'first_name' => ($ticket_payment_first_name === '') ? $lead->first_name : $ticket_payment_first_name,
                'last_name' => ($ticket_payment_last_name  === '') ? $lead->last_name : $ticket_payment_last_name,
                'email' => ($ticket_payment_email  === '') ? $lead->email : $ticket_payment_email,
                'phone' => ($ticket_payment_phone  === '') ? $lead->phone : $ticket_payment_phone
              ));

        }

        DB::table('registrations')
          ->where('id', '=', $lead_registration->id)
          ->update(array(
            'tickets_payer_id' => $ticket_payer_id
          ));

      }

      // Accommodation

      $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);

      if($lead_has_accommodation == true) {

        $accomodation_same_as_ticket = $request->input('accomodation_same_as_ticket');

        $this->DeleteAccommodationPayer($lead_registration);

        if($accomodation_same_as_ticket == 1) {

          DB::table('registrations')
            ->where('id', '=', $lead_registration->id)
            ->update(array(
              'accomodation_payer_id' => $ticket_payer_id
            ));

        } else {

          $accomodation_payment_type = $request->input('accomodation_payment_type');

          $accomodation_payment_company_name = $request->input('accomodation_payment_company_name');
          $accomodation_payment_address = $request->input('accomodation_payment_address');
          $accomodation_payment_city = $request->input('accomodation_payment_city');
          $accomodation_payment_postal_code = $request->input('accomodation_payment_postal_code');
          $accomodation_payment_country = $request->input('accomodation_payment_country');
          $accomodation_payment_first_name = $request->input('accomodation_payment_first_name');
          $accomodation_payment_last_name = $request->input('accomodation_payment_last_name');
          $accomodation_payment_email = $request->input('accomodation_payment_email');
          $accomodation_payment_phone = $request->input('accomodation_payment_phone');

          if($accomodation_payment_type == 'person') {

            $accomodation_payment_personal_id = $request->input('accomodation_payment_personal_id');

            $accomodation_payer_id = DB::table('payer_details')
              ->insertGetId(array(
                'type' => 'person',
                'company_name' => $accomodation_payment_company_name,
                'address' => $accomodation_payment_address,
                'city' => $accomodation_payment_city,
                'post_code' => $accomodation_payment_postal_code,
                'country' => $accomodation_payment_country,
                'first_name' => $accomodation_payment_first_name,
                'last_name' => $accomodation_payment_last_name,
                'email' => $accomodation_payment_email,
                'phone' => $accomodation_payment_phone,
                'personal_id' => $accomodation_payment_personal_id
              ));

          } else {

            $accomodation_payment_vat = $request->input('accomodation_payment_vat');

            $accomodation_payer_id = DB::table('payer_details')
              ->insertGetId(array(
                'type' => 'company',
                'company_name' => $accomodation_payment_company_name,
                'vat' => $accomodation_payment_vat,
                'address' => $accomodation_payment_address,
                'city' => $accomodation_payment_city,
                'post_code' => $accomodation_payment_postal_code,
                'country' => $accomodation_payment_country,
                'first_name' => ($accomodation_payment_first_name === '') ? $lead->first_name : $accomodation_payment_first_name,
                'last_name' => ($accomodation_payment_last_name  === '') ? $lead->last_name : $accomodation_payment_last_name,
                'email' => ($accomodation_payment_email  === '') ? $lead->email : $accomodation_payment_email,
                'phone' => ($accomodation_payment_phone  === '') ? $lead->phone : $accomodation_payment_phone
              ));

          }

          DB::table('registrations')
            ->where('id', '=', $lead_registration->id)
            ->update(array(
              'accomodation_payer_id' => $accomodation_payer_id
            ));

        }

      }

      // Transfers

      $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

      if($lead_has_transfers == true) {

        $transfer_same_as_ticket = $request->input('transfer_same_as_ticket');

        $this->DeleteTransferPayer($lead_registration);

        if($transfer_same_as_ticket == 1) {

          DB::table('registrations')
            ->where('id', '=', $lead_registration->id)
            ->update(array(
              'transfer_payer_id' => $ticket_payer_id
            ));

        } else {

          $transfer_payment_type = $request->input('transfer_payment_type');

          $transfer_payment_company_name = $request->input('transfer_payment_company_name');
          $transfer_payment_address = $request->input('transfer_payment_address');
          $transfer_payment_city = $request->input('transfer_payment_city');
          $transfer_payment_postal_code = $request->input('transfer_payment_postal_code');
          $transfer_payment_country = $request->input('transfer_payment_country');
          $transfer_payment_first_name = $request->input('transfer_payment_first_name');
          $transfer_payment_last_name = $request->input('transfer_payment_last_name');
          $transfer_payment_email = $request->input('transfer_payment_email');
          $transfer_payment_phone = $request->input('transfer_payment_phone');

          if($transfer_payment_type == 'person') {

            $transfer_payment_personal_id = $request->input('transfer_payment_personal_id');

            $transfer_payer_id = DB::table('payer_details')
              ->insertGetId(array(
                'type' => 'person',
                'company_name' => $transfer_payment_company_name,
                'address' => $transfer_payment_address,
                'city' => $transfer_payment_city,
                'post_code' => $transfer_payment_postal_code,
                'country' => $transfer_payment_country,
                'first_name' => $transfer_payment_first_name,
                'last_name' => $transfer_payment_last_name,
                'email' => $transfer_payment_email,
                'phone' => $transfer_payment_phone,
                'personal_id' => $transfer_payment_personal_id
              ));

          } else {

            $transfer_payment_vat = $request->input('transfer_payment_vat');

            $transfer_payer_id = DB::table('payer_details')
              ->insertGetId(array(
                'type' => 'company',
                'company_name' => $transfer_payment_company_name,
                'vat' => $transfer_payment_vat,
                'address' => $transfer_payment_address,
                'city' => $transfer_payment_city,
                'post_code' => $transfer_payment_postal_code,
                'country' => $transfer_payment_country,
                'first_name' => ($transfer_payment_first_name === '') ? $lead->first_name : $transfer_payment_first_name,
                'last_name' => ($transfer_payment_last_name  === '') ? $lead->last_name : $transfer_payment_last_name,
                'email' => ($transfer_payment_email  === '') ? $lead->email : $transfer_payment_email,
                'phone' => ($transfer_payment_phone  === '') ? $lead->phone : $transfer_payment_phone
              ));

          }

          DB::table('registrations')
            ->where('id', '=', $lead_registration->id)
            ->update(array(
              'transfer_payer_id' => $transfer_payer_id
            ));

        }

      }

      return Redirect::route('summary', array($event_code, $lead_code));

    }

}
