<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Redirect;
use Session;
use Illuminate\Support\Facades\Cache;

class RegistrationSummaryController extends RegistrationController {

    // Slanje e-mailova i invoiceova
    use RegistrationEmailsAndInvoicesController;

    public function __construct() {
      parent::__construct();
    }

    /**
     * Prikaz Summary
     */
    public function GetSummary(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $summary_registration = $this->GetLeadsSummaryRegistration($lead_registration);
      $summary_transfers = $this->GetLeadsSummaryTransfers($lead_registration);

      $summary_social_events = $this->GetLeadsSummarySocialEvents($lead_registration);

      $lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);
      $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);
      if($lead_has_accommodation == true) {
        $accommodation_days = $this->CalculateAccommodationDays($summary_registration);
      } else {
        $accommodation_days = null;
      }
      $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

      $total_vat = $this->CalculateTotalVAT($summary_registration, $summary_transfers, $accommodation_days);
      $total_price_with_vat = $this->CalculateTotalPriceWithVAT($summary_registration, $summary_transfers, $accommodation_days);

      $total_price_with_vat_in_hrk = false;
      if ($event->currency_id == 51) { // 51 == EUR
        $total_price_with_vat_in_hrk = $this->CalculateTotalPriceWithVATInHRK($summary_registration, $summary_transfers, $accommodation_days);
      }

      $currency = $this->GetEventCurrency($event_code);

      $accommodations = $this->CheckIfAvailableAccommodationExists($event_code);
      $transfers = $this->CheckIfTransfersExists($event_code);
      $free_ticket_no_accomm_trans = $this->CheckIfFreeTicketWithoutAccommTrans($event_code);

      if(WSPAY && $event->wspay) {
        if ($event->currency_id == 51) {
            $wspaySignature = $this->wspayGenerateSignature($summary_registration->paymentCart, $total_price_with_vat_in_hrk);
        } else {
            $wspaySignature = $this->wspayGenerateSignature($summary_registration->paymentCart, $total_price_with_vat);
        }

        $paymentCards = $this->getPaymentCards();
      } else { 
        $wspaySignature = false;
        $paymentCards = false;
       }

      return view('registration.steps.summary')
        ->with('event', $event)
        ->with('lead', $lead)
        ->with('summary_registration', $summary_registration)
        ->with('summary_transfers', $summary_transfers)
        ->with('summary_social_events', $summary_social_events)
        ->with('lead_has_free_ticket', $lead_has_free_ticket)
        ->with('lead_has_accommodation', $lead_has_accommodation)
        ->with('lead_has_transfers', $lead_has_transfers)
        ->with('accommodation_days', $accommodation_days)
        ->with('total_vat', $total_vat)
        ->with('total_price_with_vat', $total_price_with_vat)
        ->with('currency', $currency)
        ->with('accommodations', $accommodations)
        ->with('transfers', $transfers)
        ->with('free_ticket_no_accomm_trans', $free_ticket_no_accomm_trans)
        ->with('wspay_signature', $wspaySignature)
        ->with('total_price_with_vat_in_hrk', $total_price_with_vat_in_hrk)
        ->with('payment_cards', $paymentCards);
    }


    /**
     * Spremi Summary
     */
    public function SaveSummary(Request $request, $event_code, $lead_code) {
      $event = $this->CheckEvent($event_code);
      $lead = $this->CheckLead($event_code, $lead_code);

      $preview_registration = Session::get('preview_registration');
      $manual_registration = Session::get('manual_registration');

      if($preview_registration == true || $manual_registration == true) {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code, false);
      } else {
        $available_tickets = $this->CheckIfAvailableTicketsExists($event_code);
      }
      
      if($available_tickets == false) {
        return view('registration.messages.no-tickets')
          ->with('event', $event);
      }

      $this->CheckRegistrationVerification($event_code);
      $this->CheckLeadsRegistrationInProgress($event, $lead);

      $lead_registration = $this->GetLeadsRegistration($event, $lead);

      $lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);
      $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);
      $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

      $this->SaveLeadsRegistration($event, $lead_registration, $lead_has_accommodation, $lead_has_transfers);

      Cache::forget('leads-table');
      Cache::forget('mailings-table');

      $manual_registration = Session::get('manual_registration');

      if($manual_registration == true) {
        Session::forget('registration_id');
        Session::forget('preview_registration');
        Session::forget('manual_registration');

        return view('registration.messages.manually-done')
          ->with('event', $event);
      }

      if(MODULE_PROFORMA_INVOICE == false) {

        $this->SendEmailRegistrationCompletedWithNoInvoice($event, $lead);

      } else {

        $currency = $this->GetEventCurrency($event_code);

        $ticket_registration = $this->GetTicketRegistration($lead_registration);
        $ticket_payment = $this->GetTicketPayment($event);
        $ticket_tax = $this->CalculateTicketTax($ticket_registration);
        $ticket_total = $this->CalculateTicketTotal($ticket_registration, $ticket_tax);
        $ticket_tax = $this->ToDecimal($ticket_tax);
        $ticket_total = $this->ToDecimal($ticket_total);

        if($lead_has_accommodation == false && $lead_has_transfers == false) {

          $this->SendEmailRegistrationCompletedWithTicketInvoice($event,
            $lead, $currency,
            $ticket_registration, $ticket_payment,
            $ticket_tax, $ticket_total);

        } else if($lead_has_accommodation == true && $lead_has_transfers == true) {

          $accommodation_registration = $this->GetAccommodationRegistration($lead_registration);
          $accommodation_payment = $this->GetAccommodationPayment($event);
          $accommodation_days = $this->CalculateAccommodationDays($accommodation_registration);
          $accomodation_total_no_vat = $this->CalculateAccommodationTotalNoVAT($accommodation_registration, $accommodation_days);
          $accomodation_total_only_vat = $this->CalculateAccommodationTotalOnlyVAT($accommodation_registration, $accomodation_total_no_vat);
          $accomodation_total_with_vat = $this->CalculateAccommodationTotalWithVAT($accomodation_total_no_vat, $accomodation_total_only_vat);
          $accomodation_total_no_vat = $this->ToDecimal($accomodation_total_no_vat);
          $accomodation_total_only_vat = $this->ToDecimal($accomodation_total_only_vat);
          $accomodation_total_with_vat = $this->ToDecimal($accomodation_total_with_vat);

          $transfer_registration = $this->GetTransferRegistration($lead_registration);
          $transfer_payment = $this->GetTransferPayment($event);
          $transfers = $this->GetRegistrationTransfers($lead_registration);
          $transfer_total_no_vat = $this->CalculateTransferTotalNoVAT($transfers);
          $transfer_total_only_vat = $this->CalculateTransferTotalOnlyVAT($transfers, $transfer_total_no_vat);
          $transfer_total_with_vat = $this->CalculateTransferTotalWithVAT($transfer_total_no_vat, $transfer_total_only_vat);
          $transfer_total_no_vat = $this->ToDecimal($transfer_total_no_vat);
          $transfer_total_only_vat = $this->ToDecimal($transfer_total_only_vat);
          $transfer_total_with_vat = $this->ToDecimal($transfer_total_with_vat);

          $this->SendEmailRegistrationCompletedWithAccommodationAndTransferInvoice($event,
            $lead, $currency,
            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
            $accommodation_registration, $accommodation_payment, $accommodation_days,
            $accomodation_total_no_vat, $accomodation_total_only_vat, $accomodation_total_with_vat,
            $transfer_registration, $transfer_payment, $transfers,
            $transfer_total_no_vat, $transfer_total_only_vat, $transfer_total_with_vat);

        } else if($lead_has_accommodation == true) {

          $accommodation_registration = $this->GetAccommodationRegistration($lead_registration);
          $accommodation_payment = $this->GetAccommodationPayment($event);
          $accommodation_days = $this->CalculateAccommodationDays($accommodation_registration);
          $accomodation_total_no_vat = $this->CalculateAccommodationTotalNoVAT($accommodation_registration, $accommodation_days);
          $accomodation_total_only_vat = $this->CalculateAccommodationTotalOnlyVAT($accommodation_registration, $accomodation_total_no_vat);
          $accomodation_total_with_vat = $this->CalculateAccommodationTotalWithVAT($accomodation_total_no_vat, $accomodation_total_only_vat);
          $accomodation_total_no_vat = $this->ToDecimal($accomodation_total_no_vat);
          $accomodation_total_only_vat = $this->ToDecimal($accomodation_total_only_vat);
          $accomodation_total_with_vat = $this->ToDecimal($accomodation_total_with_vat);

          $this->SendEmailRegistrationCompletedWithAccommodationInvoice($event,
            $lead, $currency,
            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
            $accommodation_registration, $accommodation_payment, $accommodation_days,
            $accomodation_total_no_vat, $accomodation_total_only_vat, $accomodation_total_with_vat);

        } else if($lead_has_transfers == true) {

          $transfer_registration = $this->GetTransferRegistration($lead_registration);
          $transfer_payment = $this->GetTransferPayment($event);
          $transfers = $this->GetRegistrationTransfers($lead_registration);
          $transfer_total_no_vat = $this->CalculateTransferTotalNoVAT($transfers);
          $transfer_total_only_vat = $this->CalculateTransferTotalOnlyVAT($transfers, $transfer_total_no_vat);
          $transfer_total_with_vat = $this->CalculateTransferTotalWithVAT($transfer_total_no_vat, $transfer_total_only_vat);
          $transfer_total_no_vat = $this->ToDecimal($transfer_total_no_vat);
          $transfer_total_only_vat = $this->ToDecimal($transfer_total_only_vat);
          $transfer_total_with_vat = $this->ToDecimal($transfer_total_with_vat);

          $this->SendEmailRegistrationCompletedWithTransfersInvoice($event,
            $lead, $currency,
            $ticket_registration, $ticket_payment, $ticket_tax, $ticket_total,
            $transfer_registration, $transfer_payment, $transfers,
            $transfer_total_no_vat, $transfer_total_only_vat, $transfer_total_with_vat);

        }

      }

      $preview_registration = Session::get('preview_registration');

      if($preview_registration == true) {
        $this->DeletePreviewRegistration($lead_registration);
      }

      if($event->registration_notification) $this->SendEmailToEventAdminEveryRegistration($event);

      Session::forget('registration_id');
      Session::forget('preview_registration');

      return view('registration.messages.done')
        ->with('event', $event);
    }

    public function GetContentAboutUs(Request $request, $event_code, $lead_code)
    {
        $type = 'about-us';
        $event = $this->CheckEvent($event_code);
        $content = $this->GetSettingsContent($type);
        
        return view('registration.messages.content')
            ->with('event', $event)
            ->with('type', $type)
            ->with('content', $content);
    }

    public function GetContentTermsOfSale(Request $request, $event_code, $lead_code)
    {
        $type = 'terms-of-sale';
        $event = $this->CheckEvent($event_code);
        $content = $this->GetSettingsContent($type);
        
        return view('registration.messages.content')
            ->with('event', $event)
            ->with('type', $type)
            ->with('content', $content);
    }

    public function GetContentSecurity(Request $request, $event_code, $lead_code)
    {
        $type = 'security';
        $event = $this->CheckEvent($event_code);
        $content = $this->GetSettingsContent($type);
        
        return view('registration.messages.content')
            ->with('event', $event)
            ->with('type', $type)
            ->with('content', $content);
    }

    public function GetContentPrivacy(Request $request, $event_code, $lead_code)
    {
        $type = 'privacy';
        $event = $this->CheckEvent($event_code);
        $content = $this->GetSettingsContent($type);
        
        return view('registration.messages.content')
            ->with('event', $event)
            ->with('type', $type)
            ->with('content', $content);
    }

    public function GetContentConversion(Request $request, $event_code, $lead_code)
    {
        $type = 'conversion';
        $event = $this->CheckEvent($event_code);
        $content = $this->GetSettingsContent($type);
        
        return view('registration.messages.content')
            ->with('event', $event)
            ->with('type', $type)
            ->with('content', $content);
    }
}
