<?php

namespace App\Http\Controllers\Registration;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;

// Krik
use View;
use DB;
use Redirect;
use Session;
use Storage;

class RegistrationWspayController extends RegistrationController {

    // Slanje e-mailova i invoiceova
    use RegistrationEmailsAndInvoicesController;

    public function __construct() {
      parent::__construct();
    }

    /**
     * WSPay uspješno plaćanje
     */
    public function WspaySuccess(Request $request, $event_code, $lead_code) {
        $event = $this->CheckEvent($event_code);
        $lead = $this->CheckLead($event_code, $lead_code);

        $this->CheckRegistrationVerification($event_code);
        $this->CheckLeadsRegistrationInProgress($event, $lead);

        $lead_registration = $this->GetLeadsRegistration($event, $lead);

        Storage::disk('local')->append('wspay-' . $lead_registration->payment_cart . '--' . date('Y-m-d') . '.txt', $request->fullUrl());

        $this->WspayVerifySignature($request, $lead_registration->payment_cart);
        $this->WspayPayment($request, $lead_registration, true);

        $lead_has_free_ticket = $this->CheckLeadHasFreeTicket($lead_registration);
        $lead_has_accommodation = $this->CheckLeadHasAccommodation($lead_registration);
        $lead_has_transfers = $this->CheckLeadHasTransfers($lead_registration);

        $this->SaveLeadsRegistration($event, $lead_registration, $lead_has_accommodation, $lead_has_transfers);
        $this->SendEmailRegistrationCompletedWithNoInvoice($event, $lead);
        
        Session::forget('registration_id');
        Session::forget('preview_registration');
        Session::forget('manual_registration');

        return view('registration.messages.wspay-success')
            ->with('event', $event);
    }

    /**
     * WSPay neuspješno plaćanje
     */
    public function WspayError(Request $request, $event_code, $lead_code) {
        $event = $this->CheckEvent($event_code);
        $lead = $this->CheckLead($event_code, $lead_code);

        $this->CheckRegistrationVerification($event_code);
        $this->CheckLeadsRegistrationInProgress($event, $lead);

        $lead_registration = $this->GetLeadsRegistration($event, $lead);

        Storage::disk('local')->append('wspay-' . $lead_registration->payment_cart . '--' . date('Y-m-d') . '.txt', $request->fullUrl());

        $this->WspayPayment($request, $lead_registration, false);

        Session::forget('registration_id');
        Session::forget('preview_registration');
        Session::forget('manual_registration');

        return view('registration.messages.wspay-error')
            ->with('event', $event);
    }

    /**
     * WSPay odustanje od plaćanja
     */
    public function WspayCancel(Request $request, $event_code, $lead_code) {
        $event = $this->CheckEvent($event_code);
        $lead = $this->CheckLead($event_code, $lead_code);

        $this->CheckRegistrationVerification($event_code);
        $this->CheckLeadsRegistrationInProgress($event, $lead);

        $lead_registration = $this->GetLeadsRegistration($event, $lead);

        Session::forget('registration_id');
        Session::forget('preview_registration');
        Session::forget('manual_registration');

        return view('registration.messages.wspay-cancel')
            ->with('event', $event);
    }
}