<?php

namespace App\Http\Controllers\Unsubscribe;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\MainPublicController;
use DB;
use View;
use Carbon\Carbon;
use Response;
use Crypt;
use Cache;
use Illuminate\Contracts\Encryption\DecryptException;

class UnsubscribeController extends MainPublicController
{
    public function __construct() {

        parent::__construct();
        $this->setApp();

        $this->css['themes'] = [
            'admin/css/reset.css',
            'admin/css/layout.css',
            'admin/css/components.css',
            'admin/css/plugins.css',
            'admin/css/themes/laravel.theme.css',
            'admin/css/custom.css',
        ];

        $this->js['plugins'] = [];

        $this->js['scripts'] = [];

        View::share('css', $this->css);
        View::share('extraClasses', 'unsubscribe');
    }


    /**
     * Potvrdi korisnikovu želju za ne primanjem daljnjih poruka
     */
    public function GetUnsubscribe($mailing_activity_code, $lead_code_encrypted) {

        try {
            $lead_code_decrypted = Crypt::decrypt($lead_code_encrypted);
        } catch (DecryptException $lead_code_decryption_error) {
            return view('unsubscribe.unsubscribe',
                ['unsubsribed' => 'error']
            );
        }

        $mailing_id = DB::table('mailing_activities')
          ->where('mailing_activity_code', $mailing_activity_code)
          ->value('id');

        if(!$mailing_id) {
            return view('unsubscribe.unsubscribe',
                ['unsubsribed' => 'error']
            );
        }

        $lead_opt_in = DB::table('leads')
          ->where('lead_code', $lead_code_decrypted)
          ->value('opt_in');

        if ($lead_opt_in == 'No') {
            return view('unsubscribe.unsubscribe',
                ['unsubsribed' => 'already']
            );
        }

        return view('unsubscribe.unsubscribe',
            ['unsubsribed' => 'false']
        );

    }


    /**
     * Zabilježi korisnikovu želju za ne primanjem daljnjih poruka
     */
    public function SaveUnsubscribe($mailing_activity_code, $lead_code_encrypted) {

        try {
            $lead_code_decrypted = Crypt::decrypt($lead_code_encrypted);
        } catch (DecryptException $email_decryption_error) {
            return view('unsubscribe.unsubscribe',
                ['unsubsribed' => false]
            );
        }

        $mailing_id = DB::table('mailing_activities')
          ->where('mailing_activity_code', $mailing_activity_code)
          ->value('id');

        if(!$mailing_id) {
            return view('unsubscribe.unsubscribe',
                ['unsubsribed' => 'error']
            );
        }

        DB::table('leads')
          ->where('lead_code', $lead_code_decrypted)
          ->update([
            'opt_in' => 'No',
            'opt_out_activity_id' => $mailing_id,
            'opt_out_ts' => $this->Now(),
            'opt_in_method' => null
          ]);

        Cache::forget('leads-table');

        return view('unsubscribe.unsubscribe',
            ['unsubsribed' => 'true']
        );

    }
}
