<?php

namespace App\Http\Controllers\User;

use Illuminate\Http\Request;
use App\Http\Requests;

// Krik
use App\Http\Controllers\MainController as MainController;
use View;
use DB;
use Auth;
use Redirect;
use Session;
use Hash;
use Carbon\Carbon;
use Validator;

class UserController extends MainController {

	public function __construct() {
		parent::__construct();

		$this->css['pages'] = [
			'global/plugins/bower_components/fontawesome/css/font-awesome.min.css',
			'global/plugins/bower_components/animate.css/animate.min.css',
			'global/plugins/bower_components/select2/dist/css/select2.css'
		];

		$this->css['themes'] = [
			'admin/css/reset.css',
			'admin/css/layout.css',
			'admin/css/components.css',
			'admin/css/plugins.css',
			'admin/css/themes/laravel.theme.css',
			'admin/css/custom.css',
		];

		$this->js['plugins'] = [
			'global/plugins/bower_components/select2/dist/js/select2.js',
		];

    $this->js['additionalScripts'] = [
      getenv('APP_URL') . '/assets/js/jsvalidation.krik.min.js'
    ];

		View::share('css', $this->css);
		View::share('js', $this->js);
		View::share('title', 'Account Settings');
	}


  /**
   * Prikaži postavke za korisnika
   */
  public function GetUserSettings() {

		$user = Auth::user();

	  return view('user/account-settings',
			['user' => $user]
		);

	}


	/**
	 * Spremi postavke korisnika
	 */
	public function SaveUserSettings(Request $request) {

		$name = $request->input('name');
		$oldpassword = $request->input('oldpassword');
		$newpassword = $request->input('password');
		$newpasswordconfirm = $request->input('password_confirmation');

		$user = Auth::user();

		// Promijena naziva
		if($name != $user->name) {
			DB::table('users')
				->where('id', $user->id)
				->update([
					'name' => $name
				]);

			if($oldpassword) {
				$request->session()->flash('name', 'changed');
			} else {
				return redirect()->back()
					->with('name', 'changed');
			}

		}

		// Primijena lozinke
		if($oldpassword) {
			if($newpassword != $newpasswordconfirm) {
				return redirect()->back()
					->with('password', 'notconfirmed');
			}
			
			$password_strength = Validator::make($request->all(), [
				'password' => 'min:8|case_diff|numbers|letters|symbols'
			]);
			
			if($password_strength->fails()) {
				
				// Unsuccessful password change
				$this->Log(104);

				return redirect()->back()
					->with('password', 'weak');
				
			}

			if(Hash::check($oldpassword, $user->password)) {

				$newpassword_hash = bcrypt($newpassword);

				DB::table('users')
					->where('id', $user->id)
					->update([
						'password' => $newpassword_hash,
						'updated_at' => $this->Now()
					]);

				// Password change
				$this->Log(103);

				return redirect()
					->back()
					->with('password', 'changed');

			} else {

				// Unsuccessful password change
				$this->Log(104);

				return redirect()->back()
					->with('password', 'wrong');

			}
		}

		// Ukoliko nema nikakvih promijena
		return redirect()->back();

	}

}
