<?php

namespace App\Http\Requests\Events\Create;

use App\Http\Requests\Request;

class RegistrationTicket extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return false;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'ticket_name'              => 'required',
            'ticket_description'       => 'required',
            'ticket_quantity'          => 'required|numeric',
            'price_without_vat_ticket' => 'required_if:ticket_type,payment|numeric',
            'vat_percent_ticket'       => 'required_if:ticket_type,payment|numeric|min:0|max:100',
            'event_date'               => 'required',
        ];
    }
    
    public function messages()
    {
        return [
            'ticket_name.required'                 => 'Ticket name is required.',
            'ticket_description.required'          => 'Ticket description is required.',
            'ticket_quantity.required'             => 'Ticket quantity is required.',
            'price_without_vat_ticket.required_if' => 'Price without VAT is required.',
            'price_without_vat_ticket.numeric'     => 'Price without VAT needs to be a number.',
            'vat_percent_ticket.required_if'       => 'VAT percentage is required.',
            'vat_percent_ticket.numeric'           => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_ticket.min'               => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_ticket.max'               => 'VAT percentage needs to be number between 0 and 100.',
            'event_date.required'                  => 'Event duration is required.',
        ];
    }
}
