<?php

namespace App\Http\Requests\Events\Create;

use App\Http\Requests\Request;

class RegistrationTransfer extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return false;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'transfer_from_airport'      => 'required',
            'transfer_to_venue'          => 'required',
            'transfer_from_venue'        => 'required',
            'transfer_to_airport'        => 'required',
            'price_without_vat_airport'  => 'required|numeric',
            'vat_percent_airport'        => 'required|numeric|min:0|max:100',
            'price_without_vat_venue'    => 'required|numeric',
            'vat_percent_venue'          => 'required|numeric|min:0|max:100'
        ];
    }
    
    public function messages()
    {
        return [
            'transfer_from_airport.required'     => 'Transfer from airport is required.',
            'transfer_to_venue.required'         => 'Transfer to venue is required.',
            'transfer_from_venue.required'       => 'Transfer from venue is required.',
            'transfer_to_airport.required'       => 'Transfer to airport is required.',
            'price_without_vat_airport.required' => 'Price without VAT needs is required.',
            'price_without_vat_airport.numeric'  => 'Price without VAT needs to be a number.',
            'vat_percent_airport.required'       => 'VAT percentage is required.',
            'vat_percent_airport.numeric'        => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_airport.min'            => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_airport.max'            => 'VAT percentage needs to be number between 0 and 100.',
            'price_without_vat_venue.required'   => 'Price without VAT needs is required.',
            'price_without_vat_venue.numeric'    => 'Price without VAT needs to be a number.',
            'vat_percent_venue.required'         => 'VAT percentage is required.',
            'vat_percent_venue.numeric'          => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_venue.min'              => 'VAT percentage needs to be number between 0 and 100.',
            'vat_percent_venue.max'              => 'VAT percentage needs to be number between 0 and 100.'
        ];
    }
}
