<?php

namespace App\Http\Requests\Registration;

use App\Http\Requests\Request;

class Payment extends Request
{
    public function authorize()
    {
        return false;
    }

    public function rules()
    {
        return [
            'payment_option' => 'required',
            'ticket_payment_type' => 'required',
            'ticket_payment_company_name' => 'required',
            'ticket_payment_vat' => 'required',
            'ticket_payment_address' => 'required',
            'ticket_payment_city' => 'required',
            'ticket_payment_postal_code' => 'required',
            'ticket_payment_country' => 'required',
            // 'ticket_payment_first_name' => 'required',
            // 'ticket_payment_last_name' => 'required',
            // 'ticket_payment_email' => array("required", "email"),
            // 'ticket_payment_phone' => 'required',
            'ticket_payment_personal_id' => 'required',
            'accomodation_payment_type' => 'required',
            'accomodation_payment_company_name' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_vat' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_address' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_city' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_postal_code' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_country' => 'required_without:accomodation_same_as_ticket',
            // 'accomodation_payment_first_name' => 'required_without:accomodation_same_as_ticket',
            // 'accomodation_payment_last_name' => 'required_without:accomodation_same_as_ticket',
           //  'accomodation_payment_email' => array("required_without:accomodation_same_as_ticket", "email"),
           //  'accomodation_payment_phone' => 'required_without:accomodation_same_as_ticket',
            'accomodation_payment_personal_id' => 'required',
            'transfer_payment_type' => 'required',
            'transfer_payment_company_name' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_vat' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_address' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_city' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_postal_code' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_country' => 'required_without:transfer_same_as_ticket',
            // 'transfer_payment_first_name' => 'required_without:transfer_same_as_ticket',
            // 'transfer_payment_last_name' => 'required_without:transfer_same_as_ticket',
            // 'transfer_payment_email' => array("required_without:transfer_same_as_ticket", "email"),
            // 'transfer_payment_phone' => 'required_without:transfer_same_as_ticket',
            'transfer_payment_personal_id' => 'required'
        ];
    }

    public function messages()
    {
        return [
            'payment_option.required' => 'Please select payment type.',
            'ticket_payment_type.required' => 'Please select payment option for ticket.',
            'ticket_payment_company_name.required' => 'Please provide company name.',
            'ticket_payment_vat.required' => 'Please provide VAT.',
            'ticket_payment_address.required' => 'Please provide address.',
            'ticket_payment_city.required' => 'Please provide city.',
            'ticket_payment_postal_code.required' => 'Please provide postal code.',
            'ticket_payment_country.required' => 'Please select country.',
            'ticket_payment_first_name.required' => 'Please provide first name.',
            'ticket_payment_last_name.required' => 'Please provide last name.',
            'ticket_payment_email.required' => 'Please provide e-mail address.',
            'ticket_payment_email.email' => 'Please provide valid e-mail address.',
            'ticket_payment_phone.required' => 'Please provide phone number.',
            'ticket_payment_personal_id.required' => 'Please provide personal identification number.',
            'accomodation_payment_type.required' => 'Please select payment option for accomodation.',
            'accomodation_same_as_ticket.required_without' => 'Please choose accomodation payment.',
            'accomodation_payment_company_name.required_without' => 'Please provide company name.',
            'accomodation_payment_vat.required_without' => 'Please provide VAT.',
            'accomodation_payment_address.required_without' => 'Please provide address.',
            'accomodation_payment_city.required_without' => 'Please provide city.',
            'accomodation_payment_postal_code.required_without' => 'Please provide postal code.',
            'accomodation_payment_country.required_without' => 'Please select country.',
            'accomodation_payment_first_name.required_without' => 'Please provide first name.',
            'accomodation_payment_last_name.required_without' => 'Please provide last name.',
            'accomodation_payment_email.required_without' => 'Please provide e-mail address.',
            'accomodation_payment_email.email' => 'Please provide valid e-mail address.',
            'accomodation_payment_phone.required_without' => 'Please provide phone number.',
            'accomodation_payment_personal_id.required' => 'Please provide personal identification number.',
            'transfer_payment_type.required' => 'Please select payment option for transfer.',
            'transfer_same_as_ticket.required_without' => 'Please choose transfer payment.',
            'transfer_payment_company_name.required_without' => 'Please provide company name.',
            'transfer_payment_vat.required_without' => 'Please provide VAT.',
            'transfer_payment_address.required_without' => 'Please provide address.',
            'transfer_payment_city.required_without' => 'Please provide city.',
            'transfer_payment_postal_code.required_without' => 'Please provide postal code.',
            'transfer_payment_country.required_without' => 'Please select country.',
            'transfer_payment_first_name.required_without' => 'Please provide first name.',
            'transfer_payment_last_name.required_without' => 'Please provide last name.',
            'transfer_payment_email.required_without' => 'Please provide e-mail address.',
            'transfer_payment_email.email' => 'Please provide valid e-mail address.',
            'transfer_payment_phone.required_without' => 'Please provide phone number.',
            'transfer_payment_personal_id.required' => 'Please provide personal identification number.'
        ];
    }
}
