<?php

namespace App\Http\Requests\User;

use App\Http\Requests\Request;
use Illuminate\Validation\Rule;

class NewUser extends Request
{
    public function authorize()
    {
        return true;
    }

    public function rules()
    {
        return [
            'name' => 'required|max:255',
            'email' => 'required|email|unique:users',
            'password' => 'required|string|min:6|regex:/^(?=.*?[A-Z])(?=.*?[a-z])(?=.*?[0-9])(?=.*?[#?!@$%^&*-]).{6,}$/',
            'password_confirmation'  => 'required_with:password|same:password',
            'role' => 'required'
        ];
    }

    public function messages()
    {
        return [
            'name.required' => 'Nickname is required.',
            'email.required' => 'E-mail is required.',
            'email.email' => 'Please enter valid e-mail.',
            'email.unique' => 'E-mail must be unique.',
            'password.required' => 'Password is required.',
            'password.min' => 'Password must be more than 6 characters long.',
            'password.regex' => 'Password should contain at-least 1 uppercase, 1 lowercase, 1 numeric and 1 special character.',
            'password_confirmation.same' => 'Password is not confirmed.',
            'password_confirmation.required_with'  => 'Password confirmation is required.',
            'role.required' => 'Role is required.'
        ];
    }
}
