<?php

// Nije potrebna autorizacija za pristup
Route::group(['middleware' => ['web']], function() {

    // Namespace - Registration
    Route::group(['namespace' => 'Registration'], function() {

        // Prefix - /registration/{event_code}
        Route::group(['prefix' => '/registration/{event_code}'], function() {

            // Korak registracije - E-mail
            Route::get('/', [
                'uses' => 'RegistrationEmailController@GetRegistrationEmail',
                'as' => 'registration'
            ]);
            Route::post('/', [
                'uses' => 'RegistrationEmailController@SaveRegistrationEmail'
            ]);
            Route::patch('/', [
                'uses' => 'RegistrationEmailController@ManuallyCreateRegistration'
            ]);

            // Provjera vertifikacijske poveznice
            Route::get('/{email}', [
                'uses' => 'RegistrationEmailController@GetRegistrationWithEmail'
            ]);

            // Prefix - /{lead_code}
            Route::group(['prefix' => '/{lead_code}'], function() {

                // Prikaz General information
                Route::get('/general-information', [
                    'uses' => 'RegistrationGeneralInformationController@GetGeneralInformation',
                    'as' => 'general-information'
                ]);

                // Spremanje General information
                Route::post('/general-information', [
                    'uses' => 'RegistrationGeneralInformationController@SaveGeneralInformation'
                ]);

                // Prikaz Accommodation/Transfer
                Route::get('/accommodation-transfer', [
                    'uses' => 'RegistrationAccommodationTransferController@GetAccommodationTransfer',
                    'as' => 'accommodation-transfer'
                ]);

                // Spremanje Accommodation/Transfer
                Route::post('/accommodation-transfer', [
                    'uses' => 'RegistrationAccommodationTransferController@SaveAccommodationTransfer'
                ]);

                // Prikaz Payment
                Route::get('/payment', [
                    'uses' => 'RegistrationPaymentController@GetPayment',
                    'as' => 'payment'
                ]);

                // Spremanje Payment
                Route::post('/payment', [
                    'uses' => 'RegistrationPaymentController@SavePayment'
                ]);

                // Prikaz Summary
                Route::get('/summary', [
                    'uses' => 'RegistrationSummaryController@GetSummary',
                    'as' => 'summary'
                ]);

                // Spremanje Summary
                Route::post('/summary', [
                    'uses' => 'RegistrationSummaryController@SaveSummary'
                ]);

                // WSPay - uspješno
                Route::get('/wspay-success', [
                    'uses' => 'RegistrationWspayController@WspaySuccess'
                ]);

                // WSPay - pogreška
                Route::get('/wspay-error', [
                    'uses' => 'RegistrationWspayController@WspayError'
                ]);

                // WSPay - odustajenje
                Route::get('/wspay-cancel', [
                    'uses' => 'RegistrationWspayController@WspayCancel'
                ]);

                // Legal
                Route::get('/about-us', ['uses' => 'RegistrationSummaryController@GetContentAboutUs']);
                Route::get('/terms-of-sale', ['uses' => 'RegistrationSummaryController@GetContentTermsOfSale']);
                Route::get('/security', ['uses' => 'RegistrationSummaryController@GetContentSecurity']);
                Route::get('/privacy', ['uses' => 'RegistrationSummaryController@GetContentPrivacy']);
                Route::get('/conversion', ['uses' => 'RegistrationSummaryController@GetContentConversion']);

                // Provjera vertifikacijske poveznice
                Route::get('/{time_code}', [
                    'uses' => 'RegistrationEmailController@CheckVerificationLink'
                ]);

            });

        });

        // Potvrda dolaska
        Route::get('/confirmation/{event_code}/{lead_code}', [
            'uses' => 'AttendingController@ConfirmComing'
        ]);

    });

    // Namespace - Subscribe
    Route::group(['namespace' => 'Subscribe'], function() {

        // Prefix - /unsubscribe/{lead_code_encrypted}
        Route::group(['prefix' => '/subscribe/{lead_code_encrypted}'], function() {

            // Leads e-mail unsubscribe
            Route::get('/', [
                'uses' => 'SubscribeController@GetSubscribe'
            ]);

        });

    });

    // Namespace - Unsubscribe
    Route::group(['namespace' => 'Unsubscribe'], function() {

        // Prefix - /unsubscribe/{mailing_activity_code}/{lead_code_encrypted}
        Route::group(['prefix' => '/unsubscribe/{mailing_activity_code}/{lead_code_encrypted}'], function() {

            // Leads e-mail unsubscribe
            Route::get('/', [
                'uses' => 'UnsubscribeController@GetUnsubscribe'
            ]);

            Route::post('/', [
                'uses' => 'UnsubscribeController@SaveUnsubscribe'
            ]);

        });

    });

    // Namespace - PublicLeads
    Route::group(['namespace' => 'Leads'], function() {

         // Public New Lead
        // Route::get('/leads/new', [
        //   'uses' => 'PublicNewLeads@GetNewLead'
        //]);
        //Route::post('/leads/new', [
        //    'uses' => 'PublicNewLeads@SaveNewLead'
        //]);

    });

});


// Potrebna je autorizacija za pristup
Route::group(['middleware' => ['web', 'auth']], function() {

    // Keep user alive
    Route::get('/keep-alive', 'MainController@KeepAlive');
    
    // Namespace - Admin
    Route::group(['namespace' => 'Admin', 'middleware' => ['role:admin']], function() {
        
        // Promijena admin opcija
        Route::get('/admin', 'AdminController@GetAdmin');
        
        // Prefix - /admin
        Route::group(['prefix' => '/admin'], function() {
            
            // Prikaz admin kategorija
            Route::get('/categories', [
                'uses' => 'AdminCategoriesController@GetAdminCategories',
                'as' => 'admin-categories'
            ]);

            // Spreamnje admin plaćanja
            Route::post('/categories', [
                'uses' => 'AdminCategoriesController@SaveAdminCategories'
            ]);

            // Prefix - /users
            Route::group(['prefix' => '/users'], function() {
                // Prikaz svi korisnika
                Route::get('/', [
                    'uses' => 'AdminUsersController@GetAdminUsers',
                    'as' => 'admin-users'
                ]);

                // Novi korisnik
                Route::get('/create', 'AdminUsersController@NewAdminUser');
                Route::post('/create', 'AdminUsersController@CreateAdminUser');

                // Brisanje korisnika
                Route::delete('/', 'AdminUsersController@DeleteAdminUser');

                // Uređivanje korisnika
                Route::get('/edit/{user_id}', 'AdminUsersController@EditAdminUser');
                Route::post('/edit/{user_id}', 'AdminUsersController@UpdateAdminUser');

                // Dohvati sve korisnike
                Route::controller('/', 'AdminUsersController', [
                    'anyData'  => 'allUsers.data',
                    'getIndex' => 'allUsers'
                ]);
            });

            // Prikaz admin plaćanje
            Route::get('/payment', [
                'uses' => 'AdminPayController@GetAdminPayments',
                'as' => 'admin-payments'
            ]);

            // Spreamnje admin plaćanja
            Route::post('/payment', [
                'uses' => 'AdminPayController@SaveAdminPayments'
            ]);
            
        });
        
    });

    // Namespace - User
    Route::group(['namespace' => 'User'], function() {

        // Promijena podataka korisnika
        Route::get('/account-settings', [
            'uses' => 'UserController@GetUserSettings'
        ]);

        // Spremanje promijena podataka korisnika
        Route::post('/account-settings', [
            'uses' => 'UserController@SaveUserSettings'
        ]);

    });

    // Namespace - Logs
    Route::group(['namespace' => 'Logs', 'middleware' => ['role:admin']], function() {

        // Logs
        Route::get('/logs', 'LogsController@GetLogs');

        // Logs datatable
        Route::controller('/get-logs', 'LogsController', [
            'anyData'  => 'get-logs.data',
            'getIndex' => 'get-logs'
        ]);

    });

    // Prefix - /ajax
    Route::group(['prefix' => '/ajax'], function() {

        // Namespace - Events
        Route::group(['namespace' => 'Events'], function() {

            // Namespace - Mailings
            Route::group(['namespace' => 'Mailings'], function() {

                // Popis leadova za brzo slanje mailova datatable
                Route::get('/get-leads-quick-send', [
                    'uses' => 'EmailActivitiesController@GetLeadsForQuickSend',
                    'as' => 'get-leads-quick-send'
                ]);

                // Brzo slanje mailova
                Route::post('/save-quick-send', [
                    'uses' => 'EmailActivitiesController@QuickSend'
                ]);

                // Newsletters datatable
                Route::controller('/get-leads-quick-send', 'EmailActivitiesController', ['GetLeadsForQuickSend' => 'get-leads-quick-send']);

            });

        });
        
        // Namespace - Admin
        Route::group(['namespace' => 'Admin'], function() {
            
            // Ažuriranje lead typeova
            Route::post('/admin-lead-types', [
                'uses' => 'AdminCategoriesController@UpdateLeadTypes'
            ]);
            
            // Ažuriranje lead type descriptionsa
            Route::post('/admin-lead-type-descriptions', [
                'uses' => 'AdminCategoriesController@UpdateLeadTypeDescriptions'
            ]);
            
            // Brisanje kategorija
            Route::post('/admin-categories-delete', [
                'uses' => 'AdminCategoriesController@DeleteCategories'
            ]);
            
        });

    });

});





/****** OVO DOLJE SVE TREBA SLOŽITI PREMA GORNJEM PRINCIPU ****** /


/** ------------------ Krik magic ------------------ **/

// Nije zaštićeno autorizacijom -> controller mora nasljeđivati MainPublicController
Route::group(['middleware' => ['web']], function() {

  //is mail opened
  Route::get('/mail-image/{mailing_activity_code}/{lead_code}', 'Mail\MailImageController@MailOpened');

});


// Zaštićeno je autorizacijom
Route::group(['middleware' => 'web'], function() {
    Route::auth();

    // Homepage (after login)
    Route::get('/', 'Events\Single\SingleEventsController@RedirectToAllEvents')->name('home');

    // TODO Default redirect za nepostojeće rute - 404

    // Privremeno
    Route::get('/settings', 'Settings\SettingsController@getSettings');

    // All (Active & Past) Events
    Route::get('/events', 'Events\All\AllEventsController@AllEvents')->name('events');
    
    Route::group(['middleware' => ['role:admin']], function() {
        Route::post('/events', 'Events\All\AllEventsController@ManageEventsPostRequest');
        Route::delete('/events', 'Events\All\AllEventsController@DeleteEvent');
        Route::put('/events', 'Events\All\AllEventsController@CloseRegistration');
    });
    
    // Single Events
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}', 'Events\Single\SingleEventsController@SingleEvent')->name('dashboard');
        Route::put('/events/{event_code}', 'Events\Single\SingleEventsController@GenerateInvoice');
        Route::delete('/events/{event_code}', 'Events\Single\SingleEventsController@DeleteRegistration');
        Route::patch('/events/{event_code}', 'Events\Single\SingleEventsController@UpdateRegistrationStatus');
    });

    // Pregled registracijske forme za admina
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/registration-preview/{event_code}', 'Events\Single\SingleEventsController@PreviewRegistration');
    });

    // Close registration
    Route::group(['middleware' => ['role:admin']], function() {
        Route::put('/events/single', 'Events\Single\SingleEventsController@CloseRegistration');
    });

    // People e-mailed
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/people-emailed', 'Events\Mailings\PeopleEmailedController@PeopleEmailed');
    });
    Route::controller('/people-emailed', 'Events\Mailings\PeopleEmailedController', [
        'anyData'  => 'people-emailed.data',
        'getIndex' => 'people-emailed'
    ]);

    // Check in attendees
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/attendees', 'Events\Attendees\AttendeesController@GetAttendee');
        Route::post('/events/{event_code}/attendees', 'Events\Attendees\AttendeesController@SaveAttendee');
    });

    // Check gifts
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/gifts', 'Events\Gifts\GiftsController@GetGift');
        Route::post('/events/{event_code}/gifts', 'Events\Gifts\GiftsController@SaveGift');
    });
	
    // Check sessions
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/sessions', 'Events\Sessions\SessionsController@GetSessions')->name('sessions');
    });
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/sessions/manage', 'Events\Sessions\SessionsController@GetManageSessions')->name('sessions-manage');
        Route::delete('/events/{event_code}/sessions/manage', 'Events\Sessions\SessionsController@DeleteSession');
        Route::get('/events/{event_code}/sessions/manage/new', 'Events\Sessions\SessionsController@AddSession');
        Route::post('/events/{event_code}/sessions/manage/new', 'Events\Sessions\SessionsController@CreateSession');
    });
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/sessions/{session_code}', 'Events\Sessions\SessionsController@GetSession');
        Route::post('/events/{event_code}/sessions/{session_code}', 'Events\Sessions\SessionsController@SaveSession');
        Route::get('/events/{event_code}/sessions/{session_code}/report', 'Events\Sessions\SessionsController@GetReportSession');
        Route::post('/events/{event_code}/sessions/{session_code}/report', 'Events\Sessions\SessionsController@ExportReportSession');
    });
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/sessions/{session_code}/edit', 'Events\Sessions\SessionsController@EditSession');
        Route::post('/events/{event_code}/sessions/{session_code}/edit', 'Events\Sessions\SessionsController@UpdateSession');
    });
	Route::controller('/sessions', 'Events\Sessions\SessionsController', ['anySessionsData'  => 'sessions.data', 'getIndex' => 'sessions']);
    Route::controller('/sessions-report', 'Events\Sessions\SessionsController', ['anySessionReportData'  => 'sessions-report.data', 'getIndex' => 'sessions']);

    // Nametags
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/badges', 'Events\Badges\BadgesController@GetBadges');
        Route::put('/events/{event_code}/badges', 'Events\Badges\BadgesController@GenerateBadges');
        Route::controller('/badges', 'Events\Badges\BadgesController', [
        'anyData'  => 'badges.data',
        'getIndex' => 'badges'
        ]);
    });

    // To-Do Lists on Single Events
    Route::post('/events/single/todo', 'Events\Single\SingleEventsController@AddItemToDo');
    Route::put('/events/single/todo', 'Events\Single\SingleEventsController@UpdateItemToDo');

    // Reporting - registrations (tickets)
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/report-registrations', 'Events\Reports\ReportRegistrationsController@GetRegistrations');
        Route::get('/events/{event_code}/report-promo-codes/{ticket_id}', 'Events\Reports\ReportPromoCodesController@GetPromoCodes');
        Route::post('/events/{event_code}/report-promo-codes/{ticket_id}/export', 'Events\Reports\ReportPromoCodesController@ExportAll');
    });
    Route::controller('/report-registrations', 'Events\Reports\ReportRegistrationsController', [
      'anyData'  => 'report-registrations.data',
      'getIndex' => 'report-registrations'
    ]);
    Route::controller('/report-promo-codes', 'Events\Reports\ReportPromoCodesController', [
        'anyData'  => 'report-promo-codes.data',
        'getIndex' => 'report-promo-codes'
      ]);

    Route::group(['middleware' => ['permission']], function() {
        Route::patch('/events/{event_code}/report-registrations', 'Events\Reports\ReportRegistrationsController@UpdateRegistrationStatus');
        Route::put('/events/{event_code}/report-registrations', 'Events\Reports\ReportRegistrationsController@Actions');
        Route::delete('/events/{event_code}/report-registrations', 'Events\Reports\ReportRegistrationsController@DeleteRegistration');
        Route::post('/events/{event_code}/report-registrations/export', 'Events\Reports\ReportRegistrationsController@ExportAll');
    });

    // Reporting - accommodation
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/report-accommodations', 'Events\Reports\ReportAccommodationsController@GetAccommodations');
    });
    Route::controller('/report-accommodations', 'Events\Reports\ReportAccommodationsController', [
      'anyData'  => 'report-accommodations.data',
      'getIndex' => 'report-accommodations'
    ]);
    Route::group(['middleware' => ['permission']], function() {
        Route::patch('/events/{event_code}/report-accommodations', 'Events\Reports\ReportAccommodationsController@UpdateRegistrationStatus');
        Route::put('/events/{event_code}/report-accommodations', 'Events\Reports\ReportAccommodationsController@GenerateInvoice');
        Route::delete('/events/{event_code}/report-accommodations', 'Events\Reports\ReportAccommodationsController@DeleteRegistration');
    });

    // Reporting - transfers
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/report-transfers', 'Events\Reports\ReportTransfersController@GetTransfers');
    });
    Route::controller('/report-transfers', 'Events\Reports\ReportTransfersController', [
      'anyData'  => 'report-transfers.data',
      'getIndex' => 'report-transfers'
    ]);
    Route::group(['middleware' => ['permission']], function() {
        Route::patch('/events/{event_code}/report-transfers', 'Events\Reports\ReportTransfersController@UpdateRegistrationStatus');
        Route::put('/events/{event_code}/report-transfers', 'Events\Reports\ReportTransfersController@GenerateInvoice');
        Route::delete('/events/{event_code}/report-transfers', 'Events\Reports\ReportTransfersController@DeleteRegistration');
    });

    // E-mail activity pozivi
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/mailings/email-design', 'Events\Mailings\EmailDesignController@GetEmailDesign');
        Route::post('/events/{event_code}/mailings/email-design', 'Events\Mailings\EmailDesignController@UploadFile');
        Route::post('/events/{event_code}/mailings/email-design/image-upload', 'Events\Mailings\EmailDesignController@SaveWysiwygImage');
        Route::get('/events/{event_code}/mailings/{mailing_activity_code}/email-design', 'Events\Mailings\EmailDesignController@GetEmailDesign');
        Route::post('/events/{event_code}/mailings/{mailing_activity_code}/email-design', 'Events\Mailings\EmailDesignController@UploadFile');
        Route::post('/events/{event_code}/mailings/{mailing_activity_code}/email-design/image-upload', 'Events\Mailings\EmailDesignController@SaveWysiwygImage');
        Route::post('/events/{event_code}/mailings/{mailing_activity_code}/mailing-list', 'Events\Mailings\MailingListController@SaveEmailDesign');
    });

    Route::controller('/mailing-list', 'Events\Mailings\MailingListController', [
        'anyData'  => 'mailings.data',
        'getIndex' => 'mailings'
    ]);

    // All mailings for single event
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/mailings', 'Events\Mailings\EmailActivitiesController@EmailActivities')->name('all-mailings');
    });
    Route::group(['middleware' => ['role:admin']], function() {
        Route::post('/events/{event_code}/mailings', 'Events\Mailings\EmailActivitiesController@UpdateActivity');
        Route::delete('/events/{event_code}/mailings', 'Events\Mailings\EmailActivitiesController@DeleteActivity');
        Route::put('/events/{event_code}/mailings', 'Events\Mailings\EmailActivitiesController@DuplicateActivity');
    });

    // Single mailings for single event
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/mailings/{mailing_activity_code}', 'Events\Mailings\PeopleEmailedSingleController@PeopleEmailed');
    });
    Route::controller('/people-emailed-single', 'Events\Mailings\PeopleEmailedSingleController', [
        'anyData'  => 'people-emailed-single.data',
        'getIndex' => 'people-emailed-single'
    ]);

    // Mailings preview
    Route::group(['middleware' => ['permission']], function() {
        Route::get('/events/{event_code}/mailings/{mailing_activity_code}/preview', 'Events\Mailings\EmailActivitiesController@PreviewMailings');
    });

    Route::put('/events/{event_code}/mailings/{mailing_activity_code}/mailing-list', 'Events\Mailings\MailingListController@AddContactsToMailing');
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/mailings/{mailing_activity_code}/mailing-list', 'Events\Mailings\MailingListController@getIndex');
    });

    Route::patch('/events/{event_code}/mailings/{mailing_activity_code}/mailing-list', 'Events\Mailings\MailingListController@InsertImportLead');

    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/{event_code}/mailings/{mailing_activity_code}/send', 'Events\Mailings\SendController@GetSend')->name('send');
    });
    Route::post('/events/{event_code}/mailings/{mailing_activity_code}/send', 'Events\Mailings\SendController@SetScheduledOrDraft');

    // Send preview
    Route::post('/events/{event_code}/mailings/{mailing_activity_code}/send/preview', 'Events\Mailings\SendController@SendPreview');

    // Send mail
    Route::post('/events/{event_code}/mailings/{mailing_activity_code}/send/{mail}/{code}/{opt}/{method}', 'Events\Mailings\SendController@SendMail');

    // Send mail
    Route::post('/events/{event_code}/mailings/{mailing_activity_code}/send/{code}', 'Events\Mailings\SendController@SetProgress');

    // Save Registration
    Route::post('/events/{event_code}', 'Events\Single\SingleEventsController@SaveRegistrationSingleEvent');

    // Create Events
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/events/create/look-and-feel', 'Events\Create\LookAndFeelController@GetLookAndFeel');

        // Save color scheme
        Route::post('/events/create/look-and-feel/color-scheme', 'Events\Create\LookAndFeelController@SaveColorScheme');

        // Redirects
        Route::get('/events/create', 'Events\Create\LookAndFeelController@RedirectToLookAndFeel');
        Route::get('/events/create/event-info', 'Events\Create\LookAndFeelController@RedirectToLookAndFeel');
        Route::get('/events/create/registration', 'Events\Create\LookAndFeelController@RedirectToLookAndFeel');

        // Save to db and show view
        Route::post('/events/create/registration', 'Events\Create\RegistrationController@SaveEventInfo');
        Route::post('/events/create/event-info', 'Events\Create\EventInfoController@SaveLookAndFeel');

        // Ajax requests - registration step
        Route::post('/events/create/registration/saveTicket', 'Events\Create\RegistrationController@SaveTicket');
        Route::post('/events/create/registration/saveAccommodation', 'Events\Create\RegistrationController@SaveAccommondation');
        Route::post('/events/create/registration/saveTransfer', 'Events\Create\RegistrationController@SaveTransfer');
        Route::post('/events/create/registration/saveInvoice', 'Events\Create\RegistrationController@SaveInvoice');
        Route::post('/events/create/registration/saveSocialEvent', 'Events\Create\RegistrationController@saveSocialEvent');
        Route::get('/events/create/registration/get/{type}/{id}', 'Events\Create\RegistrationController@GetEditData');
        Route::delete('/events/create/registration/delete/{type}/{id}', 'Events\Create\RegistrationController@DeleteFromTable');

        // Back and update
        Route::get('/events/{event_code}/create/look-and-feel', 'Events\Create\LookAndFeelController@GetLookAndFeelData');
        Route::get('/events/{event_code}/create/event-info', 'Events\Create\EventInfoController@GetEventInfo');
        Route::get('/events/{event_code}/create/registration', 'Events\Create\RegistrationController@GetRegistrationWithData');

        Route::post('/events/{event_code}/create/event-info', 'Events\Create\EventInfoController@UpdateLookAndFeel');
        Route::post('/events/{event_code}/create/registration', 'Events\Create\RegistrationController@SaveLookAndFeelWithEventInfoData');

        // Event notifications
        Route::get('/events/{event_code}/notifications', 'Events\Create\NotificationsController@EditEventNotifications');
        Route::post('/events/{event_code}/notifications', 'Events\Create\NotificationsController@UpdateEventNotifications');

        // Insights
        Route::get('/leads/insights', 'Leads\InsightsController@GetInsights');

        Route::controller('/leads/insights', 'Leads\InsightsController', [
            'anyData'  => 'allInsights.data',
            'getIndex' => 'allInsights'
        ]);
    });

    // Leads
    Route::group(['middleware' => ['role:admin']], function() {
        Route::get('/leads/import', 'Leads\AllLeadsController@ImportLead');
        Route::post('/leads/import', 'Leads\AllLeadsController@InsertImportLead');

        Route::get('/leads/create', 'Leads\SingleLeadController@GetSingleLead');

        Route::post('/leads/create', 'Leads\SingleLeadController@InsertLead'); /* ok */

        Route::get('/leads/create/{lead_code}', 'Leads\SingleLeadController@GetLeadInfo');
        Route::post('/leads/create/{lead_code}', 'Leads\SingleLeadController@UpdateLead');

        Route::post('/leads', 'Leads\AllLeadsController@getIndex');

        Route::controller('/leads', 'Leads\AllLeadsController', [
            'anyData'  => 'leads.data',
            'getIndex' => 'leads'
        ]);

        Route::delete('/leads', 'Leads\SingleLeadController@DeleteLead');
    });

});
