<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;

class CreateEventsTable extends Migration {

	/**
	 * Run the migrations.
	 *
	 * @return void
	 */
	public function up()
	{
		Schema::create('events', function(Blueprint $table)
		{
			$table->increments('id');
			$table->string('event_code', 45)->nullable();
			$table->text('name', 65535)->nullable();
			$table->text('description', 65535)->nullable();
			$table->string('lang')->nullable();
			$table->integer('created_by_id')->unsigned()->nullable()->index('fk_events_users1_idx');
			$table->integer('updated_by_id')->unsigned()->nullable()->index('fk_events_users2_idx');
			$table->integer('event_look_and_feel_id')->unsigned()->nullable()->index('fk_events_event_look_feels1_idx');
			$table->integer('timezone_id')->unsigned()->nullable()->index('fk_events_timezones1_idx');
			$table->dateTime('start_ts')->nullable();
			$table->dateTime('end_ts')->nullable();
			$table->dateTime('registration_start_ts')->nullable();
			$table->dateTime('registration_end_ts')->nullable();
			$table->string('type_by_venue')->nullable();
			$table->string('venue_name')->nullable();
			$table->string('venue_address')->nullable();
			$table->string('venue_city')->nullable();
			$table->string('venue_postal_code')->nullable();
			$table->integer('venue_country_id')->unsigned()->nullable()->index('fk_events_countries1_idx');
			$table->string('access')->nullable();
			$table->integer('currency_id')->unsigned()->nullable()->index('fk_events_currencies1_idx');
			$table->boolean('wspay')->nullable();
			$table->string('email_name')->nullable();
			$table->string('email_sender')->nullable();
			$table->string('email_footer')->nullable();
			$table->integer('tickets_invoice_from_id')->unsigned()->nullable()->index('fk_events_payment_details1_idx');
			$table->integer('accomodation_invoice_from_id')->unsigned()->nullable()->index('fk_event_payment_details2_idx');
			$table->integer('transfer_invoice_from_id')->unsigned()->nullable()->index('fk_event_payment_details1_idx');
            $table->boolean('is_draft')->nullable()->default(1);
            $table->boolean('registration_notification')->nullable();
            $table->text('registration_starting_existing_leads_en', 65535)->nullable();
            $table->text('registration_starting_existing_leads_hr', 65535)->nullable();
            $table->text('registration_starting_new_leads_en', 65535)->nullable();
            $table->text('registration_starting_new_leads_hr', 65535)->nullable();
            $table->text('registration_email_signature_en', 65535)->nullable();
            $table->text('registration_email_signature_hr', 65535)->nullable();
            $table->text('registration_completed_with_invoices_en', 65535)->nullable();
            $table->text('registration_completed_with_invoices_hr', 65535)->nullable();
            $table->text('registration_completed_without_invoices_en', 65535)->nullable();
            $table->text('registration_completed_without_invoices_hr', 65535)->nullable();
            $table->timestamps();
			$table->softDeletes();
		});
	}


	/**
	 * Reverse the migrations.
	 *
	 * @return void
	 */
	public function down()
	{
		Schema::drop('events');
	}

}
