<?php

use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateEventInvitationsView extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */

    public function up()
    {
        DB::statement("
            CREATE VIEW `event_invitations` AS
                SELECT
                    `leads`.`id` AS `id`,
                    `leads`.`title` AS `title`,
                    `leads`.`first_name` AS `first_name`,
                    `leads`.`last_name` AS `last_name`,
                    `leads`.`email` AS `email`,
                    `leads`.`company_name` AS `company_name`,
                    `countries`.`country_name` AS `company_country`,
                    CONVERT('Invited' USING utf8) COLLATE utf8_unicode_ci AS `status`,
                    `mailing_activities`.`mailing_activity_code` AS `mailing_code`,
                    `lead_types`.`name` AS `type`,
                    GROUP_CONCAT(DISTINCT `lead_type_descriptions`.`name` SEPARATOR ', ') AS `type_description`
                FROM `leads`
                LEFT JOIN `mailings`
                    ON (`leads`.`id` = `mailings`.`lead_id`)
                LEFT JOIN `mailing_activities`
                    ON (`mailings`.`mailing_activity_id` = `mailing_activities`.`id`)
                LEFT JOIN `countries`
                    ON (`leads`.`company_country` = `countries`.`id`)
                LEFT JOIN `lead_types`
                    ON (`leads`.`lead_type_id` = `lead_types`.`id`)
                LEFT JOIN `lead_has_type_descriptions`
                    ON (`leads`.`id` = `lead_has_type_descriptions`.`lead_id`)
                LEFT JOIN `lead_type_descriptions`
                    ON (`lead_has_type_descriptions`.`lead_type_description_id` = `lead_type_descriptions`.`id`)
                WHERE ((`mailings`.`mailing_activity_id` IS NOT NULL)
                    AND (`mailings`.`deleted_at` IS NULL)
                    AND (`mailings`.`lead_id` IS NOT NULL))
                GROUP BY `leads`.`id`, `mailings`.`mailing_activity_id`
            UNION
                SELECT
                    `leads`.`id` AS `id`,
                    `leads`.`title` AS `title`,
                    `leads`.`first_name` AS `first_name`,
                    `leads`.`last_name` AS `last_name`,
                    `leads`.`email` AS `email`,
                    `leads`.`company_name` AS `company_name`,
                    `countries`.`country_name` AS `company_country`,
                    CONVERT('Uninvited' USING utf8) COLLATE utf8_unicode_ci AS `status`,
                    CONVERT('all' USING utf8) COLLATE utf8_unicode_ci AS `mailing_code`,
                    `lead_types`.`name` AS `type`,
                    GROUP_CONCAT(DISTINCT `lead_type_descriptions`.`name` SEPARATOR ', ') AS `type_description`
                FROM `leads`
                LEFT JOIN `countries`
                    ON `leads`.`company_country` = `countries`.`id`
                LEFT JOIN `lead_types`
                    ON (`leads`.`lead_type_id` = `lead_types`.`id`)
                LEFT JOIN `lead_has_type_descriptions`
                    ON (`leads`.`id` = `lead_has_type_descriptions`.`lead_id`)
                LEFT JOIN `lead_type_descriptions`
                    ON (`lead_has_type_descriptions`.`lead_type_description_id` = `lead_type_descriptions`.`id`)
                WHERE (`leads`.`deleted_at` IS NULL
                    AND `leads`.`created_at` IS NOT NULL)
                GROUP BY `leads`.`id`
        ");
    }

    public function down()
    {
        DB::statement("DROP VIEW event_invitations");
    }
}
